﻿//
// AbstractFilterMSOffice.cs
//
// Copyright (C) 2004 Novell, Inc.
//
// Author:
//   Johannes Roith(johannes at jroith dot de)

//
// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the "Software"),
// to deal in the Software without restriction, including without limitation
// the rights to use, copy, modify, merge, publish, distribute, sublicense,
// and/or sell copies of the Software, and to permit persons to whom the
// Software is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
// DEALINGS IN THE SOFTWARE.
//

using System;
using System.IO;
using System.Text;
using System.Collections;

using Poi.Net.HPSF;
using Poi.Net.HPSF.Wellknown;
using Poi.Net.PoiFS.FileSystem;
using Poi.Net.PoiFS.EventFileSystem;
using Poi.Net.Util;

namespace Beagle.Filters 
{    
	public abstract class AbstractFilterMSOffice : Beagle.Daemon.Filter 
	{

		protected POIFSFileSystem filesystem = null;
		protected string filename = null;

		protected string Title;
		protected string Author;
		protected string Comments;
		protected Object CreateDateTime;
		protected Object EditTime;
		protected string Keywords;
		protected string Subject;
		protected string Company;
		protected int PageCount;
		protected int SlideCount;

		protected string Content;


		protected POIFSReader Reader;

		public AbstractFilterMSOffice ()
		{	
		}

		protected override void DoOpen (FileInfo info)
		{
			filename = info.FullName;
			filesystem = new POIFSFileSystem(File.OpenText(filename).BaseStream);	
		}

		protected void DoPullCommonProperties()
		{
			SummaryInformation info = (SummaryInformation) PropertySetFactory.Create(
				filesystem.CreateDocumentInputStream("\x0005SummaryInformation"));
			DocumentSummaryInformation info2 = (DocumentSummaryInformation) PropertySetFactory.Create(
				filesystem.CreateDocumentInputStream("\x0005DocumentSummaryInformation"));

			Title = info.Title;
			Author = info.Author;
			Comments = info.Comments;
			CreateDateTime = info.CreateDateTime;
			EditTime = info.EditTime;
			Keywords = info.Keywords;
			Subject = info.Subject;
			PageCount = info.PageCount;
			Company = info2.Company;
			SlideCount = info2.SlideCount;

			
			if(Title != null)
				AddProperty (Beagle.Property.New ("dc:title", Title));

			if(Comments != null)
				AddProperty (Beagle.Property.New ("dc:description", Comments));

			if(Author != null)
				AddProperty (Beagle.Property.New ("dc:author", Author));

			if(Subject != null)
				AddProperty (Beagle.Property.New ("dc:subject",	Subject));
			
		}
	}

}