﻿//
// FilterMSPowerPoint.cs
//
// Copyright (C) 2004 Novell, Inc.
//
// Author:
//   Johannes Roith(johannes at jroith dot de)

//
// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the "Software"),
// to deal in the Software without restriction, including without limitation
// the rights to use, copy, modify, merge, publish, distribute, sublicense,
// and/or sell copies of the Software, and to permit persons to whom the
// Software is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
// DEALINGS IN THE SOFTWARE.
//

using System;
using System.IO;
using System.Text;

using Poi.Net.HPSF;
using Poi.Net.Util;
using Poi.Net.HPSF.Wellknown;
using Poi.Net.PoiFS.FileSystem;
using Poi.Net.PoiFS.EventFileSystem;

namespace Beagle.Filters 
{
	public class FilterMSPowerPoint: AbstractFilterMSOffice
	{
		public FilterMSPowerPoint()
		{
			AddSupportedMimeType ("application/vnd.ms-powerpoint");
		}

		protected override void DoPullProperties()
		{
			DoPullCommonProperties();

			if(PageCount != 0)
				AddProperty (Beagle.Property.New ("fixme:SlideCount", SlideCount));

		}

		protected override void DoPull() {

			StringBuilder contentBuilder = new StringBuilder();

			DocumentInputStream stream = filesystem.CreateDocumentInputStream("PowerPoint Document");
			byte[] buffer = new byte[(int)(stream.Length)];
			stream.Read(buffer, 0,(int)(stream.Length));
			Encoding enc = Encoding.GetEncoding("windows-1252");

				for(int i=0; i < buffer.Length-20; i++)
				{

					// TODO: Add credits for the next lines

					long type = LittleEndian.GetUShort(buffer,i+2);
					long size = LittleEndian.GetUInt(buffer,i+4);

					if(type == 4008)
					{
						
						contentBuilder.Append(enc.GetString(buffer, i + 4 + 4, (int) size));
						contentBuilder.Append(Environment.NewLine);

						i = i + 4 + 4 + (int) size - 1;
					}

					// End

					if(type == 4000)
					{
						bool strip = true;
						for (int j = 0; j < size; j++)
						{
							if (!strip) 
							{
								contentBuilder .Append(enc.GetString(buffer, i + 4 + 3 + j, 1));
								strip = true;
							}
							else
								strip = false;
						}

						contentBuilder.Append(Environment.NewLine);

						i = i + 4 + 3 + (int) size - 1;
					}
				}

				char[] letters = contentBuilder.ToString().ToCharArray();

				StringBuilder _buf = new StringBuilder();

				//NOTE: This will be move out, once I figured
				//      which pieces much can be shared between Word and PowerPoint

				for (int x = 0; x < letters.Length; x++)
				{
					switch (letters[x])
					{
					
					// Separate Tables
					case (char) (0x007): 
						_buf.Append(" ");
						break;

					// Vertical Tab
					case (char) (0x0B): 
						_buf.Append(Environment.NewLine);
						break;
					
					case '\f': 
						_buf.Append("\t");
						break;
					
					case '\r': 
						_buf.Append(Environment.NewLine);
						break;
					
					// Handle LB
					case (char) (0x0A): 
						_buf.Append(Environment.NewLine);
						break;

					case (char) (0x01): 
						break;

					case (char) (0x15): 
					break;

					
					default: 
							_buf.Append(letters[x]);
						break;
					}
				}
				
				Content = _buf.ToString();
				AppendText(Content);
			}
	}
}