﻿//
// FilterMSWord.cs
//
// Copyright (C) 2004 Novell, Inc.
//
// Author:
//   Johannes Roith(johannes at jroith dot de)

//
// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the "Software"),
// to deal in the Software without restriction, including without limitation
// the rights to use, copy, modify, merge, publish, distribute, sublicense,
// and/or sell copies of the Software, and to permit persons to whom the
// Software is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
// DEALINGS IN THE SOFTWARE.
//

using System;
using System.IO;
using System.Text;

using Poi.Net.HPSF;
using Poi.Net.HWPF;
using Poi.Net.HWPF.UserModel;
using Poi.Net.HPSF.Wellknown;
using Poi.Net.PoiFS.EventFileSystem;

namespace Beagle.Filters 
{
	public class FilterMSWord: AbstractFilterMSOffice
	{
		string _content = null;

		public FilterMSWord()
		{
			AddSupportedMimeType ("application/msword");
		}

		protected override void DoPullProperties()
		{
			DoPullCommonProperties();

			 if(PageCount != 0)
				AddProperty (Beagle.Property.New ("fixme:PageCount", PageCount));

		}

		public void DoPull() 
		{
			HWPFDocument doc2 = new HWPFDocument(filesystem);
			Range r = doc2.Range;
			char[] letters = r.Text.ToCharArray();

			r = null;
			doc2 = null;

			StringBuilder _buf = new StringBuilder();
			bool _hold = false;

			for (int x = 0; x < letters.Length; x++)
			{

				//NOTE: This will be move out, once I figured
				//      which pieces much can be shared between Word and PowerPoint

				switch (letters[x])
				{
					
				// Separate Tables
				case (char) (0x007): 
					_buf.Append(" ");
					break;

				case '\b': 
					_buf.Append(" ");
					break;
				
				case '\f': 
					_buf.Append(" ");
					break;
				
				case '\r': 
					_buf.Append(Environment.NewLine);
					break;
				
				// Handle LB
				case (char) (0x0A): 
					_buf.Append(Environment.NewLine);
					break;

				// Some of these are (C) by Ryan Ackley

				case (char) (0x0B): 
					_buf.Append(Environment.NewLine);
					break;
				case (char) (0x01): 
					break;
					case (char) (0x15): 
					break;
				case (char) (0x13): 
					_hold = true;
					break;
				
				case (char) (0x14): 
					_hold = false;
				break;
				
				default: 
					if (!_hold)
						_buf.Append(letters[x]);
					break;
				}
			}
		
			_content = _buf.ToString();

			// Remove some empty lines
			_content = _content.Trim();
			_content = _content.Replace("\r\n\r\n\r\n", "");
			Content = _content;
			AppendText(Content);

		}
	}

}