﻿//
// FilterMSWordTest.cs
//
// Copyright (C) 2004 Novell, Inc.
//
// Author:
//   Johannes Roith(johannes at jroith dot de)

//
// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the "Software"),
// to deal in the Software without restriction, including without limitation
// the rights to use, copy, modify, merge, publish, distribute, sublicense,
// and/or sell copies of the Software, and to permit persons to whom the
// Software is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
// DEALINGS IN THE SOFTWARE.
//

using System;
using System.IO;
using System.Text;

using Poi.Net.HPSF;
using Poi.Net.HPSF.Wellknown;
using Poi.Net.PoiFS.EventFileSystem;


namespace Beagle.Filters 
{
	public class MSWordTest: FilterMSWord
	{

		public void Test(string filename)
		{

			try {

				DoOpen(new FileInfo(filename));
				DoPullProperties();
				DoPull();

				string fname = filename.Substring(0, filename.LastIndexOf('.')) + "_report.txt";
				
				File.Delete(fname);
				StreamWriter swriter = new StreamWriter(File.OpenWrite(fname));
	
				if (Title != null)
					swriter.WriteLine("Title: " + Title);
				else
					swriter.WriteLine("* Document has no title.");
	
				if (Comments != null)
					swriter.WriteLine("Comments: " + Comments);
				else
					swriter.WriteLine("* Document has no comments.");
	
				if (Company != null)
					swriter.WriteLine("Company: " + Company);
				else
				swriter.WriteLine("* Document has no company.");

				if (Author != null)
					swriter.WriteLine("Author: " + Author);
				else
					swriter.WriteLine("* Document has no author.");
	
				if (PageCount != 0)
					swriter.WriteLine("Pages: " + PageCount);
					else
					swriter.WriteLine("* Document has no Pages !?");
	
				if (Content != null)
					swriter.WriteLine("Content: " + Content +  "");
					else
					swriter.WriteLine("* Document has no content");
	
				swriter.Close();

				Console.WriteLine("Text Written to " + fname + ".");

			}
			catch
			{
				Console.WriteLine("Something went wrong.");
			}

		}

		public static void Main(string[] args)
		{

			Console.WriteLine("Poi.Net 0.1 - Simple Test");
			Console.WriteLine("Copyright 2004 by Johannes Roith\n");

			if(args.Length < 1) 
			{
				Console.WriteLine("No Documents found. Please use: mono FilterMSWordTest.exe [file1]");
				return;
			}

			MSWordTest doc = new MSWordTest();
			doc.Test(args[0]);

		}
	}

}