// 
// HPSFRuntimeException.cs
//  
// Copyright 2002-2004  Apache Software Foundation
//
// Jakarta Poi Authors:
//   Rainer Klute (klute@rainer-klute.de)
//
// Poi.Net Authors:
//   Johannes Roith(johannes at jroith dot de)
//  
// 
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

using System;
namespace Poi.Net.HPSF
{
	
	/// <summary> This exception is the superclass of all other unchecked
	/// exceptions thrown in this package. It supports a nested "reason"
	/// throwable, i.e. an exception that caused this one to be thrown.
	/// 
	/// </summary>
	[Serializable]
	public class HPSFRuntimeException:SystemException
	{
		/// <summary> Returns the  Throwable} that caused this exception to
		/// be thrown or <code>null</code> if there was no such 
		/// Throwable}.
		/// 
		/// </summary>
		/// <returns> The reason
		/// </returns>
		
		virtual public Exception Reason {
			get {
				return reason;
			}
			
		}
		
		
		private Exception reason;
		
		
		
		/// <summary> Creates a new  HPSFRuntimeException}.</summary>
		public HPSFRuntimeException():base()
		{
		}
		
		
		
		/// <summary> Creates a new  HPSFRuntimeException} with a message
		/// string.
		/// 
		/// </summary>
		/// <param name="msg">The message string.
		/// </param>
		public HPSFRuntimeException(string msg):base(msg)
		{
		}
		
		
		
		/// <summary> Creates a new  HPSFRuntimeException} with a
		/// reason.
		/// 
		/// </summary>
		/// <param name="reason">The reason, i.e. a throwable that indirectly
		/// caused this exception.
		/// </param>
		
		public HPSFRuntimeException(Exception reason):base()
		{
			this.reason = reason;
		}
		
		
		
		/// <summary> Creates a new  HPSFRuntimeException} with a message
		/// string and a reason.
		/// 
		/// </summary>
		/// <param name="msg">The message string.
		/// </param>
		/// <param name="reason">The reason, i.e. a throwable that indirectly
		/// caused this exception.
		/// </param>
		
		public HPSFRuntimeException(string msg, Exception reason):base(msg)
		{
			this.reason = reason;
		}
	}
}