// 
// PropertySetFactory.cs
//  
// Copyright 2002-2004  Apache Software Foundation
//
// Jakarta Poi Authors:
//   Rainer Klute (klute@rainer-klute.de)
//
// Poi.Net Authors:
//   Johannes Roith(johannes at jroith dot de)
//  
// 
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

using System;
using System.IO;
using Poi.Net.PoiFS.FileSystem;

namespace Poi.Net.HPSF
{
	
	/// <summary> Factory class to create instances of  SummaryInformation},
	///  DocumentSummaryInformation} and  PropertySet}.
	/// 
	/// </summary>
	public class PropertySetFactory
	{
		
		/// <summary> Creates the most specific  PropertySet} from an 
		/// InputStream}. This is preferrably a 
		/// DocumentSummaryInformation} or a  SummaryInformation}. If
		/// the specified  InputStream} does not contain a property
		/// set stream, an exception is thrown and the  InputStream}
		/// is repositioned at its beginning.
		/// 
		/// </summary>
		/// <param name="stream">Contains the property set stream's data.
		/// </param>
		/// <returns> The created  PropertySet}.
		/// </returns>
		/// <throws>  NoPropertySetStreamException if the stream does not </throws>
		/// <summary> contain a property set.
		/// </summary>
		/// <throws>  MarkUnsupportedException if the stream does not support </throws>
		/// <summary> the <code>mark</code> operation.
		/// </summary>
		/// <throws>  UnexpectedPropertySetTypeException if the property </throws>
		/// <summary> set's type is unexpected.
		/// </summary>
		/// <throws>  IOException if some I/O problem occurs. </throws>
		public static PropertySet Create(Stream stream)
		{
			
			PropertySet ps = new PropertySet(stream);
			if (ps.SummaryInformation)
				return new SummaryInformation(ps);
			else if (ps.DocumentSummaryInformation)
				return new DocumentSummaryInformation(ps);
			else
				return ps;
		}
	}
}