// 
// Variant.cs
//  
// Copyright 2002-2004  Apache Software Foundation
//
// Jakarta Poi Authors:
//   Rainer Klute (klute@rainer-klute.de)
//
// Poi.Net Authors:
//   Johannes Roith(johannes at jroith dot de)
//  
// 
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

using System;

namespace Poi.Net.HPSF
{
	
	/// <summary> The <em>Variant</em> types as defined by Microsoft's COM. I
	/// found this information in <a
	/// href="http://www.marin.clara.net/COM/variant_type_definitions.htm">
	/// http://www.marin.clara.net/COM/variant_type_definitions.htm</a>.
	/// 
	/// In the variant types descriptions the following shortcuts are
	/// used: <strong> [V]</strong> - may appear in a VARIANT,
	/// <strong>[T]</strong> - may appear in a TYPEDESC,
	/// <strong>[P]</strong> - may appear in an OLE property set,
	/// <strong>[S]</strong> - may appear in a Safe Array.
	/// 
	/// </summary>
	public class Variant
	{
		
		/// <summary> [V][P] Nothing.</summary>
		public const int VT_EMPTY = 0;
		
		/// <summary> [V][P] SQL style Null.</summary>
		public const int VT_NULL = 1;
		
		/// <summary> [V][T][P][S] 2 byte signed int.</summary>
		public const int VT_I2 = 2;
		
		/// <summary> [V][T][P][S] 4 byte signed int.</summary>
		public const int VT_I4 = 3;
		
		/// <summary> [V][T][P][S] 4 byte real.</summary>
		public const int VT_R4 = 4;
		
		/// <summary> [V][T][P][S] 8 byte real.</summary>
		public const int VT_R8 = 5;
		
		/// <summary> [V][T][P][S] currency. <span style="background-color:
		/// #ffff00">How long is this? How is it to be
		/// interpreted?</span>
		/// </summary>
		public const int VT_CY = 6;
		
		/// <summary> [V][T][P][S] date. <span style="background-color:
		/// #ffff00">How long is this? How is it to be
		/// interpreted?</span>
		/// </summary>
		public const int VT_DATE = 7;
		
		/// <summary> [V][T][P][S] OLE Automation string. <span
		/// style="background-color: #ffff00">How long is this? How is it
		/// to be interpreted?</span>
		/// </summary>
		public const int VT_BSTR = 8;
		
		/// <summary> [V][T][P][S] IDispatch *. <span style="background-color:
		/// #ffff00">How long is this? How is it to be
		/// interpreted?</span>
		/// </summary>
		public const int VT_DISPATCH = 9;
		
		/// <summary> [V][T][S] SCODE. <span style="background-color: #ffff00">How
		/// long is this? How is it to be interpreted?</span>
		/// </summary>
		public const int VT_ERROR = 10;
		
		/// <summary> [V][T][P][S] True=-1, False=0.</summary>
		public const int VT_BOOL = 11;
		
		/// <summary> [V][T][P][S] VARIANT *. <span style="background-color:
		/// #ffff00">How long is this? How is it to be
		/// interpreted?</span>
		/// </summary>
		public const int VT_VARIANT = 12;
		
		/// <summary> [V][T][S] IUnknown *. <span style="background-color:
		/// #ffff00">How long is this? How is it to be
		/// interpreted?</span>
		/// </summary>
		public const int VT_UNKNOWN = 13;
		
		/// <summary> [V][T][S] 16 byte fixed point.</summary>
		public const int VT_DECIMAL = 14;
		
		/// <summary> [T] signed char.</summary>
		public const int VT_I1 = 16;
		
		/// <summary> [V][T][P][S] unsigned char.</summary>
		public const int VT_UI1 = 17;
		
		/// <summary> [T][P] unsigned short.</summary>
		public const int VT_UI2 = 18;
		
		/// <summary> [T][P] unsigned int.</summary>
		public const int VT_UI4 = 19;
		
		/// <summary> [T][P] signed 64-bit int.</summary>
		public const int VT_I8 = 20;
		
		/// <summary> [T][P] unsigned 64-bit int.</summary>
		public const int VT_UI8 = 21;
		
		/// <summary> [T] signed machine int.</summary>
		public const int VT_INT = 22;
		
		/// <summary> [T] unsigned machine int.</summary>
		public const int VT_UINT = 23;
		
		/// <summary> [T] C style void.</summary>
		public const int VT_VOID = 24;
		
		/// <summary> [T] Standard return type. <span style="background-color:
		/// #ffff00">How long is this? How is it to be
		/// interpreted?</span>
		/// </summary>
		public const int VT_HRESULT = 25;
		
		/// <summary> [T] pointer type. <span style="background-color:
		/// #ffff00">How long is this? How is it to be
		/// interpreted?</span>
		/// </summary>
		public const int VT_PTR = 26;
		
		/// <summary> [T] (use VT_ARRAY in VARIANT).</summary>
		public const int VT_SAFEARRAY = 27;
		
		/// <summary> [T] C style array. <span style="background-color:
		/// #ffff00">How long is this? How is it to be
		/// interpreted?</span>
		/// </summary>
		public const int VT_CARRAY = 28;
		
		/// <summary> [T] user defined type. <span style="background-color:
		/// #ffff00">How long is this? How is it to be
		/// interpreted?</span>
		/// </summary>
		public const int VT_USERDEFINED = 29;
		
		/// <summary> [T][P] null terminated string.</summary>
		public const int VT_LPSTR = 30;
		
		/// <summary> [T][P] wide (Unicode) null terminated string.</summary>
		public const int VT_LPWSTR = 31;
		
		/// <summary> [P] FILETIME. The FILETIME structure holds a date and time
		/// associated with a file. The structure identifies a 64-bit
		/// integer specifying the number of 100-nanosecond intervals which
		/// have passed since January 1, 1601. This 64-bit value is split
		/// into the two dwords stored in the structure.
		/// </summary>
		public const int VT_FILETIME = 64;
		
		/// <summary> [P] Length prefixed bytes.</summary>
		public const int VT_BLOB = 65;
		
		/// <summary> [P] Name of the stream follows.</summary>
		public const int VT_STREAM = 66;
		
		/// <summary> [P] Name of the storage follows.</summary>
		public const int VT_STORAGE = 67;
		
		/// <summary> [P] Stream contains an object. <span
		/// style="background-color: #ffff00"> How long is this? How is it
		/// to be interpreted?</span>
		/// </summary>
		public const int VT_STREAMED_OBJECT = 68;
		
		/// <summary> [P] Storage contains an object. <span
		/// style="background-color: #ffff00"> How long is this? How is it
		/// to be interpreted?</span>
		/// </summary>
		public const int VT_STORED_OBJECT = 69;
		
		/// <summary> [P] Blob contains an object. <span style="background-color:
		/// #ffff00">How long is this? How is it to be
		/// interpreted?</span>
		/// </summary>
		public const int VT_BLOB_OBJECT = 70;
		
		/// <summary> [P] Clipboard format. <span style="background-color:
		/// #ffff00">How long is this? How is it to be
		/// interpreted?</span>
		/// </summary>
		public const int VT_CF = 71;
		
		/// <summary> [P] A Class ID.
		/// 
		/// It consists of a 32 bit unsigned integer indicating the size
		/// of the structure, a 32 bit signed integer indicating (Clipboard
		/// Format Tag) indicating the type of data that it contains, and
		/// then a byte array containing the data.
		/// 
		/// The valid Clipboard Format Tags are:
		/// 
		/// <ul>
		/// <li> Thumbnail#CFTAG_WINDOWS}</li>
		/// <li> Thumbnail#CFTAG_MACINTOSH}</li>
		/// <li> Thumbnail#CFTAG_NODATA}</li>
		/// <li> Thumbnail#CFTAG_FMTID}</li>
		/// </ul>
		/// 
		/// <pre>typedef struct tagCLIPDATA {
		/// // cbSize is the size of the buffer pointed to
		/// // by pClipData, plus sizeof(ulClipFmt)
		/// ULONG              cbSize;
		/// long               ulClipFmt;
		/// BYTE*              pClipData;
		/// } CLIPDATA;</pre>
		/// 
		/// See <a
		/// href="msdn.microsoft.com/library/en-us/com/stgrstrc_0uwk.asp"
		/// target="_blank">
		/// msdn.microsoft.com/library/en-us/com/stgrstrc_0uwk.asp</a>.
		/// </summary>
		public const int VT_CLSID = 72;
		
		/// <summary> [P] simple counted array. <span style="background-color:
		/// #ffff00">How long is this? How is it to be
		/// interpreted?</span>
		/// </summary>
		public const int VT_VECTOR = 0x1000;
		
		/// <summary> [V] SAFEARRAY*. <span style="background-color: #ffff00">How
		/// long is this? How is it to be interpreted?</span>
		/// </summary>
		public const int VT_ARRAY = 0x2000;
		
		/// <summary> [V] void* for local use. <span style="background-color:
		/// #ffff00">How long is this? How is it to be
		/// interpreted?</span>
		/// </summary>
		public const int VT_BYREF = 0x4000;
		
		/// <summary> FIXME: Document this!</summary>
		public const int VT_RESERVED = 0x8000;
		
		/// <summary> FIXME: Document this!</summary>
		public const int VT_ILLEGAL = 0xFFFF;
		
		/// <summary> FIXME: Document this!</summary>
		public const int VT_ILLEGALMASKED = 0xFFF;
		
		/// <summary> FIXME: Document this!</summary>
		public const int VT_TYPEMASK = 0xFFF;
	}
}