// 
// ComplexFileTable.cs
//  
// Copyright 2002-2004  Apache Software Foundation
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

using System;
using System.IO;

using Poi.Net.Util;
using Poi.Net.HWPF.Model;
using Poi.Net.HWPF.Model.IO;


namespace Poi.Net.HWPF.Model
{
	
	public class ComplexFileTable
	{
		
		private const byte GRPPRL_TYPE = 1;
		private const byte TEXT_PIECE_TABLE_TYPE = 2;
		
		protected internal TextPieceTable _tpt;

		virtual public TextPieceTable TextPieceTable {
			get {
				return _tpt;
			}
		}
		
		public ComplexFileTable()
		{
			_tpt = new TextPieceTable();
		}
		
		public ComplexFileTable(byte[] documentStream, byte[] tableStream, int offset, int fcMin)
		{
			//skips through the prms before we reach the piece table. These contain data
			//for actual fast saved files
			while (tableStream[offset] == GRPPRL_TYPE)
			{
				offset++;
				int skip = LittleEndian.GetShort(tableStream, offset);
				offset += LittleEndian.SHORT_SIZE + skip;
			}
			if (tableStream[offset] != TEXT_PIECE_TABLE_TYPE)
			{
				throw new IOException("The text piece table is corrupted");
			}
			else
			{
				int pieceTableSize = LittleEndian.GetInt(tableStream, ++offset);
				offset += LittleEndian.INT_SIZE;
				_tpt = new TextPieceTable(documentStream, tableStream, offset, pieceTableSize, fcMin);
			}
		}
		
		public virtual void WriteTo(HWPFFileSystem sys)
		{
			HWPFOutputStream docStream = sys.GetStream("WordDocument");
			HWPFOutputStream tableStream = sys.GetStream("1Table");
			
			tableStream.WriteByte((byte) TEXT_PIECE_TABLE_TYPE);
			
			byte[] table = _tpt.WriteTo(docStream);
			
			byte[] numHolder = new byte[LittleEndian.INT_SIZE];
			LittleEndian.PutInt(numHolder, table.Length);
			tableStream.Write(numHolder, 0, numHolder.Length);
			tableStream.Write(table, 0, table.Length);
		}
	}
}