// 
// FIBShortHandler.cs
//  
// Copyright 2002-2004  Apache Software Foundation
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

using System;

using Poi.Net.Util;
using Poi.Net.HWPF.Model;
namespace Poi.Net.HWPF.Model
{
	
	class FIBShortHandler
	{
		public const int MAGICCREATED = 0;
		public const int MAGICREVISED = 1;
		public const int MAGICCREATEDPRIVATE = 2;
		public const int MAGICREVISEDPRIVATE = 3;
		public const int LIDFE = 13;
		
		internal const int START = 0x20;
		
		internal short[] _shorts;
		
		internal virtual int SizeInBytes {
			get { return (_shorts.Length * LittleEndian.SHORT_SIZE) + LittleEndian.SHORT_SIZE; }
		}

		public FIBShortHandler(byte[] mainStream)
		{
			int offset = START;
			int shortCount = LittleEndian.GetShort(mainStream, offset);
			offset += LittleEndian.SHORT_SIZE;
			_shorts = new short[shortCount];
			
			for (int x = 0; x < shortCount; x++)
			{
				_shorts[x] = LittleEndian.GetShort(mainStream, offset);
				offset += LittleEndian.SHORT_SIZE;
			}
		}
		
		
		public virtual short GetShort(int shortCode)
		{
			return _shorts[shortCode];
		}
		
		internal virtual void Serialize(byte[] mainStream)
		{
			int offset = START;
			LittleEndian.PutShort(mainStream, offset, (short) _shorts.Length);
			offset += LittleEndian.SHORT_SIZE;
			//mainStream.Write(holder);
			
			for (int x = 0; x < _shorts.Length; x++)
			{
				LittleEndian.PutShort(mainStream, offset, _shorts[x]);
				offset += LittleEndian.SHORT_SIZE;
			}
		}
	}
}