// 
// FileInformationBlock.cs
//  
// Copyright 2002-2004  Apache Software Foundation
//
// Jakarta Poi Authors:
//     andy
//
// Poi.Net Authors:
//   Johannes Roith(johannes at jroith dot de)
//  
// 
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

using System;
using System.Collections;

using Poi.Net.Util;

using Poi.Net.HWPF.Model;
using Poi.Net.HWPF.Model.IO;
using Poi.Net.HWPF.Model.Types;

namespace Poi.Net.HWPF.Model
{
	
	public class FileInformationBlock:FIBAbstractType, ICloneable
	{
		
		internal FIBLongHandler _longHandler;
		internal FIBShortHandler _shortHandler;
		internal FIBFieldHandler _fieldHandler;

		virtual public int FcDop {
			get {
				return _fieldHandler.GetFieldOffset(FIBFieldHandler.DOP);
			}
			
			set {
				_fieldHandler.SetFieldOffset(FIBFieldHandler.DOP, value);
			}	
		}

		virtual public int LcbDop {
			get {
				return _fieldHandler.GetFieldSize(FIBFieldHandler.DOP);
			}
			
			set {
				_fieldHandler.SetFieldSize(FIBFieldHandler.DOP, value);
			}			
		}

		virtual public int FcStshf {
			get {
				return _fieldHandler.GetFieldOffset(FIBFieldHandler.STSHF);
			}
			
			set {
				_fieldHandler.SetFieldOffset(FIBFieldHandler.STSHF, value);
			}			
		}

		virtual public int LcbStshf {
			get {
				return _fieldHandler.GetFieldSize(FIBFieldHandler.STSHF);
			}
			
			set {
				_fieldHandler.SetFieldSize(FIBFieldHandler.STSHF, value);
			}			
		}

		virtual public int FcClx {
			get {
				return _fieldHandler.GetFieldOffset(FIBFieldHandler.CLX);
			}
			
			set {
				_fieldHandler.SetFieldOffset(FIBFieldHandler.CLX, value);
			}			
		}

		virtual public int LcbClx {
			get {
				return _fieldHandler.GetFieldSize(FIBFieldHandler.CLX);
			}
			
			set {
				_fieldHandler.SetFieldSize(FIBFieldHandler.CLX, value);
			}
		}

		virtual public int FcPlcfbteChpx {
			get {
				return _fieldHandler.GetFieldOffset(FIBFieldHandler.PLCFBTECHPX);
			}
			
			set {
				_fieldHandler.SetFieldOffset(FIBFieldHandler.PLCFBTECHPX, value);
			}
		}

		virtual public int LcbPlcfbteChpx {
			get {
				return _fieldHandler.GetFieldSize(FIBFieldHandler.PLCFBTECHPX);
			}
			
			set {
				_fieldHandler.SetFieldSize(FIBFieldHandler.PLCFBTECHPX, value);
			}
		}

		virtual public int FcPlcfbtePapx {
			get {
				return _fieldHandler.GetFieldOffset(FIBFieldHandler.PLCFBTEPAPX);
			}
			
			set {
				_fieldHandler.SetFieldOffset(FIBFieldHandler.PLCFBTEPAPX, value);
			}
		}

		virtual public int LcbPlcfbtePapx {
			get {
				return _fieldHandler.GetFieldSize(FIBFieldHandler.PLCFBTEPAPX);
			}
			
			set {
				_fieldHandler.SetFieldSize(FIBFieldHandler.PLCFBTEPAPX, value);
			}
		}

		virtual public int FcPlcfsed {
			get {
				return _fieldHandler.GetFieldOffset(FIBFieldHandler.PLCFSED);
			}
			
			set {
				_fieldHandler.SetFieldOffset(FIBFieldHandler.PLCFSED, value);
			}			
		}

		virtual public int LcbPlcfsed {
			get {
				return _fieldHandler.GetFieldSize(FIBFieldHandler.PLCFSED);
			}
			
			set {
				_fieldHandler.SetFieldSize(FIBFieldHandler.PLCFSED, value);
			}			
		}

		virtual public int FcPlcfLst {
			get {
				return _fieldHandler.GetFieldOffset(FIBFieldHandler.PLCFLST);
			}
			
			set {
				_fieldHandler.SetFieldOffset(FIBFieldHandler.PLCFLST, value);
			}
		}

		virtual public int LcbPlcfLst {
			get {
				return _fieldHandler.GetFieldSize(FIBFieldHandler.PLCFLST);
			}
			
			set {
				_fieldHandler.SetFieldSize(FIBFieldHandler.PLCFLST, value);
			}			
		}
		virtual public int FcPlfLfo {
			get {
				return _fieldHandler.GetFieldOffset(FIBFieldHandler.PLFLFO);
			}
			
			set {
				_fieldHandler.SetFieldOffset(FIBFieldHandler.PLFLFO, value);
			}			
		}
		virtual public int LcbPlfLfo {
			get {
				return _fieldHandler.GetFieldSize(FIBFieldHandler.PLFLFO);
			}
			
			set {
				_fieldHandler.SetFieldSize(FIBFieldHandler.PLFLFO, value);
			}			
		}
		virtual public int FcSttbfffn {
			get {
				return _fieldHandler.GetFieldOffset(FIBFieldHandler.STTBFFFN);
			}
			
			set {
				_fieldHandler.SetFieldOffset(FIBFieldHandler.STTBFFFN, value);
			}
			
		}
		virtual public int LcbSttbfffn {
			get {
				return _fieldHandler.GetFieldSize(FIBFieldHandler.STTBFFFN);
			}
			
			set {
				_fieldHandler.SetFieldSize(FIBFieldHandler.STTBFFFN, value);
			}			
		}
		virtual public int ModifiedLow {
			get {
				return _fieldHandler.GetFieldOffset(FIBFieldHandler.PLFLFO);
			}
			
			set {
				_fieldHandler.SetFieldOffset(FIBFieldHandler.PLFLFO, value);
			}			
		}
		virtual public int ModifiedHigh {
			get {
				return _fieldHandler.GetFieldSize(FIBFieldHandler.PLFLFO);
			}
			
			set {
				_fieldHandler.SetFieldSize(FIBFieldHandler.PLFLFO, value);
			}			
		}
		virtual public int CbMac
		{
			set {
				_longHandler.SetLong(FIBLongHandler.CBMAC, value);
			}			
		}
		virtual public int FcPlcffldMom {
			get {
				return _fieldHandler.GetFieldOffset(FIBFieldHandler.PLCFFLDMOM);
			}			
		}
		virtual public int LcbPlcffldMom {
			get {
				return _fieldHandler.GetFieldSize(FIBFieldHandler.PLCFFLDMOM);
			}			
		}
		override public int Size {
			get {
				return base.Size + _shortHandler.SizeInBytes + _longHandler.SizeInBytes + _fieldHandler.SizeInBytes;
			}
			//    public Object clone()
			//    {
			//      try
			//      {
			//        return super.clone();
			//      }
			//      catch (CloneNotSupportedException e)
			//      {
			//        e.printStackTrace();
			//        return null;
			//      }
			//    }
			
		}

		/// <summary>Creates a new instance of FileInformationBlock </summary>
		public FileInformationBlock(byte[] mainDocument)
		{
			FillFields(mainDocument, 0);
		}
		
		public virtual void FillVariableFields(byte[] mainDocument, byte[] tableStream)
		{
			// HS
			ArrayList fieldSet = new ArrayList();

			int[] f = new int[11];
			f[0]    = (int) FIBFieldHandler.STSHF;
			f[1]    = (int) FIBFieldHandler.CLX;
			f[2]    = (int) FIBFieldHandler.DOP;
			f[3]    = (int) FIBFieldHandler.PLCFBTECHPX;
			f[4]    = (int) FIBFieldHandler.PLCFBTEPAPX;
			f[5]    = (int) FIBFieldHandler.PLCFSED;
			f[6]    = (int) FIBFieldHandler.PLCFLST;
			f[7]    = (int) FIBFieldHandler.PLFLFO;
			f[8]    = (int) FIBFieldHandler.PLCFFLDMOM;
			f[9]    = (int) FIBFieldHandler.STTBFFFN;
			f[10]   = (int) FIBFieldHandler.MODIFIED;

			foreach(int cf in f)
				if(!fieldSet.Contains(cf))
					fieldSet.Add(cf);
			
			
			_shortHandler = new FIBShortHandler(mainDocument);
			_longHandler = new FIBLongHandler(mainDocument, Poi.Net.HWPF.Model.FIBShortHandler.START + _shortHandler.SizeInBytes);
			_fieldHandler = new FIBFieldHandler(mainDocument, Poi.Net.HWPF.Model.FIBShortHandler.START + _shortHandler.SizeInBytes + _longHandler.SizeInBytes, tableStream, fieldSet, true);
		}
		
		public virtual void ClearOffsetsSizes()
		{
			_fieldHandler.ClearFields();
		}
		
		public virtual void WriteTo(byte[] mainStream, HWPFOutputStream tableStream)
		{
			//HWPFOutputStream mainDocument = sys.GetStream("WordDocument");
			//HWPFOutputStream tableStream = sys.GetStream("1Table");
			
			base.Serialize(mainStream, 0);
			
			int size = base.Size;
			_shortHandler.Serialize(mainStream);
			_longHandler.Serialize(mainStream, size + _shortHandler.SizeInBytes);
			_fieldHandler.WriteTo(mainStream, base.Size + _shortHandler.SizeInBytes + _longHandler.SizeInBytes, tableStream);
		}
		
		virtual public object Clone()
		{
			return null;
		}
	}
}