// 
// PropertyIDMap.cs
//  
// Copyright 2002-2004  Apache Software Foundation
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

using System;

using Poi.Net.Util;
namespace Poi.Net.HWPF.Model
{
	
	public class ListFormatOverride
	{
		internal int _lsid;
		internal int _reserved1;
		internal int _reserved2;
		internal byte _clfolvl;
		internal byte[] _reserved3 = new byte[3];
		internal ListFormatOverrideLevel[] _levelOverrides;
		
		virtual public ListFormatOverrideLevel[] LevelOverrides 
		{
			get {
				return _levelOverrides;
			}			
		}

		public ListFormatOverride(int lsid)
		{
			_lsid = lsid;
			_levelOverrides = new ListFormatOverrideLevel[0];
		}
		
		public ListFormatOverride(byte[] buf, int offset)
		{
			_lsid = LittleEndian.GetInt(buf, offset);
			offset += LittleEndian.INT_SIZE;
			_reserved1 = LittleEndian.GetInt(buf, offset);
			offset += LittleEndian.INT_SIZE;
			_reserved2 = LittleEndian.GetInt(buf, offset);
			offset += LittleEndian.INT_SIZE;
			_clfolvl = buf[offset++];
			Array.Copy(buf, offset, _reserved3, 0, _reserved3.Length);
			_levelOverrides = new ListFormatOverrideLevel[_clfolvl];
		}
		
		public virtual int NumOverrides {
			get { return _clfolvl; }
		}
		
		public virtual int Lsid {
			get { return _lsid; }
			set { _lsid = value; }
		}
		
		public virtual void SetOverride(int index, ListFormatOverrideLevel lfolvl)
		{
			_levelOverrides[index] = lfolvl;
		}
		
		public virtual ListFormatOverrideLevel GetOverrideLevel(int level)
		{
			
			ListFormatOverrideLevel retLevel = null;
			
			for (int x = 0; x < _levelOverrides.Length; x++)
			{
				if (_levelOverrides[x].LevelNum == level)
				{
					retLevel = _levelOverrides[x];
				}
			}
			return retLevel;
		}
		
		public  override bool Equals(object obj)
		{
			if (obj == null)
			{
				return false;
			}
			
			ListFormatOverride lfo = (ListFormatOverride) obj;
			return lfo._clfolvl == _clfolvl && lfo._lsid == _lsid && lfo._reserved1 == _reserved1 && lfo._reserved2 == _reserved2 && ArrayHelper.Equals(lfo._reserved3, _reserved3) && ArrayHelper.Equals(lfo._levelOverrides, _levelOverrides);
		}
		
		public virtual byte[] ToByteArray()
		{
			byte[] buf = new byte[16];
			int offset = 0;
			LittleEndian.PutInt(buf, offset, _lsid);
			offset += LittleEndian.INT_SIZE;
			LittleEndian.PutInt(buf, offset, _reserved1);
			offset += LittleEndian.INT_SIZE;
			LittleEndian.PutInt(buf, offset, _reserved2);
			offset += LittleEndian.INT_SIZE;
			buf[offset++] = _clfolvl;
			Array.Copy(_reserved3, 0, buf, offset, 3);
			
			return buf;
		}
	}
}