// 
// ListFormatOverrideLevel.cs
//  
// Copyright 2002-2004  Apache Software Foundation
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

using System;
using Poi.Net.Util;

namespace Poi.Net.HWPF.Model
{
	
	public class ListFormatOverrideLevel
	{
		virtual public ListLevel Level {
			get {
				return _lvl;
			}
			
		}
		virtual public int LevelNum {
			get {
				return _ilvl.GetValue(_info);
			}
			
		}
		virtual public bool Formatting {
			get {
				return _fFormatting.GetValue(_info) != 0;
			}
			
		}
		virtual public bool StartAt {
			get {
				return _fStartAt.GetValue(_info) != 0;
			}
			
		}
		virtual public int SizeInBytes {
			get {
				return (_lvl == null?BASE_SIZE:BASE_SIZE + _lvl.SizeInBytes);
			}
			
		}
		private const int BASE_SIZE = 8;
		
		internal int _iStartAt;
		internal byte _info;
		private static BitField _ilvl = new BitField(0xf);
		private static BitField _fStartAt = new BitField(0x10);
		private static BitField _fFormatting = new BitField(0x20);
		internal byte[] _reserved = new byte[3];
		internal ListLevel _lvl;
		
		public ListFormatOverrideLevel(byte[] buf, int offset)
		{
			_iStartAt = LittleEndian.GetInt(buf, offset);
			offset += LittleEndian.INT_SIZE;
			_info = buf[offset++];
			Array.Copy(buf, offset, _reserved, 0, _reserved.Length);
			offset += _reserved.Length;
			
			if (_fFormatting.GetValue(_info) > 0)
			{
				_lvl = new ListLevel(buf, offset);
			}
		}
		
		public  override bool Equals(object obj)
		{
			if (obj == null)
			{
				return false;
			}
			ListFormatOverrideLevel lfolvl = (ListFormatOverrideLevel) obj;
			bool lvlEquality = false;
			if (_lvl != null)
			{
				lvlEquality = _lvl.Equals(lfolvl._lvl);
			}
			else
			{
				lvlEquality = lfolvl._lvl == null;
			}
			
			return lvlEquality && lfolvl._iStartAt == _iStartAt && lfolvl._info == _info && ArrayHelper.Equals(lfolvl._reserved, _reserved);
		}
		
		public virtual byte[] ToByteArray()
		{
			byte[] buf = new byte[SizeInBytes];
			
			int offset = 0;
			LittleEndian.PutInt(buf, _iStartAt);
			offset += LittleEndian.INT_SIZE;
			buf[offset++] = _info;
			Array.Copy(_reserved, 0, buf, offset, 3);
			offset += 3;
			
			if (_lvl != null)
			{
				byte[] levelBuf = _lvl.ToByteArray();
				Array.Copy(levelBuf, 0, buf, offset, levelBuf.Length);
			}
			
			return buf;
		}
	}
}