﻿// 
// ListLevel.cs
//  
// Copyright 2002-2004  Apache Software Foundation
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

using System;

using Poi.Net.Util;
using Poi.Net.HWPF.UserModel;
using Poi.Net.HWPF.SPRM;

namespace Poi.Net.HWPF.Model
{
	
	public class ListLevel
	{
		virtual public int StartAt {
			get {
				return _iStartAt;
			}
			
			set {
				_iStartAt = value;
			}
			
		}
		virtual public int NumberFormat {
			get {
				return _nfc;
			}
			
			set {
				_nfc = (byte) value;
			}
			
		}
		virtual public int Alignment {
			get {
				return _jc.GetValue(_info);
			}
			
			set {
				_jc.SetValue(_info, value);
			}
			
		}
		virtual public string NumberText {
			get {
				return new string(_numberText);
			}
			
		}
		virtual public byte[] NumberProperties
		{
			set {
				_grpprlChpx = value;
			}
			
		}
		virtual public byte[] LevelProperties {
			get {
				return _grpprlPapx;
			}
			
			set {
				_grpprlPapx = value;
			}
			
		}
		virtual public int SizeInBytes {
			get {
				return 28 + _cbGrpprlChpx + _cbGrpprlPapx + (_numberText.Length * LittleEndian.SHORT_SIZE) + 2;
			}
			
		}
		private int _iStartAt;
		private byte _nfc;
		private byte _info;
		private static BitField _jc = null;
		//unused: private static BitField _fLegal;
		//unused: private static BitField _fNoRestart;
		//unused: private static BitField _fPrev;
		//unused: private static BitField _fPrevSpace;
		//unused: private static BitField _fWord6;
		private byte[] _rgbxchNums;
		private byte _ixchFollow;
		private int _dxaSpace;
		private int _dxaIndent;
		private int _cbGrpprlChpx;
		private int _cbGrpprlPapx;
		private short _reserved;
		private byte[] _grpprlPapx;
		private byte[] _grpprlChpx;
		private char[] _numberText;
		
		public ListLevel(int startAt, int numberFormatCode, int alignment, byte[] numberProperties, byte[] entryProperties, string numberText)
		{
			_iStartAt = startAt;
			_nfc = (byte) numberFormatCode;
			_jc.SetValue(_info, alignment);
			_grpprlChpx = numberProperties;
			_grpprlPapx = entryProperties;
			_numberText = numberText.ToCharArray();
		}
		
		public ListLevel(int level, bool numbered)
		{
			_iStartAt = 1;
			_grpprlPapx = new byte[0];
			_grpprlChpx = new byte[0];
			_numberText = new char[0];
			_rgbxchNums = new byte[9];
			
			if (numbered)
			{
				_rgbxchNums[0] = 1;
				_numberText = new char[]{(char) level, '.'};
			}
			else
			{
				_numberText = new char[]{'\u2022'};
			}
		}
		
		public ListLevel(byte[] buf, int offset)
		{
			_iStartAt = LittleEndian.GetInt(buf, offset);
			offset += LittleEndian.INT_SIZE;
			_nfc = buf[offset++];
			_info = buf[offset++];
			
			_rgbxchNums = new byte[9];
			for (int x = 0; x < 9; x++)
			{
				_rgbxchNums[x] = buf[offset++];
			}
			_ixchFollow = buf[offset++];
			_dxaSpace = LittleEndian.GetInt(buf, offset);
			offset += LittleEndian.INT_SIZE;
			_dxaIndent = LittleEndian.GetInt(buf, offset);
			offset += LittleEndian.INT_SIZE;
			_cbGrpprlChpx = LittleEndian.GetUnsignedByte(buf, offset++);
			_cbGrpprlPapx = LittleEndian.GetUnsignedByte(buf, offset++);
			_reserved = LittleEndian.GetShort(buf, offset);
			offset += LittleEndian.SHORT_SIZE;
			
			_grpprlPapx = new byte[_cbGrpprlPapx];
			_grpprlChpx = new byte[_cbGrpprlChpx];
			Array.Copy(buf, offset, _grpprlPapx, 0, _cbGrpprlPapx);
			offset += _cbGrpprlPapx;
			Array.Copy(buf, offset, _grpprlChpx, 0, _cbGrpprlChpx);
			offset += _cbGrpprlChpx;
			
			int numberTextLength = LittleEndian.GetShort(buf, offset);
			_numberText = new char[numberTextLength];
			offset += LittleEndian.SHORT_SIZE;
			for (int x = 0; x < numberTextLength; x++)
			{
				_numberText[x] = (char) LittleEndian.GetShort(buf, offset);
				offset += LittleEndian.SHORT_SIZE;
			}
		}
		
		public  override bool Equals(object obj)
		{
			if (obj == null)
			{
				return false;
			}
			
			ListLevel lvl = (ListLevel) obj;
			return _cbGrpprlChpx == lvl._cbGrpprlChpx && lvl._cbGrpprlPapx == _cbGrpprlPapx && lvl._dxaIndent == _dxaIndent && lvl._dxaSpace == _dxaSpace && ArrayHelper.Equals(lvl._grpprlChpx, _grpprlChpx) && ArrayHelper.Equals(lvl._grpprlPapx, _grpprlPapx) && lvl._info == _info && lvl._iStartAt == _iStartAt && lvl._ixchFollow == _ixchFollow && lvl._nfc == _nfc && ArrayHelper.Equals(lvl._numberText, _numberText) && ArrayHelper.Equals(lvl._rgbxchNums, _rgbxchNums) && lvl._reserved == _reserved;
		}
		public virtual byte[] ToByteArray()
		{
			byte[] buf = new byte[SizeInBytes];
			int offset = 0;
			LittleEndian.PutInt(buf, offset, _iStartAt);
			offset += LittleEndian.INT_SIZE;
			buf[offset++] = _nfc;
			buf[offset++] = _info;
			Array.Copy(_rgbxchNums, 0, buf, offset, _rgbxchNums.Length);
			offset += _rgbxchNums.Length;
			buf[offset++] = _ixchFollow;
			LittleEndian.PutInt(buf, offset, _dxaSpace);
			offset += LittleEndian.INT_SIZE;
			LittleEndian.PutInt(buf, offset, _dxaIndent);
			offset += LittleEndian.INT_SIZE;
			
			buf[offset++] = (byte) _cbGrpprlChpx;
			buf[offset++] = (byte) _cbGrpprlPapx;
			LittleEndian.PutShort(buf, offset, _reserved);
			offset += LittleEndian.SHORT_SIZE;
			
			Array.Copy(_grpprlChpx, 0, buf, offset, _cbGrpprlChpx);
			offset += _cbGrpprlChpx;
			Array.Copy(_grpprlPapx, 0, buf, offset, _cbGrpprlPapx);
			offset += _cbGrpprlPapx;
			
			LittleEndian.PutShort(buf, offset, (short) _numberText.Length);
			offset += LittleEndian.SHORT_SIZE;
			for (int x = 0; x < _numberText.Length; x++)
			{
				LittleEndian.PutShort(buf, offset, (short) _numberText[x]);
				offset += LittleEndian.SHORT_SIZE;
			}
			return buf;
		}
	}
}