// 
// PAPX.cs
//  
// Copyright 2002-2004  Apache Software Foundation
//
// Jakarta Poi Authors:
//   Ryan Ackley
//
// Poi.Net Authors:
//   Johannes Roith(johannes at jroith dot de)
//  
// 
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

using System;

using Poi.Net.Util;
using Poi.Net.HWPF.UserModel;
using Poi.Net.HWPF.SPRM;

namespace Poi.Net.HWPF.Model
{
	
	/// <summary> Comment me
	/// 
	/// </summary>

	public class PAPX:PropertyNode
	{
		virtual public ParagraphHeight ParagraphHeight {
			get {
				return _phe;
			}
			
		}
		virtual public byte[] Grpprl {
			get {
				return ((SprmBuffer) _buf).ToByteArray();
			}
			
		}
		virtual public int HugeGrpprlOffset {
			get {
				return _hugeGrpprlOffset;
			}
			
		}
		virtual public short Istd {
			get {
				byte[] buf = Grpprl;
				if (buf.Length == 0)
				{
					return 0;
				}
				else
				{
					return LittleEndian.GetShort(buf);
				}
			}
			
		}
		virtual public SprmBuffer SprmBuf {
			get {
				return (SprmBuffer) _buf;
			}
			
		}
		
		private ParagraphHeight _phe;
		private int _hugeGrpprlOffset = - 1;
		
		public PAPX(int fcStart, int fcEnd, byte[] papx, ParagraphHeight phe, byte[] dataStream):base(fcStart, fcEnd, new SprmBuffer(papx))
		{
			_phe = phe;
			SprmBuffer buf = FindHuge(new SprmBuffer(papx), dataStream);
			if (buf != null)
				_buf = buf;
		}
		
		public PAPX(int fcStart, int fcEnd, SprmBuffer buf, byte[] dataStream):base(fcStart, fcEnd, buf)
		{
			_phe = new ParagraphHeight();
			buf = FindHuge(buf, dataStream);
			if (buf != null)
				_buf = buf;
		}
		
		private SprmBuffer FindHuge(SprmBuffer buf, byte[] datastream)
		{
			byte[] grpprl = buf.ToByteArray();
			if (grpprl.Length == 8 && datastream != null)
			// then check for sprmPHugePapx
			{
				SprmOperation sprm = new SprmOperation(grpprl, 2);
				if ((sprm.Operation == 0x45 || sprm.Operation == 0x46) && sprm.SizeCode == 3)
				{
					int hugeGrpprlOffset = sprm.Operand;
					if (hugeGrpprlOffset + 1 < datastream.Length)
					{
						int grpprlSize = LittleEndian.GetShort(datastream, hugeGrpprlOffset);
						if (hugeGrpprlOffset + grpprlSize < datastream.Length)
						{
							byte[] hugeGrpprl = new byte[grpprlSize + 2];
							// copy original istd into huge Grpprl
							hugeGrpprl[0] = grpprl[0]; hugeGrpprl[1] = grpprl[1];
							// copy Grpprl from dataStream
							Array.Copy(datastream, hugeGrpprlOffset + 2, hugeGrpprl, 2, grpprlSize);
							// save a pointer to where we got the huge Grpprl from
							_hugeGrpprlOffset = hugeGrpprlOffset;
							return new SprmBuffer(hugeGrpprl);
						}
					}
				}
			}
			return null;
		}
		
		public virtual ParagraphProperties GetParagraphProperties(StyleSheet ss)
		{
			short istd = Istd;
			ParagraphProperties baseStyle = ss.GetParagraphStyle(istd);
			ParagraphProperties props = ParagraphSprmUncompressor.UncompressPAP(baseStyle, Grpprl, 2);
			return props;
		}
		
		public  override bool Equals(object o)
		{
			if (base.Equals(o))
			{
				return _phe.Equals(((PAPX) o)._phe);
			}
			return false;
		}
		
		override public object Clone()
		{
			return null;
		}
		
		override public int CompareTo(object obj)
		{
			return 0;
		}
	}
}