// 
// ParagraphHeight.cs
//  
// Copyright 2002-2004  Apache Software Foundation
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

using System;
using System.IO;

using Poi.Net.Util;

namespace Poi.Net.HWPF.Model
{
	
	public class ParagraphHeight
	{
		private short infoField;
		private BitField fSpare = new BitField(0x0001);
		private BitField fUnk = new BitField(0x0002);
		private BitField fDiffLines = new BitField(0x0004);
		private BitField clMac = new BitField(0xff00);
		private short reserved;
		private int dxaCol;
		private int dymLineOrHeight;
		
		public ParagraphHeight(byte[] buf, int offset)
		{
			infoField = LittleEndian.GetShort(buf, offset);
			offset += LittleEndian.SHORT_SIZE;
			reserved = LittleEndian.GetShort(buf, offset);
			offset += LittleEndian.SHORT_SIZE;
			dxaCol = LittleEndian.GetInt(buf, offset);
			offset += LittleEndian.INT_SIZE;
			dymLineOrHeight = LittleEndian.GetInt(buf, offset);
		}
		
		public ParagraphHeight()
		{
		}
		
		public virtual void Write(Stream outStream)
		{
			byte[] bArray = ToByteArray();
			outStream.Write(bArray, 0, bArray.Length);
		}
		
		protected internal virtual byte[] ToByteArray()
		{
			byte[] buf = new byte[12];
			int offset = 0;
			LittleEndian.PutShort(buf, offset, infoField);
			offset += LittleEndian.SHORT_SIZE;
			LittleEndian.PutShort(buf, offset, reserved);
			offset += LittleEndian.SHORT_SIZE;
			LittleEndian.PutInt(buf, offset, dxaCol);
			offset += LittleEndian.INT_SIZE;
			LittleEndian.PutInt(buf, offset, dymLineOrHeight);
			
			return buf;
		}
		
		public  override bool Equals(object o)
		{
			ParagraphHeight ph = (ParagraphHeight) o;
			
			return infoField == ph.infoField && reserved == ph.reserved && dxaCol == ph.dxaCol && dymLineOrHeight == ph.dymLineOrHeight;
		}
	}
}