// 
// PieceDescriptor.cs
//  
// Copyright 2002-2004  Apache Software Foundation
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

using System;
using Poi.Net.Util;

namespace Poi.Net.HWPF.Model
{
	
	public class PieceDescriptor
	{
		virtual public int FilePosition {
			get {
				return fc;
			}
			
			set {
				fc = value;
			}
			
		}
		virtual public bool Unicode {
			get {
				return unicode;
			}
			
		}
		public static int SizeInBytes {
			get {
				return 8;
			}
			
		}
		
		internal short descriptor;
		private static BitField fNoParaLast = new BitField(0x01);
		private static BitField fPaphNil = new BitField(0x02);
		private static BitField fCopied = new BitField(0x04);
		internal int fc;
		internal short prm;
		internal bool unicode;
		
		
		public PieceDescriptor(byte[] buf, int offset)
		{
			descriptor = LittleEndian.GetShort(buf, offset);
			offset += LittleEndian.SHORT_SIZE;
			fc = LittleEndian.GetInt(buf, offset);
			offset += LittleEndian.INT_SIZE;
			prm = LittleEndian.GetShort(buf, offset);
			
			// see if this piece uses unicode.
			if ((fc & 0x40000000) == 0)
			{
				unicode = true;
			}
			else
			{
				unicode = false;
				fc &= ~ (0x40000000); //gives me FC in doc stream
				fc /= 2;
			}
		}
		
		protected internal virtual byte[] ToByteArray()
		{
			// set up the fc
			int tempFc = fc;
			if (!unicode)
			{
				tempFc *= 2;
				tempFc |= (0x40000000);
			}
			
			int offset = 0;
			byte[] buf = new byte[8];
			LittleEndian.PutShort(buf, offset, descriptor);
			offset += LittleEndian.SHORT_SIZE;
			LittleEndian.PutInt(buf, offset, tempFc);
			offset += LittleEndian.INT_SIZE;
			LittleEndian.PutShort(buf, offset, prm);
			
			return buf;
		}
		
		public  override bool Equals(object o)
		{
			PieceDescriptor pd = (PieceDescriptor) o;
			
			return descriptor == pd.descriptor && prm == pd.prm && unicode == pd.unicode;
		}
	}
}