// 
// PlexOfCps.cs
//  
// Copyright 2002-2004  Apache Software Foundation
//
// Jakarta Poi Authors:
//   Ryan Ackley
//
// Poi.Net Authors:
//   Johannes Roith(johannes at jroith dot de)
//  
// 
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

using System;
using System.Collections;

using Poi.Net.Util;
namespace Poi.Net.HWPF.Model
{
	
	
	
	/// <summary> common data structure in a Word file. Contains an array of 4 byte ints in
	/// the front that relate to an array of abitrary data structures in the back.
	/// 
	/// 
	/// </summary>

	public class PlexOfCps
	{
		private int _count;
		//unused: private int _offset;
		private int _sizeOfStruct;
		private ArrayList _props;
		
		
		public PlexOfCps(int sizeOfStruct)
		{
			_props = new ArrayList();
			_sizeOfStruct = sizeOfStruct;
		}
		
		/// <summary> Constructor
		/// 
		/// </summary>
		/// <param name="size">The size in bytes of this PlexOfCps
		/// </param>
		/// <param name="sizeOfStruct">The size of the data structure type stored in
		/// this PlexOfCps.
		/// </param>
		public PlexOfCps(byte[] buf, int start, int size, int sizeOfStruct)
		{
			_count = (size - 4) / (4 + sizeOfStruct);
			_sizeOfStruct = sizeOfStruct;
			_props = new ArrayList(_count);
			
			for (int x = 0; x < _count; x++)
			{
				_props.Add(GetProperty(x, buf, start));
			}
		}
		
		public virtual GenericPropertyNode GetProperty(int index)
		{
			return (GenericPropertyNode) _props[index];
		}
		
		public virtual void AddProperty(GenericPropertyNode node)
		{
			_props.Add(node);
		}
		
		public virtual byte[] ToByteArray()
		{
			int size = _props.Count;
			int cpBufSize = ((size + 1) * LittleEndian.INT_SIZE);
			int structBufSize = + (_sizeOfStruct * size);
			int bufSize = cpBufSize + structBufSize;
			
			byte[] buf = new byte[bufSize];
			
			GenericPropertyNode node = null;
			for (int x = 0; x < size; x++)
			{
				node = (GenericPropertyNode) _props[x];
				
				// put the starting offset of the property into the plcf.
				LittleEndian.PutInt(buf, (LittleEndian.INT_SIZE * x), node.Start);
				
				// put the struct into the plcf
				Array.Copy(node.Bytes, 0, buf, cpBufSize + (x * _sizeOfStruct), _sizeOfStruct);
			}
			// put the ending offset of the last property into the plcf.
			LittleEndian.PutInt(buf, LittleEndian.INT_SIZE * size, node.End);
			
			return buf;
		}
		
		private GenericPropertyNode GetProperty(int index, byte[] buf, int offset)
		{
			int start = LittleEndian.GetInt(buf, offset + GetIntOffset(index));
			int end = LittleEndian.GetInt(buf, offset + GetIntOffset(index + 1));
			
			byte[] _struct = new byte[_sizeOfStruct];
			Array.Copy(buf, offset + GetStructOffset(index), _struct, 0, _sizeOfStruct);
			
			return new GenericPropertyNode(start, end, _struct);
		}
		
		private int GetIntOffset(int index)
		{
			return index * 4;
		}
		
		/// <summary> returns the number of data structures in this PlexOfCps.
		/// 
		/// </summary>
		/// <returns> The number of data structures in this PlexOfCps
		/// </returns>
		public virtual int Length {
			get { return _count; }
		}
		
		/// <summary> Returns the offset, in bytes, from the beginning if this PlexOfCps to
		/// the data structure at index.
		/// 
		/// </summary>
		/// <param name="index">The index of the data structure.
		/// 
		/// </param>
		/// <returns> The offset, in bytes, from the beginning if this PlexOfCps to
		/// the data structure at index.
		/// </returns>
		private int GetStructOffset(int index)
		{
			return (4 * (_count + 1)) + (_sizeOfStruct * index);
		}
	}
}