// 
// CHPAbstractType.cs
//  
// Copyright 2002-2004  Apache Software Foundation
//
// Jakarta Poi Authors:
//   S. Ryan Ackley
//
// Poi.Net Authors:
//   Johannes Roith(johannes at jroith dot de)
//  
// 
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

using System;

using Poi.Net.Util;
using Poi.Net.HWPF.Model;
using Poi.Net.HWPF.UserModel;

namespace Poi.Net.HWPF.Model.Types
{
	
	/// <summary> Character Properties.
	/// NOTE: This source is automatically generated please do not modify this file.  Either subclass or
	/// remove the record in src/records/definitions.
	/// </summary>
	public abstract class CHPAbstractType : HDFType
	{
		
		protected internal short field_1_chse;
		protected internal int field_2_format_flags;
		private static BitField fBold = new BitField(0x0001);
		private static BitField fItalic = new BitField(0x0002);
		private static BitField fRMarkDel = new BitField(0x0004);
		private static BitField fOutline = new BitField(0x0008);
		private static BitField fFldVanish = new BitField(0x0010);
		private static BitField fSmallCaps = new BitField(0x0020);
		private static BitField fCaps = new BitField(0x0040);
		private static BitField fVanish = new BitField(0x0080);
		private static BitField fRMark = new BitField(0x0100);
		private static BitField fSpec = new BitField(0x0200);
		private static BitField fStrike = new BitField(0x0400);
		private static BitField fObj = new BitField(0x0800);
		private static BitField fShadow = new BitField(0x1000);
		private static BitField fLowerCase = new BitField(0x2000);
		private static BitField fData = new BitField(0x4000);
		private static BitField fOle2 = new BitField(0x8000);
		protected internal int field_3_format_flags1;
		private static BitField fEmboss = new BitField(0x0001);
		private static BitField fImprint = new BitField(0x0002);
		private static BitField fDStrike = new BitField(0x0004);
		private static BitField fUsePgsuSettings = new BitField(0x0008);
		protected internal int field_4_ftcAscii;
		protected internal int field_5_ftcFE;
		protected internal int field_6_ftcOther;
		protected internal int field_7_hps;
		protected internal int field_8_dxaSpace;
		protected internal byte field_9_iss;
		protected internal byte field_10_kul;
		protected internal byte field_11_ico;
		protected internal int field_12_hpsPos;
		protected internal int field_13_lidDefault;
		protected internal int field_14_lidFE;
		protected internal byte field_15_idctHint;
		protected internal int field_16_wCharScale;
		protected internal int field_17_fcPic;
		protected internal int field_18_fcObj;
		protected internal int field_19_lTagObj;
		protected internal int field_20_ibstRMark;
		protected internal int field_21_ibstRMarkDel;
		protected internal DateAndTime field_22_dttmRMark;
		protected internal DateAndTime field_23_dttmRMarkDel;
		protected internal int field_24_istd;
		protected internal int field_25_baseIstd;
		protected internal int field_26_ftcSym;
		protected internal int field_27_xchSym;
		protected internal int field_28_idslRMReason;
		protected internal int field_29_idslReasonDel;
		protected internal byte field_30_ysr;
		protected internal byte field_31_chYsr;
		protected internal int field_32_hpsKern;
		protected internal short field_33_Highlight;
		private static BitField icoHighlight = new BitField(0x001f);
		private static BitField fHighlight = new BitField(0x0020);
		private static BitField kcd = new BitField(0x01c0);
		private static BitField fNavHighlight = new BitField(0x0200);
		private static BitField fChsDiff = new BitField(0x0400);
		private static BitField fMacChs = new BitField(0x0800);
		private static BitField fFtcAsciSym = new BitField(0x1000);
		protected internal short field_34_fPropMark;
		protected internal int field_35_ibstPropRMark;
		protected internal DateAndTime field_36_dttmPropRMark;
		protected internal byte field_37_sfxtText;
		protected internal byte field_38_fDispFldRMark;
		protected internal int field_39_ibstDispFldRMark;
		protected internal DateAndTime field_40_dttmDispFldRMark;
		protected internal byte[] field_41_xstDispFldRMark;
		protected internal ShadingDescriptor field_42_shd;
		protected internal BorderCode field_43_brc;
		

		/// <summary> Size of record (exluding 4 byte header)</summary>
		virtual public int Size 
		{
			get {
				return 4 + + 2 + 2 + 2 + 2 + 2 + 2 + 2 + 4 + 1 + 1 + 1 + 2 + 2 + 2 + 1 + 2 + 4 + 4 + 4 + 2 + 2 + 4 + 4 + 2 + 2 + 2 + 2 + 2 + 2 + 1 + 1 + 2 + 2 + 2 + 2 + 4 + 1 + 1 + 2 + 4 + 32 + 2 + 4;
			}
			
		}
		
		/// <summary> Get the chse field for the CHP record.</summary>
		/// <summary> Set the chse field for the CHP record.</summary>
		virtual public short Chse {
			get {
				return field_1_chse;
			}
			
			set {
				this.field_1_chse = value;
			}
			
		}
		
		/// <summary> Get the format_flags field for the CHP record.</summary>
		/// <summary> Set the format_flags field for the CHP record.</summary>
		virtual public int Format_flags {
			get {
				return field_2_format_flags;
			}
			
			set {
				this.field_2_format_flags = value;
			}
			
		}
		
		/// <summary> Get the format_flags1 field for the CHP record.</summary>
		/// <summary> Set the format_flags1 field for the CHP record.</summary>
		virtual public int Format_flags1 {
			get {
				return field_3_format_flags1;
			}
			
			set {
				this.field_3_format_flags1 = value;
			}
			
		}
		
		/// <summary> Get the ftcAscii field for the CHP record.</summary>
		/// <summary> Set the ftcAscii field for the CHP record.</summary>
		virtual public int FtcAscii {
			get {
				return field_4_ftcAscii;
			}
			
			set {
				this.field_4_ftcAscii = value;
			}
			
		}
		
		/// <summary> Get the ftcFE field for the CHP record.</summary>
		/// <summary> Set the ftcFE field for the CHP record.</summary>
		virtual public int FtcFE {
			get {
				return field_5_ftcFE;
			}
			
			set {
				this.field_5_ftcFE = value;
			}
			
		}
		
		/// <summary> Get the ftcOther field for the CHP record.</summary>
		/// <summary> Set the ftcOther field for the CHP record.</summary>
		virtual public int FtcOther {
			get {
				return field_6_ftcOther;
			}
			
			set {
				this.field_6_ftcOther = value;
			}
			
		}
		
		/// <summary> Get the hps field for the CHP record.</summary>
		/// <summary> Set the hps field for the CHP record.</summary>
		virtual public int Hps {
			get {
				return field_7_hps;
			}
			
			set {
				this.field_7_hps = value;
			}
			
		}
		
		/// <summary> Get the dxaSpace field for the CHP record.</summary>
		/// <summary> Set the dxaSpace field for the CHP record.</summary>
		virtual public int DxaSpace {
			get {
				return field_8_dxaSpace;
			}
			
			set {
				this.field_8_dxaSpace = value;
			}
			
		}
		
		/// <summary> Get the iss field for the CHP record.</summary>
		/// <summary> Set the iss field for the CHP record.</summary>
		virtual public byte Iss {
			get {
				return field_9_iss;
			}
			
			set {
				this.field_9_iss = value;
			}
			
		}
		
		/// <summary> Get the kul field for the CHP record.</summary>
		/// <summary> Set the kul field for the CHP record.</summary>
		virtual public byte Kul {
			get {
				return field_10_kul;
			}
			
			set {
				this.field_10_kul = value;
			}
			
		}
		
		/// <summary> Get the ico field for the CHP record.</summary>
		/// <summary> Set the ico field for the CHP record.</summary>
		virtual public byte Ico {
			get {
				return field_11_ico;
			}
			
			set {
				this.field_11_ico = value;
			}
			
		}
		
		/// <summary> Get the hpsPos field for the CHP record.</summary>
		/// <summary> Set the hpsPos field for the CHP record.</summary>
		virtual public int HpsPos {
			get {
				return field_12_hpsPos;
			}
			
			set {
				this.field_12_hpsPos = value;
			}
			
		}
		
		/// <summary> Get the lidDefault field for the CHP record.</summary>
		/// <summary> Set the lidDefault field for the CHP record.</summary>
		virtual public int LidDefault {
			get {
				return field_13_lidDefault;
			}
			
			set {
				this.field_13_lidDefault = value;
			}
			
		}
		
		/// <summary> Get the lidFE field for the CHP record.</summary>
		/// <summary> Set the lidFE field for the CHP record.</summary>
		virtual public int LidFE {
			get {
				return field_14_lidFE;
			}
			
			set {
				this.field_14_lidFE = value;
			}
			
		}
		
		/// <summary> Get the idctHint field for the CHP record.</summary>
		/// <summary> Set the idctHint field for the CHP record.</summary>
		virtual public byte IdctHint {
			get {
				return field_15_idctHint;
			}
			
			set {
				this.field_15_idctHint = value;
			}
			
		}
		
		/// <summary> Get the wCharScale field for the CHP record.</summary>
		/// <summary> Set the wCharScale field for the CHP record.</summary>
		virtual public int WCharScale {
			get {
				return field_16_wCharScale;
			}
			
			set {
				this.field_16_wCharScale = value;
			}
			
		}
		
		/// <summary> Get the fcPic field for the CHP record.</summary>
		/// <summary> Set the fcPic field for the CHP record.</summary>
		virtual public int FcPic {
			get {
				return field_17_fcPic;
			}
			
			set {
				this.field_17_fcPic = value;
			}
			
		}
		
		/// <summary> Get the fcObj field for the CHP record.</summary>
		/// <summary> Set the fcObj field for the CHP record.</summary>
		virtual public int FcObj {
			get {
				return field_18_fcObj;
			}
			
			set {
				this.field_18_fcObj = value;
			}
			
		}
		
		/// <summary> Get the lTagObj field for the CHP record.</summary>
		/// <summary> Set the lTagObj field for the CHP record.</summary>
		virtual public int LTagObj {
			get {
				return field_19_lTagObj;
			}
			
			set {
				this.field_19_lTagObj = value;
			}
			
		}
		
		/// <summary> Get the ibstRMark field for the CHP record.</summary>
		/// <summary> Set the ibstRMark field for the CHP record.</summary>
		virtual public int IbstRMark {
			get {
				return field_20_ibstRMark;
			}
			
			set {
				this.field_20_ibstRMark = value;
			}
			
		}
		
		/// <summary> Get the ibstRMarkDel field for the CHP record.</summary>
		/// <summary> Set the ibstRMarkDel field for the CHP record.</summary>
		virtual public int IbstRMarkDel {
			get {
				return field_21_ibstRMarkDel;
			}
			
			set {
				this.field_21_ibstRMarkDel = value;
			}
			
		}
		
		/// <summary> Get the dttmRMark field for the CHP record.</summary>
		/// <summary> Set the dttmRMark field for the CHP record.</summary>
		virtual public DateAndTime DttmRMark {
			get {
				return field_22_dttmRMark;
			}
			
			set {
				this.field_22_dttmRMark = value;
			}
			
		}
		
		/// <summary> Get the dttmRMarkDel field for the CHP record.</summary>
		/// <summary> Set the dttmRMarkDel field for the CHP record.</summary>
		virtual public DateAndTime DttmRMarkDel {
			get {
				return field_23_dttmRMarkDel;
			}
			
			set {
				this.field_23_dttmRMarkDel = value;
			}
			
		}
		
		/// <summary> Get the istd field for the CHP record.</summary>
		/// <summary> Set the istd field for the CHP record.</summary>
		virtual public int Istd {
			get {
				return field_24_istd;
			}
			
			set {
				this.field_24_istd = value;
			}
			
		}
		
		/// <summary> Get the baseIstd field for the CHP record.</summary>
		/// <summary> Set the baseIstd field for the CHP record.</summary>
		virtual public int BaseIstd {
			get {
				return field_25_baseIstd;
			}
			
			set {
				this.field_25_baseIstd = value;
			}
			
		}
		
		/// <summary> Get the ftcSym field for the CHP record.</summary>
		/// <summary> Set the ftcSym field for the CHP record.</summary>
		virtual public int FtcSym {
			get {
				return field_26_ftcSym;
			}
			
			set {
				this.field_26_ftcSym = value;
			}
			
		}
		
		/// <summary> Get the xchSym field for the CHP record.</summary>
		/// <summary> Set the xchSym field for the CHP record.</summary>
		virtual public int XchSym {
			get {
				return field_27_xchSym;
			}
			
			set {
				this.field_27_xchSym = value;
			}
			
		}
		
		/// <summary> Get the idslRMReason field for the CHP record.</summary>
		/// <summary> Set the idslRMReason field for the CHP record.</summary>
		virtual public int IdslRMReason {
			get {
				return field_28_idslRMReason;
			}
			
			set {
				this.field_28_idslRMReason = value;
			}
			
		}
		
		/// <summary> Get the idslReasonDel field for the CHP record.</summary>
		/// <summary> Set the idslReasonDel field for the CHP record.</summary>
		virtual public int IdslReasonDel {
			get {
				return field_29_idslReasonDel;
			}
			
			set {
				this.field_29_idslReasonDel = value;
			}
			
		}
		
		/// <summary> Get the ysr field for the CHP record.</summary>
		/// <summary> Set the ysr field for the CHP record.</summary>
		virtual public byte Ysr {
			get {
				return field_30_ysr;
			}
			
			set {
				this.field_30_ysr = value;
			}
			
		}
		
		/// <summary> Get the chYsr field for the CHP record.</summary>
		/// <summary> Set the chYsr field for the CHP record.</summary>
		virtual public byte ChYsr {
			get {
				return field_31_chYsr;
			}
			
			set {
				this.field_31_chYsr = value;
			}
			
		}
		
		/// <summary> Get the hpsKern field for the CHP record.</summary>
		/// <summary> Set the hpsKern field for the CHP record.</summary>
		virtual public int HpsKern {
			get {
				return field_32_hpsKern;
			}
			
			set {
				this.field_32_hpsKern = value;
			}
			
		}
		
		/// <summary> Get the Highlight field for the CHP record.</summary>
		/// <summary> Set the Highlight field for the CHP record.</summary>
		virtual public short Highlight {
			get {
				return field_33_Highlight;
			}
			
			set {
				this.field_33_Highlight = value;
			}
			
		}
		
		/// <summary> Get the fPropMark field for the CHP record.</summary>
		/// <summary> Set the fPropMark field for the CHP record.</summary>
		virtual public short FPropMark {
			get {
				return field_34_fPropMark;
			}
			
			set {
				this.field_34_fPropMark = value;
			}
			
		}
		
		/// <summary> Get the ibstPropRMark field for the CHP record.</summary>
		/// <summary> Set the ibstPropRMark field for the CHP record.</summary>
		virtual public int IbstPropRMark {
			get {
				return field_35_ibstPropRMark;
			}
			
			set {
				this.field_35_ibstPropRMark = value;
			}
			
		}
		
		/// <summary> Get the dttmPropRMark field for the CHP record.</summary>
		/// <summary> Set the dttmPropRMark field for the CHP record.</summary>
		virtual public DateAndTime DttmPropRMark {
			get {
				return field_36_dttmPropRMark;
			}
			
			set {
				this.field_36_dttmPropRMark = value;
			}
			
		}
		
		/// <summary> Get the sfxtText field for the CHP record.</summary>
		/// <summary> Set the sfxtText field for the CHP record.</summary>
		virtual public byte SfxtText {
			get {
				return field_37_sfxtText;
			}
			
			set {
				this.field_37_sfxtText = value;
			}
			
		}
		
		/// <summary> Get the fDispFldRMark field for the CHP record.</summary>
		/// <summary> Set the fDispFldRMark field for the CHP record.</summary>
		virtual public byte FDispFldRMark {
			get {
				return field_38_fDispFldRMark;
			}
			
			set {
				this.field_38_fDispFldRMark = value;
			}
			
		}
		
		/// <summary> Get the ibstDispFldRMark field for the CHP record.</summary>
		/// <summary> Set the ibstDispFldRMark field for the CHP record.</summary>
		virtual public int IbstDispFldRMark {
			get {
				return field_39_ibstDispFldRMark;
			}
			
			set {
				this.field_39_ibstDispFldRMark = value;
			}
			
		}
		
		/// <summary> Get the dttmDispFldRMark field for the CHP record.</summary>
		/// <summary> Set the dttmDispFldRMark field for the CHP record.</summary>
		virtual public DateAndTime DttmDispFldRMark {
			get {
				return field_40_dttmDispFldRMark;
			}
			
			set {
				this.field_40_dttmDispFldRMark = value;
			}
			
		}
		
		/// <summary> Get the xstDispFldRMark field for the CHP record.</summary>
		/// <summary> Set the xstDispFldRMark field for the CHP record.</summary>
		virtual public byte[] XstDispFldRMark {
			get {
				return field_41_xstDispFldRMark;
			}
			
			set {
				this.field_41_xstDispFldRMark = value;
			}
			
		}
		
		/// <summary> Get the shd field for the CHP record.</summary>
		/// <summary> Set the shd field for the CHP record.</summary>
		virtual public ShadingDescriptor Shd {
			get {
				return field_42_shd;
			}
			
			set {
				this.field_42_shd = value;
			}
			
		}
		
		/// <summary> Get the brc field for the CHP record.</summary>
		/// <summary> Set the brc field for the CHP record.</summary>
		virtual public BorderCode Brc {
			get {
				return field_43_brc;
			}
			
			set {
				this.field_43_brc = value;
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fBold field value.
		/// </returns>
		/// <summary> Sets the fBold field value.
		/// 
		/// </summary>
		virtual public bool FBold {
			get {
				return fBold.IsSet(field_2_format_flags);
			}
			
			set {
				field_2_format_flags = (int) fBold.SetBoolean(field_2_format_flags, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fItalic field value.
		/// </returns>
		/// <summary> Sets the fItalic field value.
		/// 
		/// </summary>
		virtual public bool FItalic {
			get {
				return fItalic.IsSet(field_2_format_flags);
			}
			
			set {
				field_2_format_flags = (int) fItalic.SetBoolean(field_2_format_flags, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fRMarkDel field value.
		/// </returns>
		/// <summary> Sets the fRMarkDel field value.
		/// 
		/// </summary>
		virtual public bool FRMarkDel {
			get {
				return fRMarkDel.IsSet(field_2_format_flags);
			}
			
			set {
				field_2_format_flags = (int) fRMarkDel.SetBoolean(field_2_format_flags, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fOutline field value.
		/// </returns>
		/// <summary> Sets the fOutline field value.
		/// 
		/// </summary>
		virtual public bool FOutline {
			get {
				return fOutline.IsSet(field_2_format_flags);
			}
			
			set {
				field_2_format_flags = (int) fOutline.SetBoolean(field_2_format_flags, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fFldVanish field value.
		/// </returns>
		/// <summary> Sets the fFldVanish field value.
		/// 
		/// </summary>
		virtual public bool FFldVanish {
			get {
				return fFldVanish.IsSet(field_2_format_flags);
			}
			
			set {
				field_2_format_flags = (int) fFldVanish.SetBoolean(field_2_format_flags, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fSmallCaps field value.
		/// </returns>
		/// <summary> Sets the fSmallCaps field value.
		/// 
		/// </summary>
		virtual public bool FSmallCaps {
			get {
				return fSmallCaps.IsSet(field_2_format_flags);
			}
			
			set {
				field_2_format_flags = (int) fSmallCaps.SetBoolean(field_2_format_flags, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fCaps field value.
		/// </returns>
		/// <summary> Sets the fCaps field value.
		/// 
		/// </summary>
		virtual public bool FCaps {
			get {
				return fCaps.IsSet(field_2_format_flags);
			}
			
			set {
				field_2_format_flags = (int) fCaps.SetBoolean(field_2_format_flags, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fVanish field value.
		/// </returns>
		/// <summary> Sets the fVanish field value.
		/// 
		/// </summary>
		virtual public bool FVanish {
			get {
				return fVanish.IsSet(field_2_format_flags);
			}
			
			set {
				field_2_format_flags = (int) fVanish.SetBoolean(field_2_format_flags, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fRMark field value.
		/// </returns>
		/// <summary> Sets the fRMark field value.
		/// 
		/// </summary>
		virtual public bool FRMark {
			get {
				return fRMark.IsSet(field_2_format_flags);
			}
			
			set {
				field_2_format_flags = (int) fRMark.SetBoolean(field_2_format_flags, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fSpec field value.
		/// </returns>
		/// <summary> Sets the fSpec field value.
		/// 
		/// </summary>
		virtual public bool FSpec {
			get {
				return fSpec.IsSet(field_2_format_flags);
			}
			
			set {
				field_2_format_flags = (int) fSpec.SetBoolean(field_2_format_flags, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fStrike field value.
		/// </returns>
		/// <summary> Sets the fStrike field value.
		/// 
		/// </summary>
		virtual public bool FStrike {
			get {
				return fStrike.IsSet(field_2_format_flags);
			}
			
			set {
				field_2_format_flags = (int) fStrike.SetBoolean(field_2_format_flags, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fObj field value.
		/// </returns>
		/// <summary> Sets the fObj field value.
		/// 
		/// </summary>
		virtual public bool FObj {
			get {
				return fObj.IsSet(field_2_format_flags);
			}
			
			set {
				field_2_format_flags = (int) fObj.SetBoolean(field_2_format_flags, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fShadow field value.
		/// </returns>
		/// <summary> Sets the fShadow field value.
		/// 
		/// </summary>
		virtual public bool FShadow {
			get {
				return fShadow.IsSet(field_2_format_flags);
			}
			
			set {
				field_2_format_flags = (int) fShadow.SetBoolean(field_2_format_flags, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fLowerCase field value.
		/// </returns>
		/// <summary> Sets the fLowerCase field value.
		/// 
		/// </summary>
		virtual public bool FLowerCase {
			get {
				return fLowerCase.IsSet(field_2_format_flags);
			}
			
			set {
				field_2_format_flags = (int) fLowerCase.SetBoolean(field_2_format_flags, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fData field value.
		/// </returns>
		/// <summary> Sets the fData field value.
		/// 
		/// </summary>
		virtual public bool FData {
			get {
				return fData.IsSet(field_2_format_flags);
			}
			
			set {
				field_2_format_flags = (int) fData.SetBoolean(field_2_format_flags, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fOle2 field value.
		/// </returns>
		/// <summary> Sets the fOle2 field value.
		/// 
		/// </summary>
		virtual public bool FOle2 {
			get {
				return fOle2.IsSet(field_2_format_flags);
			}
			
			set {
				field_2_format_flags = (int) fOle2.SetBoolean(field_2_format_flags, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fEmboss field value.
		/// </returns>
		/// <summary> Sets the fEmboss field value.
		/// 
		/// </summary>
		virtual public bool FEmboss {
			get {
				return fEmboss.IsSet(field_3_format_flags1);
			}
			
			set {
				field_3_format_flags1 = (int) fEmboss.SetBoolean(field_3_format_flags1, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fImprint field value.
		/// </returns>
		/// <summary> Sets the fImprint field value.
		/// 
		/// </summary>
		virtual public bool FImprint {
			get {
				return fImprint.IsSet(field_3_format_flags1);
			}
			
			set {
				field_3_format_flags1 = (int) fImprint.SetBoolean(field_3_format_flags1, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fDStrike field value.
		/// </returns>
		/// <summary> Sets the fDStrike field value.
		/// 
		/// </summary>
		virtual public bool FDStrike {
			get {
				return fDStrike.IsSet(field_3_format_flags1);
			}
			
			set {
				field_3_format_flags1 = (int) fDStrike.SetBoolean(field_3_format_flags1, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fUsePgsuSettings field value.
		/// </returns>
		/// <summary> Sets the fUsePgsuSettings field value.
		/// 
		/// </summary>
		virtual public bool FUsePgsuSettings {
			get {
				return fUsePgsuSettings.IsSet(field_3_format_flags1);
			}
			
			set {
				field_3_format_flags1 = (int) fUsePgsuSettings.SetBoolean(field_3_format_flags1, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the icoHighlight field value.
		/// </returns>
		/// <summary> Sets the icoHighlight field value.
		/// 
		/// </summary>
		virtual public byte IcoHighlight {
			get {
				return (byte) icoHighlight.GetValue(field_33_Highlight);
			}
			
			set {
				field_33_Highlight = (short) icoHighlight.SetValue(field_33_Highlight, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fHighlight field value.
		/// </returns>
		/// <summary> Sets the fHighlight field value.
		/// 
		/// </summary>
		virtual public bool FHighlight {
			get {
				return fHighlight.IsSet(field_33_Highlight);
			}
			
			set {
				field_33_Highlight = (short) fHighlight.SetBoolean(field_33_Highlight, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the kcd field value.
		/// </returns>
		/// <summary> Sets the kcd field value.
		/// 
		/// </summary>
		virtual public byte Kcd {
			get {
				return (byte) kcd.GetValue(field_33_Highlight);
			}
			
			set {
				field_33_Highlight = (short) kcd.SetValue(field_33_Highlight, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fNavHighlight field value.
		/// </returns>
		/// <summary> Sets the fNavHighlight field value.
		/// 
		/// </summary>
		virtual public bool FNavHighlight {
			get {
				return fNavHighlight.IsSet(field_33_Highlight);
			}
			
			set {
				field_33_Highlight = (short) fNavHighlight.SetBoolean(field_33_Highlight, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fChsDiff field value.
		/// </returns>
		/// <summary> Sets the fChsDiff field value.
		/// 
		/// </summary>
		virtual public bool FChsDiff {
			get {
				return fChsDiff.IsSet(field_33_Highlight);
			}
			
			set {
				field_33_Highlight = (short) fChsDiff.SetBoolean(field_33_Highlight, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fMacChs field value.
		/// </returns>
		/// <summary> Sets the fMacChs field value.
		/// 
		/// </summary>
		virtual public bool FMacChs {
			get {
				return fMacChs.IsSet(field_33_Highlight);
			}
			
			set {
				field_33_Highlight = (short) fMacChs.SetBoolean(field_33_Highlight, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fFtcAsciSym field value.
		/// </returns>
		/// <summary> Sets the fFtcAsciSym field value.
		/// 
		/// </summary>
		virtual public bool FFtcAsciSym {
			get { return fFtcAsciSym.IsSet(field_33_Highlight); }
			
			set { field_33_Highlight = (short) fFtcAsciSym.SetBoolean(field_33_Highlight, value); }
			
		}
		
		public CHPAbstractType()
		{
		}

		
		public virtual object Clone() {
			return this.MemberwiseClone();
		}
	} 
}