// 
// DOPAbstractType.cs
//  
// Copyright 2002-2004  Apache Software Foundation
//
// Jakarta Poi Authors:
//   S. Ryan Ackley
//
// Poi.Net Authors:
//   Johannes Roith(johannes at jroith dot de)
//  
// 
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

using System;

using Poi.Net.Util;
using Poi.Net.HWPF.Model;
using Poi.Net.HWPF.UserModel;

namespace Poi.Net.HWPF.Model.Types
{
	
	/// <summary> Document Properties.
	/// NOTE: This source is automatically generated please do not modify this file.  Either subclass or
	/// remove the record in src/records/definitions.
	/// </summary>

	public abstract class DOPAbstractType : HDFType
	{
		
		protected internal byte field_1_formatFlags;
		private static BitField fFacingPages = new BitField(0x01);
		private static BitField fWidowControl = new BitField(0x02);
		private static BitField fPMHMainDoc = new BitField(0x04);
		private static BitField grfSupression = new BitField(0x18);
		private static BitField fpc = new BitField(0x60);
		private static BitField unused1 = new BitField(0x80);
		protected internal byte field_2_unused2;
		protected internal short field_3_footnoteInfo;
		private static BitField rncFtn = new BitField(0x0003);
		private static BitField nFtn = new BitField(0xfffc);
		protected internal byte field_4_fOutlineDirtySave;
		protected internal byte field_5_docinfo;
		private static BitField fOnlyMacPics = new BitField(0x01);
		private static BitField fOnlyWinPics = new BitField(0x02);
		private static BitField fLabelDoc = new BitField(0x04);
		private static BitField fHyphCapitals = new BitField(0x08);
		private static BitField fAutoHyphen = new BitField(0x10);
		private static BitField fFormNoFields = new BitField(0x20);
		private static BitField fLinkStyles = new BitField(0x40);
		private static BitField fRevMarking = new BitField(0x80);
		protected internal byte field_6_docinfo1;
		private static BitField fBackup = new BitField(0x01);
		private static BitField fExactCWords = new BitField(0x02);
		private static BitField fPagHidden = new BitField(0x04);
		private static BitField fPagResults = new BitField(0x08);
		private static BitField fLockAtn = new BitField(0x10);
		private static BitField fMirrorMargins = new BitField(0x20);
		private static BitField unused3 = new BitField(0x40);
		private static BitField fDfltTrueType = new BitField(0x80);
		protected internal byte field_7_docinfo2;
		private static BitField fPagSupressTopSpacing = new BitField(0x01);
		private static BitField fProtEnabled = new BitField(0x02);
		private static BitField fDispFormFldSel = new BitField(0x04);
		private static BitField fRMView = new BitField(0x08);
		private static BitField fRMPrint = new BitField(0x10);
		private static BitField unused4 = new BitField(0x20);
		private static BitField fLockRev = new BitField(0x40);
		private static BitField fEmbedFonts = new BitField(0x80);
		protected internal short field_8_docinfo3;
		private static BitField oldfNoTabForInd = new BitField(0x0001);
		private static BitField oldfNoSpaceRaiseLower = new BitField(0x0002);
		private static BitField oldfSuppressSpbfAfterPageBreak = new BitField(0x0004);
		private static BitField oldfWrapTrailSpaces = new BitField(0x0008);
		private static BitField oldfMapPrintTextColor = new BitField(0x0010);
		private static BitField oldfNoColumnBalance = new BitField(0x0020);
		private static BitField oldfConvMailMergeEsc = new BitField(0x0040);
		private static BitField oldfSupressTopSpacing = new BitField(0x0080);
		private static BitField oldfOrigWordTableRules = new BitField(0x0100);
		private static BitField oldfTransparentMetafiles = new BitField(0x0200);
		private static BitField oldfShowBreaksInFrames = new BitField(0x0400);
		private static BitField oldfSwapBordersFacingPgs = new BitField(0x0800);
		private static BitField unused5 = new BitField(0xf000);
		protected internal int field_9_dxaTab;
		protected internal int field_10_wSpare;
		protected internal int field_11_dxaHotz;
		protected internal int field_12_cConsexHypLim;
		protected internal int field_13_wSpare2;
		protected internal int field_14_dttmCreated;
		protected internal int field_15_dttmRevised;
		protected internal int field_16_dttmLastPrint;
		protected internal int field_17_nRevision;
		protected internal int field_18_tmEdited;
		protected internal int field_19_cWords;
		protected internal int field_20_cCh;
		protected internal int field_21_cPg;
		protected internal int field_22_cParas;
		protected internal short field_23_Edn;
		private static BitField rncEdn = new BitField(0x0003);
		private static BitField nEdn = new BitField(0xfffc);
		protected internal short field_24_Edn1;
		private static BitField epc = new BitField(0x0003);
		private static BitField nfcFtnRef1 = new BitField(0x003c);
		private static BitField nfcEdnRef1 = new BitField(0x03c0);
		private static BitField fPrintFormData = new BitField(0x0400);
		private static BitField fSaveFormData = new BitField(0x0800);
		private static BitField fShadeFormData = new BitField(0x1000);
		private static BitField fWCFtnEdn = new BitField(0x8000);
		protected internal int field_25_cLines;
		protected internal int field_26_cWordsFtnEnd;
		protected internal int field_27_cChFtnEdn;
		protected internal short field_28_cPgFtnEdn;
		protected internal int field_29_cParasFtnEdn;
		protected internal int field_30_cLinesFtnEdn;
		protected internal int field_31_lKeyProtDoc;
		protected internal short field_32_view;
		private static BitField wvkSaved = new BitField(0x0007);
		private static BitField wScaleSaved = new BitField(0x0ff8);
		private static BitField zkSaved = new BitField(0x3000);
		private static BitField fRotateFontW6 = new BitField(0x4000);
		private static BitField iGutterPos = new BitField(0x8000);
		protected internal int field_33_docinfo4;
		private static BitField fNoTabForInd = new BitField(0x00000001);
		private static BitField fNoSpaceRaiseLower = new BitField(0x00000002);
		private static BitField fSupressSpdfAfterPageBreak = new BitField(0x00000004);
		private static BitField fWrapTrailSpaces = new BitField(0x00000008);
		private static BitField fMapPrintTextColor = new BitField(0x00000010);
		private static BitField fNoColumnBalance = new BitField(0x00000020);
		private static BitField fConvMailMergeEsc = new BitField(0x00000040);
		private static BitField fSupressTopSpacing = new BitField(0x00000080);
		private static BitField fOrigWordTableRules = new BitField(0x00000100);
		private static BitField fTransparentMetafiles = new BitField(0x00000200);
		private static BitField fShowBreaksInFrames = new BitField(0x00000400);
		private static BitField fSwapBordersFacingPgs = new BitField(0x00000800);
		private static BitField fSuppressTopSPacingMac5 = new BitField(0x00010000);
		private static BitField fTruncDxaExpand = new BitField(0x00020000);
		private static BitField fPrintBodyBeforeHdr = new BitField(0x00040000);
		private static BitField fNoLeading = new BitField(0x00080000);
		private static BitField fMWSmallCaps = new BitField(0x00200000);
		protected internal short field_34_adt;
		protected internal byte[] field_35_doptypography;
		protected internal byte[] field_36_dogrid;
		protected internal short field_37_docinfo5;
		private static BitField lvl = new BitField(0x001e);
		private static BitField fGramAllDone = new BitField(0x0020);
		private static BitField fGramAllClean = new BitField(0x0040);
		private static BitField fSubsetFonts = new BitField(0x0080);
		private static BitField fHideLastVersion = new BitField(0x0100);
		private static BitField fHtmlDoc = new BitField(0x0200);
		private static BitField fSnapBorder = new BitField(0x0800);
		private static BitField fIncludeHeader = new BitField(0x1000);
		private static BitField fIncludeFooter = new BitField(0x2000);
		private static BitField fForcePageSizePag = new BitField(0x4000);
		private static BitField fMinFontSizePag = new BitField(0x8000);
		protected internal short field_38_docinfo6;
		private static BitField fHaveVersions = new BitField(0x0001);
		private static BitField fAutoVersions = new BitField(0x0002);
		protected internal byte[] field_39_asumyi;
		protected internal int field_40_cChWS;
		protected internal int field_41_cChWSFtnEdn;
		protected internal int field_42_grfDocEvents;
		protected internal int field_43_virusinfo;
		private static BitField fVirusPrompted = new BitField(0x0001);
		private static BitField fVirusLoadSafe = new BitField(0x0002);
		//	private static BitField KeyVirusSession30 = new BitField(0xfffffffc);
		protected internal byte[] field_44_Spare;
		protected internal int field_45_reserved1;
		protected internal int field_46_reserved2;
		protected internal int field_47_cDBC;
		protected internal int field_48_cDBCFtnEdn;
		protected internal int field_49_reserved;
		protected internal short field_50_nfcFtnRef;
		protected internal short field_51_nfcEdnRef;
		protected internal short field_52_hpsZoonFontPag;
		protected internal short field_53_dywDispPag;
		
		/// <summary> Size of record (exluding 4 byte header)</summary>
		virtual public int Size 
		{
			get {
				return 4 + + 1 + 1 + 2 + 1 + 1 + 1 + 1 + 2 + 2 + 2 + 2 + 2 + 2 + 4 + 4 + 4 + 2 + 4 + 4 + 4 + 2 + 4 + 2 + 2 + 4 + 4 + 4 + 2 + 4 + 4 + 4 + 2 + 4 + 2 + 310 + 10 + 2 + 2 + 12 + 4 + 4 + 4 + 4 + 30 + 4 + 4 + 4 + 4 + 4 + 2 + 2 + 2 + 2;
			}
			
		}
		
		/// <summary> Get the formatFlags field for the DOP record.</summary>
		/// <summary> Set the formatFlags field for the DOP record.</summary>
		virtual public byte FormatFlags {
			get {
				return field_1_formatFlags;
			}
			
			set {
				this.field_1_formatFlags = value;
			}
			
		}
		
		/// <summary> Get the unused2 field for the DOP record.</summary>
		/// <summary> Set the unused2 field for the DOP record.</summary>
		virtual public byte Unused2 {
			get {
				return field_2_unused2;
			}
			
			set {
				this.field_2_unused2 = value;
			}
			
		}
		
		/// <summary> Get the footnoteInfo field for the DOP record.</summary>
		/// <summary> Set the footnoteInfo field for the DOP record.</summary>
		virtual public short FootnoteInfo {
			get {
				return field_3_footnoteInfo;
			}
			
			set {
				this.field_3_footnoteInfo = value;
			}
			
		}
		
		/// <summary> Get the fOutlineDirtySave field for the DOP record.</summary>
		/// <summary> Set the fOutlineDirtySave field for the DOP record.</summary>
		virtual public byte FOutlineDirtySave {
			get {
				return field_4_fOutlineDirtySave;
			}
			
			set {
				this.field_4_fOutlineDirtySave = value;
			}
			
		}
		
		/// <summary> Get the docinfo field for the DOP record.</summary>
		/// <summary> Set the docinfo field for the DOP record.</summary>
		virtual public byte Docinfo {
			get {
				return field_5_docinfo;
			}
			
			set {
				this.field_5_docinfo = value;
			}
			
		}
		
		/// <summary> Get the docinfo1 field for the DOP record.</summary>
		/// <summary> Set the docinfo1 field for the DOP record.</summary>
		virtual public byte Docinfo1 {
			get {
				return field_6_docinfo1;
			}
			
			set {
				this.field_6_docinfo1 = value;
			}
			
		}
		
		/// <summary> Get the docinfo2 field for the DOP record.</summary>
		/// <summary> Set the docinfo2 field for the DOP record.</summary>
		virtual public byte Docinfo2 {
			get {
				return field_7_docinfo2;
			}
			
			set {
				this.field_7_docinfo2 = value;
			}
			
		}
		
		/// <summary> Get the docinfo3 field for the DOP record.</summary>
		/// <summary> Set the docinfo3 field for the DOP record.</summary>
		virtual public short Docinfo3 {
			get {
				return field_8_docinfo3;
			}
			
			set {
				this.field_8_docinfo3 = value;
			}
			
		}
		
		/// <summary> Get the dxaTab field for the DOP record.</summary>
		/// <summary> Set the dxaTab field for the DOP record.</summary>
		virtual public int DxaTab {
			get {
				return field_9_dxaTab;
			}
			
			set {
				this.field_9_dxaTab = value;
			}
			
		}
		
		/// <summary> Get the wSpare field for the DOP record.</summary>
		/// <summary> Set the wSpare field for the DOP record.</summary>
		virtual public int WSpare {
			get {
				return field_10_wSpare;
			}
			
			set {
				this.field_10_wSpare = value;
			}
			
		}
		
		/// <summary> Get the dxaHotz field for the DOP record.</summary>
		/// <summary> Set the dxaHotz field for the DOP record.</summary>
		virtual public int DxaHotz {
			get {
				return field_11_dxaHotz;
			}
			
			set {
				this.field_11_dxaHotz = value;
			}
			
		}
		
		/// <summary> Get the cConsexHypLim field for the DOP record.</summary>
		/// <summary> Set the cConsexHypLim field for the DOP record.</summary>
		virtual public int CConsexHypLim {
			get {
				return field_12_cConsexHypLim;
			}
			
			set {
				this.field_12_cConsexHypLim = value;
			}
			
		}
		
		/// <summary> Get the wSpare2 field for the DOP record.</summary>
		/// <summary> Set the wSpare2 field for the DOP record.</summary>
		virtual public int WSpare2 {
			get {
				return field_13_wSpare2;
			}
			
			set {
				this.field_13_wSpare2 = value;
			}
			
		}
		
		/// <summary> Get the dttmCreated field for the DOP record.</summary>
		/// <summary> Set the dttmCreated field for the DOP record.</summary>
		virtual public int DttmCreated {
			get {
				return field_14_dttmCreated;
			}
			
			set {
				this.field_14_dttmCreated = value;
			}
			
		}
		
		/// <summary> Get the dttmRevised field for the DOP record.</summary>
		/// <summary> Set the dttmRevised field for the DOP record.</summary>
		virtual public int DttmRevised {
			get {
				return field_15_dttmRevised;
			}
			
			set {
				this.field_15_dttmRevised = value;
			}
			
		}
		
		/// <summary> Get the dttmLastPrint field for the DOP record.</summary>
		/// <summary> Set the dttmLastPrint field for the DOP record.</summary>
		virtual public int DttmLastPrint {
			get {
				return field_16_dttmLastPrint;
			}
			
			set {
				this.field_16_dttmLastPrint = value;
			}
			
		}
		
		/// <summary> Get the nRevision field for the DOP record.</summary>
		/// <summary> Set the nRevision field for the DOP record.</summary>
		virtual public int NRevision {
			get {
				return field_17_nRevision;
			}
			
			set {
				this.field_17_nRevision = value;
			}
			
		}
		
		/// <summary> Get the tmEdited field for the DOP record.</summary>
		/// <summary> Set the tmEdited field for the DOP record.</summary>
		virtual public int TmEdited {
			get {
				return field_18_tmEdited;
			}
			
			set {
				this.field_18_tmEdited = value;
			}
			
		}
		
		/// <summary> Get the cWords field for the DOP record.</summary>
		/// <summary> Set the cWords field for the DOP record.</summary>
		virtual public int CWords {
			get {
				return field_19_cWords;
			}
			
			set {
				this.field_19_cWords = value;
			}
			
		}
		
		/// <summary> Get the cCh field for the DOP record.</summary>
		/// <summary> Set the cCh field for the DOP record.</summary>
		virtual public int CCh {
			get {
				return field_20_cCh;
			}
			
			set {
				this.field_20_cCh = value;
			}
			
		}
		
		/// <summary> Get the cPg field for the DOP record.</summary>
		/// <summary> Set the cPg field for the DOP record.</summary>
		virtual public int CPg {
			get {
				return field_21_cPg;
			}
			
			set {
				this.field_21_cPg = value;
			}
			
		}
		
		/// <summary> Get the cParas field for the DOP record.</summary>
		/// <summary> Set the cParas field for the DOP record.</summary>
		virtual public int CParas {
			get {
				return field_22_cParas;
			}
			
			set {
				this.field_22_cParas = value;
			}
			
		}
		
		/// <summary> Get the Edn field for the DOP record.</summary>
		/// <summary> Set the Edn field for the DOP record.</summary>
		virtual public short Edn {
			get {
				return field_23_Edn;
			}
			
			set {
				this.field_23_Edn = value;
			}
			
		}
		
		/// <summary> Get the Edn1 field for the DOP record.</summary>
		/// <summary> Set the Edn1 field for the DOP record.</summary>
		virtual public short Edn1 {
			get {
				return field_24_Edn1;
			}
			
			set {
				this.field_24_Edn1 = value;
			}
			
		}
		
		/// <summary> Get the cLines field for the DOP record.</summary>
		/// <summary> Set the cLines field for the DOP record.</summary>
		virtual public int CLines {
			get {
				return field_25_cLines;
			}
			
			set {
				this.field_25_cLines = value;
			}
			
		}
		
		/// <summary> Get the cWordsFtnEnd field for the DOP record.</summary>
		/// <summary> Set the cWordsFtnEnd field for the DOP record.</summary>
		virtual public int CWordsFtnEnd {
			get {
				return field_26_cWordsFtnEnd;
			}
			
			set {
				this.field_26_cWordsFtnEnd = value;
			}
			
		}
		
		/// <summary> Get the cChFtnEdn field for the DOP record.</summary>
		/// <summary> Set the cChFtnEdn field for the DOP record.</summary>
		virtual public int CChFtnEdn {
			get {
				return field_27_cChFtnEdn;
			}
			
			set {
				this.field_27_cChFtnEdn = value;
			}
			
		}
		
		/// <summary> Get the cPgFtnEdn field for the DOP record.</summary>
		/// <summary> Set the cPgFtnEdn field for the DOP record.</summary>
		virtual public short CPgFtnEdn {
			get {
				return field_28_cPgFtnEdn;
			}
			
			set {
				this.field_28_cPgFtnEdn = value;
			}
			
		}
		
		/// <summary> Get the cParasFtnEdn field for the DOP record.</summary>
		/// <summary> Set the cParasFtnEdn field for the DOP record.</summary>
		virtual public int CParasFtnEdn {
			get {
				return field_29_cParasFtnEdn;
			}
			
			set {
				this.field_29_cParasFtnEdn = value;
			}
			
		}
		
		/// <summary> Get the cLinesFtnEdn field for the DOP record.</summary>
		/// <summary> Set the cLinesFtnEdn field for the DOP record.</summary>
		virtual public int CLinesFtnEdn {
			get {
				return field_30_cLinesFtnEdn;
			}
			
			set {
				this.field_30_cLinesFtnEdn = value;
			}
			
		}
		
		/// <summary> Get the lKeyProtDoc field for the DOP record.</summary>
		/// <summary> Set the lKeyProtDoc field for the DOP record.</summary>
		virtual public int LKeyProtDoc {
			get {
				return field_31_lKeyProtDoc;
			}
			
			set {
				this.field_31_lKeyProtDoc = value;
			}
			
		}
		
		/// <summary> Get the view field for the DOP record.</summary>
		/// <summary> Set the view field for the DOP record.</summary>
		virtual public short View {
			get {
				return field_32_view;
			}
			
			set {
				this.field_32_view = value;
			}
			
		}
		
		/// <summary> Get the docinfo4 field for the DOP record.</summary>
		/// <summary> Set the docinfo4 field for the DOP record.</summary>
		virtual public int Docinfo4 {
			get {
				return field_33_docinfo4;
			}
			
			set {
				this.field_33_docinfo4 = value;
			}
			
		}
		
		/// <summary> Get the adt field for the DOP record.</summary>
		/// <summary> Set the adt field for the DOP record.</summary>
		virtual public short Adt {
			get {
				return field_34_adt;
			}
			
			set {
				this.field_34_adt = value;
			}
			
		}
		
		/// <summary> Get the doptypography field for the DOP record.</summary>
		/// <summary> Set the doptypography field for the DOP record.</summary>
		virtual public byte[] Doptypography {
			get {
				return field_35_doptypography;
			}
			
			set {
				this.field_35_doptypography = value;
			}
			
		}
		
		/// <summary> Get the dogrid field for the DOP record.</summary>
		/// <summary> Set the dogrid field for the DOP record.</summary>
		virtual public byte[] Dogrid {
			get {
				return field_36_dogrid;
			}
			
			set {
				this.field_36_dogrid = value;
			}
			
		}
		
		/// <summary> Get the docinfo5 field for the DOP record.</summary>
		/// <summary> Set the docinfo5 field for the DOP record.</summary>
		virtual public short Docinfo5 {
			get {
				return field_37_docinfo5;
			}
			
			set {
				this.field_37_docinfo5 = value;
			}
			
		}
		
		/// <summary> Get the docinfo6 field for the DOP record.</summary>
		/// <summary> Set the docinfo6 field for the DOP record.</summary>
		virtual public short Docinfo6 {
			get {
				return field_38_docinfo6;
			}
			
			set {
				this.field_38_docinfo6 = value;
			}
			
		}
		
		/// <summary> Get the asumyi field for the DOP record.</summary>
		/// <summary> Set the asumyi field for the DOP record.</summary>
		virtual public byte[] Asumyi {
			get {
				return field_39_asumyi;
			}
			
			set {
				this.field_39_asumyi = value;
			}
			
		}
		
		/// <summary> Get the cChWS field for the DOP record.</summary>
		/// <summary> Set the cChWS field for the DOP record.</summary>
		virtual public int CChWS {
			get {
				return field_40_cChWS;
			}
			
			set {
				this.field_40_cChWS = value;
			}
			
		}
		
		/// <summary> Get the cChWSFtnEdn field for the DOP record.</summary>
		/// <summary> Set the cChWSFtnEdn field for the DOP record.</summary>
		virtual public int CChWSFtnEdn {
			get {
				return field_41_cChWSFtnEdn;
			}
			
			set {
				this.field_41_cChWSFtnEdn = value;
			}
			
		}
		
		/// <summary> Get the grfDocEvents field for the DOP record.</summary>
		/// <summary> Set the grfDocEvents field for the DOP record.</summary>
		virtual public int GrfDocEvents {
			get {
				return field_42_grfDocEvents;
			}
			
			set {
				this.field_42_grfDocEvents = value;
			}
			
		}
		
		/// <summary> Get the virusinfo field for the DOP record.</summary>
		/// <summary> Set the virusinfo field for the DOP record.</summary>
		virtual public int Virusinfo {
			get {
				return field_43_virusinfo;
			}
			
			set {
				this.field_43_virusinfo = value;
			}
			
		}
		
		/// <summary> Get the Spare field for the DOP record.</summary>
		/// <summary> Set the Spare field for the DOP record.</summary>
		virtual public byte[] Spare {
			get {
				return field_44_Spare;
			}
			
			set {
				this.field_44_Spare = value;
			}
			
		}
		
		/// <summary> Get the reserved1 field for the DOP record.</summary>
		/// <summary> Set the reserved1 field for the DOP record.</summary>
		virtual public int Reserved1 {
			get {
				return field_45_reserved1;
			}
			
			set {
				this.field_45_reserved1 = value;
			}
			
		}
		
		/// <summary> Get the reserved2 field for the DOP record.</summary>
		/// <summary> Set the reserved2 field for the DOP record.</summary>
		virtual public int Reserved2 {
			get {
				return field_46_reserved2;
			}
			
			set {
				this.field_46_reserved2 = value;
			}
			
		}
		
		/// <summary> Get the cDBC field for the DOP record.</summary>
		/// <summary> Set the cDBC field for the DOP record.</summary>
		virtual public int CDBC {
			get {
				return field_47_cDBC;
			}
			
			set {
				this.field_47_cDBC = value;
			}
			
		}
		
		/// <summary> Get the cDBCFtnEdn field for the DOP record.</summary>
		/// <summary> Set the cDBCFtnEdn field for the DOP record.</summary>
		virtual public int CDBCFtnEdn {
			get {
				return field_48_cDBCFtnEdn;
			}
			
			set {
				this.field_48_cDBCFtnEdn = value;
			}
			
		}
		
		/// <summary> Get the reserved field for the DOP record.</summary>
		/// <summary> Set the reserved field for the DOP record.</summary>
		virtual public int Reserved {
			get {
				return field_49_reserved;
			}
			
			set {
				this.field_49_reserved = value;
			}
			
		}
		
		/// <summary> Get the nfcFtnRef field for the DOP record.</summary>
		/// <summary> Set the nfcFtnRef field for the DOP record.</summary>
		virtual public short NfcFtnRef {
			get {
				return field_50_nfcFtnRef;
			}
			
			set {
				this.field_50_nfcFtnRef = value;
			}
			
		}
		
		/// <summary> Get the nfcEdnRef field for the DOP record.</summary>
		/// <summary> Set the nfcEdnRef field for the DOP record.</summary>
		virtual public short NfcEdnRef {
			get {
				return field_51_nfcEdnRef;
			}
			
			set {
				this.field_51_nfcEdnRef = value;
			}
			
		}
		
		/// <summary> Get the hpsZoonFontPag field for the DOP record.</summary>
		/// <summary> Set the hpsZoonFontPag field for the DOP record.</summary>
		virtual public short HpsZoonFontPag {
			get {
				return field_52_hpsZoonFontPag;
			}
			
			set {
				this.field_52_hpsZoonFontPag = value;
			}
			
		}
		
		/// <summary> Get the dywDispPag field for the DOP record.</summary>
		/// <summary> Set the dywDispPag field for the DOP record.</summary>
		virtual public short DywDispPag {
			get {
				return field_53_dywDispPag;
			}
			
			set {
				this.field_53_dywDispPag = value;
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fFacingPages field value.
		/// </returns>
		/// <summary> Sets the fFacingPages field value.
		/// 
		/// </summary>
		virtual public bool FFacingPages {
			get {
				return fFacingPages.IsSet(field_1_formatFlags);
			}
			
			set {
				field_1_formatFlags = (byte) fFacingPages.SetBoolean(field_1_formatFlags, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fWidowControl field value.
		/// </returns>
		/// <summary> Sets the fWidowControl field value.
		/// 
		/// </summary>
		virtual public bool FWidowControl {
			get {
				return fWidowControl.IsSet(field_1_formatFlags);
			}
			
			set {
				field_1_formatFlags = (byte) fWidowControl.SetBoolean(field_1_formatFlags, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fPMHMainDoc field value.
		/// </returns>
		/// <summary> Sets the fPMHMainDoc field value.
		/// 
		/// </summary>
		virtual public bool FPMHMainDoc {
			get {
				return fPMHMainDoc.IsSet(field_1_formatFlags);
			}
			
			set {
				field_1_formatFlags = (byte) fPMHMainDoc.SetBoolean(field_1_formatFlags, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the grfSupression field value.
		/// </returns>
		/// <summary> Sets the grfSupression field value.
		/// 
		/// </summary>
		virtual public byte GrfSupression {
			get {
				return (byte) grfSupression.GetValue(field_1_formatFlags);
			}
			
			set {
				field_1_formatFlags = (byte) grfSupression.SetValue(field_1_formatFlags, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fpc field value.
		/// </returns>
		/// <summary> Sets the fpc field value.
		/// 
		/// </summary>
		virtual public byte Fpc {
			get {
				return (byte) fpc.GetValue(field_1_formatFlags);
			}
			
			set {
				field_1_formatFlags = (byte) fpc.SetValue(field_1_formatFlags, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the unused1 field value.
		/// </returns>
		/// <summary> Sets the unused1 field value.
		/// 
		/// </summary>
		virtual public bool Unused1 {
			get {
				return unused1.IsSet(field_1_formatFlags);
			}
			
			set {
				field_1_formatFlags = (byte) unused1.SetBoolean(field_1_formatFlags, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the rncFtn field value.
		/// </returns>
		/// <summary> Sets the rncFtn field value.
		/// 
		/// </summary>
		virtual public byte RncFtn {
			get {
				return (byte) rncFtn.GetValue(field_3_footnoteInfo);
			}
			
			set {
				field_3_footnoteInfo = (short) rncFtn.SetValue(field_3_footnoteInfo, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the nFtn field value.
		/// </returns>
		/// <summary> Sets the nFtn field value.
		/// 
		/// </summary>
		virtual public short NFtn {
			get {
				return (short) nFtn.GetValue(field_3_footnoteInfo);
			}
			
			set {
				field_3_footnoteInfo = (short) nFtn.SetValue(field_3_footnoteInfo, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fOnlyMacPics field value.
		/// </returns>
		/// <summary> Sets the fOnlyMacPics field value.
		/// 
		/// </summary>
		virtual public bool FOnlyMacPics {
			get {
				return fOnlyMacPics.IsSet(field_5_docinfo);
			}
			
			set {
				field_5_docinfo = (byte) fOnlyMacPics.SetBoolean(field_5_docinfo, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fOnlyWinPics field value.
		/// </returns>
		/// <summary> Sets the fOnlyWinPics field value.
		/// 
		/// </summary>
		virtual public bool FOnlyWinPics {
			get {
				return fOnlyWinPics.IsSet(field_5_docinfo);
			}
			
			set {
				field_5_docinfo = (byte) fOnlyWinPics.SetBoolean(field_5_docinfo, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fLabelDoc field value.
		/// </returns>
		/// <summary> Sets the fLabelDoc field value.
		/// 
		/// </summary>
		virtual public bool FLabelDoc {
			get {
				return fLabelDoc.IsSet(field_5_docinfo);
			}
			
			set {
				field_5_docinfo = (byte) fLabelDoc.SetBoolean(field_5_docinfo, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fHyphCapitals field value.
		/// </returns>
		/// <summary> Sets the fHyphCapitals field value.
		/// 
		/// </summary>
		virtual public bool FHyphCapitals {
			get {
				return fHyphCapitals.IsSet(field_5_docinfo);
			}
			
			set {
				field_5_docinfo = (byte) fHyphCapitals.SetBoolean(field_5_docinfo, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fAutoHyphen field value.
		/// </returns>
		/// <summary> Sets the fAutoHyphen field value.
		/// 
		/// </summary>
		virtual public bool FAutoHyphen {
			get {
				return fAutoHyphen.IsSet(field_5_docinfo);
			}
			
			set {
				field_5_docinfo = (byte) fAutoHyphen.SetBoolean(field_5_docinfo, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fFormNoFields field value.
		/// </returns>
		/// <summary> Sets the fFormNoFields field value.
		/// 
		/// </summary>
		virtual public bool FFormNoFields {
			get {
				return fFormNoFields.IsSet(field_5_docinfo);
			}
			
			set {
				field_5_docinfo = (byte) fFormNoFields.SetBoolean(field_5_docinfo, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fLinkStyles field value.
		/// </returns>
		/// <summary> Sets the fLinkStyles field value.
		/// 
		/// </summary>
		virtual public bool FLinkStyles {
			get {
				return fLinkStyles.IsSet(field_5_docinfo);
			}
			
			set {
				field_5_docinfo = (byte) fLinkStyles.SetBoolean(field_5_docinfo, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fRevMarking field value.
		/// </returns>
		/// <summary> Sets the fRevMarking field value.
		/// 
		/// </summary>
		virtual public bool FRevMarking {
			get {
				return fRevMarking.IsSet(field_5_docinfo);
			}
			
			set {
				field_5_docinfo = (byte) fRevMarking.SetBoolean(field_5_docinfo, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fBackup field value.
		/// </returns>
		/// <summary> Sets the fBackup field value.
		/// 
		/// </summary>
		virtual public bool FBackup {
			get {
				return fBackup.IsSet(field_6_docinfo1);
			}
			
			set {
				field_6_docinfo1 = (byte) fBackup.SetBoolean(field_6_docinfo1, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fExactCWords field value.
		/// </returns>
		/// <summary> Sets the fExactCWords field value.
		/// 
		/// </summary>
		virtual public bool FExactCWords {
			get {
				return fExactCWords.IsSet(field_6_docinfo1);
			}
			
			set {
				field_6_docinfo1 = (byte) fExactCWords.SetBoolean(field_6_docinfo1, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fPagHidden field value.
		/// </returns>
		/// <summary> Sets the fPagHidden field value.
		/// 
		/// </summary>
		virtual public bool FPagHidden {
			get {
				return fPagHidden.IsSet(field_6_docinfo1);
			}
			
			set {
				field_6_docinfo1 = (byte) fPagHidden.SetBoolean(field_6_docinfo1, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fPagResults field value.
		/// </returns>
		/// <summary> Sets the fPagResults field value.
		/// 
		/// </summary>
		virtual public bool FPagResults {
			get {
				return fPagResults.IsSet(field_6_docinfo1);
			}
			
			set {
				field_6_docinfo1 = (byte) fPagResults.SetBoolean(field_6_docinfo1, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fLockAtn field value.
		/// </returns>
		/// <summary> Sets the fLockAtn field value.
		/// 
		/// </summary>
		virtual public bool FLockAtn {
			get {
				return fLockAtn.IsSet(field_6_docinfo1);
			}
			
			set {
				field_6_docinfo1 = (byte) fLockAtn.SetBoolean(field_6_docinfo1, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fMirrorMargins field value.
		/// </returns>
		/// <summary> Sets the fMirrorMargins field value.
		/// 
		/// </summary>
		virtual public bool FMirrorMargins {
			get {
				return fMirrorMargins.IsSet(field_6_docinfo1);
			}
			
			set {
				field_6_docinfo1 = (byte) fMirrorMargins.SetBoolean(field_6_docinfo1, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the unused3 field value.
		/// </returns>
		/// <summary> Sets the unused3 field value.
		/// 
		/// </summary>
		virtual public bool Unused3 {
			get {
				return unused3.IsSet(field_6_docinfo1);
			}
			
			set {
				field_6_docinfo1 = (byte) unused3.SetBoolean(field_6_docinfo1, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fDfltTrueType field value.
		/// </returns>
		/// <summary> Sets the fDfltTrueType field value.
		/// 
		/// </summary>
		virtual public bool FDfltTrueType {
			get {
				return fDfltTrueType.IsSet(field_6_docinfo1);
			}
			
			set {
				field_6_docinfo1 = (byte) fDfltTrueType.SetBoolean(field_6_docinfo1, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fPagSupressTopSpacing field value.
		/// </returns>
		/// <summary> Sets the fPagSupressTopSpacing field value.
		/// 
		/// </summary>
		virtual public bool FPagSupressTopSpacing {
			get {
				return fPagSupressTopSpacing.IsSet(field_7_docinfo2);
			}
			
			set {
				field_7_docinfo2 = (byte) fPagSupressTopSpacing.SetBoolean(field_7_docinfo2, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fProtEnabled field value.
		/// </returns>
		/// <summary> Sets the fProtEnabled field value.
		/// 
		/// </summary>
		virtual public bool FProtEnabled {
			get {
				return fProtEnabled.IsSet(field_7_docinfo2);
			}
			
			set {
				field_7_docinfo2 = (byte) fProtEnabled.SetBoolean(field_7_docinfo2, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fDispFormFldSel field value.
		/// </returns>
		/// <summary> Sets the fDispFormFldSel field value.
		/// 
		/// </summary>
		virtual public bool FDispFormFldSel {
			get {
				return fDispFormFldSel.IsSet(field_7_docinfo2);
			}
			
			set {
				field_7_docinfo2 = (byte) fDispFormFldSel.SetBoolean(field_7_docinfo2, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fRMView field value.
		/// </returns>
		/// <summary> Sets the fRMView field value.
		/// 
		/// </summary>
		virtual public bool FRMView {
			get {
				return fRMView.IsSet(field_7_docinfo2);
			}
			
			set {
				field_7_docinfo2 = (byte) fRMView.SetBoolean(field_7_docinfo2, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fRMPrint field value.
		/// </returns>
		/// <summary> Sets the fRMPrint field value.
		/// 
		/// </summary>
		virtual public bool FRMPrint {
			get {
				return fRMPrint.IsSet(field_7_docinfo2);
			}
			
			set {
				field_7_docinfo2 = (byte) fRMPrint.SetBoolean(field_7_docinfo2, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the unused4 field value.
		/// </returns>
		/// <summary> Sets the unused4 field value.
		/// 
		/// </summary>
		virtual public bool Unused4 {
			get {
				return unused4.IsSet(field_7_docinfo2);
			}
			
			set {
				field_7_docinfo2 = (byte) unused4.SetBoolean(field_7_docinfo2, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fLockRev field value.
		/// </returns>
		/// <summary> Sets the fLockRev field value.
		/// 
		/// </summary>
		virtual public bool FLockRev {
			get {
				return fLockRev.IsSet(field_7_docinfo2);
			}
			
			set {
				field_7_docinfo2 = (byte) fLockRev.SetBoolean(field_7_docinfo2, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fEmbedFonts field value.
		/// </returns>
		/// <summary> Sets the fEmbedFonts field value.
		/// 
		/// </summary>
		virtual public bool FEmbedFonts {
			get {
				return fEmbedFonts.IsSet(field_7_docinfo2);
			}
			
			set {
				field_7_docinfo2 = (byte) fEmbedFonts.SetBoolean(field_7_docinfo2, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the oldfNoTabForInd field value.
		/// </returns>
		/// <summary> Sets the oldfNoTabForInd field value.
		/// 
		/// </summary>
		virtual public bool OldfNoTabForInd {
			get {
				return oldfNoTabForInd.IsSet(field_8_docinfo3);
			}
			
			set {
				field_8_docinfo3 = (short) oldfNoTabForInd.SetBoolean(field_8_docinfo3, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the oldfNoSpaceRaiseLower field value.
		/// </returns>
		/// <summary> Sets the oldfNoSpaceRaiseLower field value.
		/// 
		/// </summary>
		virtual public bool OldfNoSpaceRaiseLower {
			get {
				return oldfNoSpaceRaiseLower.IsSet(field_8_docinfo3);
			}
			
			set {
				field_8_docinfo3 = (short) oldfNoSpaceRaiseLower.SetBoolean(field_8_docinfo3, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the oldfSuppressSpbfAfterPageBreak field value.
		/// </returns>
		/// <summary> Sets the oldfSuppressSpbfAfterPageBreak field value.
		/// 
		/// </summary>
		virtual public bool OldfSuppressSpbfAfterPageBreak {
			get {
				return oldfSuppressSpbfAfterPageBreak.IsSet(field_8_docinfo3);
			}
			
			set {
				field_8_docinfo3 = (short) oldfSuppressSpbfAfterPageBreak.SetBoolean(field_8_docinfo3, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the oldfWrapTrailSpaces field value.
		/// </returns>
		/// <summary> Sets the oldfWrapTrailSpaces field value.
		/// 
		/// </summary>
		virtual public bool OldfWrapTrailSpaces {
			get {
				return oldfWrapTrailSpaces.IsSet(field_8_docinfo3);
			}
			
			set {
				field_8_docinfo3 = (short) oldfWrapTrailSpaces.SetBoolean(field_8_docinfo3, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the oldfMapPrintTextColor field value.
		/// </returns>
		/// <summary> Sets the oldfMapPrintTextColor field value.
		/// 
		/// </summary>
		virtual public bool OldfMapPrintTextColor {
			get {
				return oldfMapPrintTextColor.IsSet(field_8_docinfo3);
			}
			
			set {
				field_8_docinfo3 = (short) oldfMapPrintTextColor.SetBoolean(field_8_docinfo3, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the oldfNoColumnBalance field value.
		/// </returns>
		/// <summary> Sets the oldfNoColumnBalance field value.
		/// 
		/// </summary>
		virtual public bool OldfNoColumnBalance {
			get {
				return oldfNoColumnBalance.IsSet(field_8_docinfo3);
			}
			
			set {
				field_8_docinfo3 = (short) oldfNoColumnBalance.SetBoolean(field_8_docinfo3, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the oldfConvMailMergeEsc field value.
		/// </returns>
		/// <summary> Sets the oldfConvMailMergeEsc field value.
		/// 
		/// </summary>
		virtual public bool OldfConvMailMergeEsc {
			get {
				return oldfConvMailMergeEsc.IsSet(field_8_docinfo3);
			}
			
			set {
				field_8_docinfo3 = (short) oldfConvMailMergeEsc.SetBoolean(field_8_docinfo3, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the oldfSupressTopSpacing field value.
		/// </returns>
		/// <summary> Sets the oldfSupressTopSpacing field value.
		/// 
		/// </summary>
		virtual public bool OldfSupressTopSpacing {
			get {
				return oldfSupressTopSpacing.IsSet(field_8_docinfo3);
			}
			
			set {
				field_8_docinfo3 = (short) oldfSupressTopSpacing.SetBoolean(field_8_docinfo3, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the oldfOrigWordTableRules field value.
		/// </returns>
		/// <summary> Sets the oldfOrigWordTableRules field value.
		/// 
		/// </summary>
		virtual public bool OldfOrigWordTableRules {
			get {
				return oldfOrigWordTableRules.IsSet(field_8_docinfo3);
			}
			
			set {
				field_8_docinfo3 = (short) oldfOrigWordTableRules.SetBoolean(field_8_docinfo3, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the oldfTransparentMetafiles field value.
		/// </returns>
		/// <summary> Sets the oldfTransparentMetafiles field value.
		/// 
		/// </summary>
		virtual public bool OldfTransparentMetafiles {
			get {
				return oldfTransparentMetafiles.IsSet(field_8_docinfo3);
			}
			
			set {
				field_8_docinfo3 = (short) oldfTransparentMetafiles.SetBoolean(field_8_docinfo3, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the oldfShowBreaksInFrames field value.
		/// </returns>
		/// <summary> Sets the oldfShowBreaksInFrames field value.
		/// 
		/// </summary>
		virtual public bool OldfShowBreaksInFrames {
			get {
				return oldfShowBreaksInFrames.IsSet(field_8_docinfo3);
			}
			
			set {
				field_8_docinfo3 = (short) oldfShowBreaksInFrames.SetBoolean(field_8_docinfo3, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the oldfSwapBordersFacingPgs field value.
		/// </returns>
		/// <summary> Sets the oldfSwapBordersFacingPgs field value.
		/// 
		/// </summary>
		virtual public bool OldfSwapBordersFacingPgs {
			get {
				return oldfSwapBordersFacingPgs.IsSet(field_8_docinfo3);
			}
			
			set {
				field_8_docinfo3 = (short) oldfSwapBordersFacingPgs.SetBoolean(field_8_docinfo3, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the unused5 field value.
		/// </returns>
		/// <summary> Sets the unused5 field value.
		/// 
		/// </summary>
		virtual public byte Unused5 {
			get {
				return (byte) unused5.GetValue(field_8_docinfo3);
			}
			
			set {
				field_8_docinfo3 = (short) unused5.SetValue(field_8_docinfo3, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the rncEdn field value.
		/// </returns>
		/// <summary> Sets the rncEdn field value.
		/// 
		/// </summary>
		virtual public byte RncEdn {
			get {
				return (byte) rncEdn.GetValue(field_23_Edn);
			}
			
			set {
				field_23_Edn = (short) rncEdn.SetValue(field_23_Edn, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the nEdn field value.
		/// </returns>
		/// <summary> Sets the nEdn field value.
		/// 
		/// </summary>
		virtual public short NEdn {
			get {
				return (short) nEdn.GetValue(field_23_Edn);
			}
			
			set {
				field_23_Edn = (short) nEdn.SetValue(field_23_Edn, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the epc field value.
		/// </returns>
		/// <summary> Sets the epc field value.
		/// 
		/// </summary>
		virtual public byte Epc {
			get {
				return (byte) epc.GetValue(field_24_Edn1);
			}
			
			set {
				field_24_Edn1 = (short) epc.SetValue(field_24_Edn1, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the nfcFtnRef1 field value.
		/// </returns>
		/// <summary> Sets the nfcFtnRef1 field value.
		/// 
		/// </summary>
		virtual public byte NfcFtnRef1 {
			get {
				return (byte) nfcFtnRef1.GetValue(field_24_Edn1);
			}
			
			set {
				field_24_Edn1 = (short) nfcFtnRef1.SetValue(field_24_Edn1, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the nfcEdnRef1 field value.
		/// </returns>
		/// <summary> Sets the nfcEdnRef1 field value.
		/// 
		/// </summary>
		virtual public byte NfcEdnRef1 {
			get {
				return (byte) nfcEdnRef1.GetValue(field_24_Edn1);
			}
			
			set {
				field_24_Edn1 = (short) nfcEdnRef1.SetValue(field_24_Edn1, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fPrintFormData field value.
		/// </returns>
		/// <summary> Sets the fPrintFormData field value.
		/// 
		/// </summary>
		virtual public bool FPrintFormData {
			get {
				return fPrintFormData.IsSet(field_24_Edn1);
			}
			
			set {
				field_24_Edn1 = (short) fPrintFormData.SetBoolean(field_24_Edn1, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fSaveFormData field value.
		/// </returns>
		/// <summary> Sets the fSaveFormData field value.
		/// 
		/// </summary>
		virtual public bool FSaveFormData {
			get {
				return fSaveFormData.IsSet(field_24_Edn1);
			}
			
			set {
				field_24_Edn1 = (short) fSaveFormData.SetBoolean(field_24_Edn1, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fShadeFormData field value.
		/// </returns>
		/// <summary> Sets the fShadeFormData field value.
		/// 
		/// </summary>
		virtual public bool FShadeFormData {
			get {
				return fShadeFormData.IsSet(field_24_Edn1);
			}
			
			set {
				field_24_Edn1 = (short) fShadeFormData.SetBoolean(field_24_Edn1, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fWCFtnEdn field value.
		/// </returns>
		/// <summary> Sets the fWCFtnEdn field value.
		/// 
		/// </summary>
		virtual public bool FWCFtnEdn {
			get {
				return fWCFtnEdn.IsSet(field_24_Edn1);
			}
			
			set {
				field_24_Edn1 = (short) fWCFtnEdn.SetBoolean(field_24_Edn1, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the wvkSaved field value.
		/// </returns>
		/// <summary> Sets the wvkSaved field value.
		/// 
		/// </summary>
		virtual public byte WvkSaved {
			get {
				return (byte) wvkSaved.GetValue(field_32_view);
			}
			
			set {
				field_32_view = (short) wvkSaved.SetValue(field_32_view, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the wScaleSaved field value.
		/// </returns>
		/// <summary> Sets the wScaleSaved field value.
		/// 
		/// </summary>
		virtual public short WScaleSaved {
			get {
				return (short) wScaleSaved.GetValue(field_32_view);
			}
			
			set {
				field_32_view = (short) wScaleSaved.SetValue(field_32_view, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the zkSaved field value.
		/// </returns>
		/// <summary> Sets the zkSaved field value.
		/// 
		/// </summary>
		virtual public byte ZkSaved {
			get {
				return (byte) zkSaved.GetValue(field_32_view);
			}
			
			set {
				field_32_view = (short) zkSaved.SetValue(field_32_view, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fRotateFontW6 field value.
		/// </returns>
		/// <summary> Sets the fRotateFontW6 field value.
		/// 
		/// </summary>
		virtual public bool FRotateFontW6 {
			get {
				return fRotateFontW6.IsSet(field_32_view);
			}
			
			set {
				field_32_view = (short) fRotateFontW6.SetBoolean(field_32_view, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the iGutterPos field value.
		/// </returns>
		/// <summary> Sets the iGutterPos field value.
		/// 
		/// </summary>
		virtual public bool IGutterPos {
			get {
				return iGutterPos.IsSet(field_32_view);
			}
			
			set {
				field_32_view = (short) iGutterPos.SetBoolean(field_32_view, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fNoTabForInd field value.
		/// </returns>
		/// <summary> Sets the fNoTabForInd field value.
		/// 
		/// </summary>
		virtual public bool FNoTabForInd {
			get {
				return fNoTabForInd.IsSet(field_33_docinfo4);
			}
			
			set {
				field_33_docinfo4 = (int) fNoTabForInd.SetBoolean(field_33_docinfo4, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fNoSpaceRaiseLower field value.
		/// </returns>
		/// <summary> Sets the fNoSpaceRaiseLower field value.
		/// 
		/// </summary>
		virtual public bool FNoSpaceRaiseLower {
			get {
				return fNoSpaceRaiseLower.IsSet(field_33_docinfo4);
			}
			
			set {
				field_33_docinfo4 = (int) fNoSpaceRaiseLower.SetBoolean(field_33_docinfo4, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fSupressSpdfAfterPageBreak field value.
		/// </returns>
		/// <summary> Sets the fSupressSpdfAfterPageBreak field value.
		/// 
		/// </summary>
		virtual public bool FSupressSpdfAfterPageBreak {
			get {
				return fSupressSpdfAfterPageBreak.IsSet(field_33_docinfo4);
			}
			
			set {
				field_33_docinfo4 = (int) fSupressSpdfAfterPageBreak.SetBoolean(field_33_docinfo4, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fWrapTrailSpaces field value.
		/// </returns>
		/// <summary> Sets the fWrapTrailSpaces field value.
		/// 
		/// </summary>
		virtual public bool FWrapTrailSpaces {
			get {
				return fWrapTrailSpaces.IsSet(field_33_docinfo4);
			}
			
			set {
				field_33_docinfo4 = (int) fWrapTrailSpaces.SetBoolean(field_33_docinfo4, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fMapPrintTextColor field value.
		/// </returns>
		/// <summary> Sets the fMapPrintTextColor field value.
		/// 
		/// </summary>
		virtual public bool FMapPrintTextColor {
			get {
				return fMapPrintTextColor.IsSet(field_33_docinfo4);
			}
			
			set {
				field_33_docinfo4 = (int) fMapPrintTextColor.SetBoolean(field_33_docinfo4, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fNoColumnBalance field value.
		/// </returns>
		/// <summary> Sets the fNoColumnBalance field value.
		/// 
		/// </summary>
		virtual public bool FNoColumnBalance {
			get {
				return fNoColumnBalance.IsSet(field_33_docinfo4);
			}
			
			set {
				field_33_docinfo4 = (int) fNoColumnBalance.SetBoolean(field_33_docinfo4, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fConvMailMergeEsc field value.
		/// </returns>
		/// <summary> Sets the fConvMailMergeEsc field value.
		/// 
		/// </summary>
		virtual public bool FConvMailMergeEsc {
			get {
				return fConvMailMergeEsc.IsSet(field_33_docinfo4);
			}
			
			set {
				field_33_docinfo4 = (int) fConvMailMergeEsc.SetBoolean(field_33_docinfo4, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fSupressTopSpacing field value.
		/// </returns>
		/// <summary> Sets the fSupressTopSpacing field value.
		/// 
		/// </summary>
		virtual public bool FSupressTopSpacing {
			get {
				return fSupressTopSpacing.IsSet(field_33_docinfo4);
			}
			
			set {
				field_33_docinfo4 = (int) fSupressTopSpacing.SetBoolean(field_33_docinfo4, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fOrigWordTableRules field value.
		/// </returns>
		/// <summary> Sets the fOrigWordTableRules field value.
		/// 
		/// </summary>
		virtual public bool FOrigWordTableRules {
			get {
				return fOrigWordTableRules.IsSet(field_33_docinfo4);
			}
			
			set {
				field_33_docinfo4 = (int) fOrigWordTableRules.SetBoolean(field_33_docinfo4, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fTransparentMetafiles field value.
		/// </returns>
		/// <summary> Sets the fTransparentMetafiles field value.
		/// 
		/// </summary>
		virtual public bool FTransparentMetafiles {
			get {
				return fTransparentMetafiles.IsSet(field_33_docinfo4);
			}
			
			set {
				field_33_docinfo4 = (int) fTransparentMetafiles.SetBoolean(field_33_docinfo4, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fShowBreaksInFrames field value.
		/// </returns>
		/// <summary> Sets the fShowBreaksInFrames field value.
		/// 
		/// </summary>
		virtual public bool FShowBreaksInFrames {
			get {
				return fShowBreaksInFrames.IsSet(field_33_docinfo4);
			}
			
			set {
				field_33_docinfo4 = (int) fShowBreaksInFrames.SetBoolean(field_33_docinfo4, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fSwapBordersFacingPgs field value.
		/// </returns>
		/// <summary> Sets the fSwapBordersFacingPgs field value.
		/// 
		/// </summary>
		virtual public bool FSwapBordersFacingPgs {
			get {
				return fSwapBordersFacingPgs.IsSet(field_33_docinfo4);
			}
			
			set {
				field_33_docinfo4 = (int) fSwapBordersFacingPgs.SetBoolean(field_33_docinfo4, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fSuppressTopSPacingMac5 field value.
		/// </returns>
		/// <summary> Sets the fSuppressTopSPacingMac5 field value.
		/// 
		/// </summary>
		virtual public bool FSuppressTopSPacingMac5 {
			get {
				return fSuppressTopSPacingMac5.IsSet(field_33_docinfo4);
			}
			
			set {
				field_33_docinfo4 = (int) fSuppressTopSPacingMac5.SetBoolean(field_33_docinfo4, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fTruncDxaExpand field value.
		/// </returns>
		/// <summary> Sets the fTruncDxaExpand field value.
		/// 
		/// </summary>
		virtual public bool FTruncDxaExpand {
			get {
				return fTruncDxaExpand.IsSet(field_33_docinfo4);
			}
			
			set {
				field_33_docinfo4 = (int) fTruncDxaExpand.SetBoolean(field_33_docinfo4, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fPrintBodyBeforeHdr field value.
		/// </returns>
		/// <summary> Sets the fPrintBodyBeforeHdr field value.
		/// 
		/// </summary>
		virtual public bool FPrintBodyBeforeHdr {
			get {
				return fPrintBodyBeforeHdr.IsSet(field_33_docinfo4);
			}
			
			set {
				field_33_docinfo4 = (int) fPrintBodyBeforeHdr.SetBoolean(field_33_docinfo4, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fNoLeading field value.
		/// </returns>
		/// <summary> Sets the fNoLeading field value.
		/// 
		/// </summary>
		virtual public bool FNoLeading {
			get {
				return fNoLeading.IsSet(field_33_docinfo4);
			}
			
			set {
				field_33_docinfo4 = (int) fNoLeading.SetBoolean(field_33_docinfo4, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fMWSmallCaps field value.
		/// </returns>
		/// <summary> Sets the fMWSmallCaps field value.
		/// 
		/// </summary>
		virtual public bool FMWSmallCaps {
			get {
				return fMWSmallCaps.IsSet(field_33_docinfo4);
			}
			
			set {
				field_33_docinfo4 = (int) fMWSmallCaps.SetBoolean(field_33_docinfo4, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the lvl field value.
		/// </returns>
		/// <summary> Sets the lvl field value.
		/// 
		/// </summary>
		virtual public byte Lvl {
			get {
				return (byte) lvl.GetValue(field_37_docinfo5);
			}
			
			set {
				field_37_docinfo5 = (short) lvl.SetValue(field_37_docinfo5, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fGramAllDone field value.
		/// </returns>
		/// <summary> Sets the fGramAllDone field value.
		/// 
		/// </summary>
		virtual public bool FGramAllDone {
			get {
				return fGramAllDone.IsSet(field_37_docinfo5);
			}
			
			set {
				field_37_docinfo5 = (short) fGramAllDone.SetBoolean(field_37_docinfo5, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fGramAllClean field value.
		/// </returns>
		/// <summary> Sets the fGramAllClean field value.
		/// 
		/// </summary>
		virtual public bool FGramAllClean {
			get {
				return fGramAllClean.IsSet(field_37_docinfo5);
			}
			
			set {
				field_37_docinfo5 = (short) fGramAllClean.SetBoolean(field_37_docinfo5, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fSubsetFonts field value.
		/// </returns>
		/// <summary> Sets the fSubsetFonts field value.
		/// 
		/// </summary>
		virtual public bool FSubsetFonts {
			get {
				return fSubsetFonts.IsSet(field_37_docinfo5);
			}
			
			set {
				field_37_docinfo5 = (short) fSubsetFonts.SetBoolean(field_37_docinfo5, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fHideLastVersion field value.
		/// </returns>
		/// <summary> Sets the fHideLastVersion field value.
		/// 
		/// </summary>
		virtual public bool FHideLastVersion {
			get {
				return fHideLastVersion.IsSet(field_37_docinfo5);
			}
			
			set {
				field_37_docinfo5 = (short) fHideLastVersion.SetBoolean(field_37_docinfo5, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fHtmlDoc field value.
		/// </returns>
		/// <summary> Sets the fHtmlDoc field value.
		/// 
		/// </summary>
		virtual public bool FHtmlDoc {
			get {
				return fHtmlDoc.IsSet(field_37_docinfo5);
			}
			
			set {
				field_37_docinfo5 = (short) fHtmlDoc.SetBoolean(field_37_docinfo5, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fSnapBorder field value.
		/// </returns>
		/// <summary> Sets the fSnapBorder field value.
		/// 
		/// </summary>
		virtual public bool FSnapBorder {
			get {
				return fSnapBorder.IsSet(field_37_docinfo5);
			}
			
			set {
				field_37_docinfo5 = (short) fSnapBorder.SetBoolean(field_37_docinfo5, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fIncludeHeader field value.
		/// </returns>
		/// <summary> Sets the fIncludeHeader field value.
		/// 
		/// </summary>
		virtual public bool FIncludeHeader {
			get {
				return fIncludeHeader.IsSet(field_37_docinfo5);
			}
			
			set {
				field_37_docinfo5 = (short) fIncludeHeader.SetBoolean(field_37_docinfo5, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fIncludeFooter field value.
		/// </returns>
		/// <summary> Sets the fIncludeFooter field value.
		/// 
		/// </summary>
		virtual public bool FIncludeFooter {
			get {
				return fIncludeFooter.IsSet(field_37_docinfo5);
			}
			
			set {
				field_37_docinfo5 = (short) fIncludeFooter.SetBoolean(field_37_docinfo5, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fForcePageSizePag field value.
		/// </returns>
		/// <summary> Sets the fForcePageSizePag field value.
		/// 
		/// </summary>
		virtual public bool FForcePageSizePag {
			get {
				return fForcePageSizePag.IsSet(field_37_docinfo5);
			}
			
			set {
				field_37_docinfo5 = (short) fForcePageSizePag.SetBoolean(field_37_docinfo5, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fMinFontSizePag field value.
		/// </returns>
		/// <summary> Sets the fMinFontSizePag field value.
		/// 
		/// </summary>
		virtual public bool FMinFontSizePag {
			get {
				return fMinFontSizePag.IsSet(field_37_docinfo5);
			}
			
			set {
				field_37_docinfo5 = (short) fMinFontSizePag.SetBoolean(field_37_docinfo5, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fHaveVersions field value.
		/// </returns>
		/// <summary> Sets the fHaveVersions field value.
		/// 
		/// </summary>
		virtual public bool FHaveVersions {
			get {
				return fHaveVersions.IsSet(field_38_docinfo6);
			}
			
			set {
				field_38_docinfo6 = (short) fHaveVersions.SetBoolean(field_38_docinfo6, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fAutoVersions field value.
		/// </returns>
		/// <summary> Sets the fAutoVersions field value.
		/// 
		/// </summary>
		virtual public bool FAutoVersions {
			get {
				return fAutoVersions.IsSet(field_38_docinfo6);
			}
			
			set {
				field_38_docinfo6 = (short) fAutoVersions.SetBoolean(field_38_docinfo6, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fVirusPrompted field value.
		/// </returns>
		/// <summary> Sets the fVirusPrompted field value.
		/// 
		/// </summary>
		virtual public bool FVirusPrompted {
			get {
				return fVirusPrompted.IsSet(field_43_virusinfo);
			}
			
			set {
				field_43_virusinfo = (int) fVirusPrompted.SetBoolean(field_43_virusinfo, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fVirusLoadSafe field value.
		/// </returns>
		/// <summary> Sets the fVirusLoadSafe field value.
		/// 
		/// </summary>
		virtual public bool FVirusLoadSafe {
			get {
				return fVirusLoadSafe.IsSet(field_43_virusinfo);
			}
			
			set {
				field_43_virusinfo = (int) fVirusLoadSafe.SetBoolean(field_43_virusinfo, value);
			}
			
		}
		
		public DOPAbstractType()
		{
		}
		
		protected internal virtual void FillFields(byte[] data, int offset)
		{
			field_1_formatFlags = data[0x0 + offset];
			field_2_unused2 = data[0x1 + offset];
			field_3_footnoteInfo = LittleEndian.GetShort(data, 0x2 + offset);
			field_4_fOutlineDirtySave = data[0x4 + offset];
			field_5_docinfo = data[0x5 + offset];
			field_6_docinfo1 = data[0x6 + offset];
			field_7_docinfo2 = data[0x7 + offset];
			field_8_docinfo3 = LittleEndian.GetShort(data, 0x8 + offset);
			field_9_dxaTab = LittleEndian.GetShort(data, 0xa + offset);
			field_10_wSpare = LittleEndian.GetShort(data, 0xc + offset);
			field_11_dxaHotz = LittleEndian.GetShort(data, 0xe + offset);
			field_12_cConsexHypLim = LittleEndian.GetShort(data, 0x10 + offset);
			field_13_wSpare2 = LittleEndian.GetShort(data, 0x12 + offset);
			field_14_dttmCreated = LittleEndian.GetInt(data, 0x14 + offset);
			field_15_dttmRevised = LittleEndian.GetInt(data, 0x18 + offset);
			field_16_dttmLastPrint = LittleEndian.GetInt(data, 0x1c + offset);
			field_17_nRevision = LittleEndian.GetShort(data, 0x20 + offset);
			field_18_tmEdited = LittleEndian.GetInt(data, 0x22 + offset);
			field_19_cWords = LittleEndian.GetInt(data, 0x26 + offset);
			field_20_cCh = LittleEndian.GetInt(data, 0x2a + offset);
			field_21_cPg = LittleEndian.GetShort(data, 0x2e + offset);
			field_22_cParas = LittleEndian.GetInt(data, 0x30 + offset);
			field_23_Edn = LittleEndian.GetShort(data, 0x34 + offset);
			field_24_Edn1 = LittleEndian.GetShort(data, 0x36 + offset);
			field_25_cLines = LittleEndian.GetInt(data, 0x38 + offset);
			field_26_cWordsFtnEnd = LittleEndian.GetInt(data, 0x3c + offset);
			field_27_cChFtnEdn = LittleEndian.GetInt(data, 0x40 + offset);
			field_28_cPgFtnEdn = LittleEndian.GetShort(data, 0x44 + offset);
			field_29_cParasFtnEdn = LittleEndian.GetInt(data, 0x46 + offset);
			field_30_cLinesFtnEdn = LittleEndian.GetInt(data, 0x4a + offset);
			field_31_lKeyProtDoc = LittleEndian.GetInt(data, 0x4e + offset);
			field_32_view = LittleEndian.GetShort(data, 0x52 + offset);
			field_33_docinfo4 = LittleEndian.GetInt(data, 0x54 + offset);
			field_34_adt = LittleEndian.GetShort(data, 0x58 + offset);
			field_35_doptypography = LittleEndian.GetByteArray(data, 0x5a + offset, 310);
			field_36_dogrid = LittleEndian.GetByteArray(data, 0x190 + offset, 10);
			field_37_docinfo5 = LittleEndian.GetShort(data, 0x19a + offset);
			field_38_docinfo6 = LittleEndian.GetShort(data, 0x19c + offset);
			field_39_asumyi = LittleEndian.GetByteArray(data, 0x19e + offset, 12);
			field_40_cChWS = LittleEndian.GetInt(data, 0x1aa + offset);
			field_41_cChWSFtnEdn = LittleEndian.GetInt(data, 0x1ae + offset);
			field_42_grfDocEvents = LittleEndian.GetInt(data, 0x1b2 + offset);
			field_43_virusinfo = LittleEndian.GetInt(data, 0x1b6 + offset);
			field_44_Spare = LittleEndian.GetByteArray(data, 0x1ba + offset, 30);
			field_45_reserved1 = LittleEndian.GetInt(data, 0x1d8 + offset);
			field_46_reserved2 = LittleEndian.GetInt(data, 0x1dc + offset);
			field_47_cDBC = LittleEndian.GetInt(data, 0x1e0 + offset);
			field_48_cDBCFtnEdn = LittleEndian.GetInt(data, 0x1e4 + offset);
			field_49_reserved = LittleEndian.GetInt(data, 0x1e8 + offset);
			field_50_nfcFtnRef = LittleEndian.GetShort(data, 0x1ec + offset);
			field_51_nfcEdnRef = LittleEndian.GetShort(data, 0x1ee + offset);
			field_52_hpsZoonFontPag = LittleEndian.GetShort(data, 0x1f0 + offset);
			field_53_dywDispPag = LittleEndian.GetShort(data, 0x1f2 + offset);
		}
		
		public virtual void Serialize(byte[] data, int offset)
		{
			data[0x0 + offset] = field_1_formatFlags; ;
			data[0x1 + offset] = field_2_unused2; ;
			LittleEndian.PutShort(data, 0x2 + offset, (short) field_3_footnoteInfo); ;
			data[0x4 + offset] = field_4_fOutlineDirtySave; ;
			data[0x5 + offset] = field_5_docinfo; ;
			data[0x6 + offset] = field_6_docinfo1; ;
			data[0x7 + offset] = field_7_docinfo2; ;
			LittleEndian.PutShort(data, 0x8 + offset, (short) field_8_docinfo3); ;
			LittleEndian.PutShort(data, 0xa + offset, (short) field_9_dxaTab); ;
			LittleEndian.PutShort(data, 0xc + offset, (short) field_10_wSpare); ;
			LittleEndian.PutShort(data, 0xe + offset, (short) field_11_dxaHotz); ;
			LittleEndian.PutShort(data, 0x10 + offset, (short) field_12_cConsexHypLim); ;
			LittleEndian.PutShort(data, 0x12 + offset, (short) field_13_wSpare2); ;
			LittleEndian.PutInt(data, 0x14 + offset, field_14_dttmCreated); ;
			LittleEndian.PutInt(data, 0x18 + offset, field_15_dttmRevised); ;
			LittleEndian.PutInt(data, 0x1c + offset, field_16_dttmLastPrint); ;
			LittleEndian.PutShort(data, 0x20 + offset, (short) field_17_nRevision); ;
			LittleEndian.PutInt(data, 0x22 + offset, field_18_tmEdited); ;
			LittleEndian.PutInt(data, 0x26 + offset, field_19_cWords); ;
			LittleEndian.PutInt(data, 0x2a + offset, field_20_cCh); ;
			LittleEndian.PutShort(data, 0x2e + offset, (short) field_21_cPg); ;
			LittleEndian.PutInt(data, 0x30 + offset, field_22_cParas); ;
			LittleEndian.PutShort(data, 0x34 + offset, (short) field_23_Edn); ;
			LittleEndian.PutShort(data, 0x36 + offset, (short) field_24_Edn1); ;
			LittleEndian.PutInt(data, 0x38 + offset, field_25_cLines); ;
			LittleEndian.PutInt(data, 0x3c + offset, field_26_cWordsFtnEnd); ;
			LittleEndian.PutInt(data, 0x40 + offset, field_27_cChFtnEdn); ;
			LittleEndian.PutShort(data, 0x44 + offset, (short) field_28_cPgFtnEdn); ;
			LittleEndian.PutInt(data, 0x46 + offset, field_29_cParasFtnEdn); ;
			LittleEndian.PutInt(data, 0x4a + offset, field_30_cLinesFtnEdn); ;
			LittleEndian.PutInt(data, 0x4e + offset, field_31_lKeyProtDoc); ;
			LittleEndian.PutShort(data, 0x52 + offset, (short) field_32_view); ;
			LittleEndian.PutInt(data, 0x54 + offset, field_33_docinfo4); ;
			LittleEndian.PutShort(data, 0x58 + offset, (short) field_34_adt); ;
			Array.Copy(field_35_doptypography, 0, data, 0x5a + offset, field_35_doptypography.Length); ;
			Array.Copy(field_36_dogrid, 0, data, 0x190 + offset, field_36_dogrid.Length); ;
			LittleEndian.PutShort(data, 0x19a + offset, (short) field_37_docinfo5); ;
			LittleEndian.PutShort(data, 0x19c + offset, (short) field_38_docinfo6); ;
			Array.Copy(field_39_asumyi, 0, data, 0x19e + offset, field_39_asumyi.Length); ;
			LittleEndian.PutInt(data, 0x1aa + offset, field_40_cChWS); ;
			LittleEndian.PutInt(data, 0x1ae + offset, field_41_cChWSFtnEdn); ;
			LittleEndian.PutInt(data, 0x1b2 + offset, field_42_grfDocEvents); ;
			LittleEndian.PutInt(data, 0x1b6 + offset, field_43_virusinfo); ;
			Array.Copy(field_44_Spare, 0, data, 0x1ba + offset, field_44_Spare.Length); ;
			LittleEndian.PutInt(data, 0x1d8 + offset, field_45_reserved1); ;
			LittleEndian.PutInt(data, 0x1dc + offset, field_46_reserved2); ;
			LittleEndian.PutInt(data, 0x1e0 + offset, field_47_cDBC); ;
			LittleEndian.PutInt(data, 0x1e4 + offset, field_48_cDBCFtnEdn); ;
			LittleEndian.PutInt(data, 0x1e8 + offset, field_49_reserved); ;
			LittleEndian.PutShort(data, 0x1ec + offset, (short) field_50_nfcFtnRef); ;
			LittleEndian.PutShort(data, 0x1ee + offset, (short) field_51_nfcEdnRef); ;
			LittleEndian.PutShort(data, 0x1f0 + offset, (short) field_52_hpsZoonFontPag); ;
			LittleEndian.PutShort(data, 0x1f2 + offset, (short) field_53_dywDispPag); ;
		}
		
		public override string ToString()
		{
			System.Text.StringBuilder buffer = new System.Text.StringBuilder();
			
			buffer.Append("[DOP]\n");
			
			buffer.Append("    .formatFlags          = ");
			buffer.Append(" (").Append((byte) FormatFlags).Append(" )\n");
			buffer.Append("         .fFacingPages             = ").Append(FFacingPages).Append('\n');
			buffer.Append("         .fWidowControl            = ").Append(FWidowControl).Append('\n');
			buffer.Append("         .fPMHMainDoc              = ").Append(FPMHMainDoc).Append('\n');
			buffer.Append("         .grfSupression            = ").Append((byte) GrfSupression).Append('\n');
			buffer.Append("         .fpc                      = ").Append((byte) Fpc).Append('\n');
			buffer.Append("         .unused1                  = ").Append(Unused1).Append('\n');
			
			buffer.Append("    .unused2              = ");
			buffer.Append(" (").Append((byte) Unused2).Append(" )\n");
			
			buffer.Append("    .footnoteInfo         = ");
			buffer.Append(" (").Append(FootnoteInfo).Append(" )\n");
			buffer.Append("         .rncFtn                   = ").Append((byte) RncFtn).Append('\n');
			buffer.Append("         .nFtn                     = ").Append(NFtn).Append('\n');
			
			buffer.Append("    .fOutlineDirtySave    = ");
			buffer.Append(" (").Append((byte) FOutlineDirtySave).Append(" )\n");
			
			buffer.Append("    .docinfo              = ");
			buffer.Append(" (").Append((byte) Docinfo).Append(" )\n");
			buffer.Append("         .fOnlyMacPics             = ").Append(FOnlyMacPics).Append('\n');
			buffer.Append("         .fOnlyWinPics             = ").Append(FOnlyWinPics).Append('\n');
			buffer.Append("         .fLabelDoc                = ").Append(FLabelDoc).Append('\n');
			buffer.Append("         .fHyphCapitals            = ").Append(FHyphCapitals).Append('\n');
			buffer.Append("         .fAutoHyphen              = ").Append(FAutoHyphen).Append('\n');
			buffer.Append("         .fFormNoFields            = ").Append(FFormNoFields).Append('\n');
			buffer.Append("         .fLinkStyles              = ").Append(FLinkStyles).Append('\n');
			buffer.Append("         .fRevMarking              = ").Append(FRevMarking).Append('\n');
			
			buffer.Append("    .docinfo1             = ");
			buffer.Append(" (").Append((byte) Docinfo1).Append(" )\n");
			buffer.Append("         .fBackup                  = ").Append(FBackup).Append('\n');
			buffer.Append("         .fExactCWords             = ").Append(FExactCWords).Append('\n');
			buffer.Append("         .fPagHidden               = ").Append(FPagHidden).Append('\n');
			buffer.Append("         .fPagResults              = ").Append(FPagResults).Append('\n');
			buffer.Append("         .fLockAtn                 = ").Append(FLockAtn).Append('\n');
			buffer.Append("         .fMirrorMargins           = ").Append(FMirrorMargins).Append('\n');
			buffer.Append("         .unused3                  = ").Append(Unused3).Append('\n');
			buffer.Append("         .fDfltTrueType            = ").Append(FDfltTrueType).Append('\n');
			
			buffer.Append("    .docinfo2             = ");
			buffer.Append(" (").Append((byte) Docinfo2).Append(" )\n");
			buffer.Append("         .fPagSupressTopSpacing     = ").Append(FPagSupressTopSpacing).Append('\n');
			buffer.Append("         .fProtEnabled             = ").Append(FProtEnabled).Append('\n');
			buffer.Append("         .fDispFormFldSel          = ").Append(FDispFormFldSel).Append('\n');
			buffer.Append("         .fRMView                  = ").Append(FRMView).Append('\n');
			buffer.Append("         .fRMPrint                 = ").Append(FRMPrint).Append('\n');
			buffer.Append("         .unused4                  = ").Append(Unused4).Append('\n');
			buffer.Append("         .fLockRev                 = ").Append(FLockRev).Append('\n');
			buffer.Append("         .fEmbedFonts              = ").Append(FEmbedFonts).Append('\n');
			
			buffer.Append("    .docinfo3             = ");
			buffer.Append(" (").Append(Docinfo3).Append(" )\n");
			buffer.Append("         .oldfNoTabForInd          = ").Append(OldfNoTabForInd).Append('\n');
			buffer.Append("         .oldfNoSpaceRaiseLower     = ").Append(OldfNoSpaceRaiseLower).Append('\n');
			buffer.Append("         .oldfSuppressSpbfAfterPageBreak     = ").Append(OldfSuppressSpbfAfterPageBreak).Append('\n');
			buffer.Append("         .oldfWrapTrailSpaces      = ").Append(OldfWrapTrailSpaces).Append('\n');
			buffer.Append("         .oldfMapPrintTextColor     = ").Append(OldfMapPrintTextColor).Append('\n');
			buffer.Append("         .oldfNoColumnBalance      = ").Append(OldfNoColumnBalance).Append('\n');
			buffer.Append("         .oldfConvMailMergeEsc     = ").Append(OldfConvMailMergeEsc).Append('\n');
			buffer.Append("         .oldfSupressTopSpacing     = ").Append(OldfSupressTopSpacing).Append('\n');
			buffer.Append("         .oldfOrigWordTableRules     = ").Append(OldfOrigWordTableRules).Append('\n');
			buffer.Append("         .oldfTransparentMetafiles     = ").Append(OldfTransparentMetafiles).Append('\n');
			buffer.Append("         .oldfShowBreaksInFrames     = ").Append(OldfShowBreaksInFrames).Append('\n');
			buffer.Append("         .oldfSwapBordersFacingPgs     = ").Append(OldfSwapBordersFacingPgs).Append('\n');
			buffer.Append("         .unused5                  = ").Append((byte) Unused5).Append('\n');
			
			buffer.Append("    .dxaTab               = ");
			buffer.Append(" (").Append(DxaTab).Append(" )\n");
			
			buffer.Append("    .wSpare               = ");
			buffer.Append(" (").Append(WSpare).Append(" )\n");
			
			buffer.Append("    .dxaHotz              = ");
			buffer.Append(" (").Append(DxaHotz).Append(" )\n");
			
			buffer.Append("    .cConsexHypLim        = ");
			buffer.Append(" (").Append(CConsexHypLim).Append(" )\n");
			
			buffer.Append("    .wSpare2              = ");
			buffer.Append(" (").Append(WSpare2).Append(" )\n");
			
			buffer.Append("    .dttmCreated          = ");
			buffer.Append(" (").Append(DttmCreated).Append(" )\n");
			
			buffer.Append("    .dttmRevised          = ");
			buffer.Append(" (").Append(DttmRevised).Append(" )\n");
			
			buffer.Append("    .dttmLastPrint        = ");
			buffer.Append(" (").Append(DttmLastPrint).Append(" )\n");
			
			buffer.Append("    .nRevision            = ");
			buffer.Append(" (").Append(NRevision).Append(" )\n");
			
			buffer.Append("    .tmEdited             = ");
			buffer.Append(" (").Append(TmEdited).Append(" )\n");
			
			buffer.Append("    .cWords               = ");
			buffer.Append(" (").Append(CWords).Append(" )\n");
			
			buffer.Append("    .cCh                  = ");
			buffer.Append(" (").Append(CCh).Append(" )\n");
			
			buffer.Append("    .cPg                  = ");
			buffer.Append(" (").Append(CPg).Append(" )\n");
			
			buffer.Append("    .cParas               = ");
			buffer.Append(" (").Append(CParas).Append(" )\n");
			
			buffer.Append("    .Edn                  = ");
			buffer.Append(" (").Append(Edn).Append(" )\n");
			buffer.Append("         .rncEdn                   = ").Append((byte) RncEdn).Append('\n');
			buffer.Append("         .nEdn                     = ").Append(NEdn).Append('\n');
			
			buffer.Append("    .Edn1                 = ");
			buffer.Append(" (").Append(Edn1).Append(" )\n");
			buffer.Append("         .epc                      = ").Append((byte) Epc).Append('\n');
			buffer.Append("         .nfcFtnRef1               = ").Append((byte) NfcFtnRef1).Append('\n');
			buffer.Append("         .nfcEdnRef1               = ").Append((byte) NfcEdnRef1).Append('\n');
			buffer.Append("         .fPrintFormData           = ").Append(FPrintFormData).Append('\n');
			buffer.Append("         .fSaveFormData            = ").Append(FSaveFormData).Append('\n');
			buffer.Append("         .fShadeFormData           = ").Append(FShadeFormData).Append('\n');
			buffer.Append("         .fWCFtnEdn                = ").Append(FWCFtnEdn).Append('\n');
			
			buffer.Append("    .cLines               = ");
			buffer.Append(" (").Append(CLines).Append(" )\n");
			
			buffer.Append("    .cWordsFtnEnd         = ");
			buffer.Append(" (").Append(CWordsFtnEnd).Append(" )\n");
			
			buffer.Append("    .cChFtnEdn            = ");
			buffer.Append(" (").Append(CChFtnEdn).Append(" )\n");
			
			buffer.Append("    .cPgFtnEdn            = ");
			buffer.Append(" (").Append(CPgFtnEdn).Append(" )\n");
			
			buffer.Append("    .cParasFtnEdn         = ");
			buffer.Append(" (").Append(CParasFtnEdn).Append(" )\n");
			
			buffer.Append("    .cLinesFtnEdn         = ");
			buffer.Append(" (").Append(CLinesFtnEdn).Append(" )\n");
			
			buffer.Append("    .lKeyProtDoc          = ");
			buffer.Append(" (").Append(LKeyProtDoc).Append(" )\n");
			
			buffer.Append("    .view                 = ");
			buffer.Append(" (").Append(View).Append(" )\n");
			buffer.Append("         .wvkSaved                 = ").Append((byte) WvkSaved).Append('\n');
			buffer.Append("         .wScaleSaved              = ").Append(WScaleSaved).Append('\n');
			buffer.Append("         .zkSaved                  = ").Append((byte) ZkSaved).Append('\n');
			buffer.Append("         .fRotateFontW6            = ").Append(FRotateFontW6).Append('\n');
			buffer.Append("         .iGutterPos               = ").Append(IGutterPos).Append('\n');
			
			buffer.Append("    .docinfo4             = ");
			buffer.Append(" (").Append(Docinfo4).Append(" )\n");
			buffer.Append("         .fNoTabForInd             = ").Append(FNoTabForInd).Append('\n');
			buffer.Append("         .fNoSpaceRaiseLower       = ").Append(FNoSpaceRaiseLower).Append('\n');
			buffer.Append("         .fSupressSpdfAfterPageBreak     = ").Append(FSupressSpdfAfterPageBreak).Append('\n');
			buffer.Append("         .fWrapTrailSpaces         = ").Append(FWrapTrailSpaces).Append('\n');
			buffer.Append("         .fMapPrintTextColor       = ").Append(FMapPrintTextColor).Append('\n');
			buffer.Append("         .fNoColumnBalance         = ").Append(FNoColumnBalance).Append('\n');
			buffer.Append("         .fConvMailMergeEsc        = ").Append(FConvMailMergeEsc).Append('\n');
			buffer.Append("         .fSupressTopSpacing       = ").Append(FSupressTopSpacing).Append('\n');
			buffer.Append("         .fOrigWordTableRules      = ").Append(FOrigWordTableRules).Append('\n');
			buffer.Append("         .fTransparentMetafiles     = ").Append(FTransparentMetafiles).Append('\n');
			buffer.Append("         .fShowBreaksInFrames      = ").Append(FShowBreaksInFrames).Append('\n');
			buffer.Append("         .fSwapBordersFacingPgs     = ").Append(FSwapBordersFacingPgs).Append('\n');
			buffer.Append("         .fSuppressTopSPacingMac5     = ").Append(FSuppressTopSPacingMac5).Append('\n');
			buffer.Append("         .fTruncDxaExpand          = ").Append(FTruncDxaExpand).Append('\n');
			buffer.Append("         .fPrintBodyBeforeHdr      = ").Append(FPrintBodyBeforeHdr).Append('\n');
			buffer.Append("         .fNoLeading               = ").Append(FNoLeading).Append('\n');
			buffer.Append("         .fMWSmallCaps             = ").Append(FMWSmallCaps).Append('\n');
			
			buffer.Append("    .adt                  = ");
			buffer.Append(" (").Append(Adt).Append(" )\n");
			
			buffer.Append("    .doptypography        = ");
			buffer.Append(" (").Append(Doptypography).Append(" )\n");
			
			buffer.Append("    .dogrid               = ");
			buffer.Append(" (").Append(Dogrid).Append(" )\n");
			
			buffer.Append("    .docinfo5             = ");
			buffer.Append(" (").Append(Docinfo5).Append(" )\n");
			buffer.Append("         .lvl                      = ").Append((byte) Lvl).Append('\n');
			buffer.Append("         .fGramAllDone             = ").Append(FGramAllDone).Append('\n');
			buffer.Append("         .fGramAllClean            = ").Append(FGramAllClean).Append('\n');
			buffer.Append("         .fSubsetFonts             = ").Append(FSubsetFonts).Append('\n');
			buffer.Append("         .fHideLastVersion         = ").Append(FHideLastVersion).Append('\n');
			buffer.Append("         .fHtmlDoc                 = ").Append(FHtmlDoc).Append('\n');
			buffer.Append("         .fSnapBorder              = ").Append(FSnapBorder).Append('\n');
			buffer.Append("         .fIncludeHeader           = ").Append(FIncludeHeader).Append('\n');
			buffer.Append("         .fIncludeFooter           = ").Append(FIncludeFooter).Append('\n');
			buffer.Append("         .fForcePageSizePag        = ").Append(FForcePageSizePag).Append('\n');
			buffer.Append("         .fMinFontSizePag          = ").Append(FMinFontSizePag).Append('\n');
			
			buffer.Append("    .docinfo6             = ");
			buffer.Append(" (").Append(Docinfo6).Append(" )\n");
			buffer.Append("         .fHaveVersions            = ").Append(FHaveVersions).Append('\n');
			buffer.Append("         .fAutoVersions            = ").Append(FAutoVersions).Append('\n');
			
			buffer.Append("    .asumyi               = ");
			buffer.Append(" (").Append(Asumyi).Append(" )\n");
			
			buffer.Append("    .cChWS                = ");
			buffer.Append(" (").Append(CChWS).Append(" )\n");
			
			buffer.Append("    .cChWSFtnEdn          = ");
			buffer.Append(" (").Append(CChWSFtnEdn).Append(" )\n");
			
			buffer.Append("    .grfDocEvents         = ");
			buffer.Append(" (").Append(GrfDocEvents).Append(" )\n");
			
			buffer.Append("    .virusinfo            = ");
			buffer.Append(" (").Append(Virusinfo).Append(" )\n");
			buffer.Append("         .fVirusPrompted           = ").Append(FVirusPrompted).Append('\n');
			buffer.Append("         .fVirusLoadSafe           = ").Append(FVirusLoadSafe).Append('\n');
			//BUG
			//buffer.Append("         .KeyVirusSession30        = ").Append(getKeyVirusSession30()).Append('\n');
			
			buffer.Append("    .Spare                = ");
			buffer.Append(" (").Append(Spare).Append(" )\n");
			
			buffer.Append("    .reserved1            = ");
			buffer.Append(" (").Append(Reserved1).Append(" )\n");
			
			buffer.Append("    .reserved2            = ");
			buffer.Append(" (").Append(Reserved2).Append(" )\n");
			
			buffer.Append("    .cDBC                 = ");
			buffer.Append(" (").Append(CDBC).Append(" )\n");
			
			buffer.Append("    .cDBCFtnEdn           = ");
			buffer.Append(" (").Append(CDBCFtnEdn).Append(" )\n");
			
			buffer.Append("    .reserved             = ");
			buffer.Append(" (").Append(Reserved).Append(" )\n");
			
			buffer.Append("    .nfcFtnRef            = ");
			buffer.Append(" (").Append(NfcFtnRef).Append(" )\n");
			
			buffer.Append("    .nfcEdnRef            = ");
			buffer.Append(" (").Append(NfcEdnRef).Append(" )\n");
			
			buffer.Append("    .hpsZoonFontPag       = ");
			buffer.Append(" (").Append(HpsZoonFontPag).Append(" )\n");
			
			buffer.Append("    .dywDispPag           = ");
			buffer.Append(" (").Append(DywDispPag).Append(" )\n");
			
			buffer.Append("[/DOP]\n");
			return buffer.ToString();
		}

/*
		/// <summary> Sets the KeyVirusSession30 field value.
		/// 
		/// </summary>
		public virtual void SetKeyVirusSession30(int __value)
		{
			field_43_virusinfo = (int) KeyVirusSession30.SetValue(field_43_virusinfo, __value);
		}
		
		/// <summary> </summary>
		/// <returns>  the KeyVirusSession30 field value.
		/// </returns>
		public virtual int getKeyVirusSession30()
		{
			return (int) KeyVirusSession30.GetValue(field_43_virusinfo);
		}
*/
	}
}