// 
// PropertyIDMap.cs
//  
// Copyright 2002-2004  Apache Software Foundation
//
// Jakarta Poi Authors:
//   Andrew C. Oliver
//
// Poi.Net Authors:
//   Johannes Roith(johannes at jroith dot de)
//  
// 
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

using System;

using Poi.Net.Util;

using Poi.Net.HWPF.Model;
using Poi.Net.HWPF.UserModel;
namespace Poi.Net.HWPF.Model.Types
{
	
	/// <summary> File information Block.
	/// NOTE: This source is automatically generated please do not modify this file.  Either subclass or
	/// remove the record in src/records/definitions.
	/// </summary>

	public abstract class FIBAbstractType : HDFType
	{
		protected internal int field_1_wIdent;
		protected internal int field_2_nFib;
		protected internal int field_3_nProduct;
		protected internal int field_4_lid;
		protected internal int field_5_pnNext;
		protected internal short field_6_options;
		private static BitField fDot = new BitField(0x0001);
		private static BitField fGlsy = new BitField(0x0002);
		private static BitField fComplex = new BitField(0x0004);
		private static BitField fHasPic = new BitField(0x0008);
		private static BitField cQuickSaves = new BitField(0x00F0);
		private static BitField fEncrypted = new BitField(0x0100);
		private static BitField fWhichTblStm = new BitField(0x0200);
		private static BitField fReadOnlyRecommended = new BitField(0x0400);
		private static BitField fWriteReservation = new BitField(0x0800);
		private static BitField fExtChar = new BitField(0x1000);
		private static BitField fLoadOverride = new BitField(0x2000);
		private static BitField fFarEast = new BitField(0x4000);
		private static BitField fCrypto = new BitField(0x8000);
		protected internal int field_7_nFibBack;
		protected internal int field_8_lKey;
		protected internal int field_9_envr;
		protected internal short field_10_history;
		private static BitField fMac = new BitField(0x0001);
		private static BitField fEmptySpecial = new BitField(0x0002);
		private static BitField fLoadOverridePage = new BitField(0x0004);
		private static BitField fFutureSavedUndo = new BitField(0x0008);
		private static BitField fWord97Saved = new BitField(0x0010);
		private static BitField fSpare0 = new BitField(0x00FE);
		protected internal int field_11_chs;
		protected internal int field_12_chsTables;
		protected internal int field_13_fcMin;
		protected internal int field_14_fcMac;
		
		
		/// <summary> Size of record (exluding 4 byte header)</summary>
		virtual public int Size 
		{
			get {
				return 2 + 2 + 2 + 2 + 2 + 2 + 2 + 2 + 2 + 2 + 2 + 2 + 4 + 4;
			}
			
		}
		
		/// <summary> Get the wIdent field for the FIB record.</summary>
		/// <summary> Set the wIdent field for the FIB record.</summary>
		virtual public int WIdent {
			get {
				return field_1_wIdent;
			}
			
			set {
				this.field_1_wIdent = value;
			}
			
		}
		
		/// <summary> Get the nFib field for the FIB record.</summary>
		/// <summary> Set the nFib field for the FIB record.</summary>
		virtual public int NFib {
			get {
				return field_2_nFib;
			}
			
			set {
				this.field_2_nFib = value;
			}
			
		}
		
		/// <summary> Get the nProduct field for the FIB record.</summary>
		/// <summary> Set the nProduct field for the FIB record.</summary>
		virtual public int NProduct {
			get {
				return field_3_nProduct;
			}
			
			set {
				this.field_3_nProduct = value;
			}
			
		}
		
		/// <summary> Get the lid field for the FIB record.</summary>
		/// <summary> Set the lid field for the FIB record.</summary>
		virtual public int Lid {
			get {
				return field_4_lid;
			}
			
			set {
				this.field_4_lid = value;
			}
			
		}
		
		/// <summary> Get the pnNext field for the FIB record.</summary>
		/// <summary> Set the pnNext field for the FIB record.</summary>
		virtual public int PnNext {
			get {
				return field_5_pnNext;
			}
			
			set {
				this.field_5_pnNext = value;
			}
			
		}
		
		/// <summary> Get the options field for the FIB record.</summary>
		/// <summary> Set the options field for the FIB record.</summary>
		virtual public short Options {
			get {
				return field_6_options;
			}
			
			set {
				this.field_6_options = value;
			}
			
		}
		
		/// <summary> Get the nFibBack field for the FIB record.</summary>
		/// <summary> Set the nFibBack field for the FIB record.</summary>
		virtual public int NFibBack {
			get {
				return field_7_nFibBack;
			}
			
			set {
				this.field_7_nFibBack = value;
			}
			
		}
		
		/// <summary> Get the lKey field for the FIB record.</summary>
		/// <summary> Set the lKey field for the FIB record.</summary>
		virtual public int LKey {
			get {
				return field_8_lKey;
			}
			
			set {
				this.field_8_lKey = value;
			}
			
		}
		
		/// <summary> Get the envr field for the FIB record.</summary>
		/// <summary> Set the envr field for the FIB record.</summary>
		virtual public int Envr {
			get {
				return field_9_envr;
			}
			
			set {
				this.field_9_envr = value;
			}
			
		}
		
		/// <summary> Get the history field for the FIB record.</summary>
		/// <summary> Set the history field for the FIB record.</summary>
		virtual public short History {
			get {
				return field_10_history;
			}
			
			set {
				this.field_10_history = value;
			}
			
		}
		
		/// <summary> Get the chs field for the FIB record.</summary>
		/// <summary> Set the chs field for the FIB record.</summary>
		virtual public int Chs {
			get {
				return field_11_chs;
			}
			
			set {
				this.field_11_chs = value;
			}
			
		}
		
		/// <summary> Get the chsTables field for the FIB record.</summary>
		/// <summary> Set the chsTables field for the FIB record.</summary>
		virtual public int ChsTables {
			get {
				return field_12_chsTables;
			}
			
			set {
				this.field_12_chsTables = value;
			}
			
		}
		
		/// <summary> Get the fcMin field for the FIB record.</summary>
		/// <summary> Set the fcMin field for the FIB record.</summary>
		virtual public int FcMin {
			get {
				return field_13_fcMin;
			}
			
			set {
				this.field_13_fcMin = value;
			}
			
		}
		
		/// <summary> Get the fcMac field for the FIB record.</summary>
		/// <summary> Set the fcMac field for the FIB record.</summary>
		virtual public int FcMac {
			get {
				return field_14_fcMac;
			}
			
			set {
				this.field_14_fcMac = value;
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fDot field value.
		/// </returns>
		/// <summary> Sets the fDot field value.
		/// 
		/// </summary>
		virtual public bool FDot {
			get {
				return fDot.IsSet(field_6_options);
			}
			
			set {
				field_6_options = (short) fDot.SetBoolean(field_6_options, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fGlsy field value.
		/// </returns>
		/// <summary> Sets the fGlsy field value.
		/// 
		/// </summary>
		virtual public bool FGlsy {
			get {
				return fGlsy.IsSet(field_6_options);
			}
			
			set {
				field_6_options = (short) fGlsy.SetBoolean(field_6_options, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fComplex field value.
		/// </returns>
		/// <summary> Sets the fComplex field value.
		/// 
		/// </summary>
		virtual public bool FComplex {
			get {
				return fComplex.IsSet(field_6_options);
			}
			
			set {
				field_6_options = (short) fComplex.SetBoolean(field_6_options, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fHasPic field value.
		/// </returns>
		/// <summary> Sets the fHasPic field value.
		/// 
		/// </summary>
		virtual public bool FHasPic {
			get {
				return fHasPic.IsSet(field_6_options);
			}
			
			set {
				field_6_options = (short) fHasPic.SetBoolean(field_6_options, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the cQuickSaves field value.
		/// </returns>
		/// <summary> Sets the cQuickSaves field value.
		/// 
		/// </summary>
		virtual public byte CQuickSaves {
			get {
				return (byte) cQuickSaves.GetValue(field_6_options);
			}
			
			set {
				field_6_options = (short) cQuickSaves.SetValue(field_6_options, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fEncrypted field value.
		/// </returns>
		/// <summary> Sets the fEncrypted field value.
		/// 
		/// </summary>
		virtual public bool FEncrypted {
			get {
				return fEncrypted.IsSet(field_6_options);
			}
			
			set {
				field_6_options = (short) fEncrypted.SetBoolean(field_6_options, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fWhichTblStm field value.
		/// </returns>
		/// <summary> Sets the fWhichTblStm field value.
		/// 
		/// </summary>
		virtual public bool FWhichTblStm {
			get {
				return fWhichTblStm.IsSet(field_6_options);
			}
			
			set {
				field_6_options = (short) fWhichTblStm.SetBoolean(field_6_options, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fReadOnlyRecommended field value.
		/// </returns>
		/// <summary> Sets the fReadOnlyRecommended field value.
		/// 
		/// </summary>
		virtual public bool FReadOnlyRecommended {
			get {
				return fReadOnlyRecommended.IsSet(field_6_options);
			}
			
			set {
				field_6_options = (short) fReadOnlyRecommended.SetBoolean(field_6_options, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fWriteReservation field value.
		/// </returns>
		/// <summary> Sets the fWriteReservation field value.
		/// 
		/// </summary>
		virtual public bool FWriteReservation {
			get {
				return fWriteReservation.IsSet(field_6_options);
			}
			
			set {
				field_6_options = (short) fWriteReservation.SetBoolean(field_6_options, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fExtChar field value.
		/// </returns>
		/// <summary> Sets the fExtChar field value.
		/// 
		/// </summary>
		virtual public bool FExtChar {
			get {
				return fExtChar.IsSet(field_6_options);
			}
			
			set {
				field_6_options = (short) fExtChar.SetBoolean(field_6_options, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fLoadOverride field value.
		/// </returns>
		/// <summary> Sets the fLoadOverride field value.
		/// 
		/// </summary>
		virtual public bool FLoadOverride {
			get {
				return fLoadOverride.IsSet(field_6_options);
			}
			
			set {
				field_6_options = (short) fLoadOverride.SetBoolean(field_6_options, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fFarEast field value.
		/// </returns>
		/// <summary> Sets the fFarEast field value.
		/// 
		/// </summary>
		virtual public bool FFarEast {
			get {
				return fFarEast.IsSet(field_6_options);
			}
			
			set {
				field_6_options = (short) fFarEast.SetBoolean(field_6_options, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fCrypto field value.
		/// </returns>
		/// <summary> Sets the fCrypto field value.
		/// 
		/// </summary>
		virtual public bool FCrypto {
			get {
				return fCrypto.IsSet(field_6_options);
			}
			
			set {
				field_6_options = (short) fCrypto.SetBoolean(field_6_options, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fMac field value.
		/// </returns>
		/// <summary> Sets the fMac field value.
		/// 
		/// </summary>
		virtual public bool FMac {
			get {
				return fMac.IsSet(field_10_history);
			}
			
			set {
				field_10_history = (short) fMac.SetBoolean(field_10_history, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fEmptySpecial field value.
		/// </returns>
		/// <summary> Sets the fEmptySpecial field value.
		/// 
		/// </summary>
		virtual public bool FEmptySpecial {
			get {
				return fEmptySpecial.IsSet(field_10_history);
			}
			
			set {
				field_10_history = (short) fEmptySpecial.SetBoolean(field_10_history, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fLoadOverridePage field value.
		/// </returns>
		/// <summary> Sets the fLoadOverridePage field value.
		/// 
		/// </summary>
		virtual public bool FLoadOverridePage {
			get {
				return fLoadOverridePage.IsSet(field_10_history);
			}
			
			set {
				field_10_history = (short) fLoadOverridePage.SetBoolean(field_10_history, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fFutureSavedUndo field value.
		/// </returns>
		/// <summary> Sets the fFutureSavedUndo field value.
		/// 
		/// </summary>
		virtual public bool FFutureSavedUndo {
			get {
				return fFutureSavedUndo.IsSet(field_10_history);
			}
			
			set {
				field_10_history = (short) fFutureSavedUndo.SetBoolean(field_10_history, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fWord97Saved field value.
		/// </returns>
		/// <summary> Sets the fWord97Saved field value.
		/// 
		/// </summary>
		virtual public bool FWord97Saved {
			get {
				return fWord97Saved.IsSet(field_10_history);
			}
			
			set {
				field_10_history = (short) fWord97Saved.SetBoolean(field_10_history, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fSpare0 field value.
		/// </returns>
		/// <summary> Sets the fSpare0 field value.
		/// 
		/// </summary>
		virtual public byte FSpare0 {
			get {
				return (byte) fSpare0.GetValue(field_10_history);
			}
			
			set {
				field_10_history = (short) fSpare0.SetValue(field_10_history, value);
			}
			
		}
		
		public FIBAbstractType()
		{
		}
		
		protected internal virtual void FillFields(byte[] data, int offset)
		{
			field_1_wIdent = LittleEndian.GetShort(data, 0x0 + offset);
			field_2_nFib = LittleEndian.GetShort(data, 0x2 + offset);
			field_3_nProduct = LittleEndian.GetShort(data, 0x4 + offset);
			field_4_lid = LittleEndian.GetShort(data, 0x6 + offset);
			field_5_pnNext = LittleEndian.GetShort(data, 0x8 + offset);
			field_6_options = LittleEndian.GetShort(data, 0xa + offset);
			field_7_nFibBack = LittleEndian.GetShort(data, 0xc + offset);
			field_8_lKey = LittleEndian.GetShort(data, 0xe + offset);
			field_9_envr = LittleEndian.GetShort(data, 0x10 + offset);
			field_10_history = LittleEndian.GetShort(data, 0x12 + offset);
			field_11_chs = LittleEndian.GetShort(data, 0x14 + offset);
			field_12_chsTables = LittleEndian.GetShort(data, 0x16 + offset);
			field_13_fcMin = LittleEndian.GetInt(data, 0x18 + offset);
			field_14_fcMac = LittleEndian.GetInt(data, 0x1c + offset);
		}
		
		public virtual void Serialize(byte[] data, int offset)
		{
			LittleEndian.PutShort(data, 0x0 + offset, (short) field_1_wIdent); ;
			LittleEndian.PutShort(data, 0x2 + offset, (short) field_2_nFib); ;
			LittleEndian.PutShort(data, 0x4 + offset, (short) field_3_nProduct); ;
			LittleEndian.PutShort(data, 0x6 + offset, (short) field_4_lid); ;
			LittleEndian.PutShort(data, 0x8 + offset, (short) field_5_pnNext); ;
			LittleEndian.PutShort(data, 0xa + offset, (short) field_6_options); ;
			LittleEndian.PutShort(data, 0xc + offset, (short) field_7_nFibBack); ;
			LittleEndian.PutShort(data, 0xe + offset, (short) field_8_lKey); ;
			LittleEndian.PutShort(data, 0x10 + offset, (short) field_9_envr); ;
			LittleEndian.PutShort(data, 0x12 + offset, (short) field_10_history); ;
			LittleEndian.PutShort(data, 0x14 + offset, (short) field_11_chs); ;
			LittleEndian.PutShort(data, 0x16 + offset, (short) field_12_chsTables); ;
			LittleEndian.PutInt(data, 0x18 + offset, field_13_fcMin); ;
			LittleEndian.PutInt(data, 0x1c + offset, field_14_fcMac); ;
		}
		
		public override string ToString()
		{
			System.Text.StringBuilder buffer = new System.Text.StringBuilder();
			
			buffer.Append("[FIB]\n");
			
			buffer.Append("    .wIdent               = ");
			buffer.Append(" (").Append(WIdent).Append(" )\n");
			
			buffer.Append("    .nFib                 = ");
			buffer.Append(" (").Append(NFib).Append(" )\n");
			
			buffer.Append("    .nProduct             = ");
			buffer.Append(" (").Append(NProduct).Append(" )\n");
			
			buffer.Append("    .lid                  = ");
			buffer.Append(" (").Append(Lid).Append(" )\n");
			
			buffer.Append("    .pnNext               = ");
			buffer.Append(" (").Append(PnNext).Append(" )\n");
			
			buffer.Append("    .options              = ");
			buffer.Append(" (").Append(Options).Append(" )\n");
			buffer.Append("         .fDot                     = ").Append(FDot).Append('\n');
			buffer.Append("         .fGlsy                    = ").Append(FGlsy).Append('\n');
			buffer.Append("         .fComplex                 = ").Append(FComplex).Append('\n');
			buffer.Append("         .fHasPic                  = ").Append(FHasPic).Append('\n');
			buffer.Append("         .cQuickSaves              = ").Append((byte) CQuickSaves).Append('\n');
			buffer.Append("         .fEncrypted               = ").Append(FEncrypted).Append('\n');
			buffer.Append("         .fWhichTblStm             = ").Append(FWhichTblStm).Append('\n');
			buffer.Append("         .fReadOnlyRecommended     = ").Append(FReadOnlyRecommended).Append('\n');
			buffer.Append("         .fWriteReservation        = ").Append(FWriteReservation).Append('\n');
			buffer.Append("         .fExtChar                 = ").Append(FExtChar).Append('\n');
			buffer.Append("         .fLoadOverride            = ").Append(FLoadOverride).Append('\n');
			buffer.Append("         .fFarEast                 = ").Append(FFarEast).Append('\n');
			buffer.Append("         .fCrypto                  = ").Append(FCrypto).Append('\n');
			
			buffer.Append("    .nFibBack             = ");
			buffer.Append(" (").Append(NFibBack).Append(" )\n");
			
			buffer.Append("    .lKey                 = ");
			buffer.Append(" (").Append(LKey).Append(" )\n");
			
			buffer.Append("    .envr                 = ");
			buffer.Append(" (").Append(Envr).Append(" )\n");
			
			buffer.Append("    .history              = ");
			buffer.Append(" (").Append(History).Append(" )\n");
			buffer.Append("         .fMac                     = ").Append(FMac).Append('\n');
			buffer.Append("         .fEmptySpecial            = ").Append(FEmptySpecial).Append('\n');
			buffer.Append("         .fLoadOverridePage        = ").Append(FLoadOverridePage).Append('\n');
			buffer.Append("         .fFutureSavedUndo         = ").Append(FFutureSavedUndo).Append('\n');
			buffer.Append("         .fWord97Saved             = ").Append(FWord97Saved).Append('\n');
			buffer.Append("         .fSpare0                  = ").Append((byte) FSpare0).Append('\n');
			
			buffer.Append("    .chs                  = ");
			buffer.Append(" (").Append(Chs).Append(" )\n");
			
			buffer.Append("    .chsTables            = ");
			buffer.Append(" (").Append(ChsTables).Append(" )\n");
			
			buffer.Append("    .fcMin                = ");
			buffer.Append(" (").Append(FcMin).Append(" )\n");
			
			buffer.Append("    .fcMac                = ");
			buffer.Append(" (").Append(FcMac).Append(" )\n");
			
			buffer.Append("[/FIB]\n");
			return buffer.ToString();
		}
	} 
}