// 
// PAPAbstractType.cs
//  
// Copyright 2002-2004  Apache Software Foundation
//
// Jakarta Poi Authors:
//   S. Ryan Ackley
//
// Poi.Net Authors:
//   Johannes Roith(johannes at jroith dot de)
//  
// 
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

using System;

using Poi.Net.Util;
using Poi.Net.HWPF.Model;
using Poi.Net.HWPF.UserModel;

namespace Poi.Net.HWPF.Model.Types
{
	
	/// <summary> Paragraph Properties.
	/// NOTE: This source is automatically generated please do not modify this file.  Either subclass or
	/// remove the record in src/records/definitions.
	/// </summary>
	public abstract class PAPAbstractType : HDFType
	{
		
		protected internal int field_1_istd;
		protected internal byte field_2_jc;
		protected internal byte field_3_fKeep;
		protected internal byte field_4_fKeepFollow;
		protected internal byte field_5_fPageBreakBefore;
		protected internal byte field_6_fBrLnAbove;
		protected internal byte field_7_fBrLnBelow;
		protected internal byte field_8_pcVert;
		protected internal byte field_9_pcHorz;
		protected internal byte field_10_brcp;
		protected internal byte field_11_brcl;
		protected internal byte field_12_ilvl;
		protected internal byte field_13_fNoLnn;
		protected internal int field_14_ilfo;
		protected internal byte field_15_fSideBySide;
		protected internal byte field_16_fNoAutoHyph;
		protected internal byte field_17_fWidowControl;
		protected internal int field_18_dxaRight;
		protected internal int field_19_dxaLeft;
		protected internal int field_20_dxaLeft1;
		protected internal LineSpacingDescriptor field_21_lspd;
		protected internal int field_22_dyaBefore;
		protected internal int field_23_dyaAfter;
		protected internal byte[] field_24_phe;
		protected internal byte field_25_fCrLf;
		protected internal byte field_26_fUsePgsuSettings;
		protected internal byte field_27_fAdjustRight;
		protected internal byte field_28_fKinsoku;
		protected internal byte field_29_fWordWrap;
		protected internal byte field_30_fOverflowPunct;
		protected internal byte field_31_fTopLinePunct;
		protected internal byte field_32_fAutoSpaceDE;
		protected internal byte field_33_fAutoSpaceDN;
		protected internal int field_34_wAlignFont;
		protected internal short field_35_fontAlign;
		private static BitField fVertical = new BitField(0x0001);
		private static BitField fBackward = new BitField(0x0002);
		private static BitField fRotateFont = new BitField(0x0004);
		protected internal byte field_36_fBackward;
		protected internal byte field_37_fRotateFont;
		protected internal byte field_38_fInTable;
		protected internal byte field_39_fTtp;
		protected internal byte field_40_wr;
		protected internal byte field_41_fLocked;
		protected internal byte[] field_42_ptap;
		protected internal int field_43_dxaAbs;
		protected internal int field_44_dyaAbs;
		protected internal int field_45_dxaWidth;
		protected internal BorderCode field_46_brcTop;
		protected internal BorderCode field_47_brcLeft;
		protected internal BorderCode field_48_brcBottom;
		protected internal BorderCode field_49_brcRight;
		protected internal BorderCode field_50_brcBetween;
		protected internal BorderCode field_51_brcBar;
		protected internal int field_52_dxaFromText;
		protected internal int field_53_dyaFromText;
		protected internal int field_54_dyaHeight;
		protected internal byte field_55_fMinHeight;
		protected internal ShadingDescriptor field_56_shd;
		protected internal DropCapSpecifier field_57_dcs;
		protected internal byte field_58_lvl;
		protected internal byte field_59_fNumRMIns;
		protected internal byte[] field_60_anld;
		protected internal int field_61_fPropRMark;
		protected internal int field_62_ibstPropRMark;
		protected internal DateAndTime field_63_dttmPropRMark;
		protected internal byte[] field_64_numrm;
		protected internal int field_65_itbdMac;
		protected internal int[] field_66_rgdxaTab;
		protected internal byte[] field_67_rgtbd;
		protected internal byte field_68_tableLevel;
		protected internal byte field_69_fTtpEmbedded;
		protected internal byte field_70_embeddedCellMark;
		
		/// <summary> Size of record (exluding 4 byte header)</summary>
		virtual public int Size 
		{
			get {
				return 4 + + 2 + 1 + 1 + 1 + 1 + 1 + 1 + 1 + 1 + 1 + 1 + 1 + 1 + 2 + 1 + 1 + 1 + 4 + 4 + 4 + 4 + 4 + 4 + 12 + 1 + 1 + 1 + 1 + 1 + 1 + 1 + 1 + 1 + 2 + 2 + 1 + 1 + 1 + 1 + 1 + 1 + 4 + 4 + 4 + 4 + 4 + 4 + 4 + 4 + 4 + 4 + 4 + 4 + 2 + 1 + 2 + 2 + 1 + 1 + 84 + 1 + 2 + 4 + 128 + 2 + 128 + 128 + 1 + 1 + 1;
			}
			
		}
		
		/// <summary> Get the istd field for the PAP record.</summary>
		/// <summary> Set the istd field for the PAP record.</summary>
		virtual public int Istd {
			get {
				return field_1_istd;
			}
			
			set {
				this.field_1_istd = value;
			}
			
		}
		
		/// <summary> Get the jc field for the PAP record.</summary>
		/// <summary> Set the jc field for the PAP record.</summary>
		virtual public byte Jc {
			get {
				return field_2_jc;
			}
			
			set {
				this.field_2_jc = value;
			}
			
		}
		
		/// <summary> Get the fKeep field for the PAP record.</summary>
		/// <summary> Set the fKeep field for the PAP record.</summary>
		virtual public byte FKeep {
			get {
				return field_3_fKeep;
			}
			
			set {
				this.field_3_fKeep = value;
			}
			
		}
		
		/// <summary> Get the fKeepFollow field for the PAP record.</summary>
		/// <summary> Set the fKeepFollow field for the PAP record.</summary>
		virtual public byte FKeepFollow {
			get {
				return field_4_fKeepFollow;
			}
			
			set {
				this.field_4_fKeepFollow = value;
			}
			
		}
		
		/// <summary> Get the fPageBreakBefore field for the PAP record.</summary>
		/// <summary> Set the fPageBreakBefore field for the PAP record.</summary>
		virtual public byte FPageBreakBefore {
			get {
				return field_5_fPageBreakBefore;
			}
			
			set {
				this.field_5_fPageBreakBefore = value;
			}
			
		}
		
		/// <summary> Get the fBrLnAbove field for the PAP record.</summary>
		/// <summary> Set the fBrLnAbove field for the PAP record.</summary>
		virtual public byte FBrLnAbove {
			get {
				return field_6_fBrLnAbove;
			}
			
			set {
				this.field_6_fBrLnAbove = value;
			}
			
		}
		
		/// <summary> Get the fBrLnBelow field for the PAP record.</summary>
		/// <summary> Set the fBrLnBelow field for the PAP record.</summary>
		virtual public byte FBrLnBelow {
			get {
				return field_7_fBrLnBelow;
			}
			
			set {
				this.field_7_fBrLnBelow = value;
			}
			
		}
		
		/// <summary> Get the pcVert field for the PAP record.</summary>
		/// <summary> Set the pcVert field for the PAP record.</summary>
		virtual public byte PcVert {
			get {
				return field_8_pcVert;
			}
			
			set {
				this.field_8_pcVert = value;
			}
			
		}
		
		/// <summary> Get the pcHorz field for the PAP record.</summary>
		/// <summary> Set the pcHorz field for the PAP record.</summary>
		virtual public byte PcHorz {
			get {
				return field_9_pcHorz;
			}
			
			set {
				this.field_9_pcHorz = value;
			}
			
		}
		
		/// <summary> Get the brcp field for the PAP record.</summary>
		/// <summary> Set the brcp field for the PAP record.</summary>
		virtual public byte Brcp {
			get {
				return field_10_brcp;
			}
			
			set {
				this.field_10_brcp = value;
			}
			
		}
		
		/// <summary> Get the brcl field for the PAP record.</summary>
		/// <summary> Set the brcl field for the PAP record.</summary>
		virtual public byte Brcl {
			get {
				return field_11_brcl;
			}
			
			set {
				this.field_11_brcl = value;
			}
			
		}
		
		/// <summary> Get the ilvl field for the PAP record.</summary>
		/// <summary> Set the ilvl field for the PAP record.</summary>
		virtual public byte Ilvl {
			get {
				return field_12_ilvl;
			}
			
			set {
				this.field_12_ilvl = value;
			}
			
		}
		
		/// <summary> Get the fNoLnn field for the PAP record.</summary>
		/// <summary> Set the fNoLnn field for the PAP record.</summary>
		virtual public byte FNoLnn {
			get {
				return field_13_fNoLnn;
			}
			
			set {
				this.field_13_fNoLnn = value;
			}
			
		}
		
		/// <summary> Get the ilfo field for the PAP record.</summary>
		/// <summary> Set the ilfo field for the PAP record.</summary>
		virtual public int Ilfo {
			get {
				return field_14_ilfo;
			}
			
			set {
				this.field_14_ilfo = value;
			}
			
		}
		
		/// <summary> Get the fSideBySide field for the PAP record.</summary>
		/// <summary> Set the fSideBySide field for the PAP record.</summary>
		virtual public byte FSideBySide {
			get {
				return field_15_fSideBySide;
			}
			
			set {
				this.field_15_fSideBySide = value;
			}
			
		}
		
		/// <summary> Get the fNoAutoHyph field for the PAP record.</summary>
		/// <summary> Set the fNoAutoHyph field for the PAP record.</summary>
		virtual public byte FNoAutoHyph {
			get {
				return field_16_fNoAutoHyph;
			}
			
			set {
				this.field_16_fNoAutoHyph = value;
			}
			
		}
		
		/// <summary> Get the fWidowControl field for the PAP record.</summary>
		/// <summary> Set the fWidowControl field for the PAP record.</summary>
		virtual public byte FWidowControl {
			get {
				return field_17_fWidowControl;
			}
			
			set {
				this.field_17_fWidowControl = value;
			}
			
		}
		
		/// <summary> Get the dxaRight field for the PAP record.</summary>
		/// <summary> Set the dxaRight field for the PAP record.</summary>
		virtual public int DxaRight {
			get {
				return field_18_dxaRight;
			}
			
			set {
				this.field_18_dxaRight = value;
			}
			
		}
		
		/// <summary> Get the dxaLeft field for the PAP record.</summary>
		/// <summary> Set the dxaLeft field for the PAP record.</summary>
		virtual public int DxaLeft {
			get {
				return field_19_dxaLeft;
			}
			
			set {
				this.field_19_dxaLeft = value;
			}
			
		}
		
		/// <summary> Get the dxaLeft1 field for the PAP record.</summary>
		/// <summary> Set the dxaLeft1 field for the PAP record.</summary>
		virtual public int DxaLeft1 {
			get {
				return field_20_dxaLeft1;
			}
			
			set {
				this.field_20_dxaLeft1 = value;
			}
			
		}
		
		/// <summary> Get the lspd field for the PAP record.</summary>
		/// <summary> Set the lspd field for the PAP record.</summary>
		virtual public LineSpacingDescriptor Lspd {
			get {
				return field_21_lspd;
			}
			
			set {
				this.field_21_lspd = value;
			}
			
		}
		
		/// <summary> Get the dyaBefore field for the PAP record.</summary>
		/// <summary> Set the dyaBefore field for the PAP record.</summary>
		virtual public int DyaBefore {
			get {
				return field_22_dyaBefore;
			}
			
			set {
				this.field_22_dyaBefore = value;
			}
			
		}
		
		/// <summary> Get the dyaAfter field for the PAP record.</summary>
		/// <summary> Set the dyaAfter field for the PAP record.</summary>
		virtual public int DyaAfter {
			get {
				return field_23_dyaAfter;
			}
			
			set {
				this.field_23_dyaAfter = value;
			}
			
		}
		
		/// <summary> Get the phe field for the PAP record.</summary>
		/// <summary> Set the phe field for the PAP record.</summary>
		virtual public byte[] Phe {
			get {
				return field_24_phe;
			}
			
			set {
				this.field_24_phe = value;
			}
			
		}
		
		/// <summary> Get the fCrLf field for the PAP record.</summary>
		/// <summary> Set the fCrLf field for the PAP record.</summary>
		virtual public byte FCrLf {
			get {
				return field_25_fCrLf;
			}
			
			set {
				this.field_25_fCrLf = value;
			}
			
		}
		
		/// <summary> Get the fUsePgsuSettings field for the PAP record.</summary>
		/// <summary> Set the fUsePgsuSettings field for the PAP record.</summary>
		virtual public byte FUsePgsuSettings {
			get {
				return field_26_fUsePgsuSettings;
			}
			
			set {
				this.field_26_fUsePgsuSettings = value;
			}
			
		}
		
		/// <summary> Get the fAdjustRight field for the PAP record.</summary>
		/// <summary> Set the fAdjustRight field for the PAP record.</summary>
		virtual public byte FAdjustRight {
			get {
				return field_27_fAdjustRight;
			}
			
			set {
				this.field_27_fAdjustRight = value;
			}
			
		}
		
		/// <summary> Get the fKinsoku field for the PAP record.</summary>
		/// <summary> Set the fKinsoku field for the PAP record.</summary>
		virtual public byte FKinsoku {
			get {
				return field_28_fKinsoku;
			}
			
			set {
				this.field_28_fKinsoku = value;
			}
			
		}
		
		/// <summary> Get the fWordWrap field for the PAP record.</summary>
		/// <summary> Set the fWordWrap field for the PAP record.</summary>
		virtual public byte FWordWrap {
			get {
				return field_29_fWordWrap;
			}
			
			set {
				this.field_29_fWordWrap = value;
			}
			
		}
		
		/// <summary> Get the fOverflowPunct field for the PAP record.</summary>
		/// <summary> Set the fOverflowPunct field for the PAP record.</summary>
		virtual public byte FOverflowPunct {
			get {
				return field_30_fOverflowPunct;
			}
			
			set {
				this.field_30_fOverflowPunct = value;
			}
			
		}
		
		/// <summary> Get the fTopLinePunct field for the PAP record.</summary>
		/// <summary> Set the fTopLinePunct field for the PAP record.</summary>
		virtual public byte FTopLinePunct {
			get {
				return field_31_fTopLinePunct;
			}
			
			set {
				this.field_31_fTopLinePunct = value;
			}
			
		}
		
		/// <summary> Get the fAutoSpaceDE field for the PAP record.</summary>
		/// <summary> Set the fAutoSpaceDE field for the PAP record.</summary>
		virtual public byte FAutoSpaceDE {
			get {
				return field_32_fAutoSpaceDE;
			}
			
			set {
				this.field_32_fAutoSpaceDE = value;
			}
			
		}
		
		/// <summary> Get the fAutoSpaceDN field for the PAP record.</summary>
		/// <summary> Set the fAutoSpaceDN field for the PAP record.</summary>
		virtual public byte FAutoSpaceDN {
			get {
				return field_33_fAutoSpaceDN;
			}
			
			set {
				this.field_33_fAutoSpaceDN = value;
			}
			
		}
		
		/// <summary> Get the wAlignFont field for the PAP record.</summary>
		/// <summary> Set the wAlignFont field for the PAP record.</summary>
		virtual public int WAlignFont {
			get {
				return field_34_wAlignFont;
			}
			
			set {
				this.field_34_wAlignFont = value;
			}
			
		}
		
		/// <summary> Get the fontAlign field for the PAP record.</summary>
		/// <summary> Set the fontAlign field for the PAP record.</summary>
		virtual public short FontAlign {
			get {
				return field_35_fontAlign;
			}
			
			set {
				this.field_35_fontAlign = value;
			}
			
		}
		
		/// <summary> Get the fInTable field for the PAP record.</summary>
		/// <summary> Set the fInTable field for the PAP record.</summary>
		virtual public byte FInTable {
			get {
				return field_38_fInTable;
			}
			
			set {
				this.field_38_fInTable = value;
			}
			
		}
		
		/// <summary> Get the fTtp field for the PAP record.</summary>
		/// <summary> Set the fTtp field for the PAP record.</summary>
		virtual public byte FTtp {
			get {
				return field_39_fTtp;
			}
			
			set {
				this.field_39_fTtp = value;
			}
			
		}
		
		/// <summary> Get the wr field for the PAP record.</summary>
		/// <summary> Set the wr field for the PAP record.</summary>
		virtual public byte Wr {
			get {
				return field_40_wr;
			}
			
			set {
				this.field_40_wr = value;
			}
			
		}
		
		/// <summary> Get the fLocked field for the PAP record.</summary>
		/// <summary> Set the fLocked field for the PAP record.</summary>
		virtual public byte FLocked {
			get {
				return field_41_fLocked;
			}
			
			set {
				this.field_41_fLocked = value;
			}
			
		}
		
		/// <summary> Get the ptap field for the PAP record.</summary>
		/// <summary> Set the ptap field for the PAP record.</summary>
		virtual public byte[] Ptap {
			get {
				return field_42_ptap;
			}
			
			set {
				this.field_42_ptap = value;
			}
			
		}
		
		/// <summary> Get the dxaAbs field for the PAP record.</summary>
		/// <summary> Set the dxaAbs field for the PAP record.</summary>
		virtual public int DxaAbs {
			get {
				return field_43_dxaAbs;
			}
			
			set {
				this.field_43_dxaAbs = value;
			}
			
		}
		
		/// <summary> Get the dyaAbs field for the PAP record.</summary>
		/// <summary> Set the dyaAbs field for the PAP record.</summary>
		virtual public int DyaAbs {
			get {
				return field_44_dyaAbs;
			}
			
			set {
				this.field_44_dyaAbs = value;
			}
			
		}
		
		/// <summary> Get the dxaWidth field for the PAP record.</summary>
		/// <summary> Set the dxaWidth field for the PAP record.</summary>
		virtual public int DxaWidth {
			get {
				return field_45_dxaWidth;
			}
			
			set {
				this.field_45_dxaWidth = value;
			}
			
		}
		
		/// <summary> Get the brcTop field for the PAP record.</summary>
		/// <summary> Set the brcTop field for the PAP record.</summary>
		virtual public BorderCode BrcTop {
			get {
				return field_46_brcTop;
			}
			
			set {
				this.field_46_brcTop = value;
			}
			
		}
		
		/// <summary> Get the brcLeft field for the PAP record.</summary>
		/// <summary> Set the brcLeft field for the PAP record.</summary>
		virtual public BorderCode BrcLeft {
			get {
				return field_47_brcLeft;
			}
			
			set {
				this.field_47_brcLeft = value;
			}
			
		}
		
		/// <summary> Get the brcBottom field for the PAP record.</summary>
		/// <summary> Set the brcBottom field for the PAP record.</summary>
		virtual public BorderCode BrcBottom {
			get {
				return field_48_brcBottom;
			}
			
			set {
				this.field_48_brcBottom = value;
			}
			
		}
		
		/// <summary> Get the brcRight field for the PAP record.</summary>
		/// <summary> Set the brcRight field for the PAP record.</summary>
		virtual public BorderCode BrcRight {
			get {
				return field_49_brcRight;
			}
			
			set {
				this.field_49_brcRight = value;
			}
			
		}
		
		/// <summary> Get the brcBetween field for the PAP record.</summary>
		/// <summary> Set the brcBetween field for the PAP record.</summary>
		virtual public BorderCode BrcBetween {
			get {
				return field_50_brcBetween;
			}
			
			set {
				this.field_50_brcBetween = value;
			}
			
		}
		
		/// <summary> Get the brcBar field for the PAP record.</summary>
		/// <summary> Set the brcBar field for the PAP record.</summary>
		virtual public BorderCode BrcBar {
			get {
				return field_51_brcBar;
			}
			
			set {
				this.field_51_brcBar = value;
			}
			
		}
		
		/// <summary> Get the dxaFromText field for the PAP record.</summary>
		/// <summary> Set the dxaFromText field for the PAP record.</summary>
		virtual public int DxaFromText {
			get {
				return field_52_dxaFromText;
			}
			
			set {
				this.field_52_dxaFromText = value;
			}
			
		}
		
		/// <summary> Get the dyaFromText field for the PAP record.</summary>
		/// <summary> Set the dyaFromText field for the PAP record.</summary>
		virtual public int DyaFromText {
			get {
				return field_53_dyaFromText;
			}
			
			set {
				this.field_53_dyaFromText = value;
			}
			
		}
		
		/// <summary> Get the dyaHeight field for the PAP record.</summary>
		/// <summary> Set the dyaHeight field for the PAP record.</summary>
		virtual public int DyaHeight {
			get {
				return field_54_dyaHeight;
			}
			
			set {
				this.field_54_dyaHeight = value;
			}
			
		}
		
		/// <summary> Get the fMinHeight field for the PAP record.</summary>
		/// <summary> Set the fMinHeight field for the PAP record.</summary>
		virtual public byte FMinHeight {
			get {
				return field_55_fMinHeight;
			}
			
			set {
				this.field_55_fMinHeight = value;
			}
			
		}
		
		/// <summary> Get the shd field for the PAP record.</summary>
		/// <summary> Set the shd field for the PAP record.</summary>
		virtual public ShadingDescriptor Shd {
			get {
				return field_56_shd;
			}
			
			set {
				this.field_56_shd = value;
			}
			
		}
		
		/// <summary> Get the dcs field for the PAP record.</summary>
		/// <summary> Set the dcs field for the PAP record.</summary>
		virtual public DropCapSpecifier Dcs {
			get {
				return field_57_dcs;
			}
			
			set {
				this.field_57_dcs = value;
			}
			
		}
		
		/// <summary> Get the lvl field for the PAP record.</summary>
		/// <summary> Set the lvl field for the PAP record.</summary>
		virtual public byte Lvl {
			get {
				return field_58_lvl;
			}
			
			set {
				this.field_58_lvl = value;
			}
			
		}
		
		/// <summary> Get the fNumRMIns field for the PAP record.</summary>
		/// <summary> Set the fNumRMIns field for the PAP record.</summary>
		virtual public byte FNumRMIns {
			get {
				return field_59_fNumRMIns;
			}
			
			set {
				this.field_59_fNumRMIns = value;
			}
			
		}
		
		/// <summary> Get the anld field for the PAP record.</summary>
		/// <summary> Set the anld field for the PAP record.</summary>
		virtual public byte[] Anld {
			get {
				return field_60_anld;
			}
			
			set {
				this.field_60_anld = value;
			}
			
		}
		
		/// <summary> Get the fPropRMark field for the PAP record.</summary>
		/// <summary> Set the fPropRMark field for the PAP record.</summary>
		virtual public int FPropRMark {
			get {
				return field_61_fPropRMark;
			}
			
			set {
				this.field_61_fPropRMark = value;
			}
			
		}
		
		/// <summary> Get the ibstPropRMark field for the PAP record.</summary>
		/// <summary> Set the ibstPropRMark field for the PAP record.</summary>
		virtual public int IbstPropRMark {
			get {
				return field_62_ibstPropRMark;
			}
			
			set {
				this.field_62_ibstPropRMark = value;
			}
			
		}
		
		/// <summary> Get the dttmPropRMark field for the PAP record.</summary>
		/// <summary> Set the dttmPropRMark field for the PAP record.</summary>
		virtual public DateAndTime DttmPropRMark {
			get {
				return field_63_dttmPropRMark;
			}
			
			set {
				this.field_63_dttmPropRMark = value;
			}
			
		}
		
		/// <summary> Get the numrm field for the PAP record.</summary>
		/// <summary> Set the numrm field for the PAP record.</summary>
		virtual public byte[] Numrm {
			get {
				return field_64_numrm;
			}
			
			set {
				this.field_64_numrm = value;
			}
			
		}
		
		/// <summary> Get the itbdMac field for the PAP record.</summary>
		/// <summary> Set the itbdMac field for the PAP record.</summary>
		virtual public int ItbdMac {
			get {
				return field_65_itbdMac;
			}
			
			set {
				this.field_65_itbdMac = value;
			}
			
		}
		
		/// <summary> Get the rgdxaTab field for the PAP record.</summary>
		/// <summary> Set the rgdxaTab field for the PAP record.</summary>
		virtual public int[] RgdxaTab {
			get {
				return field_66_rgdxaTab;
			}
			
			set {
				this.field_66_rgdxaTab = value;
			}
			
		}
		
		/// <summary> Get the rgtbd field for the PAP record.</summary>
		/// <summary> Set the rgtbd field for the PAP record.</summary>
		virtual public byte[] Rgtbd {
			get {
				return field_67_rgtbd;
			}
			
			set {
				this.field_67_rgtbd = value;
			}
			
		}
		
		/// <summary> Get the tableLevel field for the PAP record.</summary>
		/// <summary> Set the tableLevel field for the PAP record.</summary>
		virtual public byte TableLevel {
			get {
				return field_68_tableLevel;
			}
			
			set {
				this.field_68_tableLevel = value;
			}
			
		}
		
		/// <summary> Get the fTtpEmbedded field for the PAP record.</summary>
		/// <summary> Set the fTtpEmbedded field for the PAP record.</summary>
		virtual public byte FTtpEmbedded {
			get {
				return field_69_fTtpEmbedded;
			}
			
			set {
				this.field_69_fTtpEmbedded = value;
			}
			
		}
		
		/// <summary> Get the embeddedCellMark field for the PAP record.</summary>
		/// <summary> Set the embeddedCellMark field for the PAP record.</summary>
		virtual public byte EmbeddedCellMark {
			get {
				return field_70_embeddedCellMark;
			}
			
			set {
				this.field_70_embeddedCellMark = value;
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fVertical field value.
		/// </returns>
		/// <summary> Sets the fVertical field value.
		/// 
		/// </summary>
		virtual public bool FVertical {
			get {
				return fVertical.IsSet(field_35_fontAlign);
			}
			
			set {
				field_35_fontAlign = (short) fVertical.SetBoolean(field_35_fontAlign, value);
			}
			
		}
		
		public PAPAbstractType()
		{
		}
		
		/// <summary> Get the fBackward field for the PAP record.</summary>
		public virtual byte GetFBackward()
		{
			return field_36_fBackward;
		}
		
		/// <summary> Set the fBackward field for the PAP record.</summary>
		public virtual void SetFBackward(byte field_36_fBackward)
		{
			this.field_36_fBackward = field_36_fBackward;
		}
		
		/// <summary> Get the fRotateFont field for the PAP record.</summary>
		public virtual byte GetFRotateFont()
		{
			return field_37_fRotateFont;
		}
		
		/// <summary> Set the fRotateFont field for the PAP record.</summary>
		public virtual void SetFRotateFont(byte field_37_fRotateFont)
		{
			this.field_37_fRotateFont = field_37_fRotateFont;
		}
		
		/// <summary> Sets the fBackward field value.
		/// 
		/// </summary>
		public virtual void SetFBackward(bool __value)
		{
			field_35_fontAlign = (short) fBackward.SetBoolean(field_35_fontAlign, __value);
		}
		
		/// <summary> </summary>
		/// <returns>  the fBackward field value.
		/// </returns>
		public virtual bool IsFBackward()
		{
			return fBackward.IsSet(field_35_fontAlign);
		}
		
		/// <summary> Sets the fRotateFont field value.
		/// 
		/// </summary>
		public virtual void SetFRotateFont(bool __value)
		{
			field_35_fontAlign = (short) fRotateFont.SetBoolean(field_35_fontAlign, __value);
		}
		
		/// <summary> </summary>
		/// <returns>  the fRotateFont field value.
		/// </returns>
		public virtual bool IsFRotateFont()
		{
			return fRotateFont.IsSet(field_35_fontAlign);
		}
		
		public virtual object Clone() {
			return this.MemberwiseClone();
		}
	} 
}