// 
// SEPAbstractType.cs
//  
// Copyright 2002-2004  Apache Software Foundation
//
// Jakarta Poi Authors:
//   S. Ryan Ackley
//
// Poi.Net Authors:
//   Johannes Roith(johannes at jroith dot de)
//  
// 
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

using System;

using Poi.Net.Util;
using Poi.Net.HWPF.Model;
using Poi.Net.HWPF.UserModel;

namespace Poi.Net.HWPF.Model.Types
{
	
	/// <summary> Section Properties.
	/// NOTE: This source is automatically generated please do not modify this file.  Either subclass or
	/// remove the record in src/records/definitions.
	/// </summary>

	public abstract class SEPAbstractType : HDFType
	{
		protected internal byte field_1_bkc;
		protected internal bool field_2_fTitlePage;
		protected internal bool field_3_fAutoPgn;
		protected internal byte field_4_nfcPgn;
		protected internal bool field_5_fUnlocked;
		protected internal byte field_6_cnsPgn;
		protected internal bool field_7_fPgnRestart;
		protected internal bool field_8_fEndNote;
		protected internal byte field_9_lnc;
		protected internal byte field_10_grpfIhdt;
		protected internal int field_11_nLnnMod;
		protected internal int field_12_dxaLnn;
		protected internal int field_13_dxaPgn;
		protected internal int field_14_dyaPgn;
		protected internal bool field_15_fLBetween;
		protected internal byte field_16_vjc;
		protected internal int field_17_dmBinFirst;
		protected internal int field_18_dmBinOther;
		protected internal int field_19_dmPaperReq;
		protected internal BorderCode field_20_brcTop;
		protected internal BorderCode field_21_brcLeft;
		protected internal BorderCode field_22_brcBottom;
		protected internal BorderCode field_23_brcRight;
		protected internal bool field_24_fPropMark;
		protected internal int field_25_ibstPropRMark;
		protected internal DateAndTime field_26_dttmPropRMark;
		protected internal int field_27_dxtCharSpace;
		protected internal int field_28_dyaLinePitch;
		protected internal int field_29_clm;
		protected internal int field_30_unused2;
		protected internal byte field_31_dmOrientPage;
		protected internal byte field_32_iHeadingPgn;
		protected internal int field_33_pgnStart;
		protected internal int field_34_lnnMin;
		protected internal int field_35_wTextFlow;
		protected internal short field_36_unused3;
		protected internal int field_37_pgbProp;
		protected internal short field_38_unused4;
		protected internal int field_39_xaPage;
		protected internal int field_40_yaPage;
		protected internal int field_41_xaPageNUp;
		protected internal int field_42_yaPageNUp;
		protected internal int field_43_dxaLeft;
		protected internal int field_44_dxaRight;
		protected internal int field_45_dyaTop;
		protected internal int field_46_dyaBottom;
		protected internal int field_47_dzaGutter;
		protected internal int field_48_dyaHdrTop;
		protected internal int field_49_dyaHdrBottom;
		protected internal int field_50_ccolM1;
		protected internal bool field_51_fEvenlySpaced;
		protected internal byte field_52_unused5;
		protected internal int field_53_dxaColumns;
		protected internal int[] field_54_rgdxaColumn;
		protected internal int field_55_dxaColumnWidth;
		protected internal byte field_56_dmOrientFirst;
		protected internal byte field_57_fLayout;
		protected internal short field_58_unused6;
		protected internal byte[] field_59_olstAnm;
		
		/// <summary> Size of record (exluding 4 byte header)</summary>
		virtual public int Size 
		{
			get {
				return 4 + + 1 + 0 + 0 + 1 + 0 + 1 + 0 + 0 + 1 + 1 + 2 + 4 + 2 + 2 + 0 + 1 + 2 + 2 + 2 + 4 + 4 + 4 + 4 + 0 + 2 + 4 + 4 + 4 + 2 + 2 + 1 + 1 + 2 + 2 + 2 + 2 + 2 + 2 + 4 + 4 + 4 + 4 + 4 + 4 + 4 + 4 + 4 + 4 + 4 + 2 + 0 + 1 + 4 + 356 + 4 + 1 + 1 + 2 + 212;
			}
			
		}
		
		/// <summary> Get the bkc field for the SEP record.</summary>
		/// <summary> Set the bkc field for the SEP record.</summary>
		virtual public byte Bkc {
			get {
				return field_1_bkc;
			}
			
			set {
				this.field_1_bkc = value;
			}
			
		}
		
		/// <summary> Get the fTitlePage field for the SEP record.</summary>
		/// <summary> Set the fTitlePage field for the SEP record.</summary>
		virtual public bool FTitlePage {
			get {
				return field_2_fTitlePage;
			}
			
			set {
				this.field_2_fTitlePage = value;
			}
			
		}
		
		/// <summary> Get the fAutoPgn field for the SEP record.</summary>
		/// <summary> Set the fAutoPgn field for the SEP record.</summary>
		virtual public bool FAutoPgn {
			get {
				return field_3_fAutoPgn;
			}
			
			set {
				this.field_3_fAutoPgn = value;
			}
			
		}
		
		/// <summary> Get the nfcPgn field for the SEP record.</summary>
		/// <summary> Set the nfcPgn field for the SEP record.</summary>
		virtual public byte NfcPgn {
			get {
				return field_4_nfcPgn;
			}
			
			set {
				this.field_4_nfcPgn = value;
			}
			
		}
		
		/// <summary> Get the fUnlocked field for the SEP record.</summary>
		/// <summary> Set the fUnlocked field for the SEP record.</summary>
		virtual public bool FUnlocked {
			get {
				return field_5_fUnlocked;
			}
			
			set {
				this.field_5_fUnlocked = value;
			}
			
		}
		
		/// <summary> Get the cnsPgn field for the SEP record.</summary>
		/// <summary> Set the cnsPgn field for the SEP record.</summary>
		virtual public byte CnsPgn {
			get {
				return field_6_cnsPgn;
			}
			
			set {
				this.field_6_cnsPgn = value;
			}
			
		}
		
		/// <summary> Get the fPgnRestart field for the SEP record.</summary>
		/// <summary> Set the fPgnRestart field for the SEP record.</summary>
		virtual public bool FPgnRestart {
			get {
				return field_7_fPgnRestart;
			}
			
			set {
				this.field_7_fPgnRestart = value;
			}
			
		}
		
		/// <summary> Get the fEndNote field for the SEP record.</summary>
		/// <summary> Set the fEndNote field for the SEP record.</summary>
		virtual public bool FEndNote {
			get {
				return field_8_fEndNote;
			}
			
			set {
				this.field_8_fEndNote = value;
			}
			
		}
		
		/// <summary> Get the lnc field for the SEP record.</summary>
		/// <summary> Set the lnc field for the SEP record.</summary>
		virtual public byte Lnc {
			get {
				return field_9_lnc;
			}
			
			set {
				this.field_9_lnc = value;
			}
			
		}
		
		/// <summary> Get the grpfIhdt field for the SEP record.</summary>
		/// <summary> Set the grpfIhdt field for the SEP record.</summary>
		virtual public byte GrpfIhdt {
			get {
				return field_10_grpfIhdt;
			}
			
			set {
				this.field_10_grpfIhdt = value;
			}
			
		}
		
		/// <summary> Get the nLnnMod field for the SEP record.</summary>
		/// <summary> Set the nLnnMod field for the SEP record.</summary>
		virtual public int NLnnMod {
			get {
				return field_11_nLnnMod;
			}
			
			set {
				this.field_11_nLnnMod = value;
			}
			
		}
		
		/// <summary> Get the dxaLnn field for the SEP record.</summary>
		/// <summary> Set the dxaLnn field for the SEP record.</summary>
		virtual public int DxaLnn {
			get {
				return field_12_dxaLnn;
			}
			
			set {
				this.field_12_dxaLnn = value;
			}
			
		}
		
		/// <summary> Get the dxaPgn field for the SEP record.</summary>
		/// <summary> Set the dxaPgn field for the SEP record.</summary>
		virtual public int DxaPgn {
			get {
				return field_13_dxaPgn;
			}
			
			set {
				this.field_13_dxaPgn = value;
			}
			
		}
		
		/// <summary> Get the dyaPgn field for the SEP record.</summary>
		/// <summary> Set the dyaPgn field for the SEP record.</summary>
		virtual public int DyaPgn {
			get {
				return field_14_dyaPgn;
			}
			
			set {
				this.field_14_dyaPgn = value;
			}
			
		}
		
		/// <summary> Get the fLBetween field for the SEP record.</summary>
		/// <summary> Set the fLBetween field for the SEP record.</summary>
		virtual public bool FLBetween {
			get {
				return field_15_fLBetween;
			}
			
			set {
				this.field_15_fLBetween = value;
			}
			
		}
		
		/// <summary> Get the vjc field for the SEP record.</summary>
		/// <summary> Set the vjc field for the SEP record.</summary>
		virtual public byte Vjc {
			get {
				return field_16_vjc;
			}
			
			set {
				this.field_16_vjc = value;
			}
			
		}
		
		/// <summary> Get the dmBinFirst field for the SEP record.</summary>
		/// <summary> Set the dmBinFirst field for the SEP record.</summary>
		virtual public int DmBinFirst {
			get {
				return field_17_dmBinFirst;
			}
			
			set {
				this.field_17_dmBinFirst = value;
			}
			
		}
		
		/// <summary> Get the dmBinOther field for the SEP record.</summary>
		/// <summary> Set the dmBinOther field for the SEP record.</summary>
		virtual public int DmBinOther {
			get {
				return field_18_dmBinOther;
			}
			
			set {
				this.field_18_dmBinOther = value;
			}
			
		}
		
		/// <summary> Get the dmPaperReq field for the SEP record.</summary>
		/// <summary> Set the dmPaperReq field for the SEP record.</summary>
		virtual public int DmPaperReq {
			get {
				return field_19_dmPaperReq;
			}
			
			set {
				this.field_19_dmPaperReq = value;
			}
			
		}
		
		/// <summary> Get the brcTop field for the SEP record.</summary>
		/// <summary> Set the brcTop field for the SEP record.</summary>
		virtual public BorderCode BrcTop {
			get {
				return field_20_brcTop;
			}
			
			set {
				this.field_20_brcTop = value;
			}
			
		}
		
		/// <summary> Get the brcLeft field for the SEP record.</summary>
		/// <summary> Set the brcLeft field for the SEP record.</summary>
		virtual public BorderCode BrcLeft {
			get {
				return field_21_brcLeft;
			}
			
			set {
				this.field_21_brcLeft = value;
			}
			
		}
		
		/// <summary> Get the brcBottom field for the SEP record.</summary>
		/// <summary> Set the brcBottom field for the SEP record.</summary>
		virtual public BorderCode BrcBottom {
			get {
				return field_22_brcBottom;
			}
			
			set {
				this.field_22_brcBottom = value;
			}
			
		}
		
		/// <summary> Get the brcRight field for the SEP record.</summary>
		/// <summary> Set the brcRight field for the SEP record.</summary>
		virtual public BorderCode BrcRight {
			get {
				return field_23_brcRight;
			}
			
			set {
				this.field_23_brcRight = value;
			}
			
		}
		
		/// <summary> Get the fPropMark field for the SEP record.</summary>
		/// <summary> Set the fPropMark field for the SEP record.</summary>
		virtual public bool FPropMark {
			get {
				return field_24_fPropMark;
			}
			
			set {
				this.field_24_fPropMark = value;
			}
			
		}
		
		/// <summary> Get the ibstPropRMark field for the SEP record.</summary>
		/// <summary> Set the ibstPropRMark field for the SEP record.</summary>
		virtual public int IbstPropRMark {
			get {
				return field_25_ibstPropRMark;
			}
			
			set {
				this.field_25_ibstPropRMark = value;
			}
			
		}
		
		/// <summary> Get the dttmPropRMark field for the SEP record.</summary>
		/// <summary> Set the dttmPropRMark field for the SEP record.</summary>
		virtual public DateAndTime DttmPropRMark {
			get {
				return field_26_dttmPropRMark;
			}
			
			set {
				this.field_26_dttmPropRMark = value;
			}
			
		}
		
		/// <summary> Get the dxtCharSpace field for the SEP record.</summary>
		/// <summary> Set the dxtCharSpace field for the SEP record.</summary>
		virtual public int DxtCharSpace {
			get {
				return field_27_dxtCharSpace;
			}
			
			set {
				this.field_27_dxtCharSpace = value;
			}
			
		}
		
		/// <summary> Get the dyaLinePitch field for the SEP record.</summary>
		/// <summary> Set the dyaLinePitch field for the SEP record.</summary>
		virtual public int DyaLinePitch {
			get {
				return field_28_dyaLinePitch;
			}
			
			set {
				this.field_28_dyaLinePitch = value;
			}
			
		}
		
		/// <summary> Get the clm field for the SEP record.</summary>
		/// <summary> Set the clm field for the SEP record.</summary>
		virtual public int Clm {
			get {
				return field_29_clm;
			}
			
			set {
				this.field_29_clm = value;
			}
			
		}
		
		/// <summary> Get the unused2 field for the SEP record.</summary>
		/// <summary> Set the unused2 field for the SEP record.</summary>
		virtual public int Unused2 {
			get {
				return field_30_unused2;
			}
			
			set {
				this.field_30_unused2 = value;
			}
			
		}
		
		/// <summary> Get the dmOrientPage field for the SEP record.</summary>
		/// <summary> Set the dmOrientPage field for the SEP record.</summary>
		virtual public byte DmOrientPage {
			get {
				return field_31_dmOrientPage;
			}
			
			set {
				this.field_31_dmOrientPage = value;
			}
			
		}
		
		/// <summary> Get the iHeadingPgn field for the SEP record.</summary>
		/// <summary> Set the iHeadingPgn field for the SEP record.</summary>
		virtual public byte IHeadingPgn {
			get {
				return field_32_iHeadingPgn;
			}
			
			set {
				this.field_32_iHeadingPgn = value;
			}
			
		}
		
		/// <summary> Get the pgnStart field for the SEP record.</summary>
		/// <summary> Set the pgnStart field for the SEP record.</summary>
		virtual public int PgnStart {
			get {
				return field_33_pgnStart;
			}
			
			set {
				this.field_33_pgnStart = value;
			}
			
		}
		
		/// <summary> Get the lnnMin field for the SEP record.</summary>
		/// <summary> Set the lnnMin field for the SEP record.</summary>
		virtual public int LnnMin {
			get {
				return field_34_lnnMin;
			}
			
			set {
				this.field_34_lnnMin = value;
			}
			
		}
		
		/// <summary> Get the wTextFlow field for the SEP record.</summary>
		/// <summary> Set the wTextFlow field for the SEP record.</summary>
		virtual public int WTextFlow {
			get {
				return field_35_wTextFlow;
			}
			
			set {
				this.field_35_wTextFlow = value;
			}
			
		}
		
		/// <summary> Get the unused3 field for the SEP record.</summary>
		/// <summary> Set the unused3 field for the SEP record.</summary>
		virtual public short Unused3 {
			get {
				return field_36_unused3;
			}
			
			set {
				this.field_36_unused3 = value;
			}
			
		}
		
		/// <summary> Get the pgbProp field for the SEP record.</summary>
		/// <summary> Set the pgbProp field for the SEP record.</summary>
		virtual public int PgbProp {
			get {
				return field_37_pgbProp;
			}
			
			set {
				this.field_37_pgbProp = value;
			}
			
		}
		
		/// <summary> Get the unused4 field for the SEP record.</summary>
		/// <summary> Set the unused4 field for the SEP record.</summary>
		virtual public short Unused4 {
			get {
				return field_38_unused4;
			}
			
			set {
				this.field_38_unused4 = value;
			}
			
		}
		
		/// <summary> Get the xaPage field for the SEP record.</summary>
		/// <summary> Set the xaPage field for the SEP record.</summary>
		virtual public int XaPage {
			get {
				return field_39_xaPage;
			}
			
			set {
				this.field_39_xaPage = value;
			}
			
		}
		
		/// <summary> Get the yaPage field for the SEP record.</summary>
		/// <summary> Set the yaPage field for the SEP record.</summary>
		virtual public int YaPage {
			get {
				return field_40_yaPage;
			}
			
			set {
				this.field_40_yaPage = value;
			}
			
		}
		
		/// <summary> Get the xaPageNUp field for the SEP record.</summary>
		/// <summary> Set the xaPageNUp field for the SEP record.</summary>
		virtual public int XaPageNUp {
			get {
				return field_41_xaPageNUp;
			}
			
			set {
				this.field_41_xaPageNUp = value;
			}
			
		}
		
		/// <summary> Get the yaPageNUp field for the SEP record.</summary>
		/// <summary> Set the yaPageNUp field for the SEP record.</summary>
		virtual public int YaPageNUp {
			get {
				return field_42_yaPageNUp;
			}
			
			set {
				this.field_42_yaPageNUp = value;
			}
			
		}
		
		/// <summary> Get the dxaLeft field for the SEP record.</summary>
		/// <summary> Set the dxaLeft field for the SEP record.</summary>
		virtual public int DxaLeft {
			get {
				return field_43_dxaLeft;
			}
			
			set {
				this.field_43_dxaLeft = value;
			}
			
		}
		
		/// <summary> Get the dxaRight field for the SEP record.</summary>
		/// <summary> Set the dxaRight field for the SEP record.</summary>
		virtual public int DxaRight {
			get {
				return field_44_dxaRight;
			}
			
			set {
				this.field_44_dxaRight = value;
			}
			
		}
		
		/// <summary> Get the dyaTop field for the SEP record.</summary>
		/// <summary> Set the dyaTop field for the SEP record.</summary>
		virtual public int DyaTop {
			get {
				return field_45_dyaTop;
			}
			
			set {
				this.field_45_dyaTop = value;
			}
			
		}
		
		/// <summary> Get the dyaBottom field for the SEP record.</summary>
		/// <summary> Set the dyaBottom field for the SEP record.</summary>
		virtual public int DyaBottom {
			get {
				return field_46_dyaBottom;
			}
			
			set {
				this.field_46_dyaBottom = value;
			}
			
		}
		
		/// <summary> Get the dzaGutter field for the SEP record.</summary>
		/// <summary> Set the dzaGutter field for the SEP record.</summary>
		virtual public int DzaGutter {
			get {
				return field_47_dzaGutter;
			}
			
			set {
				this.field_47_dzaGutter = value;
			}
			
		}
		
		/// <summary> Get the dyaHdrTop field for the SEP record.</summary>
		/// <summary> Set the dyaHdrTop field for the SEP record.</summary>
		virtual public int DyaHdrTop {
			get {
				return field_48_dyaHdrTop;
			}
			
			set {
				this.field_48_dyaHdrTop = value;
			}
			
		}
		
		/// <summary> Get the dyaHdrBottom field for the SEP record.</summary>
		/// <summary> Set the dyaHdrBottom field for the SEP record.</summary>
		virtual public int DyaHdrBottom {
			get {
				return field_49_dyaHdrBottom;
			}
			
			set {
				this.field_49_dyaHdrBottom = value;
			}
			
		}
		
		/// <summary> Get the ccolM1 field for the SEP record.</summary>
		/// <summary> Set the ccolM1 field for the SEP record.</summary>
		virtual public int CcolM1 {
			get {
				return field_50_ccolM1;
			}
			
			set {
				this.field_50_ccolM1 = value;
			}
			
		}
		
		/// <summary> Get the fEvenlySpaced field for the SEP record.</summary>
		/// <summary> Set the fEvenlySpaced field for the SEP record.</summary>
		virtual public bool FEvenlySpaced {
			get {
				return field_51_fEvenlySpaced;
			}
			
			set {
				this.field_51_fEvenlySpaced = value;
			}
			
		}
		
		/// <summary> Get the unused5 field for the SEP record.</summary>
		/// <summary> Set the unused5 field for the SEP record.</summary>
		virtual public byte Unused5 {
			get {
				return field_52_unused5;
			}
			
			set {
				this.field_52_unused5 = value;
			}
			
		}
		
		/// <summary> Get the dxaColumns field for the SEP record.</summary>
		/// <summary> Set the dxaColumns field for the SEP record.</summary>
		virtual public int DxaColumns {
			get {
				return field_53_dxaColumns;
			}
			
			set {
				this.field_53_dxaColumns = value;
			}
			
		}
		
		/// <summary> Get the rgdxaColumn field for the SEP record.</summary>
		/// <summary> Set the rgdxaColumn field for the SEP record.</summary>
		virtual public int[] RgdxaColumn {
			get {
				return field_54_rgdxaColumn;
			}
			
			set {
				this.field_54_rgdxaColumn = value;
			}
			
		}
		
		/// <summary> Get the dxaColumnWidth field for the SEP record.</summary>
		/// <summary> Set the dxaColumnWidth field for the SEP record.</summary>
		virtual public int DxaColumnWidth {
			get {
				return field_55_dxaColumnWidth;
			}
			
			set {
				this.field_55_dxaColumnWidth = value;
			}
			
		}
		
		/// <summary> Get the dmOrientFirst field for the SEP record.</summary>
		/// <summary> Set the dmOrientFirst field for the SEP record.</summary>
		virtual public byte DmOrientFirst {
			get {
				return field_56_dmOrientFirst;
			}
			
			set {
				this.field_56_dmOrientFirst = value;
			}
			
		}
		
		/// <summary> Get the fLayout field for the SEP record.</summary>
		/// <summary> Set the fLayout field for the SEP record.</summary>
		virtual public byte FLayout {
			get {
				return field_57_fLayout;
			}
			
			set {
				this.field_57_fLayout = value;
			}
			
		}
		
		/// <summary> Get the unused6 field for the SEP record.</summary>
		/// <summary> Set the unused6 field for the SEP record.</summary>
		virtual public short Unused6 {
			get {
				return field_58_unused6;
			}
			
			set {
				this.field_58_unused6 = value;
			}
			
		}
		
		/// <summary> Get the olstAnm field for the SEP record.</summary>
		/// <summary> Set the olstAnm field for the SEP record.</summary>
		virtual public byte[] OlstAnm {
			get { return field_59_olstAnm; }
			set { this.field_59_olstAnm = value; }			
		}
				
		public SEPAbstractType()
		{
		}

		public virtual object Clone() 
		{
			return this.MemberwiseClone();
		}
	} 
}