// 
// TAPAbstractType.cs
//  
// Copyright 2002-2004  Apache Software Foundation
//
// Jakarta Poi Authors:
//   S. Ryan Ackley
//
// Poi.Net Authors:
//   Johannes Roith(johannes at jroith dot de)
//  
// 
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

using System;

using Poi.Net.Util;
using Poi.Net.HWPF.Model;
using Poi.Net.HWPF.UserModel;

namespace Poi.Net.HWPF.Model.Types
{
	
	/// <summary> Table Properties.
	/// NOTE: This source is automatically generated please do not modify this file.  Either subclass or
	/// remove the record in src/records/definitions.
	/// </summary>

	public abstract class TAPAbstractType : HDFType
	{
		
		protected internal int field_1_jc;
		protected internal int field_2_dxaGapHalf;
		protected internal int field_3_dyaRowHeight;
		protected internal bool field_4_fCantSplit;
		protected internal bool field_5_fTableHeader;
		protected internal int field_6_tlp;
		protected internal short field_7_itcMac;
		protected internal short[] field_8_rgdxaCenter;
		protected internal TableCellDescriptor[] field_9_rgtc;
		protected internal ShadingDescriptor[] field_10_rgshd;
		protected internal BorderCode field_11_brcBottom;
		protected internal BorderCode field_12_brcTop;
		protected internal BorderCode field_13_brcLeft;
		protected internal BorderCode field_14_brcRight;
		protected internal BorderCode field_15_brcVertical;
		protected internal BorderCode field_16_brcHorizontal;


		/// <summary> Size of record (exluding 4 byte header)</summary>
		virtual public int Size {
			get {
				return 4 + + 2 + 4 + 4 + 0 + 0 + 4 + 2 + 130 + 0 + 0 + 4 + 4 + 4 + 4 + 4 + 4;
			}
			
		}
		
		/// <summary> Get the jc field for the TAP record.</summary>
		/// <summary> Set the jc field for the TAP record.</summary>
		virtual public int Jc {
			get {
				return field_1_jc;
			}
			
			set {
				this.field_1_jc = value;
			}
			
		}
		
		/// <summary> Get the dxaGapHalf field for the TAP record.</summary>
		/// <summary> Set the dxaGapHalf field for the TAP record.</summary>
		virtual public int DxaGapHalf {
			get {
				return field_2_dxaGapHalf;
			}
			
			set {
				this.field_2_dxaGapHalf = value;
			}
			
		}
		
		/// <summary> Get the dyaRowHeight field for the TAP record.</summary>
		/// <summary> Set the dyaRowHeight field for the TAP record.</summary>
		virtual public int DyaRowHeight {
			get {
				return field_3_dyaRowHeight;
			}
			
			set {
				this.field_3_dyaRowHeight = value;
			}
			
		}
		
		/// <summary> Get the fCantSplit field for the TAP record.</summary>
		/// <summary> Set the fCantSplit field for the TAP record.</summary>
		virtual public bool FCantSplit {
			get {
				return field_4_fCantSplit;
			}
			
			set {
				this.field_4_fCantSplit = value;
			}
			
		}
		
		/// <summary> Get the fTableHeader field for the TAP record.</summary>
		/// <summary> Set the fTableHeader field for the TAP record.</summary>
		virtual public bool FTableHeader {
			get {
				return field_5_fTableHeader;
			}
			
			set {
				this.field_5_fTableHeader = value;
			}
			
		}
		
		/// <summary> Get the tlp field for the TAP record.</summary>
		/// <summary> Set the tlp field for the TAP record.</summary>
		virtual public int Tlp {
			get {
				return field_6_tlp;
			}
			
			set {
				this.field_6_tlp = value;
			}
			
		}
		
		/// <summary> Get the itcMac field for the TAP record.</summary>
		/// <summary> Set the itcMac field for the TAP record.</summary>
		virtual public short ItcMac {
			get {
				return field_7_itcMac;
			}
			
			set {
				this.field_7_itcMac = value;
			}
			
		}
		
		/// <summary> Get the rgdxaCenter field for the TAP record.</summary>
		/// <summary> Set the rgdxaCenter field for the TAP record.</summary>
		virtual public short[] RgdxaCenter {
			get {
				return field_8_rgdxaCenter;
			}
			
			set {
				this.field_8_rgdxaCenter = value;
			}
			
		}
		
		/// <summary> Get the rgtc field for the TAP record.</summary>
		/// <summary> Set the rgtc field for the TAP record.</summary>
		virtual public TableCellDescriptor[] Rgtc {
			get {
				return field_9_rgtc;
			}
			
			set {
				this.field_9_rgtc = value;
			}
			
		}
		
		/// <summary> Get the rgshd field for the TAP record.</summary>
		/// <summary> Set the rgshd field for the TAP record.</summary>
		virtual public ShadingDescriptor[] Rgshd {
			get {
				return field_10_rgshd;
			}
			
			set {
				this.field_10_rgshd = value;
			}
			
		}
		
		/// <summary> Get the brcBottom field for the TAP record.</summary>
		/// <summary> Set the brcBottom field for the TAP record.</summary>
		virtual public BorderCode BrcBottom {
			get {
				return field_11_brcBottom;
			}
			
			set {
				this.field_11_brcBottom = value;
			}
			
		}
		
		/// <summary> Get the brcTop field for the TAP record.</summary>
		/// <summary> Set the brcTop field for the TAP record.</summary>
		virtual public BorderCode BrcTop {
			get {
				return field_12_brcTop;
			}
			
			set {
				this.field_12_brcTop = value;
			}
			
		}
		
		/// <summary> Get the brcLeft field for the TAP record.</summary>
		/// <summary> Set the brcLeft field for the TAP record.</summary>
		virtual public BorderCode BrcLeft {
			get {
				return field_13_brcLeft;
			}
			
			set {
				this.field_13_brcLeft = value;
			}
			
		}
		
		/// <summary> Get the brcRight field for the TAP record.</summary>
		/// <summary> Set the brcRight field for the TAP record.</summary>
		virtual public BorderCode BrcRight {
			get {
				return field_14_brcRight;
			}
			
			set {
				this.field_14_brcRight = value;
			}
			
		}
		
		/// <summary> Get the brcVertical field for the TAP record.</summary>
		/// <summary> Set the brcVertical field for the TAP record.</summary>
		virtual public BorderCode BrcVertical {
			get {
				return field_15_brcVertical;
			}
			
			set {
				this.field_15_brcVertical = value;
			}
			
		}
		
		/// <summary> Get the brcHorizontal field for the TAP record.</summary>
		/// <summary> Set the brcHorizontal field for the TAP record.</summary>
		virtual public BorderCode BrcHorizontal {
			get { return field_16_brcHorizontal; }			
			set { this.field_16_brcHorizontal = value; }
			
		}
		
		public TAPAbstractType()
		{
		}

		public virtual object Clone() 
		{
			return this.MemberwiseClone();
		}
	} 
}