// 
// TCAbstractType.cs
//  
// Copyright 2002-2004  Apache Software Foundation
//
// Jakarta Poi Authors:
//   S. Ryan Ackley
//
// Poi.Net Authors:
//   Johannes Roith(johannes at jroith dot de)
//  
// 
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

using System;

using Poi.Net.Util;
using Poi.Net.HWPF.Model;
using Poi.Net.HWPF.UserModel;

namespace Poi.Net.HWPF.Model.Types
{
	
	/// <summary> Table Cell Descriptor.
	/// NOTE: This source is automatically generated please do not modify this file.  Either subclass or
	/// remove the record in src/records/definitions.
	/// </summary>

	public abstract class TCAbstractType : HDFType
	{
		
		protected internal short field_1_rgf;
		private static BitField fFirstMerged = new BitField(0x0001);
		private static BitField fMerged = new BitField(0x0002);
		private static BitField fVertical = new BitField(0x0004);
		private static BitField fBackward = new BitField(0x0008);
		private static BitField fRotateFont = new BitField(0x0010);
		private static BitField fVertMerge = new BitField(0x0020);
		private static BitField fVertRestart = new BitField(0x0040);
		private static BitField vertAlign = new BitField(0x0180);
		protected internal short field_2_unused;
		protected internal BorderCode field_3_brcTop;
		protected internal BorderCode field_4_brcLeft;
		protected internal BorderCode field_5_brcBottom;
		protected internal BorderCode field_6_brcRight;

		/// <summary> Size of record (exluding 4 byte header)</summary>
		virtual public int Size {
			get {
				return 4 + + 2 + 2 + 4 + 4 + 4 + 4;
			}
			
		}
		
		/// <summary> Get the rgf field for the TC record.</summary>
		/// <summary> Set the rgf field for the TC record.</summary>
		virtual public short Rgf {
			get {
				return field_1_rgf;
			}
			
			set {
				this.field_1_rgf = value;
			}
			
		}
		
		/// <summary> Get the unused field for the TC record.</summary>
		/// <summary> Set the unused field for the TC record.</summary>
		virtual public short Unused {
			get {
				return field_2_unused;
			}
			
			set {
				this.field_2_unused = value;
			}
			
		}
		
		/// <summary> Get the brcTop field for the TC record.</summary>
		/// <summary> Set the brcTop field for the TC record.</summary>
		virtual public BorderCode BrcTop {
			get {
				return field_3_brcTop;
			}
			
			set {
				this.field_3_brcTop = value;
			}
			
		}
		
		/// <summary> Get the brcLeft field for the TC record.</summary>
		/// <summary> Set the brcLeft field for the TC record.</summary>
		virtual public BorderCode BrcLeft {
			get {
				return field_4_brcLeft;
			}
			
			set {
				this.field_4_brcLeft = value;
			}
			
		}
		
		/// <summary> Get the brcBottom field for the TC record.</summary>
		/// <summary> Set the brcBottom field for the TC record.</summary>
		virtual public BorderCode BrcBottom {
			get {
				return field_5_brcBottom;
			}
			
			set {
				this.field_5_brcBottom = value;
			}
			
		}
		
		/// <summary> Get the brcRight field for the TC record.</summary>
		/// <summary> Set the brcRight field for the TC record.</summary>
		virtual public BorderCode BrcRight {
			get {
				return field_6_brcRight;
			}
			
			set {
				this.field_6_brcRight = value;
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fFirstMerged field value.
		/// </returns>
		/// <summary> Sets the fFirstMerged field value.
		/// 
		/// </summary>
		virtual public bool FFirstMerged {
			get {
				return fFirstMerged.IsSet(field_1_rgf);
			}
			
			set {
				field_1_rgf = (short) fFirstMerged.SetBoolean(field_1_rgf, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fMerged field value.
		/// </returns>
		/// <summary> Sets the fMerged field value.
		/// 
		/// </summary>
		virtual public bool FMerged {
			get {
				return fMerged.IsSet(field_1_rgf);
			}
			
			set {
				field_1_rgf = (short) fMerged.SetBoolean(field_1_rgf, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fVertical field value.
		/// </returns>
		/// <summary> Sets the fVertical field value.
		/// 
		/// </summary>
		virtual public bool FVertical {
			get {
				return fVertical.IsSet(field_1_rgf);
			}
			
			set {
				field_1_rgf = (short) fVertical.SetBoolean(field_1_rgf, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fBackward field value.
		/// </returns>
		/// <summary> Sets the fBackward field value.
		/// 
		/// </summary>
		virtual public bool FBackward {
			get {
				return fBackward.IsSet(field_1_rgf);
			}
			
			set {
				field_1_rgf = (short) fBackward.SetBoolean(field_1_rgf, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fRotateFont field value.
		/// </returns>
		/// <summary> Sets the fRotateFont field value.
		/// 
		/// </summary>
		virtual public bool FRotateFont {
			get {
				return fRotateFont.IsSet(field_1_rgf);
			}
			
			set {
				field_1_rgf = (short) fRotateFont.SetBoolean(field_1_rgf, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fVertMerge field value.
		/// </returns>
		/// <summary> Sets the fVertMerge field value.
		/// 
		/// </summary>
		virtual public bool FVertMerge {
			get {
				return fVertMerge.IsSet(field_1_rgf);
			}
			
			set {
				field_1_rgf = (short) fVertMerge.SetBoolean(field_1_rgf, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the fVertRestart field value.
		/// </returns>
		/// <summary> Sets the fVertRestart field value.
		/// 
		/// </summary>
		virtual public bool FVertRestart {
			get {
				return fVertRestart.IsSet(field_1_rgf);
			}
			
			set {
				field_1_rgf = (short) fVertRestart.SetBoolean(field_1_rgf, value);
			}
			
		}
		
		/// <summary> </summary>
		/// <returns>  the vertAlign field value.
		/// </returns>
		/// <summary> Sets the vertAlign field value.
		/// 
		/// </summary>
		virtual public byte VertAlign {
			get {
				return (byte) vertAlign.GetValue(field_1_rgf);
			}
			
			set {
				field_1_rgf = (short) vertAlign.SetValue(field_1_rgf, value);
			}
			
		}
		
		
		public TCAbstractType()
		{
		}
		
		protected internal virtual void FillFields(byte[] data, int offset)
		{
			field_1_rgf = LittleEndian.GetShort(data, 0x0 + offset);
			field_2_unused = LittleEndian.GetShort(data, 0x2 + offset);
			field_3_brcTop = new BorderCode(data, 0x4 + offset);
			field_4_brcLeft = new BorderCode(data, 0x8 + offset);
			field_5_brcBottom = new BorderCode(data, 0xc + offset);
			field_6_brcRight = new BorderCode(data, 0x10 + offset);
		}
		
		public virtual void Serialize(byte[] data, int offset)
		{
			LittleEndian.PutShort(data, 0x0 + offset, (short) field_1_rgf); ;
			LittleEndian.PutShort(data, 0x2 + offset, (short) field_2_unused); ;
			field_3_brcTop.Serialize(data, 0x4 + offset); ;
			field_4_brcLeft.Serialize(data, 0x8 + offset); ;
			field_5_brcBottom.Serialize(data, 0xc + offset); ;
			field_6_brcRight.Serialize(data, 0x10 + offset); ;
		}
		
		public override string ToString()
		{
			System.Text.StringBuilder buffer = new System.Text.StringBuilder();
			
			buffer.Append("[TC]\n");
			
			buffer.Append("    .rgf                  = ");
			buffer.Append(" (").Append(Rgf).Append(" )\n");
			buffer.Append("         .fFirstMerged             = ").Append(FFirstMerged).Append('\n');
			buffer.Append("         .fMerged                  = ").Append(FMerged).Append('\n');
			buffer.Append("         .fVertical                = ").Append(FVertical).Append('\n');
			buffer.Append("         .fBackward                = ").Append(FBackward).Append('\n');
			buffer.Append("         .fRotateFont              = ").Append(FRotateFont).Append('\n');
			buffer.Append("         .fVertMerge               = ").Append(FVertMerge).Append('\n');
			buffer.Append("         .fVertRestart             = ").Append(FVertRestart).Append('\n');
			buffer.Append("         .vertAlign                = ").Append((byte) VertAlign).Append('\n');
			
			buffer.Append("    .unused               = ");
			buffer.Append(" (").Append(Unused).Append(" )\n");
			
			buffer.Append("    .brcTop               = ");
			buffer.Append(" (").Append(BrcTop).Append(" )\n");
			
			buffer.Append("    .brcLeft              = ");
			buffer.Append(" (").Append(BrcLeft).Append(" )\n");
			
			buffer.Append("    .brcBottom            = ");
			buffer.Append(" (").Append(BrcBottom).Append(" )\n");
			
			buffer.Append("    .brcRight             = ");
			buffer.Append(" (").Append(BrcRight).Append(" )\n");
			
			buffer.Append("[/TC]\n");
			return buffer.ToString();
		}

		public virtual object Clone() 
		{
			return this.MemberwiseClone();
		}
	} 
}