// 
// CharacterSprmCompressor.cs
//  
// Copyright 2002-2004  Apache Software Foundation
//
// Jakarta Poi Authors:
//   Rainer Klute (klute@rainer-klute.de)
//
// Poi.Net Authors:
//   Johannes Roith(johannes at jroith dot de)
//  
// 
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

using System;
using System.Collections;

using Poi.Net.HWPF.UserModel;
using Poi.Net.Util;

namespace Poi.Net.HWPF.SPRM
{
	
	public class CharacterSprmCompressor
	{
		public CharacterSprmCompressor()
		{
		}
		public static byte[] CompressCharacterProperty(CharacterProperties newCHP, CharacterProperties oldCHP)
		{
			ArrayList sprmList = new ArrayList();
			int size = 0;
			
			if (newCHP.FRMarkDel != oldCHP.FRMarkDel)
			{
				int __value = 0;
				if (newCHP.FRMarkDel)
				{
					__value = 0x01;
				}
				size += SprmUtils.AddSprm((short) 0x0800, __value, null, sprmList);
			}
			if (newCHP.FRMark != oldCHP.FRMark)
			{
				int __value = 0;
				if (newCHP.FRMark)
				{
					__value = 0x01;
				}
				size += SprmUtils.AddSprm((short) 0x0801, __value, null, sprmList);
			}
			if (newCHP.FFldVanish != oldCHP.FFldVanish)
			{
				int __value = 0;
				if (newCHP.FFldVanish)
				{
					__value = 0x01;
				}
				size += SprmUtils.AddSprm((short) 0x0802, __value, null, sprmList);
			}
			if (newCHP.FSpec != oldCHP.FSpec || newCHP.FcPic != oldCHP.FcPic)
			{
				size += SprmUtils.AddSprm((short) 0x6a03, newCHP.FcPic, null, sprmList);
			}
			if (newCHP.IbstRMark != oldCHP.IbstRMark)
			{
				size += SprmUtils.AddSprm((short) 0x4804, newCHP.IbstRMark, null, sprmList);
			}
			if (!newCHP.DttmRMark.Equals(oldCHP.DttmRMark))
			{
				byte[] buf = new byte[4];
				newCHP.DttmRMark.Serialize(buf, 0);
				
				size += SprmUtils.AddSprm((short) 0x6805, LittleEndian.GetInt(buf), null, sprmList);
			}
			if (newCHP.FData != oldCHP.FData)
			{
				int __value = 0;
				if (newCHP.FData)
				{
					__value = 0x01;
				}
				size += SprmUtils.AddSprm((short) 0x0806, __value, null, sprmList);
			}
			if (newCHP.FSpec && newCHP.FtcSym != 0)
			{
				byte[] varParam = new byte[4];
				LittleEndian.PutShort(varParam, 0, (short) newCHP.FtcSym);
				LittleEndian.PutShort(varParam, 2, (short) newCHP.XchSym);
				
				size += SprmUtils.AddSprm((short) 0x6a09, 0, varParam, sprmList);
			}
			if (newCHP.FOle2 != newCHP.FOle2)
			{
				int __value = 0;
				if (newCHP.FOle2)
				{
					__value = 0x01;
				}
				size += SprmUtils.AddSprm((short) 0x080a, __value, null, sprmList);
			}
			if (newCHP.IcoHighlight != oldCHP.IcoHighlight)
			{
				size += SprmUtils.AddSprm((short) 0x2a0c, newCHP.IcoHighlight, null, sprmList);
			}
			if (newCHP.FcObj != oldCHP.FcObj)
			{
				size += SprmUtils.AddSprm((short) 0x680e, newCHP.FcObj, null, sprmList);
			}
			if (newCHP.Istd != oldCHP.Istd)
			{
				size += SprmUtils.AddSprm((short) 0x4a30, newCHP.Istd, null, sprmList);
			}
			if (newCHP.FBold != oldCHP.FBold)
			{
				int __value = 0;
				if (newCHP.FBold)
				{
					__value = 0x01;
				}
				size += SprmUtils.AddSprm((short) 0x0835, __value, null, sprmList);
			}
			if (newCHP.FItalic != oldCHP.FItalic)
			{
				int __value = 0;
				if (newCHP.FItalic)
				{
					__value = 0x01;
				}
				size += SprmUtils.AddSprm((short) 0x0836, __value, null, sprmList);
			}
			if (newCHP.FStrike != oldCHP.FStrike)
			{
				int __value = 0;
				if (newCHP.FStrike)
				{
					__value = 0x01;
				}
				size += SprmUtils.AddSprm((short) 0x0837, __value, null, sprmList);
			}
			if (newCHP.FOutline != oldCHP.FOutline)
			{
				int __value = 0;
				if (newCHP.FOutline)
				{
					__value = 0x01;
				}
				size += SprmUtils.AddSprm((short) 0x0838, __value, null, sprmList);
			}
			if (newCHP.FShadow != oldCHP.FShadow)
			{
				int __value = 0;
				if (newCHP.FShadow)
				{
					__value = 0x01;
				}
				size += SprmUtils.AddSprm((short) 0x0839, __value, null, sprmList);
			}
			if (newCHP.FSmallCaps != oldCHP.FSmallCaps)
			{
				int __value = 0;
				if (newCHP.FSmallCaps)
				{
					__value = 0x01;
				}
				size += SprmUtils.AddSprm((short) 0x083a, __value, null, sprmList);
			}
			if (newCHP.FCaps != oldCHP.FCaps)
			{
				int __value = 0;
				if (newCHP.FCaps)
				{
					__value = 0x01;
				}
				size += SprmUtils.AddSprm((short) 0x083b, __value, null, sprmList);
			}
			if (newCHP.FVanish != oldCHP.FVanish)
			{
				int __value = 0;
				if (newCHP.FVanish)
				{
					__value = 0x01;
				}
				size += SprmUtils.AddSprm((short) 0x083c, __value, null, sprmList);
			}
			if (newCHP.Kul != oldCHP.Kul)
			{
				size += SprmUtils.AddSprm((short) 0x2a3e, newCHP.Kul, null, sprmList);
			}
			if (newCHP.DxaSpace != oldCHP.DxaSpace)
			{
				size += SprmUtils.AddSprm(unchecked( (short) 0x8840), newCHP.DxaSpace, null, sprmList);
			}
			if (newCHP.Ico != oldCHP.Ico)
			{
				size += SprmUtils.AddSprm((short) 0x2a42, newCHP.Ico, null, sprmList);
			}
			if (newCHP.Hps != oldCHP.Hps)
			{
				size += SprmUtils.AddSprm((short) 0x4a43, newCHP.Hps, null, sprmList);
			}
			if (newCHP.HpsPos != oldCHP.HpsPos)
			{
				size += SprmUtils.AddSprm((short) 0x4845, newCHP.HpsPos, null, sprmList);
			}
			if (newCHP.HpsKern != oldCHP.HpsKern)
			{
				size += SprmUtils.AddSprm((short) 0x484b, newCHP.HpsKern, null, sprmList);
			}
			if (newCHP.Ysr != oldCHP.Ysr)
			{
				size += SprmUtils.AddSprm((short) 0x484e, newCHP.Ysr, null, sprmList);
			}
			if (newCHP.FtcAscii != oldCHP.FtcAscii)
			{
				size += SprmUtils.AddSprm((short) 0x4a4f, newCHP.FtcAscii, null, sprmList);
			}
			if (newCHP.FtcFE != oldCHP.FtcFE)
			{
				size += SprmUtils.AddSprm((short) 0x4a50, newCHP.FtcFE, null, sprmList);
			}
			if (newCHP.FtcOther != oldCHP.FtcOther)
			{
				size += SprmUtils.AddSprm((short) 0x4a51, newCHP.FtcOther, null, sprmList);
			}
			
			if (newCHP.FDStrike != oldCHP.FDStrike)
			{
				int __value = 0;
				if (newCHP.FDStrike)
				{
					__value = 0x01;
				}
				size += SprmUtils.AddSprm((short) 0x2a53, __value, null, sprmList);
			}
			if (newCHP.FImprint != oldCHP.FImprint)
			{
				int __value = 0;
				if (newCHP.FImprint)
				{
					__value = 0x01;
				}
				size += SprmUtils.AddSprm((short) 0x0854, __value, null, sprmList);
			}
			if (newCHP.FSpec != oldCHP.FSpec)
			{
				int __value = 0;
				if (newCHP.FSpec)
				{
					__value = 0x01;
				}
				size += SprmUtils.AddSprm((short) 0x0855, __value, null, sprmList);
			}
			if (newCHP.FObj != oldCHP.FObj)
			{
				int __value = 0;
				if (newCHP.FObj)
				{
					__value = 0x01;
				}
				size += SprmUtils.AddSprm((short) 0x0856, __value, null, sprmList);
			}
			if (newCHP.FEmboss != oldCHP.FEmboss)
			{
				int __value = 0;
				if (newCHP.FEmboss)
				{
					__value = 0x01;
				}
				size += SprmUtils.AddSprm((short) 0x0858, __value, null, sprmList);
			}
			if (newCHP.SfxtText != oldCHP.SfxtText)
			{
				size += SprmUtils.AddSprm((short) 0x2859, newCHP.SfxtText, null, sprmList);
			}
			if (newCHP.Ico24 != oldCHP.Ico24)
			{
				if (newCHP.Ico24 != - 1)
				// don't add a sprm if we're looking at an ico = Auto
					size += SprmUtils.AddSprm((short) 0x6870, newCHP.Ico24, null, sprmList);
			}
			
			return SprmUtils.GetGrpprl(sprmList, size);
		}
	}
}