// 
// CharacterSprmUncompressor.cs
//  
// Copyright 2002-2004  Apache Software Foundation
//
// Jakarta Poi Authors:
//   Rainer Klute (klute@rainer-klute.de)
//
// Poi.Net Authors:
//   Johannes Roith(johannes at jroith dot de)
//  
// 
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

using System;

using Poi.Net.HWPF.UserModel;
using Poi.Net.HWPF.Model;
using Poi.Net.Util;

namespace Poi.Net.HWPF.SPRM
{
	
	public class CharacterSprmUncompressor
	{
		public CharacterSprmUncompressor()
		{
		}
		
		public static CharacterProperties UncompressCHP(CharacterProperties parent, byte[] grpprl, int offset)
		{
			CharacterProperties newProperties = null;
			try
			{
				newProperties = (CharacterProperties) parent.Clone();
			}
			catch
			{
				throw new System.SystemException("There is no way this exception should happen!!");
			}
			SprmIterator sprmIt = new SprmIterator(grpprl, offset);
			
			while (sprmIt.HasNext())
			{
				SprmOperation sprm = (SprmOperation) sprmIt.Next();
				UnCompressCHPOperation(parent, newProperties, sprm);
			}
			
			return newProperties;
		}
		
		/// <summary> Used in decompression of a chpx. This performs an operation defined by
		/// a single sprm.
		/// 
		/// </summary>
		/// <param name="oldCHP">The base CharacterProperties.
		/// </param>
		/// <param name="newCHP">The current CharacterProperties.
		/// </param>
		/// <param name="operand">The operand defined by the sprm (See Word file format spec)
		/// </param>
		/// <param name="param">The parameter defined by the sprm (See Word file format spec)
		/// </param>
		/// <param name="varParam">The variable length parameter defined by the sprm. (See
		/// Word file format spec)
		/// </param>
		/// <param name="grpprl">The entire chpx that this operation is a part of.
		/// </param>
		/// <param name="offset">The offset in the grpprl of the next sprm
		/// </param>
		/// <param name="styleSheet">The StyleSheet for this document.
		/// </param>
		internal static void UnCompressCHPOperation(CharacterProperties oldCHP, CharacterProperties newCHP, SprmOperation sprm)
		{
			
			switch (sprm.Operation)
			{
				
				case 0: 
					newCHP.FRMarkDel = GetFlag(sprm.Operand);
					break;
				
				case 0x1: 
					newCHP.FRMark = GetFlag(sprm.Operand);
					break;
				
				case 0x2: 
					newCHP.FFldVanish = GetFlag(sprm.Operand);
					break;
				
				case 0x3: 
					newCHP.FcPic = sprm.Operand;
					newCHP.FSpec = true;
					break;
				
				case 0x4: 
					newCHP.IbstRMark = (short) sprm.Operand;
					break;
				
				case 0x5: 
					newCHP.DttmRMark = new DateAndTime(sprm.Grpprl, sprm.GrpprlOffset);
					break;
				
				case 0x6: 
					newCHP.FData = GetFlag(sprm.Operand);
					break;
				
				case 0x7: 
					//don't care about this
					break;
				
				case 0x8: 
					//short chsDiff = (short)((param & 0xff0000) >>> 16);
					int operand = sprm.Operand;
					short chsDiff = (short) (operand & 0x0000ff);
					newCHP.FChsDiff = GetFlag(chsDiff);
					newCHP.Chse = (short) (operand & 0xffff00);
					break;
				
				case 0x9: 
					newCHP.FSpec = true;
					newCHP.FtcSym = (short) LittleEndian.GetShort(sprm.Grpprl, sprm.GrpprlOffset);
					newCHP.XchSym = (short) LittleEndian.GetShort(sprm.Grpprl, sprm.GrpprlOffset + 2);
					break;
				
				case 0xa: 
					newCHP.FOle2 = GetFlag(sprm.Operand);
					break;
				
				case 0xb: 
					
					// Obsolete
					break;
				
				case 0xc: 
					newCHP.IcoHighlight = (byte) sprm.Operand;
					newCHP.FHighlight = GetFlag(sprm.Operand);
					break;
				
				case 0xd: 
					
					//	undocumented
					break;
				
				case 0xe: 
					newCHP.FcObj = sprm.Operand;
					break;
				
				case 0xf: 
					
					// undocumented
					break;
				
				case 0x10: 
					
					// undocumented
					break;
					
					// undocumented till 0x30
				
				
				case 0x11: 
					break;
				
				case 0x12: 
					break;
				
				case 0x13: 
					break;
				
				case 0x14: 
					break;
				
				case 0x15: 
					break;
				
				case 0x16: 
					break;
				
				case 0x17: 
					break;
				
				case 0x18: 
					break;
				
				case 0x19: 
					break;
				
				case 0x1a: 
					break;
				
				case 0x1b: 
					break;
				
				case 0x1c: 
					break;
				
				case 0x1d: 
					break;
				
				case 0x1e: 
					break;
				
				case 0x1f: 
					break;
				
				case 0x20: 
					break;
				
				case 0x21: 
					break;
				
				case 0x22: 
					break;
				
				case 0x23: 
					break;
				
				case 0x24: 
					break;
				
				case 0x25: 
					break;
				
				case 0x26: 
					break;
				
				case 0x27: 
					break;
				
				case 0x28: 
					break;
				
				case 0x29: 
					break;
				
				case 0x2a: 
					break;
				
				case 0x2b: 
					break;
				
				case 0x2c: 
					break;
				
				case 0x2d: 
					break;
				
				case 0x2e: 
					break;
				
				case 0x2f: 
					break;
				
				case 0x30: 
					newCHP.Istd = sprm.Operand;
					break;
				
				case 0x31: 
					
					//permutation vector for fast saves, who cares!
					break;
				
				case 0x32: 
					newCHP.FBold = false;
					newCHP.FItalic = false;
					newCHP.FOutline = false;
					newCHP.FStrike = false;
					newCHP.FShadow = false;
					newCHP.FSmallCaps = false;
					newCHP.FCaps = false;
					newCHP.FVanish = false;
					newCHP.Kul = (byte) 0;
					newCHP.Ico = (byte) 0;
					break;
				
				case 0x33: 
					try
					{
						// preserve the fSpec setting from the original CHP
						bool fSpec = newCHP.FSpec;
						newCHP = (CharacterProperties) oldCHP.Clone();
						newCHP.FSpec = fSpec;
					}
					
					catch
					{
						//do nothing
					}
					return ;
				
				case 0x34: 
					
					// undocumented
					break;
				
				case 0x35: 
					newCHP.FBold = GetCHPFlag((byte) sprm.Operand, oldCHP.FBold);
					break;
				
				case 0x36: 
					newCHP.FItalic = GetCHPFlag((byte) sprm.Operand, oldCHP.FItalic);
					break;
				
				case 0x37: 
					newCHP.FStrike = GetCHPFlag((byte) sprm.Operand, oldCHP.FStrike);
					break;
				
				case 0x38: 
					newCHP.FOutline = GetCHPFlag((byte) sprm.Operand, oldCHP.FOutline);
					break;
				
				case 0x39: 
					newCHP.FShadow = GetCHPFlag((byte) sprm.Operand, oldCHP.FShadow);
					break;
				
				case 0x3a: 
					newCHP.FSmallCaps = GetCHPFlag((byte) sprm.Operand, oldCHP.FSmallCaps);
					break;
				
				case 0x3b: 
					newCHP.FCaps = GetCHPFlag((byte) sprm.Operand, oldCHP.FCaps);
					break;
				
				case 0x3c: 
					newCHP.FVanish = GetCHPFlag((byte) sprm.Operand, oldCHP.FVanish);
					break;
				
				case 0x3d: 
					newCHP.FtcAscii = (short) sprm.Operand;
					break;
				
				case 0x3e: 
					newCHP.Kul = (byte) sprm.Operand;
					break;
				
				case 0x3f: 
					operand = sprm.Operand;
					int hps = operand & 0xff;
					if (hps != 0)
					{
						newCHP.Hps = hps;
					}
					
					//byte cInc = (byte)(((byte)(param & 0xfe00) >>> 4) >> 1);
					byte cInc;

					int n = (operand & 0xff00);

					//URShift

					if ( n >= 0)
						cInc = (byte) (n >> 8);
					else
						cInc = (byte) ((n >> 8) + (2 << ~8));
					
					if ( cInc >= 0)
						cInc = (byte) (cInc >> 1);
					else
						cInc = (byte) ((cInc >> 1) + (2 << ~1));

					if (cInc != 0)
					{
						newCHP.Hps = System.Math.Max(newCHP.Hps + (cInc * 2), 2);
					}
					
					//byte hpsPos = (byte)((param & 0xff0000) >>> 8);
					byte hpsPos;

					n = (operand & 0xff0000);

					if ( n >= 0)
						hpsPos = (byte) (n >> 16);
					else
						hpsPos = (byte) ((n >> 16) + (2 << ~16));

					if (hpsPos != 0x80)
					{
						newCHP.HpsPos = hpsPos;
					}
					bool fAdjust = (operand & 0x0100) > 0;
					if (fAdjust && hpsPos != 128 && hpsPos != 0 && oldCHP.HpsPos == 0)
					{
						newCHP.Hps = System.Math.Max(newCHP.Hps + (- 2), 2);
					}
					if (fAdjust && hpsPos == 0 && oldCHP.HpsPos != 0)
					{
						newCHP.Hps = System.Math.Max(newCHP.Hps + 2, 2);
					}
					break;
				
				case 0x40: 
					newCHP.DxaSpace = sprm.Operand;
					break;
				
				case 0x41: 
					newCHP.LidDefault = (short) sprm.Operand;
					break;
				
				case 0x42: 
					newCHP.Ico = (byte) sprm.Operand;
					break;
				
				case 0x43: 
					newCHP.Hps = sprm.Operand;
					break;
				
				case 0x44: 
					byte hpsLvl = (byte) sprm.Operand;
					newCHP.Hps = System.Math.Max(newCHP.Hps + (hpsLvl * 2), 2);
					break;
				
				case 0x45: 
					newCHP.HpsPos = (short) sprm.Operand;
					break;
				
				case 0x46: 
					if (sprm.Operand != 0)
					{
						if (oldCHP.HpsPos == 0)
						{
							newCHP.Hps = System.Math.Max(newCHP.Hps + (- 2), 2);
						}
					}
					else
					{
						if (oldCHP.HpsPos != 0)
						{
							newCHP.Hps = System.Math.Max(newCHP.Hps + 2, 2);
						}
					}
					break;
				
				case 0x47: 
					/*CharacterProperties genCHP = new CharacterProperties ();
					genCHP.SetFtcAscii (4);
					genCHP = (CharacterProperties) unCompressProperty (varParam, genCHP,
					styleSheet);
					CharacterProperties styleCHP = styleSheet.getStyleDescription (oldCHP.
					getBaseIstd ()).getCHP ();
					if (genCHP.IsFBold () == newCHP.IsFBold ())
					{
					newCHP.SetFBold (styleCHP.IsFBold ());
					}
					if (genCHP.IsFItalic () == newCHP.IsFItalic ())
					{
					newCHP.SetFItalic (styleCHP.IsFItalic ());
					}
					if (genCHP.IsFSmallCaps () == newCHP.IsFSmallCaps ())
					{
					newCHP.SetFSmallCaps (styleCHP.IsFSmallCaps ());
					}
					if (genCHP.IsFVanish () == newCHP.IsFVanish ())
					{
					newCHP.SetFVanish (styleCHP.IsFVanish ());
					}
					if (genCHP.IsFStrike () == newCHP.IsFStrike ())
					{
					newCHP.SetFStrike (styleCHP.IsFStrike ());
					}
					if (genCHP.IsFCaps () == newCHP.IsFCaps ())
					{
					newCHP.SetFCaps (styleCHP.IsFCaps ());
					}
					if (genCHP.getFtcAscii () == newCHP.getFtcAscii ())
					{
					newCHP.SetFtcAscii (styleCHP.getFtcAscii ());
					}
					if (genCHP.getFtcFE () == newCHP.getFtcFE ())
					{
					newCHP.SetFtcFE (styleCHP.getFtcFE ());
					}
					if (genCHP.getFtcOther () == newCHP.getFtcOther ())
					{
					newCHP.SetFtcOther (styleCHP.getFtcOther ());
					}
					if (genCHP.getHps () == newCHP.getHps ())
					{
					newCHP.SetHps (styleCHP.getHps ());
					}
					if (genCHP.getHpsPos () == newCHP.getHpsPos ())
					{
					newCHP.SetHpsPos (styleCHP.getHpsPos ());
					}
					if (genCHP.getKul () == newCHP.getKul ())
					{
					newCHP.SetKul (styleCHP.getKul ());
					}
					if (genCHP.getDxaSpace () == newCHP.getDxaSpace ())
					{
					newCHP.SetDxaSpace (styleCHP.getDxaSpace ());
					}
					if (genCHP.getIco () == newCHP.getIco ())
					{
					newCHP.SetIco (styleCHP.getIco ());
					}
					if (genCHP.getLidDefault () == newCHP.getLidDefault ())
					{
					newCHP.SetLidDefault (styleCHP.getLidDefault ());
					}
					if (genCHP.getLidFE () == newCHP.getLidFE ())
					{
					newCHP.SetLidFE (styleCHP.getLidFE ());
					}*/
					break;
				
				case 0x48: 
					newCHP.Iss = (byte) sprm.Operand;
					break;
				
				case 0x49: 
					newCHP.Hps = LittleEndian.GetShort(sprm.Grpprl, sprm.GrpprlOffset);
					break;
				
				case 0x4a: 
					int increment = LittleEndian.GetShort(sprm.Grpprl, sprm.GrpprlOffset);
					newCHP.Hps = System.Math.Max(newCHP.Hps + increment, 8);
					break;
				
				case 0x4b: 
					newCHP.HpsKern = sprm.Operand;
					break;
				
				case 0x4c: 
					//        unCompressCHPOperation (oldCHP, newCHP, 0x47, param, varParam,
					//                                styleSheet, opSize);
					break;
				
				case 0x4d: 
					
					float percentage = (float) sprm.Operand / 100.0f;
					
					int add = (int) ((float) percentage * (float) newCHP.Hps);
					newCHP.Hps = newCHP.Hps + add;
					break;
				
				case 0x4e: 
					newCHP.Ysr = (byte) sprm.Operand;
					break;
				
				case 0x4f: 
					newCHP.FtcAscii = (short) sprm.Operand;
					break;
				
				case 0x50: 
					newCHP.FtcFE = (short) sprm.Operand;
					break;
				
				case 0x51: 
					newCHP.FtcOther = (short) sprm.Operand;
					break;
				
				case 0x52: 
					
					// undocumented
					break;
				
				case 0x53: 
					newCHP.FDStrike = GetFlag(sprm.Operand);
					break;
				
				case 0x54: 
					newCHP.FImprint = GetFlag(sprm.Operand);
					break;
				
				case 0x55: 
					newCHP.FSpec = GetFlag(sprm.Operand);
					break;
				
				case 0x56: 
					newCHP.FObj = GetFlag(sprm.Operand);
					break;
				
				case 0x57: 
					byte[] buf = sprm.Grpprl;
					int offset = sprm.GrpprlOffset;
					newCHP.FPropMark = buf[offset];
					newCHP.IbstPropRMark = (short) LittleEndian.GetShort(buf, offset + 1);
					newCHP.DttmPropRMark = new DateAndTime(buf, offset + 3);
					break;
				
				case 0x58: 
					newCHP.FEmboss = GetFlag(sprm.Operand);
					break;
				
				case 0x59: 
					newCHP.SfxtText = (byte) sprm.Operand;
					break;
					
					// undocumented till 0x61
				
				case 0x5a: 
					break;
				
				case 0x5b: 
					break;
				
				case 0x5c: 
					break;
				
				case 0x5d: 
					break;
				
				case 0x5e: 
					break;
				
				case 0x5f: 
					break;
				
				case 0x60: 
					break;
				
				case 0x61: 
					break;
				
				case 0x62: 
					byte[] xstDispFldRMark = new byte[32];
					buf = sprm.Grpprl;
					offset = sprm.GrpprlOffset;
					newCHP.FDispFldRMark = buf[offset];
					newCHP.IbstDispFldRMark = (short) LittleEndian.GetShort(buf, offset + 1);
					newCHP.DttmDispFldRMark = new DateAndTime(buf, offset + 3);
					Array.Copy(buf, offset + 7, xstDispFldRMark, 0, 32);
					newCHP.XstDispFldRMark = xstDispFldRMark;
					break;
				
				case 0x63: 
					newCHP.IbstRMarkDel = (short) sprm.Operand;
					break;
				
				case 0x64: 
					newCHP.DttmRMarkDel = new DateAndTime(sprm.Grpprl, sprm.GrpprlOffset);
					break;
				
				case 0x65: 
					newCHP.Brc = new BorderCode(sprm.Grpprl, sprm.GrpprlOffset);
					break;
				
				case 0x66: 
					newCHP.Shd = new ShadingDescriptor(sprm.Grpprl, sprm.GrpprlOffset);
					break;
				
				case 0x67: 
					
					// Obsolete
					break;
				
				case 0x68: 
					break;
					
					// undocumented till 0x6c
				
				
				case 0x69: 
					break;
				
				case 0x6a: 
					break;
				
				case 0x6b: 
					break;
				
				case 0x6c: 
					break;
				
				case 0x6d: 
					newCHP.LidDefault = (short) sprm.Operand;
					break;
				
				case 0x6e: 
					newCHP.LidFE = (short) sprm.Operand;
					break;
				
				case 0x6f: 
					newCHP.IdctHint = (byte) sprm.Operand;
					break;
				
				case 0x70: 
					newCHP.Ico24 = sprm.Operand;
					break;
				}
		}
		
		/// <summary> Converts an int into a boolean. If the int is non-zero, it returns true.
		/// Otherwise it returns false.
		/// 
		/// </summary>
		/// <param name="x">The int to convert.
		/// 
		/// </param>
		/// <returns> A boolean whose value depends on x.
		/// </returns>
		public static bool GetFlag(int x)
		{
			if (x != 0)
			{
				return true;
			}
			else
			{
				return false;
			}
		}
		
		private static bool GetCHPFlag(byte x, bool oldVal)
		{
			/*
			switch(x)
			{
			case 0:
			return false;
			case 1:
			return true;
			case (byte)0x80:
			return oldVal;
			case (byte)0x81:
			return !oldVal;
			default:
			return false;
			}
			*/
			if (x == 0)
			{
				return false;
			}
			else if (x == 1)
			{
				return true;
			}
			else if ((x & 0x81) == 0x80)
			{
				return oldVal;
			}
			else if ((x & 0x81) == 0x81)
			{
				return !oldVal;
			}
			else
			{
				return false;
			}
		}
	}
}