// 
// ParagraphSprmCompressor.cs
//  
// Copyright 2002-2004  Apache Software Foundation
//
// Jakarta Poi Authors:
//   Rainer Klute (klute@rainer-klute.de)
//
// Poi.Net Authors:
//   Johannes Roith(johannes at jroith dot de)
//  
// 
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

using System;
using System.Collections;

using Poi.Net.Util;
using Poi.Net.HWPF.UserModel;
namespace Poi.Net.HWPF.SPRM
{
	
	public class ParagraphSprmCompressor
	{
		public ParagraphSprmCompressor()
		{
		}
		
		public static byte[] CompressParagraphProperty(ParagraphProperties newPAP, ParagraphProperties oldPAP)
		{
			ArrayList sprmList = new ArrayList();
			int size = 0;
			
			if (newPAP.Jc != oldPAP.Jc)
			{
				size += SprmUtils.AddSprm((short) 0x2403, newPAP.Jc, null, sprmList);
			}
			if (newPAP.FKeep != oldPAP.FKeep)
			{
				size += SprmUtils.AddSprm((short) 0x2405, newPAP.FKeep, null, sprmList);
			}
			if (newPAP.FKeepFollow != oldPAP.FKeepFollow)
			{
				size += SprmUtils.AddSprm((short) 0x2406, newPAP.FKeepFollow, null, sprmList);
			}
			if (newPAP.FPageBreakBefore != oldPAP.FPageBreakBefore)
			{
				size += SprmUtils.AddSprm((short) 0x2407, newPAP.FPageBreakBefore, null, sprmList);
			}
			if (newPAP.Brcl != oldPAP.Brcl)
			{
				size += SprmUtils.AddSprm((short) 0x2408, newPAP.Brcl, null, sprmList);
			}
			if (newPAP.Brcp != oldPAP.Brcp)
			{
				size += SprmUtils.AddSprm((short) 0x2409, newPAP.Brcp, null, sprmList);
			}
			if (newPAP.Ilvl != oldPAP.Ilvl)
			{
				size += SprmUtils.AddSprm((short) 0x260A, newPAP.Ilvl, null, sprmList);
			}
			if (newPAP.Ilfo != oldPAP.Ilfo)
			{
				size += SprmUtils.AddSprm((short) 0x460b, newPAP.Ilfo, null, sprmList);
			}
			if (newPAP.FNoLnn != oldPAP.FNoLnn)
			{
				size += SprmUtils.AddSprm((short) 0x240C, newPAP.FNoLnn, null, sprmList);
			}
			if (newPAP.FSideBySide != oldPAP.FSideBySide)
			{
				size += SprmUtils.AddSprm((short) 0x2404, newPAP.FSideBySide, null, sprmList);
			}
			if (newPAP.FNoAutoHyph != oldPAP.FNoAutoHyph)
			{
				size += SprmUtils.AddSprm((short) 0x242A, newPAP.FNoAutoHyph, null, sprmList);
			}
			if (newPAP.FWidowControl != oldPAP.FWidowControl)
			{
				size += SprmUtils.AddSprm((short) 0x2431, newPAP.FWidowControl, null, sprmList);
			}
			if (newPAP.ItbdMac != oldPAP.ItbdMac || !ArrayHelper.Equals(newPAP.RgdxaTab, oldPAP.RgdxaTab) || !ArrayHelper.Equals(newPAP.Rgtbd, oldPAP.Rgtbd))
			{
				/// <todo>  revisit this  </todo>
				//      byte[] oldTabArray = oldPAP.getRgdxaTab();
				//      byte[] newTabArray = newPAP.getRgdxaTab();
				//      byte[] newTabDescriptors = newPAP.getRgtbd();
				//      byte[] varParam = new byte[2 + oldTabArray.length + newTabArray.length +
				//                                 newTabDescriptors.length];
				//      varParam[0] = (byte)(oldTabArray.length/2);
				//      int offset = 1;
				//      System.arraycopy(oldTabArray, 0, varParam, offset, oldTabArray.length);
				//      offset += oldTabArray.length;
				//      varParam[offset] = (byte)(newTabArray.length/2);
				//      offset += 1;
				//      System.arraycopy(newTabArray, 0, varParam, offset, newTabArray.length);
				//      offset += newTabArray.length;
				//      System.arraycopy(newTabDescriptors, 0, varParam, offset, newTabDescriptors.length);
				//
				//      size += SprmUtils.AddSprm((short)0xC60D, 0, varParam, sprmList);
			}
			if (newPAP.DxaRight != oldPAP.DxaRight)
			{
				size += SprmUtils.AddSprm(unchecked((short) 0x840E), newPAP.DxaRight, null, sprmList);
			}
			if (newPAP.DxaLeft != oldPAP.DxaLeft)
			{
				size += SprmUtils.AddSprm(unchecked( (short) 0x840F), newPAP.DxaLeft, null, sprmList);
			}
			if (newPAP.DxaLeft1 != oldPAP.DxaLeft1)
			{
				size += SprmUtils.AddSprm(unchecked( (short) 0x8411), newPAP.DxaLeft1, null, sprmList);
			}
			if (!newPAP.Lspd.Equals(oldPAP.Lspd))
			{
				byte[] buf = new byte[4];
				newPAP.Lspd.Serialize(buf, 0);
				
				size += SprmUtils.AddSprm((short) 0x6412, LittleEndian.GetInt(buf), null, sprmList);
			}
			if (newPAP.DyaBefore != oldPAP.DyaBefore)
			{
				size += SprmUtils.AddSprm(unchecked( (short) 0xA413), newPAP.DyaBefore, null, sprmList);
			}
			if (newPAP.DyaAfter != oldPAP.DyaAfter)
			{
				size += SprmUtils.AddSprm(unchecked( (short) 0xA414), newPAP.DyaAfter, null, sprmList);
			}
			if (newPAP.DyaBefore != oldPAP.DyaBefore)
			{
				size += SprmUtils.AddSprm((short) 0x2404, newPAP.DyaBefore, null, sprmList);
			}
			if (newPAP.FKinsoku != oldPAP.FKinsoku)
			{
				size += SprmUtils.AddSprm((short) 0x2433, newPAP.DyaBefore, null, sprmList);
			}
			if (newPAP.FWordWrap != oldPAP.FWordWrap)
			{
				size += SprmUtils.AddSprm((short) 0x2434, newPAP.FWordWrap, null, sprmList);
			}
			if (newPAP.FOverflowPunct != oldPAP.FOverflowPunct)
			{
				size += SprmUtils.AddSprm((short) 0x2435, newPAP.FOverflowPunct, null, sprmList);
			}
			if (newPAP.FTopLinePunct != oldPAP.FTopLinePunct)
			{
				size += SprmUtils.AddSprm((short) 0x2436, newPAP.FTopLinePunct, null, sprmList);
			}
			if (newPAP.FAutoSpaceDE != oldPAP.FAutoSpaceDE)
			{
				size += SprmUtils.AddSprm((short) 0x2437, newPAP.FAutoSpaceDE, null, sprmList);
			}
			if (newPAP.FAutoSpaceDN != oldPAP.FAutoSpaceDN)
			{
				size += SprmUtils.AddSprm((short) 0x2438, newPAP.FAutoSpaceDN, null, sprmList);
			}
			if (newPAP.WAlignFont != oldPAP.WAlignFont)
			{
				size += SprmUtils.AddSprm((short) 0x4439, newPAP.WAlignFont, null, sprmList);
			}
			if (newPAP.IsFBackward() != oldPAP.IsFBackward() || newPAP.FVertical != oldPAP.FVertical || newPAP.IsFRotateFont() != oldPAP.IsFRotateFont())
			{
				int val = 0;
				if (newPAP.IsFBackward())
				{
					val |= 0x2;
				}
				if (newPAP.FVertical)
				{
					val |= 0x1;
				}
				if (newPAP.IsFRotateFont())
				{
					val |= 0x4;
				}
				size += SprmUtils.AddSprm((short) 0x443A, val, null, sprmList);
			}
			if (!ArrayHelper.Equals(newPAP.Anld, oldPAP.Anld))
			{
				size += SprmUtils.AddSprm(unchecked( (short) 0xC63E), 0, newPAP.Anld, sprmList);
			}
			if (newPAP.FInTable != oldPAP.FInTable)
			{
				size += SprmUtils.AddSprm((short) 0x2416, newPAP.FInTable, null, sprmList);
			}
			if (newPAP.FTtp != oldPAP.FTtp)
			{
				size += SprmUtils.AddSprm((short) 0x2417, newPAP.FTtp, null, sprmList);
			}
			if (newPAP.Wr != oldPAP.Wr)
			{
				size += SprmUtils.AddSprm((short) 0x2423, newPAP.Wr, null, sprmList);
			}
			if (newPAP.FLocked != oldPAP.FLocked)
			{
				size += SprmUtils.AddSprm((short) 0x2430, newPAP.FLocked, null, sprmList);
			}
			if (newPAP.DxaAbs != oldPAP.DxaAbs)
			{
				size += SprmUtils.AddSprm(unchecked( (short) 0x8418), newPAP.DxaAbs, null, sprmList);
			}
			if (newPAP.DyaAbs != oldPAP.DyaAbs)
			{
				size += SprmUtils.AddSprm(unchecked( (short) 0x8419), newPAP.DyaAbs, null, sprmList);
			}
			if (newPAP.DxaWidth != oldPAP.DxaWidth)
			{
				size += SprmUtils.AddSprm(unchecked( (short) 0x841A), newPAP.DxaWidth, null, sprmList);
			}
			if (!newPAP.BrcTop.Equals(oldPAP.BrcTop))
			{
				int brc = newPAP.BrcTop.ToInt();
				size += SprmUtils.AddSprm((short) 0x6424, brc, null, sprmList);
			}
			if (!newPAP.BrcLeft.Equals(oldPAP.BrcLeft))
			{
				int brc = newPAP.BrcLeft.ToInt();
				size += SprmUtils.AddSprm((short) 0x6425, brc, null, sprmList);
			}
			if (!newPAP.BrcBottom.Equals(oldPAP.BrcBottom))
			{
				int brc = newPAP.BrcBottom.ToInt();
				size += SprmUtils.AddSprm((short) 0x6426, brc, null, sprmList);
			}
			if (!newPAP.BrcRight.Equals(oldPAP.BrcRight))
			{
				int brc = newPAP.BrcRight.ToInt();
				size += SprmUtils.AddSprm((short) 0x6427, brc, null, sprmList);
			}
			if (newPAP.BrcBar.Equals(oldPAP.BrcBar))
			{
				int brc = newPAP.BrcBar.ToInt();
				size += SprmUtils.AddSprm((short) 0x6428, brc, null, sprmList);
			}
			if (newPAP.DxaFromText != oldPAP.DxaFromText)
			{
				size += SprmUtils.AddSprm(unchecked( (short) 0x842F), newPAP.DxaFromText, null, sprmList);
			}
			if (newPAP.DyaFromText != oldPAP.DyaFromText)
			{
				size += SprmUtils.AddSprm(unchecked( (short) 0x842E), newPAP.DyaFromText, null, sprmList);
			}
			if (newPAP.DyaHeight != oldPAP.DyaHeight || newPAP.FMinHeight != oldPAP.FMinHeight)
			{
				short val = (short) newPAP.DyaHeight;
				if (newPAP.FMinHeight > 0)
				{
					val |= unchecked((short) (0x8000));
				}
				size += SprmUtils.AddSprm((short) 0x442B, val, null, sprmList);
			}
			if (newPAP.Shd != null && !newPAP.Shd.Equals(oldPAP.Shd))
			{
				size += SprmUtils.AddSprm((short) 0x442D, newPAP.Shd.ToShort(), null, sprmList);
			}
			if (newPAP.Dcs != null && !newPAP.Dcs.Equals(oldPAP.Dcs))
			{
				size += SprmUtils.AddSprm((short) 0x442C, newPAP.Dcs.ToShort(), null, sprmList);
			}
			if (newPAP.Lvl != oldPAP.Lvl)
			{
				size += SprmUtils.AddSprm((short) 0x2640, newPAP.Lvl, null, sprmList);
			}
			if (newPAP.FNumRMIns != oldPAP.FNumRMIns)
			{
				size += SprmUtils.AddSprm((short) 0x2443, newPAP.FNumRMIns, null, sprmList);
			}
			if (newPAP.FPropRMark != oldPAP.FPropRMark || newPAP.IbstPropRMark != oldPAP.IbstPropRMark || !newPAP.DttmPropRMark.Equals(oldPAP.DttmPropRMark))
			{
				byte[] buf = new byte[7];
				buf[0] = (byte) newPAP.FPropRMark;
				LittleEndian.PutShort(buf, 1, (short) newPAP.IbstPropRMark);
				newPAP.DttmPropRMark.Serialize(buf, 3);
				size += SprmUtils.AddSprm(unchecked( (short) 0xC63F), 0, buf, sprmList);
			}
			if (!ArrayHelper.Equals(newPAP.Numrm, oldPAP.Numrm))
			{
				size += SprmUtils.AddSprm(unchecked( (short) 0xC645), 0, newPAP.Numrm, sprmList);
			}
			
			if (newPAP.TableLevel != oldPAP.TableLevel)
			{
				size += SprmUtils.AddSprm((short) 0x6649, newPAP.TableLevel, null, sprmList);
			}
			
			if (newPAP.EmbeddedCellMark != oldPAP.EmbeddedCellMark)
			{
				size += SprmUtils.AddSprm((short) 0x244b, newPAP.EmbeddedCellMark, null, sprmList);
			}
			
			if (newPAP.FTtpEmbedded != oldPAP.FTtpEmbedded)
			{
				size += SprmUtils.AddSprm((short) 0x244c, newPAP.FTtpEmbedded, null, sprmList);
			}
			
			return SprmUtils.GetGrpprl(sprmList, size);
		}
	}
}