// 
// ParagraphSprmUncompressor.cs
//  
// Copyright 2002-2004  Apache Software Foundation
//
// Jakarta Poi Authors:
//   Rainer Klute (klute@rainer-klute.de)
//
// Poi.Net Authors:
//   Johannes Roith(johannes at jroith dot de)
//  
// 
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

using System;
using System.Collections;

using Poi.Net.HWPF.UserModel;
using Poi.Net.Util;

namespace Poi.Net.HWPF.SPRM
{	
	public class ParagraphSprmUncompressor:SprmUncompressor
	{
		public ParagraphSprmUncompressor()
		{
		}
		
		public static ParagraphProperties UncompressPAP(ParagraphProperties parent, byte[] grpprl, int offset)
		{
			ParagraphProperties newProperties = null;
			try
			{
				newProperties = (ParagraphProperties) parent.Clone();
			}
			
			catch
			{
				throw new System.SystemException("There is no way this exception should happen!!");
			}
			SprmIterator sprmIt = new SprmIterator(grpprl, offset);
			
			while (sprmIt.HasNext())
			{
				SprmOperation sprm = (SprmOperation) sprmIt.Next();
				
				// PAPXs can contain table sprms if the paragraph marks the end of a
				// table row
				if (sprm.Type == SprmOperation.PAP_TYPE)
				{
					UnCompressPAPOperation(newProperties, sprm);
				}
			}
			
			return newProperties;
		}
		
		/// <summary> Performs an operation on a ParagraphProperties object. Used to uncompress
		/// from a papx.
		/// 
		/// </summary>
		/// <param name="newPAP">The ParagraphProperties object to perform the operation on.
		/// </param>
		/// <param name="operand">The operand that defines the operation.
		/// </param>
		/// <param name="param">The operation's parameter.
		/// </param>
		/// <param name="varParam">The operation's variable length parameter.
		/// </param>
		/// <param name="grpprl">The original papx.
		/// </param>
		/// <param name="offset">The current offset in the papx.
		/// </param>
		/// <param name="spra">A part of the sprm that defined this operation.
		/// </param>
		internal static void UnCompressPAPOperation(ParagraphProperties newPAP, SprmOperation sprm)
		{
			switch (sprm.Operation)
			{
				
				case 0: 
					newPAP.Istd = sprm.Operand;
					break;
				
				case 0x1: 
					
					// Used only for piece table grpprl's not for PAPX
					//        int istdFirst = LittleEndian.GetShort (varParam, 2);
					//        int istdLast = LittleEndian.GetShort (varParam, 4);
					//        if ((newPAP.getIstd () > istdFirst) || (newPAP.getIstd () <= istdLast))
					//        {
					//          permuteIstd (newPAP, varParam, opSize);
					//        }
					break;
				
				case 0x2: 
					if (newPAP.Istd <= 9 || newPAP.Istd >= 1)
					{
						byte paramTmp = (byte) sprm.Operand;
						newPAP.Istd = newPAP.Istd + paramTmp;
						newPAP.Lvl = (byte) (newPAP.Lvl + paramTmp);
						
						if (((paramTmp >> 7) & 0x01) == 1)
						{
							newPAP.Istd = System.Math.Max(newPAP.Istd, 1);
						}
						else
						{
							newPAP.Istd = System.Math.Min(newPAP.Istd, 9);
						}
					}
					break;
				
				case 0x3: 
					newPAP.Jc = (byte) sprm.Operand;
					break;
				
				case 0x4: 
					newPAP.FSideBySide = (byte) sprm.Operand;
					break;
				
				case 0x5: 
					newPAP.FKeep = (byte) sprm.Operand;
					break;
				
				case 0x6: 
					newPAP.FKeepFollow = (byte) sprm.Operand;
					break;
				
				case 0x7: 
					newPAP.FPageBreakBefore = (byte) sprm.Operand;
					break;
				
				case 0x8: 
					newPAP.Brcl = (byte) sprm.Operand;
					break;
				
				case 0x9: 
					newPAP.Brcp = (byte) sprm.Operand;
					break;
				
				case 0xa: 
					newPAP.Ilvl = (byte) sprm.Operand;
					break;
				
				case 0xb: 
					newPAP.Ilfo = sprm.Operand;
					break;
				
				case 0xc: 
					newPAP.FNoLnn = (byte) sprm.Operand;
					break;
				
				case 0xd: 
					/// <summary>handle tabs . variable parameter. seperate processing needed</summary>
					HandleTabs(newPAP, sprm);
					break;
				
				case 0xe: 
					newPAP.DxaRight = sprm.Operand;
					break;
				
				case 0xf: 
					newPAP.DxaLeft = sprm.Operand;
					break;
				
				case 0x10: 
					
					// sprmPNest is only stored in grpprls linked to a piece table.
					newPAP.DxaLeft = newPAP.DxaLeft + sprm.Operand;
					newPAP.DxaLeft = System.Math.Max(0, newPAP.DxaLeft);
					break;
				
				case 0x11: 
					newPAP.DxaLeft1 = sprm.Operand;
					break;
				
				case 0x12: 
					newPAP.Lspd = new LineSpacingDescriptor(sprm.Grpprl, sprm.GrpprlOffset);
					break;
				
				case 0x13: 
					newPAP.DyaBefore = sprm.Operand;
					break;
				
				case 0x14: 
					newPAP.DyaAfter = sprm.Operand;
					break;
				
				case 0x15: 
					// fast saved only
					//applySprmPChgTabs (newPAP, varParam, opSize);
					break;
				
				case 0x16: 
					newPAP.FInTable = (byte) sprm.Operand;
					break;
				
				case 0x17: 
					newPAP.FTtp = (byte) sprm.Operand;
					break;
				
				case 0x18: 
					newPAP.DxaAbs = sprm.Operand;
					break;
				
				case 0x19: 
					newPAP.DyaAbs = sprm.Operand;
					break;
				
				case 0x1a: 
					newPAP.DxaWidth = sprm.Operand;
					break;
				
				case 0x1b: 
					byte param = (byte) sprm.Operand;
					/// <todo>  handle paragraph postioning </todo>
					byte pcVert = (byte) ((param & 0x0c) >> 2);
					byte pcHorz = (byte) (param & 0x03);
					if (pcVert != 3)
					{
						newPAP.PcVert = pcVert;
					}
					if (pcHorz != 3)
					{
						newPAP.PcHorz = pcHorz;
					}
					break;
					
					// BrcXXX1 is older Version. Brc is used
				
				case 0x1c: 
					
					//newPAP.SetBrcTop1((short)param);
					break;
				
				case 0x1d: 
					
					//newPAP.SetBrcLeft1((short)param);
					break;
				
				case 0x1e: 
					
					//newPAP.SetBrcBottom1((short)param);
					break;
				
				case 0x1f: 
					
					//newPAP.SetBrcRight1((short)param);
					break;
				
				case 0x20: 
					
					//newPAP.SetBrcBetween1((short)param);
					break;
				
				case 0x21: 
					
					//newPAP.SetBrcBar1((byte)param);
					break;
				
				case 0x22: 
					newPAP.DxaFromText = sprm.Operand;
					break;
				
				case 0x23: 
					newPAP.Wr = (byte) sprm.Operand;
					break;
				
				case 0x24: 
					newPAP.BrcTop = new BorderCode(sprm.Grpprl, sprm.GrpprlOffset);
					break;
				
				case 0x25: 
					newPAP.BrcLeft = new BorderCode(sprm.Grpprl, sprm.GrpprlOffset);
					break;
				
				case 0x26: 
					newPAP.BrcBottom = new BorderCode(sprm.Grpprl, sprm.GrpprlOffset);
					break;
				
				case 0x27: 
					newPAP.BrcRight = new BorderCode(sprm.Grpprl, sprm.GrpprlOffset);
					break;
				
				case 0x28: 
					newPAP.BrcBetween = new BorderCode(sprm.Grpprl, sprm.GrpprlOffset);
					break;
				
				case 0x29: 
					newPAP.BrcBar = new BorderCode(sprm.Grpprl, sprm.GrpprlOffset);
					break;
				
				case 0x2a: 
					newPAP.FNoAutoHyph = (byte) sprm.Operand;
					break;
				
				case 0x2b: 
					newPAP.DyaHeight = sprm.Operand;
					break;
				
				case 0x2c: 
					newPAP.Dcs = new DropCapSpecifier((short) sprm.Operand);
					break;
				
				case 0x2d: 
					newPAP.Shd = new ShadingDescriptor((short) sprm.Operand);
					break;
				
				case 0x2e: 
					newPAP.DyaFromText = sprm.Operand;
					break;
				
				case 0x2f: 
					newPAP.DxaFromText = sprm.Operand;
					break;
				
				case 0x30: 
					newPAP.FLocked = (byte) sprm.Operand;
					break;
				
				case 0x31: 
					newPAP.FWidowControl = (byte) sprm.Operand;
					break;
				
				case 0x32: 
					
					//undocumented
					break;
				
				case 0x33: 
					newPAP.FKinsoku = (byte) sprm.Operand;
					break;
				
				case 0x34: 
					newPAP.FWordWrap = (byte) sprm.Operand;
					break;
				
				case 0x35: 
					newPAP.FOverflowPunct = (byte) sprm.Operand;
					break;
				
				case 0x36: 
					newPAP.FTopLinePunct = (byte) sprm.Operand;
					break;
				
				case 0x37: 
					newPAP.FAutoSpaceDE = (byte) sprm.Operand;
					break;
				
				case 0x38: 
					newPAP.FAutoSpaceDN = (byte) sprm.Operand;
					break;
				
				case 0x39: 
					newPAP.WAlignFont = sprm.Operand;
					break;
				
				case 0x3a: 
					newPAP.FontAlign = (short) sprm.Operand;
					break;
				
				case 0x3b: 
					
					//obsolete
					break;
				
				case 0x3e: 
				{
					byte[] buf = new byte[sprm.Size - 3];
					Array.Copy(buf, 0, sprm.Grpprl, sprm.GrpprlOffset, buf.Length);
					newPAP.Anld = buf;
					break;
				}
				
				case 0x3f: 
					//don't really need this. spec is confusing regarding this
					//sprm
					try
					{
						byte[] varParam = sprm.Grpprl;
						int offset = sprm.GrpprlOffset;
						newPAP.FPropRMark = (int) varParam[offset];
						newPAP.IbstPropRMark = (int) LittleEndian.GetShort(varParam, offset + 1);
						newPAP.DttmPropRMark = new DateAndTime(varParam, offset + 3);
					}
					catch
					{
						//SupportClass.WriteStackTrace(e, Console.Error);
					}
					break;
				
				case 0x40: 
					
					//newPAP._lvl = param;
					if (newPAP.Istd >= 1 && newPAP.Istd <= 9)
					{
						newPAP.Ilvl = (byte) sprm.Operand;
					}
					break;
				
				case 0x41: 
					
					// undocumented
					break;
				
				case 0x43: 
					
					//pap.fNumRMIns
					newPAP.FNumRMIns = (byte) sprm.Operand;
					break;
				
				case 0x44: 
					
					//undocumented
					break;
				
				case 0x45: 
					if (sprm.SizeCode == 6)
					{
						byte[] buf = new byte[sprm.Size - 3];
						Array.Copy(buf, 0, sprm.Grpprl, sprm.GrpprlOffset, buf.Length);
						newPAP.Numrm = buf;
					}
					else
					{
						/// <todo>  handle large PAPX from data stream </todo>
					}
					break;
				
				
				case 0x47: 
					newPAP.FUsePgsuSettings = (byte) sprm.Operand;
					break;
				
				case 0x48: 
					newPAP.FAdjustRight = (byte) sprm.Operand;
					break;
				
				case 0x49: 
					newPAP.TableLevel = (byte) sprm.Operand;
					break;
				
				case 0x4b: 
					newPAP.EmbeddedCellMark = (byte) sprm.Operand;
					break;
				
				case 0x4c: 
					newPAP.FTtpEmbedded = (byte) sprm.Operand;
					break;
				
				default: 
					break;
				
			}
		}
		
		private static void HandleTabs(ParagraphProperties pap, SprmOperation sprm)
		{
			byte[] grpprl = sprm.Grpprl;
			int offset = sprm.GrpprlOffset;
			int delSize = grpprl[offset++];
			int[] tabPositions = pap.RgdxaTab;
			byte[] tabDescriptors = pap.Rgtbd;
			
			
			Hashtable tabMap = new Hashtable();
			for (int x = 0; x < tabPositions.Length; x++)
			{
				tabMap[(int) tabPositions[x]] = (byte) tabDescriptors[x];
			}
			
			for (int x = 0; x < delSize; x++)
			{
				tabMap.Remove((int) LittleEndian.GetShort(grpprl, offset));
				offset += LittleEndian.SHORT_SIZE;
			}
			
			int addSize = grpprl[offset++];
			int start = offset;
			for (int x = 0; x < addSize; x++)
			{
				int key = (int) LittleEndian.GetShort(grpprl, offset);
				byte val = (byte) grpprl[start + ((LittleEndian.SHORT_SIZE * addSize) + x)];
				tabMap[key] = val;
				offset += LittleEndian.SHORT_SIZE;
			}
			
			tabPositions = new int[tabMap.Count];
			tabDescriptors = new byte[tabPositions.Length];
			ArrayList list = new ArrayList();
						
			foreach (Object key in tabMap.Keys)
				list.Add(key);

			((ArrayList)list).Sort();
			
			for (int x = 0; x < tabPositions.Length; x++)
			{
				int key = ((int) list[x]);
				tabPositions[x] = key;
				
				tabDescriptors[x] = (byte) ((byte) tabMap[key]);
			}
			
			pap.RgdxaTab = tabPositions;
			pap.Rgtbd = tabDescriptors;
		}
		
		//  private static void handleTabsAgain(ParagraphProperties pap, SprmOperation sprm)
		//  {
		//    byte[] grpprl = sprm.GetGrpprl();
		//    int offset = sprm.GetGrpprlOffset();
		//    int delSize = grpprl[offset++];
		//    int[] tabPositions = pap.getRgdxaTab();
		//    byte[] tabDescriptors = pap.getRgtbd();
		//
		//    HashMap tabMap = new HashMap();
		//    for (int x = 0; x < tabPositions.length; x++)
		//    {
		//      tabMap.put(new Integer(tabPositions[x]), new Byte(tabDescriptors[x]));
		//    }
		//
		//    for (int x = 0; x < delSize; x++)
		//    {
		//      tabMap.remove(new Integer(LittleEndian.GetInt(grpprl, offset)));
		//      offset += LittleEndian.INT_SIZE;;
		//    }
		//
		//    int addSize = grpprl[offset++];
		//    for (int x = 0; x < addSize; x++)
		//    {
		//      Integer key = new Integer(LittleEndian.GetInt(grpprl, offset));
		//      Byte val = new Byte(grpprl[(LittleEndian.INT_SIZE * (addSize - x)) + x]);
		//      tabMap.put(key, val);
		//      offset += LittleEndian.INT_SIZE;
		//    }
		//
		//    tabPositions = new int[tabMap_upxs[x].Size];
		//    tabDescriptors = new byte[tabPositions.length];
		//    ArrayList list = new ArrayList();
		//
		//    Iterator keyIT = tabMap.keySet().iterator();
		//    while (keyIT.HasNext())
		//    {
		//      list.add(keyIT.Next());
		//    }
		//    Collections.sort(list);
		//
		//    for (int x = 0; x < tabPositions.length; x++)
		//    {
		//      Integer key = ((Integer)list.get(x));
		//      tabPositions[x] = key.intValue();
		//      tabDescriptors[x] = ((Byte)tabMap.get(key)).byteValue();
		//    }
		//
		//    pap.SetRgdxaTab(tabPositions);
		//    pap.SetRgtbd(tabDescriptors);
		//  }
	}
}