// 
// SectionSprmUncompressor.cs
//  
// Copyright 2002-2004  Apache Software Foundation
//
// Jakarta Poi Authors:
//   Rainer Klute (klute@rainer-klute.de)
//
// Poi.Net Authors:
//   Johannes Roith(johannes at jroith dot de)
//  
// 
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

using System;
using Poi.Net.HWPF.UserModel;

namespace Poi.Net.HWPF.SPRM
{
	
	public class SectionSprmUncompressor:SprmUncompressor
	{
		public SectionSprmUncompressor()
		{
		}
		public static SectionProperties UncompressSEP(byte[] grpprl, int offset)
		{
			SectionProperties newProperties = new SectionProperties();
			
			SprmIterator sprmIt = new SprmIterator(grpprl, offset);
			
			while (sprmIt.HasNext())
			{
				SprmOperation sprm = (SprmOperation) sprmIt.Next();
				UnCompressSEPOperation(newProperties, sprm);
			}
			
			return newProperties;
		}
		
		/// <summary> Used in decompression of a sepx. This performs an operation defined by
		/// a single sprm.
		/// 
		/// </summary>
		/// <param name="newSEP">The SectionProperty to perfrom the operation on.
		/// </param>
		/// <param name="operand">The operation to perform.
		/// </param>
		/// <param name="param">The operation's parameter.
		/// </param>
		/// <param name="varParam">The operation variable length parameter.
		/// </param>
		internal static void UnCompressSEPOperation(SectionProperties newSEP, SprmOperation sprm)
		{
			switch (sprm.Operation)
			{
				
				case 0: 
					newSEP.CnsPgn = (byte) sprm.Operand;
					break;
				
				case 0x1: 
					newSEP.IHeadingPgn = (byte) sprm.Operand;
					break;
				
				case 0x2: 
					byte[] buf = new byte[sprm.Size - 3];
					Array.Copy(sprm.Grpprl, sprm.GrpprlOffset, buf, 0, buf.Length);
					newSEP.OlstAnm = buf;
					break;
				
				case 0x3: 
					//not quite sure
					break;
				
				case 0x4: 
					//not quite sure
					break;
				
				case 0x5: 
					newSEP.FEvenlySpaced = GetFlag(sprm.Operand);
					break;
				
				case 0x6: 
					newSEP.FUnlocked = GetFlag(sprm.Operand);
					break;
				
				case 0x7: 
					newSEP.DmBinFirst = (short) sprm.Operand;
					break;
				
				case 0x8: 
					newSEP.DmBinOther = (short) sprm.Operand;
					break;
				
				case 0x9: 
					newSEP.Bkc = (byte) sprm.Operand;
					break;
				
				case 0xa: 
					newSEP.FTitlePage = GetFlag(sprm.Operand);
					break;
				
				case 0xb: 
					newSEP.CcolM1 = (short) sprm.Operand;
					break;
				
				case 0xc: 
					newSEP.DxaColumns = sprm.Operand;
					break;
				
				case 0xd: 
					newSEP.FAutoPgn = GetFlag(sprm.Operand);
					break;
				
				case 0xe: 
					newSEP.NfcPgn = (byte) sprm.Operand;
					break;
				
				case 0xf: 
					newSEP.DyaPgn = (short) sprm.Operand;
					break;
				
				case 0x10: 
					newSEP.DxaPgn = (short) sprm.Operand;
					break;
				
				case 0x11: 
					newSEP.FPgnRestart = GetFlag(sprm.Operand);
					break;
				
				case 0x12: 
					newSEP.FEndNote = GetFlag(sprm.Operand);
					break;
				
				case 0x13: 
					newSEP.Lnc = (byte) sprm.Operand;
					break;
				
				case 0x14: 
					newSEP.GrpfIhdt = (byte) sprm.Operand;
					break;
				
				case 0x15: 
					newSEP.NLnnMod = (short) sprm.Operand;
					break;
				
				case 0x16: 
					newSEP.DxaLnn = sprm.Operand;
					break;
				
				case 0x17: 
					newSEP.DyaHdrTop = sprm.Operand;
					break;
				
				case 0x18: 
					newSEP.DyaHdrBottom = sprm.Operand;
					break;
				
				case 0x19: 
					newSEP.FLBetween = GetFlag(sprm.Operand);
					break;
				
				case 0x1a: 
					newSEP.Vjc = (byte) sprm.Operand;
					break;
				
				case 0x1b: 
					newSEP.LnnMin = (short) sprm.Operand;
					break;
				
				case 0x1c: 
					newSEP.PgnStart = (short) sprm.Operand;
					break;
				
				case 0x1d: 
					newSEP.DmOrientPage = (byte) sprm.Operand;
					break;
				
				case 0x1e: 
					
					//nothing
					break;
				
				case 0x1f: 
					newSEP.XaPage = sprm.Operand;
					break;
				
				case 0x20: 
					newSEP.YaPage = sprm.Operand;
					break;
				
				case 0x21: 
					newSEP.DxaLeft = sprm.Operand;
					break;
				
				case 0x22: 
					newSEP.DxaRight = sprm.Operand;
					break;
				
				case 0x23: 
					newSEP.DyaTop = sprm.Operand;
					break;
				
				case 0x24: 
					newSEP.DyaBottom = sprm.Operand;
					break;
				
				case 0x25: 
					newSEP.DzaGutter = sprm.Operand;
					break;
				
				case 0x26: 
					newSEP.DmPaperReq = (short) sprm.Operand;
					break;
				
				case 0x27: 
					newSEP.FPropMark = GetFlag(sprm.Operand);
					break;
				
				case 0x28: 
					break;
				
				case 0x29: 
					break;
				
				case 0x2a: 
					break;
				
				case 0x2b: 
					newSEP.BrcTop = new BorderCode(sprm.Grpprl, sprm.GrpprlOffset);
					break;
				
				case 0x2c: 
					newSEP.BrcLeft = new BorderCode(sprm.Grpprl, sprm.GrpprlOffset);
					break;
				
				case 0x2d: 
					newSEP.BrcBottom = new BorderCode(sprm.Grpprl, sprm.GrpprlOffset);
					break;
				
				case 0x2e: 
					newSEP.BrcRight = new BorderCode(sprm.Grpprl, sprm.GrpprlOffset);
					break;
				
				case 0x2f: 
					newSEP.PgbProp = sprm.Operand;
					break;
				
				case 0x30: 
					newSEP.DxtCharSpace = sprm.Operand;
					break;
				
				case 0x31: 
					newSEP.DyaLinePitch = sprm.Operand;
					break;
				
				case 0x33: 
					newSEP.WTextFlow = (short) sprm.Operand;
					break;
				
				default: 
					break;
				
			}
		}
	}
}