// 
// SprmUtils.cs
//  
// Copyright 2002-2004  Apache Software Foundation
//
// Jakarta Poi Authors:
//   Rainer Klute (klute@rainer-klute.de)
//
// Poi.Net Authors:
//   Johannes Roith(johannes at jroith dot de)
//  
// 
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

using System;
using System.Collections;

using Poi.Net.Util;
namespace Poi.Net.HWPF.SPRM
{
	
	
	public class SprmUtils
	{
		public SprmUtils()
		{
		}
		
		public static byte[] ShortArrayToByteArray(short[] convert)
		{
			byte[] buf = new byte[convert.Length * LittleEndian.SHORT_SIZE];
			
			for (int x = 0; x < convert.Length; x++)
			{
				LittleEndian.PutShort(buf, x * LittleEndian.SHORT_SIZE, convert[x]);
			}
			
			return buf;
		}
		
		public static int AddSpecialSprm(short instruction, byte[] varParam, IList list)
		{
			byte[] sprm = new byte[varParam.Length + 4];
			Array.Copy(varParam, 0, sprm, 4, varParam.Length);
			LittleEndian.PutShort(sprm, instruction);
			LittleEndian.PutShort(sprm, 2, (short) (varParam.Length + 1));
			list.Add(sprm);
			return sprm.Length;
		}
		
		public static int AddSprm(short instruction, int param, byte[] varParam, IList list)
		{
			int type = (instruction & 0xe000) >> 13;
			
			byte[] sprm = null;
			switch (type)
			{
				
				case 0: 
				case 1: 
					sprm = new byte[3];
					sprm[2] = (byte) param;
					break;
				
				case 2: 
					sprm = new byte[4];
					LittleEndian.PutShort(sprm, 2, (short) param);
					break;
				
				case 3: 
					sprm = new byte[6];
					LittleEndian.PutInt(sprm, 2, param);
					break;
				
				case 4: 
				case 5: 
					sprm = new byte[4];
					LittleEndian.PutShort(sprm, 2, (short) param);
					break;
				
				case 6: 
					sprm = new byte[3 + varParam.Length];
					sprm[2] = (byte) varParam.Length;
					Array.Copy(varParam, 0, sprm, 3, varParam.Length);
					break;
				
				case 7: 
					sprm = new byte[5];
					// this is a three byte int so it has to be handled special
					byte[] temp = new byte[4];
					LittleEndian.PutInt(temp, 0, param);
					Array.Copy(temp, 0, sprm, 2, 3);
					break;
				
				default: 
					//should never happen
					break;
				
			}
			LittleEndian.PutShort(sprm, 0, instruction);
			list.Add(sprm);
			return sprm.Length;
		}
		
		public static byte[] GetGrpprl(IList sprmList, int size)
		{
			// spit out the final grpprl
			byte[] grpprl = new byte[size];
			int listSize = sprmList.Count - 1;
			int index = 0;
			for (; listSize >= 0; listSize--)
			{
				object tempObject;
				tempObject = sprmList[0];
				sprmList.RemoveAt(0);
				byte[] sprm = (byte[]) tempObject;
				Array.Copy(sprm, 0, grpprl, index, sprm.Length);
				index += sprm.Length;
			}
			
			return grpprl;
		}
		
		public static int ConvertBrcToInt(short[] brc)
		{
			byte[] buf = new byte[4];
			LittleEndian.PutShort(buf, brc[0]);
			LittleEndian.PutShort(buf, LittleEndian.SHORT_SIZE, brc[1]);
			return LittleEndian.GetInt(buf);
		}
	}
}