// 
// TableSprmCompressor.cs
//  
// Copyright 2002-2004  Apache Software Foundation
//
// Jakarta Poi Authors:
//   Rainer Klute (klute@rainer-klute.de)
//
// Poi.Net Authors:
//   Johannes Roith(johannes at jroith dot de)
//  
// 
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

using System;
using System.Collections;

using Poi.Net.HWPF.UserModel;
using Poi.Net.Util;

namespace Poi.Net.HWPF.SPRM
{
	
	public class TableSprmCompressor
	{
		public TableSprmCompressor()
		{
		}
		public static byte[] CompressTableProperty(TableProperties newTAP)
		{
			int size = 0;
			ArrayList sprmList = new ArrayList();
			
			if (newTAP.Jc != 0)
			{
				size += SprmUtils.AddSprm((short) 0x5400, newTAP.Jc, null, sprmList);
			}
			if (newTAP.FCantSplit)
			{
				size += SprmUtils.AddSprm((short) 0x3403, 1, null, sprmList);
			}
			if (newTAP.FTableHeader)
			{
				size += SprmUtils.AddSprm((short) 0x3404, 1, null, sprmList);
			}
			byte[] brcBuf = new byte[6 * BorderCode.SIZE];
			int offset = 0;
			newTAP.BrcTop.Serialize(brcBuf, offset);
			offset += BorderCode.SIZE;
			newTAP.BrcLeft.Serialize(brcBuf, offset);
			offset += BorderCode.SIZE;
			newTAP.BrcBottom.Serialize(brcBuf, offset);
			offset += BorderCode.SIZE;
			newTAP.BrcRight.Serialize(brcBuf, offset);
			offset += BorderCode.SIZE;
			newTAP.BrcHorizontal.Serialize(brcBuf, offset);
			offset += BorderCode.SIZE;
			newTAP.BrcVertical.Serialize(brcBuf, offset);
			byte[] compare = new byte[6 * BorderCode.SIZE];
			if (!ArrayHelper.Equals(brcBuf, compare))
			{
				size += SprmUtils.AddSprm(unchecked( (short) 0xD605), 0, brcBuf, sprmList);
			}
			if (newTAP.DyaRowHeight != 0)
			{
				size += SprmUtils.AddSprm(unchecked( (short) 0x9407), newTAP.DyaRowHeight, null, sprmList);
			}
			if (newTAP.ItcMac > 0)
			{
				int itcMac = newTAP.ItcMac;
				byte[] buf = new byte[1 + (LittleEndian.SHORT_SIZE * (itcMac + 1)) + (TableCellDescriptor.SIZE * itcMac)];
				buf[0] = (byte) itcMac;
				
				short[] dxaCenters = newTAP.RgdxaCenter;
				for (int x = 0; x < dxaCenters.Length; x++)
				{
					LittleEndian.PutShort(buf, 1 + (x * LittleEndian.SHORT_SIZE), dxaCenters[x]);
				}
				
				TableCellDescriptor[] cellDescriptors = newTAP.Rgtc;
				for (int x = 0; x < cellDescriptors.Length; x++)
				{
					cellDescriptors[x].Serialize(buf, 1 + ((itcMac + 1) * LittleEndian.SHORT_SIZE) + (x * TableCellDescriptor.SIZE));
				}
				size += SprmUtils.AddSpecialSprm(unchecked( (short) 0xD608), buf, sprmList);
				
				//      buf = new byte[(itcMac * ShadingDescriptor_upxs[x].Size + 1];
				//      buf[0] = (byte)itcMac;
				//      ShadingDescriptor[] shds = newTAP.getRgshd();
				//      for (int x = 0; x < itcMac; x++)
				//      {
				//        shds[x].Serialize(buf, 1 + (x * ShadingDescriptor_upxs[x].Size);
				//      }
				//      size += SprmUtils.AddSpecialSprm((short)0xD609, buf, sprmList);
			}
			if (newTAP.Tlp != 0)
			{
				size += SprmUtils.AddSprm((short) 0x740a, newTAP.Tlp, null, sprmList);
			}
			
			return SprmUtils.GetGrpprl(sprmList, size);
		}
	}
}