// 
// BorderCode.cs
//  
// Copyright 2002-2004  Apache Software Foundation
// 
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

using System;

using Poi.Net.Util;

namespace Poi.Net.HWPF.UserModel
{
	
	public class BorderCode : ICloneable
	{
		virtual public bool Empty {
			get {
				return _info == 0 && _info2 == 0;
			}
			
		}
		public const int SIZE = 4;
		private short _info;
		
		private static readonly BitField _dptLineWidth = new BitField(0xff);
		
		private static readonly BitField _brcType = new BitField(0xff00);
		private short _info2;
		
		private static readonly BitField _ico = new BitField(0xff);
		
		private static readonly BitField _dptDpace = new BitField(0x1f00);
		
		private static readonly BitField _fShadow = new BitField(0x2000);
		
		private static readonly BitField _fFrame = new BitField(0x4000);
		
		public BorderCode()
		{
		}
		
		public BorderCode(byte[] buf, int offset)
		{
			_info = LittleEndian.GetShort(buf, offset);
			_info2 = LittleEndian.GetShort(buf, offset + LittleEndian.SHORT_SIZE);
		}
		
		public virtual void Serialize(byte[] buf, int offset)
		{
			LittleEndian.PutShort(buf, offset, _info);
			LittleEndian.PutShort(buf, offset + LittleEndian.SHORT_SIZE, _info2);
		}
		
		public virtual int ToInt()
		{
			byte[] buf = new byte[4];
			Serialize(buf, 0);
			return LittleEndian.GetInt(buf);
		}
		
		public  override bool Equals(object o)
		{
			BorderCode brc = (BorderCode) o;
			return _info == brc._info && _info2 == brc._info2;
		}
		
		public virtual object Clone()
		{
			return base.MemberwiseClone();
		}
	}
}