// 
// CharacterProperties.cs
//  
// Copyright 2002-2004  Apache Software Foundation
//
// Jakarta Poi Authors:
//   Ryan Ackley
//
// Poi.Net Authors:
//   Johannes Roith(johannes at jroith dot de)
//  
// 
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

using System;
using Poi.Net.HWPF.Model;
using Poi.Net.HWPF.Model.Types;

namespace Poi.Net.HWPF.UserModel
{

	public class CharacterProperties:CHPAbstractType, ICloneable
	{
		virtual public bool MarkedDeleted {
			get {
				return FRMarkDel;
			}
			
		}
		virtual public bool Bold {
			get {
				return FBold;
			}
			
			set {
				base.FBold = value;
			}
			
		}
		virtual public bool Italic {
			get {
				return FItalic;
			}
			
			set {
				base.FItalic = value;
			}
			
		}
		virtual public bool Outlined {
			get {
				return FOutline;
			}
			
		}
		virtual public bool Outline
		{
			set {
				base.FOutline = value;
			}
			
		}
		virtual public bool FldVanished {
			get {
				return FFldVanish;
			}
			
		}
		virtual public bool FldVanish
		{
			set {
				base.FFldVanish = value;
			}
			
		}
		virtual public bool SmallCaps {
			get {
				return FSmallCaps;
			}
			
			set {
				base.FSmallCaps = value;
			}
			
		}
		virtual public bool Capitalized {
			get {
				return FCaps;
			}
			
			set {
				base.FCaps = value;
			}
			
		}
		virtual public bool Vanished {
			get {
				return FVanish;
			}
			
			set {
				base.FVanish = value;
			}
			
		}
		virtual public bool MarkedInserted {
			get {
				return FRMark;
			}
			
		}
		virtual public bool StrikeThrough {
			get {
				return FStrike;
			}
			
		}
		virtual public bool Shadowed {
			get {
				return FShadow;
			}
			
		}
		virtual public bool Shadow
		{
			set {
				base.FShadow = value;
			}
			
		}
		virtual public bool Embossed {
			get {
				return FEmboss;
			}
			
			set {
				base.FEmboss = value;
			}
			
		}
		virtual public bool Imprinted {
			get {
				return FImprint;
			}
			
			set {
				base.FImprint = value;
			}
			
		}
		virtual public bool DoubleStrikeThrough {
			get {
				return FDStrike;
			}
			
			set {
				base.FDStrike = value;
			}
			
		}
		virtual public int FontSize {
			get {
				return Hps;
			}
			
			set {
				base.Hps = value;
			}
			
		}
		virtual public int CharacterSpacing {
			get {
				return DxaSpace;
			}
			
			set {
				base.DxaSpace = value;
			}
			
		}
		virtual public short SubSuperScriptIndex {
			get {
				return Iss;
			}
			
			set {
				base.DxaSpace = value;
			}
			
		}
		virtual public int UnderlineCode {
			get {
				return base.Kul;
			}
			
			set {
				base.Kul = (byte) value;
			}
			
		}
		virtual public int Color {
			get {
				return base.Ico;
			}
			
			set {
				base.Ico = (byte) value;
			}
			
		}
		virtual public int VerticalOffset {
			get {
				return base.HpsPos;
			}
			
			set {
				base.HpsPos = value;
			}
			
		}
		virtual public int Kerning {
			get {
				return base.HpsKern;
			}
			
			set {
				base.HpsKern = value;
			}
			
		}
		
		/// <summary> Get the ico24 field for the CHP record.</summary>
		/// <summary> Set the ico24 field for the CHP record.</summary>
		virtual public int Ico24 {
			get {
				if (_ico24 == - 1)
				{
					switch (field_11_ico)
					// convert word 97 colour numbers to 0xBBGGRR value
					{
						
						case 0:  // auto
							return - 1;
						
						case 1:  // black
							return 0x000000;
						
						case 2:  // blue
							return 0xFF0000;
						
						case 3:  // cyan
							return 0xFFFF00;
						
						case 4:  // green
							return 0x00FF00;
						
						case 5:  // magenta
							return 0xFF00FF;
						
						case 6:  // red
							return 0x0000FF;
						
						case 7:  // yellow
							return 0x00FFFF;
						
						case 8:  // white
							return 0x0FFFFFF;
						
						case 9:  // dark blue
							return 0x800000;
						
						case 10:  // dark cyan
							return 0x808000;
						
						case 11:  // dark green
							return 0x008000;
						
						case 12:  // dark magenta
							return 0x800080;
						
						case 13:  // dark red
							return 0x000080;
						
						case 14:  // dark yellow
							return 0x008080;
						
						case 15:  // dark grey
							return 0x808080;
						
						case 16:  // light grey
							return 0xC0C0C0;
						}
				}
				return _ico24;
			}
			
			set {
				_ico24 = value & 0xFFFFFF; // only keep the 24bit 0xBBGGRR colour
			}
			
		}
		public static short SPRM_FRMARKDEL = (short) 0x0800;
		public const short SPRM_FRMARK = (short) (0x0801);
		public const short SPRM_FFLDVANISH = (short) (0x0802);
		public const short SPRM_PICLOCATION = (short) (0x6A03);
		public const short SPRM_IBSTRMARK = (short) (0x4804);
		public const short SPRM_DTTMRMARK = (short) (0x6805);
		public const short SPRM_FDATA = (short) (0x0806);
		public const short SPRM_SYMBOL = (short) (0x6A09);
		public const short SPRM_FOLE2 = (short) (0x080A);
		public const short SPRM_HIGHLIGHT = (short) (0x2A0C);
		public const short SPRM_OBJLOCATION = (short) (0x680E);
		public const short SPRM_ISTD = (short) (0x4A30);
		public const short SPRM_FBOLD = (short) (0x0835);
		public const short SPRM_FITALIC = (short) (0x0836);
		public const short SPRM_FSTRIKE = (short) (0x0837);
		public const short SPRM_FOUTLINE = (short) (0x0838);
		public const short SPRM_FSHADOW = (short) (0x0839);
		public const short SPRM_FSMALLCAPS = (short) (0x083A);
		public const short SPRM_FCAPS = (short) (0x083B);
		public const short SPRM_FVANISH = (short) (0x083C);
		public const short SPRM_KUL = (short) (0x2A3E);
		public static short SPRM_DXASPACE = -30656;
		public const short SPRM_LID = (short) (0x4A41);
		public const short SPRM_ICO = (short) (0x2A42);
		public const short SPRM_HPS = (short) (0x4A43);
		public const short SPRM_HPSPOS = (short) (0x4845);
		public const short SPRM_ISS = (short) (0x2A48);
		public const short SPRM_HPSKERN = (short) (0x484B);
		public const short SPRM_YSRI = (short) (0x484E);
		public const short SPRM_RGFTCASCII = (short) (0x4A4F);
		public const short SPRM_RGFTCFAREAST = (short) (0x4A50);
		public const short SPRM_RGFTCNOTFAREAST = (short) (0x4A51);
		public const short SPRM_CHARSCALE = (short) (0x4852);
		public const short SPRM_FDSTRIKE = (short) (0x2A53);
		public const short SPRM_FIMPRINT = (short) (0x0854);
		public const short SPRM_FSPEC = (short) (0x0855);
		public const short SPRM_FOBJ = (short) (0x0856);
		public static short SPRM_PROPRMARK = -13737;
		public const short SPRM_FEMBOSS = (short) (0x0858);
		public const short SPRM_SFXTEXT = (short) (0x2859);
		public static short SPRM_DISPFLDRMARK = -13726;
		public const short SPRM_IBSTRMARKDEL = (short) (0x4863);
		public const short SPRM_DTTMRMARKDEL = (short) (0x6864);
		public const short SPRM_BRC = (short) (0x6865);
		public const short SPRM_SHD = (short) (0x4866);
		public const short SPRM_IDSIRMARKDEL = (short) (0x4867);
		public const short SPRM_CPG = (short) (0x486B);
		public const short SPRM_NONFELID = (short) (0x486D);
		public const short SPRM_FELID = (short) (0x486E);
		public const short SPRM_IDCTHINT = (short) (0x286F);
		
		internal int _ico24 = - 1; // default to -1 so we can ignore it for word 97 files
		
		public CharacterProperties()
		{
			field_17_fcPic = - 1;
			field_22_dttmRMark = new DateAndTime();
			field_23_dttmRMarkDel = new DateAndTime();
			field_36_dttmPropRMark = new DateAndTime();
			field_40_dttmDispFldRMark = new DateAndTime();
			field_41_xstDispFldRMark = new byte[36];
			field_42_shd = new ShadingDescriptor();
			field_43_brc = new BorderCode();
			field_7_hps = 20;
			field_24_istd = 10;
			field_16_wCharScale = 100;
			field_13_lidDefault = 0x0400;
			field_14_lidFE = 0x0400;
		}
		
		public virtual void MarkDeleted(bool mark)
		{
			base.FRMarkDel = mark;
		}
		
		public virtual void MarkInserted(bool mark)
		{
			base.FRMark = mark;
		}
		
		public virtual void StrikedThrough(bool strike)
		{
			base.FStrike = strike;
		}
		
		public virtual bool IsHighlighted()
		{
			return base.FHighlight;
		}
		
		public virtual void SetHighlighted(byte color)
		{
			base.IcoHighlight = color;
		}
		
		public override object Clone()
		{

			CharacterProperties cp = (CharacterProperties) base.Clone();
			cp.field_22_dttmRMark = (DateAndTime) field_22_dttmRMark.Clone();
			cp.field_23_dttmRMarkDel = (DateAndTime) field_23_dttmRMarkDel.Clone();
			cp.field_36_dttmPropRMark = (DateAndTime) field_36_dttmPropRMark.Clone();
			cp.field_40_dttmDispFldRMark = (DateAndTime) field_40_dttmDispFldRMark.Clone();
			cp.field_41_xstDispFldRMark = new byte[field_41_xstDispFldRMark.Length];
			field_41_xstDispFldRMark.CopyTo(cp.field_41_xstDispFldRMark, 0);
			cp.field_42_shd = (ShadingDescriptor) field_42_shd.Clone();
			
			cp._ico24 = _ico24;
			return cp;
		}
	}
}