// 
// CharacterRun.cs
//  
// Copyright 2002-2004  Apache Software Foundation
//
// Jakarta Poi Authors:
//   Ryan Ackley
//
// Poi.Net Authors:
//   Johannes Roith(johannes at jroith dot de)
//  
// 
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

using System;

using Poi.Net.HWPF.Model;
using Poi.Net.HWPF.SPRM;

namespace Poi.Net.HWPF.UserModel
{
	
	/// <summary> This class represents a run of text that share common properties.
	/// 
	/// </summary>

	public class CharacterRun:Range, ICloneable
	{
		virtual public bool MarkedDeleted {
			get {
				return _props.FRMarkDel;
			}
			
		}
		virtual public bool Bold {
			get {
				return _props.FBold;
			}
			
			set {
				_props.FBold = value;
				
				byte newVal = (byte) (value?1:0);
				_chpx.UpdateSprm(SPRM_FBOLD, newVal);
			}
			
		}
		virtual public bool Italic {
			get {
				return _props.FItalic;
			}
			
			set {
				_props.FItalic = value;
				
				byte newVal = (byte) (value?1:0);
				_chpx.UpdateSprm(SPRM_FITALIC, newVal);
			}
			
		}
		virtual public bool Outlined {
			get {
				return _props.FOutline;
			}
			
		}
		virtual public bool Outline
		{
			set {
				_props.FOutline = value;
				
				byte newVal = (byte) (value?1:0);
				_chpx.UpdateSprm(SPRM_FOUTLINE, newVal);
			}
			
		}
		virtual public bool FldVanished {
			get {
				return _props.FFldVanish;
			}
			
		}
		virtual public bool FldVanish
		{
			set {
				_props.FFldVanish = value;
				
				byte newVal = (byte) (value?1:0);
				_chpx.UpdateSprm(SPRM_FFLDVANISH, newVal);
			}
			
		}
		virtual public bool SmallCaps {
			get {
				return _props.FSmallCaps;
			}
			
			set {
				_props.FSmallCaps = value;
				
				byte newVal = (byte) (value?1:0);
				_chpx.UpdateSprm(SPRM_FSMALLCAPS, newVal);
			}
			
		}
		virtual public bool Capitalized {
			get {
				return _props.FCaps;
			}
			
			set {
				_props.FCaps = value;
				
				byte newVal = (byte) (value?1:0);
				_chpx.UpdateSprm(SPRM_FCAPS, newVal);
			}
			
		}
		virtual public bool Vanished {
			get {
				return _props.FVanish;
			}
			
			set {
				_props.FVanish = value;
				
				byte newVal = (byte) (value?1:0);
				_chpx.UpdateSprm(SPRM_FVANISH, newVal);
			}
			
		}
		virtual public bool MarkedInserted {
			get {
				return _props.FRMark;
			}
			
		}
		virtual public bool StrikedThrough {
			get {
				return _props.FStrike;
			}
			
		}
		virtual public bool Shadowed {
			get {
				return _props.FShadow;
			}
			
		}
		virtual public bool Shadow
		{
			set {
				_props.FShadow = value;
				
				byte newVal = (byte) (value?1:0);
				_chpx.UpdateSprm(SPRM_FSHADOW, newVal);
			}
			
		}
		virtual public bool Embossed {
			get {
				return _props.FEmboss;
			}
			
			set {
				_props.FEmboss = value;
				
				byte newVal = (byte) (value?1:0);
				_chpx.UpdateSprm(SPRM_FEMBOSS, newVal);
			}
			
		}
		virtual public bool Imprinted {
			get {
				return _props.FImprint;
			}
			
			set {
				_props.FImprint = value;
				
				byte newVal = (byte) (value?1:0);
				_chpx.UpdateSprm(SPRM_FIMPRINT, newVal);
			}
			
		}
		virtual public bool DoubleStrikeThrough {
			get {
				return _props.FDStrike;
			}
			
		}
		virtual public int FtcAscii
		{
			set {
				_props.FtcAscii = value;
				
				_chpx.UpdateSprm(SPRM_RGFTCASCII, (short) value);
			}
			
		}
		virtual public int FtcFE
		{
			set {
				_props.FtcFE = value;
				
				_chpx.UpdateSprm(SPRM_RGFTCFAREAST, (short) value);
			}
			
		}
		virtual public int FtcOther
		{
			set {
				_props.FtcOther = value;
				
				_chpx.UpdateSprm(SPRM_RGFTCNOTFAREAST, (short) value);
			}
			
		}
		virtual public int FontSize {
			get {
				return _props.Hps;
			}
			
			set {
				_props.Hps = value;
				
				_chpx.UpdateSprm(SPRM_HPS, (short) value);
			}
			
		}
		virtual public int CharacterSpacing {
			get {
				return _props.DxaSpace;
			}
			
			set {
				_props.DxaSpace = value;
				
				_chpx.UpdateSprm(SPRM_DXASPACE, value);
			}
			
		}
		virtual public short SubSuperScriptIndex {
			get {
				return _props.Iss;
			}
			
			set {
				_props.DxaSpace = value;
				
				_chpx.UpdateSprm(SPRM_DXASPACE, value);
			}
			
		}
		virtual public int UnderlineCode {
			get {
				return _props.Kul;
			}
			
			set {
				_props.Kul = (byte) value;
				_chpx.UpdateSprm(SPRM_KUL, (byte) value);
			}
			
		}
		virtual public int Color {
			get {
				return _props.Ico;
			}
			
			set {
				_props.Ico = (byte) value;
				_chpx.UpdateSprm(SPRM_ICO, (byte) value);
			}
			
		}
		virtual public int VerticalOffset {
			get {
				return _props.HpsPos;
			}
			
			set {
				_props.HpsPos = value;
				_chpx.UpdateSprm(SPRM_HPSPOS, (byte) value);
			}
			
		}
		virtual public int Kerning {
			get {
				return _props.HpsKern;
			}
			
			set {
				_props.HpsKern = value;
				_chpx.UpdateSprm(SPRM_HPSKERN, (short) value);
			}
			
		}
		virtual public string FontName {
			get {
				return _doc.FontTable.GetMainFont(_props.FtcAscii);
			}
			
		}
		virtual public bool SpecialCharacter {
			get {
				return _props.FSpec;
			}
			
			set {
				_props.FSpec = value;
				
				byte newVal = (byte) (value?1:0);
				_chpx.UpdateSprm(SPRM_FSPEC, newVal);
			}
			
		}
		virtual public bool Obj {
			get {
				return _props.FObj;
			}
			
			set {
				_props.FObj = value;
				
				byte newVal = (byte) (value?1:0);
				_chpx.UpdateSprm(SPRM_FOBJ, newVal);
			}
			
		}
		virtual public int PicOffset {
			get {
				return _props.FcPic;
			}
			
			set {
				_props.FcPic = value;
				_chpx.UpdateSprm(SPRM_PICLOCATION, value);
			}
			
		}
		virtual public bool Data {
			get {
				return _props.FData;
			}
			
			set {
				_props.FData = value;
				
				byte newVal = (byte) (value?1:0);
				_chpx.UpdateSprm(SPRM_FOBJ, newVal);
			}
			
		}
		virtual public bool Ole2 {
			get {
				return _props.FOle2;
			}
			
			set {
				_props.FOle2 = value;
				
				byte newVal = (byte) (value?1:0);
				_chpx.UpdateSprm(SPRM_FOBJ, newVal);
			}
			
		}
		virtual public int ObjOffset {
			get {
				return _props.FcObj;
			}
			
			set {
				_props.FcObj = value;
				_chpx.UpdateSprm(SPRM_OBJLOCATION, value);
			}
			
		}
		
		/// <summary> Get the ico24 field for the CHP record.</summary>
		/// <summary> Set the ico24 field for the CHP record.</summary>
		virtual public int Ico24 {
			get {
				return _props.Ico24;
			}
			
			set {
				_props.Ico24 = value;
			}
			
		}
		public static short SPRM_FRMARKDEL = (short) 0x0800;
		public const short SPRM_FRMARK = (short) (0x0801);
		public const short SPRM_FFLDVANISH = (short) (0x0802);
		public const short SPRM_PICLOCATION = (short) (0x6A03);
		public const short SPRM_IBSTRMARK = (short) (0x4804);
		public const short SPRM_DTTMRMARK = (short) (0x6805);
		public const short SPRM_FDATA = (short) (0x0806);
		public const short SPRM_SYMBOL = (short) (0x6A09);
		public const short SPRM_FOLE2 = (short) (0x080A);
		public const short SPRM_HIGHLIGHT = (short) (0x2A0C);
		public const short SPRM_OBJLOCATION = (short) (0x680E);
		public const short SPRM_ISTD = (short) (0x4A30);
		public const short SPRM_FBOLD = (short) (0x0835);
		public const short SPRM_FITALIC = (short) (0x0836);
		public const short SPRM_FSTRIKE = (short) (0x0837);
		public const short SPRM_FOUTLINE = (short) (0x0838);
		public const short SPRM_FSHADOW = (short) (0x0839);
		public const short SPRM_FSMALLCAPS = (short) (0x083A);
		public const short SPRM_FCAPS = (short) (0x083B);
		public const short SPRM_FVANISH = (short) (0x083C);
		public const short SPRM_KUL = (short) (0x2A3E);
		public static short SPRM_DXASPACE = -30656;
		public const short SPRM_LID = (short) (0x4A41);
		public const short SPRM_ICO = (short) (0x2A42);
		public const short SPRM_HPS = (short) (0x4A43);
		public const short SPRM_HPSPOS = (short) (0x4845);
		public const short SPRM_ISS = (short) (0x2A48);
		public const short SPRM_HPSKERN = (short) (0x484B);
		public const short SPRM_YSRI = (short) (0x484E);
		public const short SPRM_RGFTCASCII = (short) (0x4A4F);
		public const short SPRM_RGFTCFAREAST = (short) (0x4A50);
		public const short SPRM_RGFTCNOTFAREAST = (short) (0x4A51);
		public const short SPRM_CHARSCALE = (short) (0x4852);
		public const short SPRM_FDSTRIKE = (short) (0x2A53);
		public const short SPRM_FIMPRINT = (short) (0x0854);
		public const short SPRM_FSPEC = (short) (0x0855);
		public const short SPRM_FOBJ = (short) (0x0856);
		public static short SPRM_PROPRMARK = -13737;
		public const short SPRM_FEMBOSS = (short) (0x0858);
		public const short SPRM_SFXTEXT = (short) (0x2859);
		public static short SPRM_DISPFLDRMARK = -13726;
		public const short SPRM_IBSTRMARKDEL = (short) (0x4863);
		public const short SPRM_DTTMRMARKDEL = (short) (0x6864);
		public const short SPRM_BRC = (short) (0x6865);
		public const short SPRM_SHD = (short) (0x4866);
		public const short SPRM_IDSIRMARKDEL = (short) (0x4867);
		public const short SPRM_CPG = (short) (0x486B);
		public const short SPRM_NONFELID = (short) (0x486D);
		public const short SPRM_FELID = (short) (0x486E);
		public const short SPRM_IDCTHINT = (short) (0x286F);
		
		internal SprmBuffer _chpx;
		internal CharacterProperties _props;
		
		/// <summary> </summary>
		/// <param name="chpx">The chpx this object is based on.
		/// </param>
		/// <param name="ss">The stylesheet for the document this run belongs to.
		/// </param>
		/// <param name="istd">The style index if this run's base style.
		/// </param>
		/// <param name="parent">The parent range of this character run (usually a paragraph).
		/// </param>
		internal CharacterRun(CHPX chpx, StyleSheet ss, short istd, Range parent):base(System.Math.Max(parent._start, chpx.Start), System.Math.Min(parent._end, chpx.End), parent)
		{
			_props = chpx.GetCharacterProperties(ss, istd);
			_chpx = chpx.SprmBuf;
		}
		
		/// <summary> Here for runtime type determination using a switch statement convenient.
		/// 
		/// </summary>
		/// <returns> TYPE_CHARACTER
		/// </returns>
		public override int Type {
			get { return TYPE_CHARACTER; }
		}
		
		public virtual void MarkDeleted(bool mark)
		{
			_props.FRMarkDel = mark;
			
			byte newVal = (byte) (mark?1:0);
			_chpx.UpdateSprm(SPRM_FRMARKDEL, newVal);
		}
		
		public virtual void MarkInserted(bool mark)
		{
			_props.FRMark = mark;
			
			byte newVal = (byte) (mark?1:0);
			_chpx.UpdateSprm(SPRM_FRMARK, newVal);
		}
		
		public virtual void StrikeThrough(bool strike)
		{
			_props.FStrike = strike;
			
			byte newVal = (byte) (strike?1:0);
			_chpx.UpdateSprm(SPRM_FSTRIKE, newVal);
		}
		
		public virtual bool IsHighlighted()
		{
			return _props.FHighlight;
		}
		
		public virtual void SetHighlighted(byte color)
		{
			_props.FHighlight = true;
			_props.IcoHighlight = color;
			_chpx.UpdateSprm(SPRM_HIGHLIGHT, color);
		}
		
		/// <summary> Used to create a deep copy of this object.
		/// 
		/// </summary>
		/// <returns> A deep copy.
		/// </returns>
		/// <throws>  CloneNotSupportedException never </throws>
		public override object Clone()
		{
			CharacterRun cp = (CharacterRun) base.Clone();
			cp._props.DttmRMark = (DateAndTime) _props.DttmRMark.Clone();
			cp._props.DttmRMarkDel = (DateAndTime) _props.DttmRMarkDel.Clone();
			cp._props.DttmPropRMark = (DateAndTime) _props.DttmPropRMark.Clone();
			cp._props.DttmDispFldRMark = (DateAndTime) _props.DttmDispFldRMark.Clone();
			cp._props.XstDispFldRMark = (byte[]) _props.XstDispFldRMark.Clone();
			cp._props.Shd = (ShadingDescriptor) _props.Shd.Clone();
			
			return cp;
		}
	}
}