// 
// DateAndTime.cs
//  
// Copyright 2002-2004  Apache Software Foundation
//
// Jakarta Poi Authors:
//   Rainer Klute (klute@rainer-klute.de)
//
// Poi.Net Authors:
//   Johannes Roith(johannes at jroith dot de)
//  
// 
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

using System;

using Poi.Net.Util;

namespace Poi.Net.HWPF.UserModel
{
	
	/// <summary> This class is used to represent a date and time in a Word document.
	/// 
	/// </summary>
	/// <author>  Ryan Ackley
	/// </author>
	public class DateAndTime : ICloneable
	{
		public const int SIZE = 4;
		private short _info;
		
		private static readonly BitField _minutes = new BitField(0x3f);
		
		private static readonly BitField _hours = new BitField(0x7c0);
		
		private static readonly BitField _dom = new BitField(0xf800);
		private short _info2;
		
		private static readonly BitField _months = new BitField(0xf);
		
		private static readonly BitField _years = new BitField(0x1ff0);
		
		private static readonly BitField _weekday = new BitField(0xe000);
		
		public DateAndTime()
		{
		}
		
		public DateAndTime(byte[] buf, int offset)
		{
			_info = LittleEndian.GetShort(buf, offset);
			_info2 = LittleEndian.GetShort(buf, offset + LittleEndian.SHORT_SIZE);
		}
		
		public virtual void Serialize(byte[] buf, int offset)
		{
			LittleEndian.PutShort(buf, offset, _info);
			LittleEndian.PutShort(buf, offset + LittleEndian.SHORT_SIZE, _info2);
		}
		
		public  override bool Equals(object o)
		{
			DateAndTime dttm = (DateAndTime) o;
			return _info == dttm._info && _info2 == dttm._info2;
		}
		
		public virtual object Clone()
		{
			return base.MemberwiseClone();
		}
	}
}