// 
// LineSpacingDescriptor.cs
//  
// Copyright 2002-2004  Apache Software Foundation
//
// Jakarta Poi Authors:
//   Ryan Ackley
//
// Poi.Net Authors:
//   Johannes Roith(johannes at jroith dot de)
//  
// 
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

using System;
using Poi.Net.Util;

namespace Poi.Net.HWPF.UserModel
{
	
	/// <summary> This class is used to determine line spacing for a paragraph.
	/// 
	/// </summary>
	public class LineSpacingDescriptor : ICloneable
	{
		virtual public short MultiLinespace
		{
			set {
				_fMultiLinespace = value;
			}
			
		}
		virtual public short DyaLine
		{
			set {
				_dyaLine = value;
			}
			
		}
		internal short _dyaLine;
		internal short _fMultiLinespace;
		
		public LineSpacingDescriptor()
		{
		}
		
		public LineSpacingDescriptor(byte[] buf, int offset)
		{
			_dyaLine = LittleEndian.GetShort(buf, offset);
			_fMultiLinespace = LittleEndian.GetShort(buf, offset + LittleEndian.SHORT_SIZE);
		}
		
		public virtual object Clone()
		{
			return base.MemberwiseClone();
		}
		
		public virtual int ToInt()
		{
			byte[] intHolder = new byte[4];
			Serialize(intHolder, 0);
			return LittleEndian.GetInt(intHolder);
		}
		
		public virtual void Serialize(byte[] buf, int offset)
		{
			LittleEndian.PutShort(buf, offset, _dyaLine);
			LittleEndian.PutShort(buf, offset + LittleEndian.SHORT_SIZE, _fMultiLinespace);
		}
		public  override bool Equals(object o)
		{
			LineSpacingDescriptor lspd = (LineSpacingDescriptor) o;
			
			return _dyaLine == lspd._dyaLine && _fMultiLinespace == lspd._fMultiLinespace;
		}
	}
}