// 
// Paragraph.cs
//  
// Copyright 2002-2004  Apache Software Foundation
//
// Jakarta Poi Authors:
//   Rainer Klute (klute@rainer-klute.de)
//
// Poi.Net Authors:
//   Johannes Roith(johannes at jroith dot de)
//  
// 
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

using System;
using Poi.Net.HWPF.Model;
using Poi.Net.HWPF.SPRM;

namespace Poi.Net.HWPF.UserModel
{
	
	public class Paragraph:Range, ICloneable
	{
		virtual public short StyleIndex {
			get {
				return _istd;
			}
			
		}
		virtual public bool InTable {
			get {
				return _props.FInTable != 0;
			}
			
		}
		virtual public int TableLevel {
			get {
				return _props.TableLevel;
			}
			
		}
		virtual public bool EmbeddedCellMark {
			get {
				return _props.EmbeddedCellMark != 0;
			}
			
		}
		virtual public bool KeepOnPage
		{
			get { return _props.FKeep != 0; }

			set {
				byte keep = (byte) (value?1:0);
				_props.FKeep = keep;
				_papx.UpdateSprm(SPRM_FKEEP, keep);
			}
			
		}
		virtual public bool KeepWithNext
		{
			get { return _props.FKeepFollow != 0; }
			set {
				byte keepFollow = (byte) (value?1:0);
				_props.FKeepFollow = keepFollow;
				_papx.UpdateSprm(SPRM_FKEEPFOLLOW, keepFollow);
			}
			
		}
		virtual public bool PageBreakBefore
		{
			get { return _props.FPageBreakBefore != 0; }
			set {
				byte pageBreak = (byte) (value?1:0);
				_props.FPageBreakBefore = pageBreak;
				_papx.UpdateSprm(SPRM_FPAGEBREAKBEFORE, pageBreak);
			}
			
		}
		virtual public bool LineNotNumbered {
			get {
				return _props.FNoLnn != 0;
			}
			
			set {
				byte noLnn = (byte) (value?1:0);
				_props.FNoLnn = noLnn;
				_papx.UpdateSprm(SPRM_FNOLINENUMB, noLnn);
			}
			
		}
		virtual public bool SideBySide {
			get {
				return _props.FSideBySide != 0;
			}
			
			set {
				byte sideBySide = (byte) (value?1:0);
				_props.FSideBySide = sideBySide;
				_papx.UpdateSprm(SPRM_FSIDEBYSIDE, sideBySide);
			}
			
		}
		virtual public bool AutoHyphenated {
			get {
				return _props.FNoAutoHyph == 0;
			}
			
			set {
				byte auto = (byte) (!value?1:0);
				_props.FNoAutoHyph = auto;
				_papx.UpdateSprm(SPRM_FNOAUTOHYPH, auto);
			}
			
		}
		virtual public bool WidowControlled {
			get {
				return _props.FWidowControl != 0;
			}
			
		}
		virtual public bool WidowControl
		{
			set {
				byte widow = (byte) (value?1:0);
				_props.FWidowControl = widow;
				_papx.UpdateSprm(SPRM_FWIDOWCONTROL, widow);
			}
			
		}
		virtual public int IndentFromRight {
			get {
				return _props.DxaRight;
			}
			
			set {
				_props.DxaRight = value;
				_papx.UpdateSprm(SPRM_DXARIGHT, (short) value);
			}
			
		}
		virtual public int IndentFromLeft {
			get {
				return _props.DxaLeft;
			}
			
			set {
				_props.DxaLeft = value;
				_papx.UpdateSprm(SPRM_DXALEFT, (short) value);
			}
			
		}
		virtual public int FirstLineIndent {
			get {
				return _props.DxaLeft1;
			}
			
			set {
				_props.DxaLeft1 = value;
				_papx.UpdateSprm(SPRM_DXALEFT1, (short) value);
			}
			
		}
		virtual public LineSpacingDescriptor LineSpacing {
			get {
				return _props.Lspd;
			}
			
			set {
				_props.Lspd = value;
				_papx.UpdateSprm(SPRM_DYALINE, value.ToInt());
			}
			
		}
		virtual public int SpacingBefore {
			get {
				return _props.DyaBefore;
			}
			
			set {
				_props.DyaBefore = value;
				_papx.UpdateSprm(SPRM_DYABEFORE, (short) value);
			}
			
		}
		virtual public int SpacingAfter {
			get {
				return _props.DyaAfter;
			}
			
			set {
				_props.DyaAfter = value;
				_papx.UpdateSprm(SPRM_DYAAFTER, (short) value);
			}
			
		}
		virtual public bool Kinsoku {
			get {
				return _props.FKinsoku != 0;
			}
			
			set {
				byte kin = (byte) (value?1:0);
				_props.FKinsoku = kin;
				_papx.UpdateSprm(SPRM_FKINSOKU, kin);
			}
			
		}
		virtual public bool WordWrapped {
			get {
				return _props.FWordWrap != 0;
			}
			
			set {
				byte wordWrap = (byte) (value?1:0);
				_props.FWordWrap = wordWrap;
				_papx.UpdateSprm(SPRM_FWORDWRAP, wordWrap);
			}
			
		}
		virtual public int FontAlignment {
			get {
				return _props.WAlignFont;
			}
			
			set {
				_props.WAlignFont = value;
				_papx.UpdateSprm(SPRM_WALIGNFONT, (short) value);
			}
			
		}
		virtual public bool Vertical {
			get {
				return _props.FVertical;
			}
			
			set {
				_props.FVertical = value;
				_papx.UpdateSprm(SPRM_FRAMETEXTFLOW, FrameTextFlow);
			}
			
		}
		virtual public bool Backward {
			get {
				return _props.IsFBackward();
			}
			
			set {
				_props.SetFBackward(value);
				_papx.UpdateSprm(SPRM_FRAMETEXTFLOW, FrameTextFlow);
			}
			
		}
		virtual public BorderCode TopBorder {
			get {
				return _props.BrcTop;
			}
			
			set {
				_props.BrcTop = value;
				_papx.UpdateSprm(SPRM_BRCTOP, value.ToInt());
			}
			
		}
		virtual public BorderCode LeftBorder {
			get {
				return _props.BrcLeft;
			}
			
			set {
				_props.BrcLeft = value;
				_papx.UpdateSprm(SPRM_BRCLEFT, value.ToInt());
			}
			
		}
		virtual public BorderCode BottomBorder {
			get {
				return _props.BrcBottom;
			}
			
			set {
				_props.BrcBottom = value;
				_papx.UpdateSprm(SPRM_BRCBOTTOM, value.ToInt());
			}
			
		}
		virtual public BorderCode RightBorder {
			get {
				return _props.BrcRight;
			}
			
			set {
				_props.BrcRight = value;
				_papx.UpdateSprm(SPRM_BRCRIGHT, value.ToInt());
			}
			
		}
		virtual public BorderCode BarBorder {
			get {
				return _props.BrcBar;
			}
			
			set {
				_props.BrcBar = value;
				_papx.UpdateSprm(SPRM_BRCBAR, value.ToInt());
			}
			
		}
		virtual public ShadingDescriptor Shading {
			get {
				return _props.Shd;
			}
			
			set {
				_props.Shd = value;
				_papx.UpdateSprm(SPRM_SHD, value.ToShort());
			}
			
		}
		virtual public DropCapSpecifier DropCap {
			get {
				return _props.Dcs;
			}
			
			set {
				_props.Dcs = value;
				_papx.UpdateSprm(SPRM_DCS, value.ToShort());
			}
			
		}
		virtual public int Ilfo {
			get {
				return _props.Ilfo;
			}
			
		}
		virtual public int Ilvl {
			get {
				return _props.Ilvl;
			}
			
		}
		private short FrameTextFlow {
			get {
				ushort retVal = 0;
				if (_props.FVertical)
				{
					retVal |= 1;
				}
				if (_props.IsFBackward())
				{
					retVal |= 2;
				}
				if (_props.IsFRotateFont())
				{
					retVal |= 4;
				}
				return (short) retVal;
			}
			
		}
		public const short SPRM_JC = (short) (0x2403);
		public const short SPRM_FSIDEBYSIDE = (short) (0x2404);
		public const short SPRM_FKEEP = (short) (0x2405);
		public const short SPRM_FKEEPFOLLOW = (short) (0x2406);
		public const short SPRM_FPAGEBREAKBEFORE = (short) (0x2407);
		public const short SPRM_BRCL = (short) (0x2408);
		public const short SPRM_BRCP = (short) (0x2409);
		public const short SPRM_ILVL = (short) (0x260A);
		public const short SPRM_ILFO = (short) (0x460B);
		public const short SPRM_FNOLINENUMB = (short) (0x240C);
		public static short SPRM_CHGTABSPAPX = -14835;
		public static short SPRM_DXARIGHT = -31730;
		public static short SPRM_DXALEFT = -31729;
		public static short SPRM_DXALEFT1 = -31727;
		public const short SPRM_DYALINE = (short) (0x6412);
		public static short SPRM_DYABEFORE = -23533;
		public static short SPRM_DYAAFTER = -23532;
		public static short SPRM_CHGTABS = -14827;
		public const short SPRM_FINTABLE = (short) (0x2416);
		public const short SPRM_FTTP = (short) (0x2417);
		public static short SPRM_DXAABS = -31720;
		public static short SPRM_DYAABS = -31719;
		public static short SPRM_DXAWIDTH = -31718;
		public const short SPRM_PC = (short) (0x261B);
		public const short SPRM_WR = (short) (0x2423);
		public const short SPRM_BRCTOP = (short) (0x6424);
		public const short SPRM_BRCLEFT = (short) (0x6425);
		public const short SPRM_BRCBOTTOM = (short) (0x6426);
		public const short SPRM_BRCRIGHT = (short) (0x6427);
		public const short SPRM_BRCBAR = (short) (0x6629);
		public const short SPRM_FNOAUTOHYPH = (short) (0x242A);
		public const short SPRM_WHEIGHTABS = (short) (0x442B);
		public const short SPRM_DCS = (short) (0x442C);
		public const short SPRM_SHD = (short) (0x442D);
		public static short SPRM_DYAFROMTEXT = -31698;
		public static short SPRM_DXAFROMTEXT = -31697;
		public const short SPRM_FLOCKED = (short) (0x2430);
		public const short SPRM_FWIDOWCONTROL = (short) (0x2431);
		public static short SPRM_RULER = -14798;
		public const short SPRM_FKINSOKU = (short) (0x2433);
		public const short SPRM_FWORDWRAP = (short) (0x2434);
		public const short SPRM_FOVERFLOWPUNCT = (short) (0x2435);
		public const short SPRM_FTOPLINEPUNCT = (short) (0x2436);
		public const short SPRM_AUTOSPACEDE = (short) (0x2437);
		public const short SPRM_AUTOSPACEDN = (short) (0x2438);
		public const short SPRM_WALIGNFONT = (short) (0x4439);
		public const short SPRM_FRAMETEXTFLOW = (short) (0x443A);
		public static short SPRM_ANLD = -14786;
		public static short SPRM_PROPRMARK = -14785;
		public const short SPRM_OUTLVL = (short) (0x2640);
		public const short SPRM_FBIDI = (short) (0x2441);
		public const short SPRM_FNUMRMLNS = (short) (0x2443);
		public const short SPRM_CRLF = (short) (0x2444);
		public static short SPRM_NUMRM = -14779;
		public const short SPRM_USEPGSUSETTINGS = (short) (0x2447);
		public const short SPRM_FADJUSTRIGHT = (short) (0x2448);
		
		
		protected internal short _istd;
		protected internal ParagraphProperties _props;
		protected internal SprmBuffer _papx;
		
		protected internal Paragraph(int startIdx, int endIdx, Table parent):base(startIdx, endIdx, Range.TYPE_PARAGRAPH, parent)
		{
			PAPX papx = (PAPX) _paragraphs[_parEnd - 1];
			_props = papx.GetParagraphProperties(_doc.StyleSheet);
			_papx = papx.SprmBuf;
			_istd = papx.Istd;
		}
		
		protected internal Paragraph(PAPX papx, Range parent):base(System.Math.Max(parent._start, papx.Start), System.Math.Min(parent._end, papx.End), parent)
		{
			_props = papx.GetParagraphProperties(_doc.StyleSheet);
			_papx = papx.SprmBuf;
			_istd = papx.Istd;
		}
		
		public override int Type {
			get { return TYPE_PARAGRAPH; }
		}
		
		public virtual bool IsTableRowEnd()
		{
			return _props.FTtp != 0 || _props.FTtpEmbedded != 0;
		}
		
		public virtual int Justification {
			get { return _props.Jc; }
		}
		
		public virtual void SetJustification(byte jc)
		{
			_props.Jc = jc;
			_papx.UpdateSprm(SPRM_JC, jc);
		}
		
		internal virtual void SetTableRowEnd(TableProperties props)
		{
			SetTableRowEnd((byte) 1);
			byte[] grpprl = TableSprmCompressor.CompressTableProperty(props);
			_papx.Append(grpprl);
		}
		
		private void SetTableRowEnd(byte val)
		{
			_props.FTtp = val;
			_papx.UpdateSprm(SPRM_FTTP, val);
		}
		
		public override object Clone()
		{
			Paragraph p = (Paragraph) base.Clone();
			p._props = (ParagraphProperties) _props.Clone();
			//p._baseStyle = _baseStyle;
			p._papx = new SprmBuffer();
			return p;
		}
	}
}