// 
// ParagraphProperties.cs
//  
// Copyright 2002-2004  Apache Software Foundation
//
// Jakarta Poi Authors:
//   Rainer Klute (klute@rainer-klute.de)
//
// Poi.Net Authors:
//   Johannes Roith(johannes at jroith dot de)
//  
// 
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

using System;

using Poi.Net.HWPF.Model;
using Poi.Net.HWPF.Model.Types;
using Poi.Net.HWPF.SPRM;

namespace Poi.Net.HWPF.UserModel
{
	
	public class ParagraphProperties:PAPAbstractType, ICloneable
	{
		virtual public bool KeepOnPage
		{
			get { return base.FKeep != 0; }
			set {
				base.FKeep = (byte) (value?1:0);
			}
			
		}
		virtual public bool KeepWithNext
		{
			get { return base.FKeepFollow != 0; }
			set {
				base.FKeepFollow = (byte) (value?1:0);
			}
			
		}
		virtual public bool PageBreakBefore
		{
			get { return base.FPageBreakBefore != 0; }
			set {
				base.FPageBreakBefore = (byte) (value?1:0);
			}
			
		}
		virtual public bool LineNotNumbered {
			get {
				return base.FNoLnn != 0;
			}
			
			set {
				base.FNoLnn = (byte) (value?1:0);
			}
			
		}
		virtual public bool SideBySide {
			get {
				return base.FSideBySide != 0;
			}
			
			set {
				base.FSideBySide = (byte) (value?1:0);
			}
			
		}
		virtual public bool AutoHyphenated {
			get {
				return base.FNoAutoHyph == 0;
			}
			
			set {
				base.FNoAutoHyph = (byte) (!value?1:0);
			}
			
		}
		virtual public bool WidowControlled {
			get {
				return base.FWidowControl != 0;
			}
			
		}
		virtual public bool WidowControl
		{
			set {
				base.FWidowControl = (byte) (value?1:0);
			}
			
		}
		virtual public int IndentFromRight {
			get {
				return base.DxaRight;
			}
			
			set {
				base.DxaRight = value;
			}
			
		}
		virtual public int IndentFromLeft {
			get {
				return base.DxaLeft;
			}
			
			set {
				base.DxaLeft = value;
			}
			
		}
		virtual public int FirstLineIndent {
			get {
				return base.DxaLeft1;
			}
			
			set {
				base.DxaLeft1 = value;
			}
			
		}
		virtual public LineSpacingDescriptor LineSpacing {
			get {
				return base.Lspd;
			}
			
			set {
				base.Lspd = value;
			}
			
		}
		virtual public int SpacingBefore {
			get {
				return base.DyaBefore;
			}
			
			set {
				base.DyaBefore = value;
			}
			
		}
		virtual public int SpacingAfter {
			get {
				return base.DyaAfter;
			}
			
			set {
				base.DyaAfter = value;
			}
			
		}
		virtual public bool Kinsoku {
			get {
				return base.FKinsoku != 0;
			}
			
			set {
				base.FKinsoku = (byte) (value?1:0);
			}
			
		}
		virtual public bool WordWrapped {
			get {
				return base.FWordWrap != 0;
			}
			
			set {
				base.FWordWrap = (byte) (value?1:0);
			}
			
		}
		virtual public int FontAlignment {
			get {
				return base.WAlignFont;
			}
			
			set {
				base.WAlignFont = value;
			}
			
		}
		virtual public bool Vertical {
			get {
				return base.FVertical;
			}
			
			set {
				base.FVertical = value;
			}
			
		}
		virtual public bool Backward {
			get {
				return base.IsFBackward();
			}
			
			set {
				base.SetFBackward(value);
			}
			
		}
		virtual public BorderCode TopBorder {
			get {
				return base.BrcTop;
			}
			
			set {
				base.BrcTop = value;
			}
			
		}
		virtual public BorderCode LeftBorder {
			get {
				return base.BrcLeft;
			}
			
			set {
				base.BrcLeft = value;
			}
			
		}
		virtual public BorderCode BottomBorder {
			get {
				return base.BrcBottom;
			}
			
			set {
				base.BrcBottom = value;
			}
			
		}
		virtual public BorderCode RightBorder {
			get {
				return base.BrcRight;
			}
			
			set {
				base.BrcRight = value;
			}
			
		}
		virtual public BorderCode BarBorder {
			get {
				return base.BrcBar;
			}
			
			set {
				base.BrcBar = value;
			}
			
		}
		virtual public ShadingDescriptor Shading {
			get {
				return base.Shd;
			}
			
			set {
				base.Shd = value;
			}
			
		}
		virtual public DropCapSpecifier DropCap {
			get {
				return base.Dcs;
			}
			
			set {
				base.Dcs = value;
			}
			
		}
		
		public ParagraphProperties()
		{
			field_21_lspd = new LineSpacingDescriptor();
			field_24_phe = new byte[12];
			field_46_brcTop = new BorderCode();
			field_47_brcLeft = new BorderCode();
			field_48_brcBottom = new BorderCode();
			field_49_brcRight = new BorderCode();
			field_50_brcBetween = new BorderCode();
			field_51_brcBar = new BorderCode();
			field_60_anld = new byte[84];
			this.field_17_fWidowControl = 1;
			this.field_21_lspd.MultiLinespace = (short) 1;
			this.field_21_lspd.DyaLine = (short) 240;
			this.field_12_ilvl = (byte) 9;
			this.field_66_rgdxaTab = new int[0];
			this.field_67_rgtbd = new byte[0];
			this.field_63_dttmPropRMark = new DateAndTime();
		}
		
		public virtual int Justification {
			get { return base.Jc; }
			set { base.Jc = (byte) value; }
		}

		public override object Clone()
		{
			ParagraphProperties pp = (ParagraphProperties) base.Clone();
			pp.field_21_lspd = (LineSpacingDescriptor) field_21_lspd.Clone();
			pp.field_24_phe = new byte[field_24_phe.Length];
			field_24_phe.CopyTo(pp.field_24_phe, 0);
			pp.field_46_brcTop = (BorderCode) field_46_brcTop.Clone();
			pp.field_47_brcLeft = (BorderCode) field_47_brcLeft.Clone();
			pp.field_48_brcBottom = (BorderCode) field_48_brcBottom.Clone();
			pp.field_49_brcRight = (BorderCode) field_49_brcRight.Clone();
			pp.field_50_brcBetween = (BorderCode) field_50_brcBetween.Clone();
			pp.field_51_brcBar = (BorderCode) field_51_brcBar.Clone();

			pp.field_60_anld = new byte[field_60_anld.Length];
			field_60_anld.CopyTo(pp.field_60_anld, 0);
			return pp;

		}
	}
}