// 
// ShadingDescriptor.cs
//  
// Copyright 2002-2004  Apache Software Foundation
//
// Jakarta Poi Authors:
//   Rainer Klute (klute@rainer-klute.de)
//
// Poi.Net Authors:
//   Johannes Roith(johannes at jroith dot de)
//  
// 
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

using System;
using Poi.Net.Util;

namespace Poi.Net.HWPF.UserModel
{
	
	public class ShadingDescriptor : ICloneable
	{
		public const int SIZE = 2;
		
		private short _info;
		
		private static readonly BitField _icoFore = new BitField(0x1f);
		
		private static readonly BitField _icoBack = new BitField(0x3e0);
		
		private static readonly BitField _ipat = new BitField(0xfc00);
		
		public ShadingDescriptor()
		{
		}
		
		public ShadingDescriptor(byte[] buf, int offset):this(LittleEndian.GetShort(buf, offset))
		{
		}
		
		public ShadingDescriptor(short info)
		{
			_info = info;
		}
		
		public virtual short ToShort()
		{
			return _info;
		}
		
		public virtual void Serialize(byte[] buf, int offset)
		{
			LittleEndian.PutShort(buf, offset, _info);
		}
		
		public virtual object Clone()
		{
			return base.MemberwiseClone();
		}
	}
}