// 
// TableIterator.cs
//  
// Copyright 2002-2004  Apache Software Foundation
// 
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

using System;

namespace Poi.Net.HWPF.UserModel
{
	
	public class TableIterator
	{
		internal Range _range;
		internal int _index;
		internal int _levelNum;
		
		internal TableIterator(Range range, int levelNum)
		{
			_range = range;
			_index = 0;
			_levelNum = levelNum;
		}
		
		public TableIterator(Range range):this(range, 1)
		{
		}
		
		
		public virtual bool HasNext()
		{
			int NumParagraphs = _range.NumParagraphs();
			for (; _index < NumParagraphs; _index++)
			{
				Paragraph paragraph = _range.GetParagraph(_index);
				if (paragraph.InTable && paragraph.TableLevel == _levelNum)
				{
					return true;
				}
			}
			return false;
		}
		
		public virtual Table Next()
		{
			int NumParagraphs = _range.NumParagraphs();
			int startIndex = _index;
			int endIndex = _index;
			
			for (; _index < NumParagraphs; _index++)
			{
				Paragraph paragraph = _range.GetParagraph(_index);
				if (!paragraph.InTable || paragraph.TableLevel < _levelNum)
				{
					endIndex = _index;
					break;
				}
			}
			return new Table(startIndex, endIndex, _range, _levelNum);
		}
	}
}