// 
// TableRow.cs
//  
// Copyright 2002-2004  Apache Software Foundation
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

using System;
using Poi.Net.HWPF.SPRM;

namespace Poi.Net.HWPF.UserModel
{
	
	public class TableRow:Paragraph
	{
		virtual public int RowJustification {
			get {
				return _tprops.Jc;
			}
			
			set {
				_tprops.Jc = value;
				_papx.UpdateSprm(SPRM_TJC, (short) value);
			}
			
		}
		virtual public int GapHalf {
			get {
				return _tprops.DxaGapHalf;
			}
			
			set {
				_tprops.DxaGapHalf = value;
				_papx.UpdateSprm(SPRM_DXAGAPHALF, (short) value);
			}
			
		}
		virtual public int RowHeight {
			get {
				return _tprops.DyaRowHeight;
			}
			
			set {
				_tprops.DyaRowHeight = value;
				_papx.UpdateSprm(SPRM_DYAROWHEIGHT, (short) value);
			}
			
		}
		virtual public bool CantSplit
		{
			get { return _tprops.FCantSplit; }

			set {
				_tprops.FCantSplit = value;
				_papx.UpdateSprm(SPRM_FCANTSPLIT, (byte) (value?1:0));
			}
			
		}
		virtual public bool TableHeader {
			get {
				return _tprops.FTableHeader;
			}
			
			set {
				_tprops.FTableHeader = value;
				_papx.UpdateSprm(SPRM_FTABLEHEADER, (byte) (value?1:0));
			}
			
		}
		private const char TABLE_CELL_MARK = '\u0007';
		
		private const short SPRM_TJC = (short) (0x5400);
		private static short SPRM_DXAGAPHALF = -27134;
		private const short SPRM_FCANTSPLIT = (short) (0x3403);
		private const short SPRM_FTABLEHEADER = (short) (0x3404);
		private static short SPRM_DYAROWHEIGHT = -27641;
		
		internal int _levelNum;
		private TableProperties _tprops;
		private TableCell[] _cells;
		
		public TableRow(int startIdx, int endIdx, Table parent, int levelNum):base(startIdx, endIdx, parent)
		{
			
			_tprops = TableSprmUncompressor.UncompressTAP(_papx.ToByteArray(), 2);
			_levelNum = levelNum;
			_cells = new TableCell[_tprops.ItcMac];
			
			int start = 0;
			int end = 0;
			
			for (int cellIndex = 0; cellIndex < _cells.Length; cellIndex++)
			{
				Paragraph p = GetParagraph(start);
				string s = p.Text;
				
				while (!((s[s.Length - 1] == TABLE_CELL_MARK) || p.EmbeddedCellMark && p.TableLevel == levelNum))
				{
					end++;
					p = GetParagraph(end);
					s = p.Text;
				}
				_cells[cellIndex] = new TableCell(start, end, this, levelNum, _tprops.Rgtc[cellIndex], _tprops.RgdxaCenter[cellIndex], _tprops.RgdxaCenter[cellIndex + 1] - _tprops.RgdxaCenter[cellIndex]);
				end++;
				start = end;
			}
		}
				
		public virtual int NumCells {
			get { return _cells.Length; }
		}
		
		public virtual TableCell GetCell(int index)
		{
			return _cells[index];
		}
	}
}