// 
// POIFSReader.cs
//  
// Copyright 2002-2004  Apache Software Foundation
//
// Jakarta Poi Authors:
//   Marc Johnson (mjohnson at apache dot org)
//
// Poi.Net Authors:
//   Johannes Roith(johannes at jroith dot de)
//  
// 
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.


using System;
using System.IO;
using System.Text;
using System.Collections;

using Poi.Net.PoiFS.FileSystem;

namespace Poi.Net.PoiFS.Dev
{
	
	/// <summary> A simple viewer for POIFS files
	/// 
	/// </summary>
	
	public class POIFSViewer
	{
		
		/// <summary> Display the contents of multiple POIFS files
		/// 
		/// </summary>
		/// <param name="args">the names of the files to be displayed
		/// </param>
		
		public static void Main2(string[] args)
		{
			if (args.Length < 0)
			{
				Console.Error.WriteLine("Must specify at least one file to view");
				Environment.Exit(1);
			}
			bool printNames = (args.Length > 1);
			
			for (int j = 0; j < args.Length; j++)
			{
				ViewFile(args[j], printNames);
			}
		}
		
		private static void ViewFile(string filename, bool printName)
		{
			if (printName)
			{
				StringBuilder flowerbox = new StringBuilder();
				
				flowerbox.Append(".");
				for (int j = 0; j < filename.Length; j++)
				{
					flowerbox.Append("-");
				}
				flowerbox.Append(".");
				
				Console.WriteLine(flowerbox);
				Console.WriteLine("|" + filename + "|");
				
				Console.WriteLine(flowerbox);
			}
			try
			{
				
				POIFSViewable fs = new POIFSFileSystem(new FileStream(filename, FileMode.Open, FileAccess.Read));
				IList strings = POIFSViewEngine.InspectViewable(fs, true, 0, "  ");

				foreach(string current in strings)
					Console.Write(current);
			}
			catch (IOException e)
			{
				
				Console.WriteLine(e.Message);
			}
		}
	} 
}