// 
// POIFSReaderEvent.cs
//  
// Copyright 2002-2004  Apache Software Foundation
//
// Jakarta Poi Authors:
//   Marc Johnson (mjohnson at apache dot org)
//
// Poi.Net Authors:
//   Johannes Roith(johannes at jroith dot de)
//  
// 
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

using System;
using Poi.Net.PoiFS.FileSystem;

namespace Poi.Net.PoiFS.EventFileSystem
{
	
	/// <summary> 
	/// Class POIFSReaderEvent
	/// </summary>
	
	public class POIFSReaderEvent
	{
		private DocumentInputStream stream;
		private POIFSDocumentPath path;
		private string documentName;

		/// <returns> the DocumentInputStream, freshly opened
		/// </returns>
		virtual public DocumentInputStream Stream {
			get { return stream; }
			
		}
		/// <returns> the document's path
		/// </returns>
		virtual public POIFSDocumentPath Path {
			get { return path; }
			
		}
		/// <returns> the document's name
		/// </returns>
		virtual public string Name {
			get { return documentName; }
			
		}
		
		/// <summary> package scoped constructor
		/// 
		/// </summary>
		/// <param name="stream">the DocumentInputStream, freshly opened
		/// </param>
		/// <param name="path">the path of the document
		/// </param>
		/// <param name="documentName">the name of the document
		/// </param>
		
		internal POIFSReaderEvent(DocumentInputStream stream, POIFSDocumentPath path, string documentName)
		{
			this.stream = stream;
			this.path = path;
			this.documentName = documentName;
		}
	}
}