// 
// DirectoryEntyy.cs
//  
// Copyright 2002-2004  Apache Software Foundation
//
// Jakarta Poi Authors:
//   Marc Johnson (mjohnson at apache dot org)
//
// Poi.Net Authors:
//   Johannes Roith(johannes at jroith dot de)
//  
// 
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

using System;
using System.IO;
using System.Collections;

using Poi.Net.HPSF;

namespace Poi.Net.PoiFS.FileSystem
{
	
	/// <summary> This interface defines methods specific to Directory objects
	/// managed by a Filesystem instance.
	/// 
	/// </summary>
	
	public interface DirectoryEntry:Entry
	{
		/// <summary> get an iterator of the Entry instances contained directly in
		/// this instance (in other words, children only; no grandchildren
		/// etc.)
		/// 
		/// </summary>
		/// <returns> iterator; never null, but HasNext() may return false
		/// immediately (i.e., this DirectoryEntry is empty). All
		/// objects retrieved by Next() are guaranteed to be
		/// implementations of Entry.
		/// </returns>
		IEnumerator Entries {
			get;			
		}
		/// <summary> is this DirectoryEntry empty?
		/// 
		/// </summary>
		/// <returns> true if this instance contains no Entry instances
		/// </returns>
		bool Empty {
			get;			
		}
		/// <summary> find out how many Entry instances are contained directly within
		/// this DirectoryEntry
		/// 
		/// </summary>
		/// <returns> number of immediately (no grandchildren etc.) contained
		/// Entry instances
		/// </returns>
		int EntryCount {
			get;		
		}
		
		/// <summary> Gets the storage clsid of the directory entry
		/// 
		/// </summary>
		/// <returns> storage Class ID
		/// </returns>
		/// <summary> Sets the storage clsid for the directory entry
		/// 
		/// </summary>
		/// <param name="clsidStorage">storage Class ID
		/// </param>
		ClassID StorageClsid {
			get;			
			set;			
		}
		
		/// <summary> get a specified Entry by name
		/// 
		/// </summary>
		/// <param name="name">the name of the Entry to obtain.
		/// 
		/// </param>
		/// <returns> the specified Entry, if it is directly contained in
		/// this DirectoryEntry
		/// 
		/// </returns>
		/// <exception cref=""> FileNotFoundException if no Entry with the specified
		/// name exists in this DirectoryEntry
		/// </exception>
		
		Entry GetEntry(string name);
		
		/// <summary> create a new DocumentEntry
		/// 
		/// </summary>
		/// <param name="name">the name of the new DocumentEntry
		/// </param>
		/// <param name="stream">the InputStream from which to create the new
		/// DocumentEntry
		/// 
		/// </param>
		/// <returns> the new DocumentEntry
		/// 
		/// </returns>
		/// <exception cref=""> IOException
		/// </exception>
		
		DocumentEntry CreateDocument(string name, Stream stream);
		
		/// <summary> create a new DocumentEntry; the data will be provided later
		/// 
		/// </summary>
		/// <param name="name">the name of the new DocumentEntry
		/// </param>
		/// <param name="size">the size of the new DocumentEntry
		/// </param>
		/// <param name="writer">the writer of the new DocumentEntry
		/// 
		/// </param>
		/// <returns> the new DocumentEntry
		/// 
		/// </returns>
		/// <exception cref=""> IOException
		/// </exception>
		
		DocumentEntry CreateDocument(string name, int size, POIFSWriterListener writer);
		
		/// <summary> create a new DirectoryEntry
		/// 
		/// </summary>
		/// <param name="name">the name of the new DirectoryEntry
		/// 
		/// </param>
		/// <returns> the new DirectoryEntry
		/// 
		/// </returns>
		/// <exception cref=""> IOException
		/// </exception>
		
		DirectoryEntry CreateDirectory(string name);
	} 
}