// 
// DocumentDescriptor.cs
//  
// Copyright 2002-2004  Apache Software Foundation
//
// Jakarta Poi Authors:
//   Marc Johnson (mjohnson at apache dot org)
//
// Poi.Net Authors:
//   Johannes Roith(johannes at jroith dot de)
//  
// 
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

using System;
using System.Text;

namespace Poi.Net.PoiFS.FileSystem
{
	
	/// <summary> Class DocumentDescriptor
	/// 
	/// </summary>
	
	public class DocumentDescriptor
	{
		private POIFSDocumentPath path;
		private string name;
		private int hashcode = 0;
		
		/// <summary> Trivial constructor
		/// 
		/// </summary>
		/// <param name="path">the Document path
		/// </param>
		/// <param name="name">the Document name
		/// </param>
		
		public DocumentDescriptor(POIFSDocumentPath path, string name)
		{
			if (path == null)
			{
				throw new NullReferenceException("path must not be null");
			}
			if ((object) name == null)
			{
				throw new NullReferenceException("name must not be null");
			}
			if (name.Length == 0)
			{
				throw new ArgumentException("name cannot be empty");
			}
			this.path = path;
			this.name = name;
		}
		
		/// <summary> equality. Two DocumentDescriptor instances are equal if they
		/// have equal paths and names
		/// 
		/// </summary>
		/// <param name="o">the object we're checking equality for
		/// 
		/// </param>
		/// <returns> true if the object is equal to this object
		/// </returns>
		
		public  override bool Equals(object o)
		{
			bool rval = false;
			
			if ((o != null) && (o.GetType() == this.GetType()))
			{
				if (this == o)
				{
					rval = true;
				}
				else
				{
					DocumentDescriptor descriptor = (DocumentDescriptor) o;
					
					rval = this.path.Equals(descriptor.path) && this.name.Equals(descriptor.name);
				}
			}
			return rval;
		}
		
		/// <summary> calculate and return the hashcode
		/// 
		/// </summary>
		/// <returns> hashcode
		/// </returns>
		
		public override int GetHashCode()
		{
			if (hashcode == 0)
			{
				hashcode = path.GetHashCode() ^ name.GetHashCode();
			}
			return hashcode;
		}
		
		public override string ToString()
		{
			StringBuilder buffer = new StringBuilder(40 * (path.Length + 1));
			
			for (int j = 0; j < path.Length; j++)
			{
				buffer.Append(path.GetComponent(j)).Append("/");
			}
			buffer.Append(name);
			return buffer.ToString();
		}
	} 
}