// 
// DocumentNode.cs
//  
// Copyright 2002-2004  Apache Software Foundation
//
// Jakarta Poi Authors:
//   Marc Johnson (mjohnson at apache dot org)
//
// Poi.Net Authors:
//   Johannes Roith(johannes at jroith dot de)
//  
// 
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

using System;
using System.Collections;

using Poi.Net.PoiFS.Dev;
using Poi.Net.PoiFS.Properties;
namespace Poi.Net.PoiFS.FileSystem
{
	
	/// <summary> Simple implementation of DocumentEntry
	/// 
	/// </summary>
	
	public class DocumentNode:EntryNode, DocumentEntry, POIFSViewable
	{
		/// <summary> get the POIFSDocument
		/// 
		/// </summary>
		/// <returns> the internal POIFSDocument
		/// </returns>
		virtual internal POIFSDocument Document
		{
			
			
			get
			{
				return _document;
			}
			
		}
		/// <summary> get the zize of the document, in bytes
		/// 
		/// </summary>
		/// <returns> size in bytes
		/// </returns>
		virtual public int Size
		{
			
			
			get
			{
				return Property.Size;
			}
			
		}
		/// <summary> is this a DocumentEntry?
		/// 
		/// </summary>
		/// <returns> true if the Entry is a DocumentEntry, else false
		/// </returns>
		override public bool DocumentEntry
		{
			
			
			get
			{
				return true;
			}
			
		}
		/// <summary> extensions use this method to verify internal rules regarding
		/// deletion of the underlying store.
		/// 
		/// </summary>
		/// <returns> true if it's ok to delete the underlying store, else
		/// false
		/// </returns>
		override protected internal bool DeleteOK
		{
			
			
			get
			{
				return true;
			}
			
		}
		/// <summary> Get an array of objects, some of which may implement
		/// POIFSViewable
		/// 
		/// </summary>
		/// <returns> an array of Object; may not be null, but may be empty
		/// </returns>
		virtual public object[] ViewableArray
		{
			
			
			get
			{
				return new object[0];
			}
			
		}
		/// <summary> Get an Iterator of objects, some of which may implement
		/// POIFSViewable
		/// 
		/// </summary>
		/// <returns> an Iterator; may not be null, but may have an empty
		/// back end store
		/// </returns>
		virtual public IEnumerator ViewableIterator
		{
			
			
			get
			{
				IList components = new ArrayList();
				
				components.Add(Property);
				components.Add(_document);
				return components.GetEnumerator();
			}
			
		}
		/// <summary> Provides a short description of the object, to be used when a
		/// POIFSViewable object has not provided its contents.
		/// 
		/// </summary>
		/// <returns> short description
		/// </returns>
		virtual public string ShortDescription
		{
			
			
			get
			{
				return Name;
			}
			
			/* **********  END  begin implementation of POIFSViewable ********** */
			
		}
		
		// underlying POIFSDocument instance
		private POIFSDocument _document;
		
		/// <summary> create a DocumentNode. This method is not public by design; it
		/// is intended strictly for the internal use of this package
		/// 
		/// </summary>
		/// <param name="property">the DocumentProperty for this DocumentEntry
		/// </param>
		/// <param name="parent">the parent of this entry
		/// </param>
		
		internal DocumentNode(DocumentProperty property, DirectoryNode parent):base(property, parent)
		{
			_document = property.Document;
		}
		
		/* ********** START implementation of DocumentEntry ********** */
		
		/* **********  END  implementation of DocumentEntry ********** */
		/* ********** START implementation of Entry ********** */
		
		/* **********  END  implementation of Entry ********** */
		/* ********** START extension of Entry ********** */
		
		/* **********  END  extension of Entry ********** */
		/* ********** START begin implementation of POIFSViewable ********** */
		
		/// <summary> Give viewers a hint as to whether to call getViewableArray or
		/// getViewableIterator
		/// 
		/// </summary>
		/// <returns> true if a viewer should call getViewableArray, false if
		/// a viewer should call getViewableIterator
		/// </returns>
		
		public virtual bool PreferArray
		{
			get 
			{	
				return false;
			}
		}
	} 
}