// 
// Entry.cs
//  
// Copyright 2002-2004  Apache Software Foundation
//
// Jakarta Poi Authors:
//   Marc Johnson (mjohnson at apache dot org)
//
// Poi.Net Authors:
//   Johannes Roith(johannes at jroith dot de)
//  
// 
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

using System;
namespace Poi.Net.PoiFS.FileSystem
{
	
	/// <summary> This interface provides access to an object managed by a Filesystem
	/// instance. Entry objects are further divided into DocumentEntry and
	/// DirectoryEntry instances.
	/// 
	/// </summary>
	
	public interface Entry
	{
		/// <summary> get the name of the Entry
		/// 
		/// </summary>
		/// <returns> name
		/// </returns>
		string Name
		{
			
			
			get;
			
		}
		/// <summary> is this a DirectoryEntry?
		/// 
		/// </summary>
		/// <returns> true if the Entry is a DirectoryEntry, else false
		/// </returns>
		bool DirectoryEntry
		{
			
			
			get;
			
		}
		/// <summary> is this a DocumentEntry?
		/// 
		/// </summary>
		/// <returns> true if the Entry is a DocumentEntry, else false
		/// </returns>
		bool DocumentEntry
		{
			
			
			get;
			
		}
		/// <summary> get this Entry's parent (the DirectoryEntry that owns this
		/// Entry). All Entry objects, except the root Entry, has a parent.
		/// 
		/// </summary>
		/// <returns> this Entry's parent; null iff this is the root Entry
		/// </returns>
		DirectoryEntry Parent
		{
			
			
			get;
			
		}
		
		/// <summary> Delete this Entry. This operation should succeed, but there are
		/// special circumstances when it will not:
		/// 
		/// If this Entry is the root of the Entry tree, it cannot be
		/// deleted, as there is no way to create another one.
		/// 
		/// If this Entry is a directory, it cannot be deleted unless it is
		/// empty.
		/// 
		/// </summary>
		/// <returns> true if the Entry was successfully deleted, else false
		/// </returns>
		
		bool Delete();
		
		/// <summary> Rename this Entry. This operation will fail if:
		/// 
		/// There is a sibling Entry (i.e., an Entry whose parent is the
		/// same as this Entry's parent) with the same name.
		/// 
		/// This Entry is the root of the Entry tree. Its name is dictated
		/// by the Filesystem and many not be changed.
		/// 
		/// </summary>
		/// <param name="newName">the new name for this Entry
		/// 
		/// </param>
		/// <returns> true if the operation succeeded, else false
		/// </returns>
		
		bool RenameTo(string newName);
	} 
}