// 
// Child.cs
//  
// Copyright 2002-2004  Apache Software Foundation
//
// Jakarta Poi Authors:
//   Marc Johnson (mjohnson at apache dot org)
//
// Poi.Net Authors:
//   Johannes Roith(johannes at jroith dot de)
//  
// 
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

using System;
namespace Poi.Net.PoiFS.Properties
{
	
	/// <summary> This interface defines methods for finding and setting sibling
	/// Property instances
	/// 
	/// </summary>
	
	public interface Child
	{
		
		/// <summary> Get the next Child, if any
		/// 
		/// </summary>
		/// <returns> the next Child; may return null
		/// </returns>
		
		Child NextChild 
		{
			get;
			set;
		}
		
		/// <summary> Get the previous Child, if any
		/// 
		/// </summary>
		/// <returns> the previous Child; may return null
		/// </returns>
		
		Child GetPreviousChild();
		
		/// <summary> Set the next Child
		/// 
		/// </summary>
		/// <param name="child">the new 'next' child; may be null, which has the
		/// effect of saying there is no 'next' child
		/// </param>
				
		/// <summary> Set the previous Child
		/// 
		/// </summary>
		/// <param name="child">the new 'previous' child; may be null, which has
		/// the effect of saying there is no 'previous' child
		/// </param>
		
		void SetPreviousChild(Child child);
	} 
}