// 
// DocumentProperty.cs
//  
// Copyright 2002-2004  Apache Software Foundation
//
// Jakarta Poi Authors:
//   Marc Johnson (mjohnson at apache dot org)
//
// Poi.Net Authors:
//   Johannes Roith(johannes at jroith dot de)
//  
// 
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

using System;
using Poi.Net.PoiFS.FileSystem;

namespace Poi.Net.PoiFS.Properties
{
	
	/// <summary> Trivial extension of Property for POIFSDocuments
	/// 
	/// </summary>
	
	public class DocumentProperty:Property
	{
		
		/// <summary> get the POIFSDocument
		/// 
		/// </summary>
		/// <returns> the associated document
		/// </returns>
		/// <summary> set the POIFSDocument
		/// 
		/// </summary>
		/// <param name="doc">the associated POIFSDocument
		/// </param>
		virtual public POIFSDocument Document
		{
			
			
			get
			{
				return _document;
			}
			
			
			
			set {
				_document = value;
			}
			
		}
		/// <returns> true if a directory type Property
		/// </returns>
		override public bool Directory
		{
			
			
			get
			{
				return false;
			}
			
		}
		
		// the POIFSDocument this property is associated with
		private POIFSDocument _document;
		
		/// <summary> Constructor
		/// 
		/// </summary>
		/// <param name="name">POIFSDocument name
		/// </param>
		/// <param name="size">POIFSDocument size
		/// </param>
		
		public DocumentProperty(string name, int size):base()
		{
			_document = null;
			Name = name;
			Size = size;
			NodeColor = _NODE_BLACK; // simplification
			PropertyType = PropertyConstants.DOCUMENT_TYPE;
		}
		
		/// <summary> reader constructor
		/// 
		/// </summary>
		/// <param name="index">index number
		/// </param>
		/// <param name="array">byte data
		/// </param>
		/// <param name="offset">offset into byte data
		/// </param>
		
		protected internal DocumentProperty(int index, byte[] array, int offset):base(index, array, offset)
		{
			_document = null;
		}
		
		/* ********** START extension of Property ********** */
		
		/// <summary> give method more visibility
		/// 
		/// </summary>
		/// <returns> true if this property should use small blocks
		/// </returns>
		
		public override bool ShouldUseSmallBlocks()
		{
			return base.ShouldUseSmallBlocks();
		}
		
		/// <summary> Perform whatever activities need to be performed prior to
		/// writing
		/// </summary>
		
		protected internal override void PreWrite()
		{
			
			// do nothing
		}
		
		/* **********  END  extension of Property ********** */
	} 
}