// 
// Parent.cs
//  
// Copyright 2002-2004  Apache Software Foundation
//
// Jakarta Poi Authors:
//   Marc Johnson (mjohnson at apache dot org)
//
// Poi.Net Authors:
//   Johannes Roith(johannes at jroith dot de)
//  
// 
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

using System;
using System.Collections;

namespace Poi.Net.PoiFS.Properties
{
	
	/// <summary> Behavior for parent (directory) properties
	/// 
	/// </summary>
	
	public interface Parent:Child
	{
		/// <summary> Get an iterator over the children of this Parent; all elements
		/// are instances of Property.
		/// 
		/// </summary>
		/// <returns> Iterator of children; may refer to an empty collection
		/// </returns>
		IEnumerator Children
		{
			
			
			get;
			
		}
		
		/// <summary> Add a new child to the collection of children
		/// 
		/// </summary>
		/// <param name="property">the new child to be added; must not be null
		/// 
		/// </param>
		/// <exception cref=""> IOException if the Parent already has a child with
		/// the same name
		/// </exception>
		
		void AddChild(Property property);
		
		/// <summary> Set the previous Child
		/// 
		/// </summary>
		/// <param name="child">the new 'previous' child; may be null, which has
		/// the effect of saying there is no 'previous' child
		/// </param>
		
		new void SetPreviousChild(Child child);
		
		/// <summary> Set the next Child
		/// 
		/// </summary>
		/// <param name="child">the new 'next' child; may be null, which has the
		/// effect of saying there is no 'next' child
		/// </param>
		
		new Child NextChild
		{
			set;
		}
		
		/// <summary>** end methods from interface Child *** </summary>
	} 
}