// 
// POIFSReader.cs
//  
// Copyright 2002-2004  Apache Software Foundation
//
// Jakarta Poi Authors:
//   Marc Johnson (mjohnson at apache dot org)
//
// Poi.Net Authors:
//   Johannes Roith(johannes at jroith dot de)
//  
// 
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.


using System;
using System.IO;

namespace Poi.Net.PoiFS.Storage
{
	
	/// <summary> Abstract base class of all POIFS block storage classes. All
	/// extensions of BigBlock should write 512 bytes of data when
	/// requested to write their data.
	/// 
	/// This class has package scope, as there is no reason at this time to
	/// make the class public.
	/// 
	/// </summary>

	abstract public class BigBlock : BlockWritable
	{
		
		/// <summary> Default implementation of write for extending classes that
		/// contain their data in a simple array of bytes.
		/// 
		/// </summary>
		/// <param name="stream">the OutputStream to which the data should be
		/// written.
		/// </param>
		/// <param name="data">the byte array of to be written.
		/// 
		/// </param>
		/// <exception cref=""> IOException on problems writing to the specified
		/// stream.
		/// </exception>
		
		protected internal virtual void DoWriteData(Stream stream, byte[] data)
		{
				stream.Write(data, 0, data.Length);
		}
		
		/// <summary> Write the block's data to an OutputStream
		/// 
		/// </summary>
		/// <param name="stream">the OutputStream to which the stored data should
		/// be written
		/// 
		/// </param>
		/// <exception cref=""> IOException on problems writing to the specified
		/// stream
		/// </exception>
		
		internal abstract void WriteData(Stream stream);
		
		/* ********** START implementation of BlockWritable ********** */
		
		/// <summary> Write the storage to an OutputStream
		/// 
		/// </summary>
		/// <param name="stream">the OutputStream to which the stored data should
		/// be written
		/// 
		/// </param>
		/// <exception cref=""> IOException on problems writing to the specified
		/// stream
		/// </exception>
		
		public virtual void WriteBlocks(Stream stream)
		{
			WriteData(stream);
		}
		
		/* **********  END  implementation of BlockWritable ********** */
	} // end abstract class BigBlock
}