// 
// BlockList.cs
//  
// Copyright 2002-2004  Apache Software Foundation
//
// Jakarta Poi Authors:
//   Marc Johnson (mjohnson at apache dot org)
//
// Poi.Net Authors:
//   Johannes Roith(johannes at jroith dot de)
//  
// 
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

using System;

namespace Poi.Net.PoiFS.Storage
{
	
	/// <summary> Interface for lists of blocks that are mapped by block allocation
	/// tables
	/// 
	/// </summary>
	
	public interface BlockList
	{
		/// <summary> set the associated BlockAllocationTable
		/// 
		/// </summary>
		/// <param name="bat">the associated BlockAllocationTable
		/// 
		/// </param>
		/// <exception cref=""> IOException
		/// </exception>
		BlockAllocationTableReader BAT
		{
			
			
			set;
			
		}
		
		/// <summary> Remove the specified block from the list
		/// 
		/// </summary>
		/// <param name="index">the index of the specified block; if the index is
		/// out of range, that's ok
		/// </param>
		
		void Zap(int index);
		
		/// <summary> Remove and return the specified block from the list
		/// 
		/// </summary>
		/// <param name="index">the index of the specified block
		/// 
		/// </param>
		/// <returns> the specified block
		/// 
		/// </returns>
		/// <exception cref=""> IOException if the index is out of range or has
		/// already been Removed
		/// </exception>
		
		ListManagedBlock Remove(int index);
		
		/// <summary> get the blocks making up a particular stream in the list. The
		/// blocks are Removed from the list.
		/// 
		/// </summary>
		/// <param name="startBlock">the index of the first block in the stream
		/// 
		/// </param>
		/// <returns> the stream as an array of correctly ordered blocks
		/// 
		/// </returns>
		/// <exception cref=""> IOException if blocks are missing
		/// </exception>
		
		ListManagedBlock[] FetchBlocks(int startBlock);
	} 
}