// 
// BlockListImpl.cs
//  
// Copyright 2002-2004  Apache Software Foundation
//
// Jakarta Poi Authors:
//   Marc Johnson (mjohnson at apache dot org)
//
// Poi.Net Authors:
//   Johannes Roith(johannes at jroith dot de)
//  
// 
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

using System;
using System.IO;

namespace Poi.Net.PoiFS.Storage
{
	
	/// <summary> A simple implementation of BlockList
	/// 
	/// </summary>
	
	
	public class BlockListImpl : BlockList
	{
		/// <summary> provide blocks to manage
		/// 
		/// </summary>
		/// <param name="blocks">blocks to be managed
		/// </param>
		virtual protected internal ListManagedBlock[] Blocks
		{
			
			
			set {
				_blocks = value;
			}
			
		}
		/// <summary> set the associated BlockAllocationTable
		/// 
		/// </summary>
		/// <param name="bat">the associated BlockAllocationTable
		/// 
		/// </param>
		/// <exception cref=""> IOException
		/// </exception>
		virtual public BlockAllocationTableReader BAT
		{
			
			
			set {
				if (_bat != null)
				{
					throw new IOException("Attempt to replace existing BlockAllocationTable");
				}
				_bat = value;
			}
			
			/* **********  END  implementation of BlockList ********** */
			
		}
		private ListManagedBlock[] _blocks;
		private BlockAllocationTableReader _bat;
		
		/// <summary> Constructor BlockListImpl</summary>
		
		protected internal BlockListImpl()
		{
			_blocks = new ListManagedBlock[0];
			_bat = null;
		}
		
		/* ********** START implementation of BlockList ********** */
		
		/// <summary> Remove the specified block from the list
		/// 
		/// </summary>
		/// <param name="index">the index of the specified block; if the index is
		/// out of range, that's ok
		/// </param>
		
		public virtual void Zap(int index)
		{
			if ((index >= 0) && (index < _blocks.Length))
			{
				_blocks[index] = null;
			}
		}
		
		/// <summary> Remove and return the specified block from the list
		/// 
		/// </summary>
		/// <param name="index">the index of the specified block
		/// 
		/// </param>
		/// <returns> the specified block
		/// 
		/// </returns>
		/// <exception cref=""> IOException if the index is out of range or has
		/// already been Removed
		/// </exception>
		
		public virtual ListManagedBlock Remove(int index)
		{
			ListManagedBlock result = null;
			
			try
			{
				result = _blocks[index];
				if (result == null)
				{
					throw new IOException("block[ " + index + " ] already Removed");
				}
				_blocks[index] = null;
			}
			catch (IndexOutOfRangeException ignored)
			{
				throw new IOException("Cannot Remove block[ " + index + " ]; out of range");
			}
			return result;
		}
		
		/// <summary> get the blocks making up a particular stream in the list. The
		/// blocks are Removed from the list.
		/// 
		/// </summary>
		/// <param name="startBlock">the index of the first block in the stream
		/// 
		/// </param>
		/// <returns> the stream as an array of correctly ordered blocks
		/// 
		/// </returns>
		/// <exception cref=""> IOException if blocks are missing
		/// </exception>
		
		public virtual ListManagedBlock[] FetchBlocks(int startBlock)
		{
			if (_bat == null)
			{
				throw new IOException("Improperly initialized list: no block allocation table provided");
			}
			return _bat.FetchBlocks(startBlock, this);
		}
	} 
}