// 
// RawDataBlock.cs
//  
// Copyright 2002-2004  Apache Software Foundation
//
// Jakarta Poi Authors:
//   Marc Johnson (mjohnson at apache dot org)
//
// Poi.Net Authors:
//   Johannes Roith(johannes at jroith dot de)
//  
// 
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

using System;
using System.IO;

using Poi.Net.PoiFS.Common;
using Poi.Net.Util;

namespace Poi.Net.PoiFS.Storage
{
	
	/// <summary> A big block created from an InputStream, holding the raw data
	/// 
	/// </summary>
	
	public class RawDataBlock : ListManagedBlock
	{
		/// <summary> Get the data from the block
		/// 
		/// </summary>
		/// <returns> the block's data as a byte array
		/// 
		/// </returns>
		/// <exception cref=""> IOException if there is no data
		/// </exception>
		virtual public byte[] Data
		{
			
			
			get
			{
				if (EOF)
				{
					throw new IOException("Cannot return empty data");
				}
				return _data;
			}
			
			/* **********  END  implementation of ListManagedBlock ********** */
			
		}
		private byte[] _data;
		private bool _eof;
		
		/// <summary> Constructor RawDataBlock
		/// 
		/// </summary>
		/// <param name="stream">the InputStream from which the data will be read
		/// 
		/// </param>
		/// <exception cref=""> IOException on I/O errors, and if an insufficient
		/// amount of data is read
		/// </exception>
		
		public RawDataBlock(Stream stream)
		{
			_data = new byte[POIFSConstants.BIG_BLOCK_SIZE];
			int count = IOUtils.ReadFully(stream, _data);
			
			if (count == - 1)
			{
				_eof = true;
			}
			else if (count != POIFSConstants.BIG_BLOCK_SIZE)
			{
				string type = " byte" + ((count == 1)?(""):("s"));
				
				throw new IOException("Unable to read entire block; " + count + type + " read; expected " + POIFSConstants.BIG_BLOCK_SIZE + " bytes");
			}
			else
			{
				_eof = false;
			}
		}
		
		/// <summary> When we read the data, did we hit end of file?
		/// 
		/// </summary>
		/// <returns> true if no data was read because we were at the end of
		/// the file, else false
		/// 
		/// </returns>
		/// <exception cref=""> IOException
		/// </exception>
		
		public virtual bool EOF	{
			get { return _eof; }
		}
		
		/* ********** START implementation of ListManagedBlock ********** */
	} 
}