// 
// RawDataBlockList.cs
//  
// Copyright 2002-2004  Apache Software Foundation
//
// Jakarta Poi Authors:
//   Marc Johnson (mjohnson at apache dot org)
//
// Poi.Net Authors:
//   Johannes Roith(johannes at jroith dot de)
//  
// 
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

using System;
using System.IO;
using System.Collections;

namespace Poi.Net.PoiFS.Storage
{
	
	/// <summary> A list of RawDataBlocks instances, and methods to manage the list
	/// 
	/// </summary>
	
	public class RawDataBlockList:BlockListImpl
	{
		
		/// <summary> Constructor RawDataBlockList
		/// 
		/// </summary>
		/// <param name="stream">the InputStream from which the data will be read
		/// 
		/// </param>
		/// <exception cref=""> IOException on I/O errors, and if an incomplete
		/// block is read
		/// </exception>
		
		public RawDataBlockList(Stream stream)
		{
			IList blocks = new ArrayList();
			
			while (true)
			{
				RawDataBlock block = new RawDataBlock(stream);
				
				if (block.EOF)
				{
					break;
				}
				blocks.Add(block);
			}
			
			RawDataBlock[] temp = new RawDataBlock[blocks.Count];
			blocks.CopyTo(temp,0);

			Blocks = (RawDataBlock[]) temp;
		}
	} 
}