// 
// SmallBlockTableReader.cs
//  
// Copyright 2002-2004  Apache Software Foundation
//
// Jakarta Poi Authors:
//   Marc Johnson (mjohnson at apache dot org)
//
// Poi.Net Authors:
//   Johannes Roith(johannes at jroith dot de)
//  
// 
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

using System;

using Poi.Net.PoiFS.Properties;

namespace Poi.Net.PoiFS.Storage
{
	
	/// <summary> This class implements reading the small document block list from an
	/// existing file
	/// 
	/// </summary>
	
	public class SmallBlockTableReader
	{
		
		/// <summary> fetch the small document block list from an existing file
		/// 
		/// </summary>
		/// <param name="blockList">the raw data from which the small block table
		/// will be extracted
		/// </param>
		/// <param name="root">the root property (which contains the start block
		/// and small block table size)
		/// </param>
		/// <param name="sbatStart">the start block of the SBAT
		/// 
		/// </param>
		/// <returns> the small document block list
		/// 
		/// </returns>
		/// <exception cref=""> IOException
		/// </exception>
		
		public static BlockList GetSmallDocumentBlocks(RawDataBlockList blockList, RootProperty root, int sbatStart)
		{
			BlockList list = new SmallDocumentBlockList(SmallDocumentBlock.Extract(blockList.FetchBlocks(root.StartBlock)));
			
			new BlockAllocationTableReader(blockList.FetchBlocks(sbatStart), list);
			return list;
		}
	}
}