// 
// FixedField.cs
//  
// Copyright 2002-2004  Apache Software Foundation
//
// Jakarta Poi Authors:
//   Marc Johnson (mjohnson at apache dot org)
//
// Poi.Net Authors:
//   Johannes Roith(johannes at jroith dot de)
//  
// 
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

using System;
using System.IO;

using Poi.Net.Util;
namespace Poi.Net.Util
{
	
	/// <summary> behavior of a field at a fixed location within a byte array
	/// 
	/// </summary>
	
	public interface FixedField
	{
		
		/// <summary> set the value from its offset into an array of bytes
		/// 
		/// </summary>
		/// <param name="data">the byte array from which the value is to be read
		/// 
		/// </param>
		/// <exception cref=""> ArrayIndexOutOfBoundsException if the offset is out
		/// of the array's valid index range
		/// </exception>
		
		void ReadFromBytes(byte[] data);
		
		/// <summary> set the value from an InputStream
		/// 
		/// </summary>
		/// <param name="stream">the InputStream from which the value is to be
		/// read
		/// 
		/// </param>
		/// <exception cref=""> BufferUnderrunException if there is not enough data
		/// available from the InputStream
		/// </exception>
		/// <exception cref=""> IOException if an IOException is thrown from reading
		/// the InputStream
		/// </exception>
		
		void ReadFromStream(Stream stream);
		
		/// <summary> write the value out to an array of bytes at the appropriate
		/// offset
		/// 
		/// </summary>
		/// <param name="data">the array of bytes to which the value is to be
		/// written
		/// 
		/// </param>
		/// <exception cref=""> ArrayIndexOutOfBoundsException if the offset is out
		/// of the array's valid index range
		/// </exception>
		
		void WriteToBytes(byte[] data);
		
		/// <summary> return the value as a String
		/// 
		/// </summary>
		/// <returns> the value as a String
		/// </returns>
		
		string ToString();
	} 
}