// 
// IOUtils.cs
//  
// Copyright 2002-2004  Apache Software Foundation
//
// Jakarta Poi Authors:
//   Marc Johnson (mjohnson at apache dot org)
//
// Poi.Net Authors:
//   Johannes Roith(johannes at jroith dot de)
//  
// 
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

using System;
using System.IO;

namespace Poi.Net.Util
{
	
	public class IOUtils
	{
		private IOUtils()
		{
		}
		
		/// <summary> Helper method, just calls <tt>ReadFully(in, b, 0, b.length)</tt></summary>
		public static int ReadFully(Stream inStream, byte[] b)
		{
			return ReadFully(inStream, b, 0, b.Length);
		}
		
		/// <summary> Same as the normal <tt>in.read(b, off, len)</tt>, but tries to ensure that
		/// the entire len number of bytes is read.
		/// 
		/// If the end of file is reached before any bytes are read, returns -1.
		/// Otherwise, returns the number of bytes read.
		/// </summary>
		public static int ReadFully(Stream inStream, byte[] b, int off, int len)
		{

			int total = 0;
			for (; ; )
			{

				int got;

				got = inStream.Read(b,off+total, len - total);

				if (got == 0)
				{
					return (total == 0)?- 1:total;
				}
				else
				{
					total += got;
					if (total == len)
						return total;
				}
			}
		}
	}
}