// 
// NullLogger.cs
//  
// Copyright 2002-2004  Apache Software Foundation
//
// Jakarta Poi Authors:
//   Marc Johnson (mjohnson at apache dot org)
//   Nicola Ken Barozzi (nicolaken at apache.org)
//   Glen Stampoultzis (glens at apache.org)
//
// Poi.Net Authors:
//   Johannes Roith(johannes at jroith dot de)
//  
// 
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

using System;

namespace Poi.Net.Util
{
	
	/// <summary> A Logger class that strives to make it as easy as possible for
	/// developers to write Log calls, while simultaneously making those
	/// calls as cheap as possible by performing lazy evaluation of the Log
	/// message.
	/// 
	/// </summary>

	public class NullLogger:POILogger
	{
		public override void Initialize(string cat)
		{
			//do nothing    
		}
		
		/// <summary> Log a message
		/// 
		/// </summary>
		/// <param name="level">One of DEBUG, INFO, WARN, ERROR, FATAL
		/// </param>
		/// <param name="obj1">The object to Log.
		/// </param>
		
		public override void Log(int level, object obj1)
		{
			//do nothing
		}
		
		/// <summary> Check if a Logger is enabled to Log at the specified level
		/// 
		/// </summary>
		/// <param name="level">One of DEBUG, INFO, WARN, ERROR, FATAL
		/// </param>
		/// <param name="obj1">The Logger to check.
		/// </param>
		
		public override bool Check(int level)
		{
			return false;
		}
		
		/// <summary> Log a message. Lazily appends Object parameters together.
		/// 
		/// </summary>
		/// <param name="level">One of DEBUG, INFO, WARN, ERROR, FATAL
		/// </param>
		/// <param name="obj1">first object to place in the message
		/// </param>
		/// <param name="obj2">second object to place in the message
		/// </param>
		
		public override void Log(int level, object obj1, object obj2)
		{
			//do nothing
		}
		
		/// <summary> Log a message. Lazily appends Object parameters together.
		/// 
		/// </summary>
		/// <param name="level">One of DEBUG, INFO, WARN, ERROR, FATAL
		/// </param>
		/// <param name="obj1">first Object to place in the message
		/// </param>
		/// <param name="obj2">second Object to place in the message
		/// </param>
		/// <param name="obj3">third Object to place in the message
		/// </param>
		
		public override void Log(int level, object obj1, object obj2, object obj3)
		{
			//do nothing
		}
		
		/// <summary> Log a message. Lazily appends Object parameters together.
		/// 
		/// </summary>
		/// <param name="level">One of DEBUG, INFO, WARN, ERROR, FATAL
		/// </param>
		/// <param name="obj1">first Object to place in the message
		/// </param>
		/// <param name="obj2">second Object to place in the message
		/// </param>
		/// <param name="obj3">third Object to place in the message
		/// </param>
		/// <param name="obj4">fourth Object to place in the message
		/// </param>
		
		public override void Log(int level, object obj1, object obj2, object obj3, object obj4)
		{
			//do nothing
		}
		
		/// <summary> Log a message. Lazily appends Object parameters together.
		/// 
		/// </summary>
		/// <param name="level">One of DEBUG, INFO, WARN, ERROR, FATAL
		/// </param>
		/// <param name="obj1">first Object to place in the message
		/// </param>
		/// <param name="obj2">second Object to place in the message
		/// </param>
		/// <param name="obj3">third Object to place in the message
		/// </param>
		/// <param name="obj4">fourth Object to place in the message
		/// </param>
		/// <param name="obj5">fifth Object to place in the message
		/// </param>
		
		public override void Log(int level, object obj1, object obj2, object obj3, object obj4, object obj5)
		{
			//do nothing
		}
		
		/// <summary> Log a message. Lazily appends Object parameters together.
		/// 
		/// </summary>
		/// <param name="level">One of DEBUG, INFO, WARN, ERROR, FATAL
		/// </param>
		/// <param name="obj1">first Object to place in the message
		/// </param>
		/// <param name="obj2">second Object to place in the message
		/// </param>
		/// <param name="obj3">third Object to place in the message
		/// </param>
		/// <param name="obj4">fourth Object to place in the message
		/// </param>
		/// <param name="obj5">fifth Object to place in the message
		/// </param>
		/// <param name="obj6">sixth Object to place in the message
		/// </param>
		
		public override void Log(int level, object obj1, object obj2, object obj3, object obj4, object obj5, object obj6)
		{
			//do nothing
		}
		
		/// <summary> Log a message. Lazily appends Object parameters together.
		/// 
		/// </summary>
		/// <param name="level">One of DEBUG, INFO, WARN, ERROR, FATAL
		/// </param>
		/// <param name="obj1">first Object to place in the message
		/// </param>
		/// <param name="obj2">second Object to place in the message
		/// </param>
		/// <param name="obj3">third Object to place in the message
		/// </param>
		/// <param name="obj4">fourth Object to place in the message
		/// </param>
		/// <param name="obj5">fifth Object to place in the message
		/// </param>
		/// <param name="obj6">sixth Object to place in the message
		/// </param>
		/// <param name="obj7">seventh Object to place in the message
		/// </param>
		
		public override void Log(int level, object obj1, object obj2, object obj3, object obj4, object obj5, object obj6, object obj7)
		{
			//do nothing
		}
		
		/// <summary> Log a message. Lazily appends Object parameters together.
		/// 
		/// </summary>
		/// <param name="level">One of DEBUG, INFO, WARN, ERROR, FATAL
		/// </param>
		/// <param name="obj1">first Object to place in the message
		/// </param>
		/// <param name="obj2">second Object to place in the message
		/// </param>
		/// <param name="obj3">third Object to place in the message
		/// </param>
		/// <param name="obj4">fourth Object to place in the message
		/// </param>
		/// <param name="obj5">fifth Object to place in the message
		/// </param>
		/// <param name="obj6">sixth Object to place in the message
		/// </param>
		/// <param name="obj7">seventh Object to place in the message
		/// </param>
		/// <param name="obj8">eighth Object to place in the message
		/// </param>
		
		public override void Log(int level, object obj1, object obj2, object obj3, object obj4, object obj5, object obj6, object obj7, object obj8)
		{
			//do nothing
		}
		
		/// <summary> Log a message
		/// 
		/// </summary>
		/// <param name="level">One of DEBUG, INFO, WARN, ERROR, FATAL
		/// </param>
		/// <param name="obj1">The object to Log.  This is converted to a string.
		/// </param>
		/// <param name="exception">An exception to be Logged
		/// </param>
		
		
		public override void Log(int level, object obj1, Exception exception)
		{
			//do nothing
		}
		
		/// <summary> Log a message. Lazily appends Object parameters together.
		/// 
		/// </summary>
		/// <param name="level">One of DEBUG, INFO, WARN, ERROR, FATAL
		/// </param>
		/// <param name="obj1">first Object to place in the message
		/// </param>
		/// <param name="obj2">second Object to place in the message
		/// </param>
		/// <param name="exception">An exception to be Logged
		/// </param>
		
		
		public override void Log(int level, object obj1, object obj2, Exception exception)
		{
			//do nothing
		}
		
		/// <summary> Log a message. Lazily appends Object parameters together.
		/// 
		/// </summary>
		/// <param name="level">One of DEBUG, INFO, WARN, ERROR, FATAL
		/// </param>
		/// <param name="obj1">first Object to place in the message
		/// </param>
		/// <param name="obj2">second Object to place in the message
		/// </param>
		/// <param name="obj3">third object to place in the message
		/// </param>
		/// <param name="exception">An error message to be Logged
		/// </param>
		
		
		public override void Log(int level, object obj1, object obj2, object obj3, Exception exception)
		{
			//do nothing
		}
		
		/// <summary> Log a message. Lazily appends Object parameters together.
		/// 
		/// </summary>
		/// <param name="level">One of DEBUG, INFO, WARN, ERROR, FATAL
		/// </param>
		/// <param name="obj1">first Object to place in the message
		/// </param>
		/// <param name="obj2">second Object to place in the message
		/// </param>
		/// <param name="obj3">third object to place in the message
		/// </param>
		/// <param name="obj4">fourth object to place in the message
		/// </param>
		/// <param name="exception">An exception to be Logged
		/// </param>
		
		
		public override void Log(int level, object obj1, object obj2, object obj3, object obj4, Exception exception)
		{
			//do nothing
		}
		
		/// <summary> Log a message. Lazily appends Object parameters together.
		/// 
		/// </summary>
		/// <param name="level">One of DEBUG, INFO, WARN, ERROR, FATAL
		/// </param>
		/// <param name="obj1">first Object to place in the message
		/// </param>
		/// <param name="obj2">second Object to place in the message
		/// </param>
		/// <param name="obj3">third object to place in the message
		/// </param>
		/// <param name="obj4">fourth object to place in the message
		/// </param>
		/// <param name="obj5">fifth object to place in the message
		/// </param>
		/// <param name="exception">An exception to be Logged
		/// </param>
		
		
		public override void Log(int level, object obj1, object obj2, object obj3, object obj4, object obj5, Exception exception)
		{
			//do nothing
		}
		
		/// <summary> Log a message. Lazily appends Object parameters together.
		/// 
		/// </summary>
		/// <param name="level">One of DEBUG, INFO, WARN, ERROR, FATAL
		/// </param>
		/// <param name="obj1">first Object to place in the message
		/// </param>
		/// <param name="obj2">second Object to place in the message
		/// </param>
		/// <param name="obj3">third object to place in the message
		/// </param>
		/// <param name="obj4">fourth object to place in the message
		/// </param>
		/// <param name="obj5">fifth object to place in the message
		/// </param>
		/// <param name="obj6">sixth object to place in the message
		/// </param>
		/// <param name="exception">An exception to be Logged
		/// </param>
		
		
		public override void Log(int level, object obj1, object obj2, object obj3, object obj4, object obj5, object obj6, Exception exception)
		{
			//do nothing
		}
		
		/// <summary> Log a message. Lazily appends Object parameters together.
		/// 
		/// </summary>
		/// <param name="level">One of DEBUG, INFO, WARN, ERROR, FATAL
		/// </param>
		/// <param name="obj1">first Object to place in the message
		/// </param>
		/// <param name="obj2">second Object to place in the message
		/// </param>
		/// <param name="obj3">third object to place in the message
		/// </param>
		/// <param name="obj4">fourth object to place in the message
		/// </param>
		/// <param name="obj5">fifth object to place in the message
		/// </param>
		/// <param name="obj6">sixth object to place in the message
		/// </param>
		/// <param name="obj7">seventh object to place in the message
		/// </param>
		/// <param name="exception">An exception to be Logged
		/// </param>
		
		
		public override void Log(int level, object obj1, object obj2, object obj3, object obj4, object obj5, object obj6, object obj7, Exception exception)
		{
			//do nothing
		}
		
		/// <summary> Log a message. Lazily appends Object parameters together.
		/// 
		/// </summary>
		/// <param name="level">One of DEBUG, INFO, WARN, ERROR, FATAL
		/// </param>
		/// <param name="obj1">first Object to place in the message
		/// </param>
		/// <param name="obj2">second Object to place in the message
		/// </param>
		/// <param name="obj3">third object to place in the message
		/// </param>
		/// <param name="obj4">fourth object to place in the message
		/// </param>
		/// <param name="obj5">fifth object to place in the message
		/// </param>
		/// <param name="obj6">sixth object to place in the message
		/// </param>
		/// <param name="obj7">seventh object to place in the message
		/// </param>
		/// <param name="obj8">eighth object to place in the message
		/// </param>
		/// <param name="exception">An exception to be Logged
		/// </param>
		
		
		public override void Log(int level, object obj1, object obj2, object obj3, object obj4, object obj5, object obj6, object obj7, object obj8, Exception exception)
		{
			//do nothing
		}
		
		/// <summary> Logs a formated message. The message itself may contain %
		/// characters as place holders. This routine will attempt to match
		/// the placeholder by looking at the type of parameter passed to
		/// obj1.
		/// 
		/// If the parameter is an array, it traverses the array first and
		/// matches parameters sequentially against the array items.
		/// Otherwise the parameters after <code>message</code> are matched
		/// in order.
		/// 
		/// If the place holder matches against a number it is printed as a
		/// whole number. This can be overridden by specifying a precision
		/// in the form %n.m where n is the padding for the whole part and
		/// m is the number of decimal places to display. n can be excluded
		/// if desired. n and m may not be more than 9.
		/// 
		/// If the last parameter (after flattening) is a Throwable it is
		/// Logged specially.
		/// 
		/// </summary>
		/// <param name="level">One of DEBUG, INFO, WARN, ERROR, FATAL
		/// </param>
		/// <param name="message">The message to Log.
		/// </param>
		/// <param name="obj1">The first object to match against.
		/// </param>
		
		public override void LogFormatted(int level, string message, object obj1)
		{
			//do nothing
		}
		
		/// <summary> Logs a formated message. The message itself may contain %
		/// characters as place holders. This routine will attempt to match
		/// the placeholder by looking at the type of parameter passed to
		/// obj1.
		/// 
		/// If the parameter is an array, it traverses the array first and
		/// matches parameters sequentially against the array items.
		/// Otherwise the parameters after <code>message</code> are matched
		/// in order.
		/// 
		/// If the place holder matches against a number it is printed as a
		/// whole number. This can be overridden by specifying a precision
		/// in the form %n.m where n is the padding for the whole part and
		/// m is the number of decimal places to display. n can be excluded
		/// if desired. n and m may not be more than 9.
		/// 
		/// If the last parameter (after flattening) is a Throwable it is
		/// Logged specially.
		/// 
		/// </summary>
		/// <param name="level">One of DEBUG, INFO, WARN, ERROR, FATAL
		/// </param>
		/// <param name="message">The message to Log.
		/// </param>
		/// <param name="obj1">The first object to match against.
		/// </param>
		/// <param name="obj2">The second object to match against.
		/// </param>
		
		public override void LogFormatted(int level, string message, object obj1, object obj2)
		{
			//do nothing
		}
		
		/// <summary> Logs a formated message. The message itself may contain %
		/// characters as place holders. This routine will attempt to match
		/// the placeholder by looking at the type of parameter passed to
		/// obj1.
		/// 
		/// If the parameter is an array, it traverses the array first and
		/// matches parameters sequentially against the array items.
		/// Otherwise the parameters after <code>message</code> are matched
		/// in order.
		/// 
		/// If the place holder matches against a number it is printed as a
		/// whole number. This can be overridden by specifying a precision
		/// in the form %n.m where n is the padding for the whole part and
		/// m is the number of decimal places to display. n can be excluded
		/// if desired. n and m may not be more than 9.
		/// 
		/// If the last parameter (after flattening) is a Throwable it is
		/// Logged specially.
		/// 
		/// </summary>
		/// <param name="level">One of DEBUG, INFO, WARN, ERROR, FATAL
		/// </param>
		/// <param name="message">The message to Log.
		/// </param>
		/// <param name="obj1">The first object to match against.
		/// </param>
		/// <param name="obj2">The second object to match against.
		/// </param>
		/// <param name="obj3">The third object to match against.
		/// </param>
		
		public override void LogFormatted(int level, string message, object obj1, object obj2, object obj3)
		{
			//do nothing
		}
		
		/// <summary> Logs a formated message. The message itself may contain %
		/// characters as place holders. This routine will attempt to match
		/// the placeholder by looking at the type of parameter passed to
		/// obj1.
		/// 
		/// If the parameter is an array, it traverses the array first and
		/// matches parameters sequentially against the array items.
		/// Otherwise the parameters after <code>message</code> are matched
		/// in order.
		/// 
		/// If the place holder matches against a number it is printed as a
		/// whole number. This can be overridden by specifying a precision
		/// in the form %n.m where n is the padding for the whole part and
		/// m is the number of decimal places to display. n can be excluded
		/// if desired. n and m may not be more than 9.
		/// 
		/// If the last parameter (after flattening) is a Throwable it is
		/// Logged specially.
		/// 
		/// </summary>
		/// <param name="level">One of DEBUG, INFO, WARN, ERROR, FATAL
		/// </param>
		/// <param name="message">The message to Log.
		/// </param>
		/// <param name="obj1">The first object to match against.
		/// </param>
		/// <param name="obj2">The second object to match against.
		/// </param>
		/// <param name="obj3">The third object to match against.
		/// </param>
		/// <param name="obj4">The forth object to match against.
		/// </param>
		
		public override void LogFormatted(int level, string message, object obj1, object obj2, object obj3, object obj4)
		{
			//do nothing
		}
	}
}