// 
// POILogFactory.cs
//  
// Copyright 2002-2004  Apache Software Foundation
//
// Jakarta Poi Authors:
//   Andrew C. Oliver (acoliver at apache dot org)
//   Marc Johnson (mjohnson at apache dot org)
//   Nicola Ken Barozzi (nicolaken at apache.org)
//
// Poi.Net Authors:
//   Johannes Roith(johannes at jroith dot de)
//  
// 
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

using System;
using System.Collections;

namespace Poi.Net.Util
{
	
	/// <summary> Provides Logging without clients having to mess with
	/// configuration/initialization.
	/// 
	/// </summary>
	
	public class POILogFactory
	{
		
		// map of POILogger instances, with classes as keys
		
		private static IDictionary _loggers = new Hashtable(); 
		
		
		/// <summary> construct a POILogFactory.</summary>
		
		private POILogFactory()
		{
		}
		
		/// <summary> Get a Logger, based on a class name
		/// 
		/// </summary>
		/// <param name="theclass">the class whose name defines the Log
		/// 
		/// </param>
		/// <returns> a POILogger for the specified class
		/// </returns>
		
		public static POILogger GetLogger(Type theclass)
		{
			
			return GetLogger(theclass.FullName);
		}
		
		/// <summary> Get a Logger, based on a String
		/// 
		/// </summary>
		/// <param name="cat">the String that defines the Log
		/// 
		/// </param>
		/// <returns> a POILogger for the specified class
		/// </returns>
		
		public static POILogger GetLogger(string cat)
		{
			POILogger logger = null;
			
			if (_loggers.Contains(cat))
			{
				logger = (POILogger) _loggers[cat];
			}
			else
			{
				try
				{
		/*		
					string LoggerClassName = System_Renamed.GetProperty("Poi.Net.Util.POILogger");
					
					System.Type LoggerClass = System.Type.GetType(loggerClassName);
					
					logger = (POILogger) System.Activator.CreateInstance(loggerClass);
			*/	}
				catch (Exception ignored)
				{
					
					logger = new NullLogger();
				}
				
				logger.Initialize(cat);
				
				_loggers[cat] = logger;
			}
			return logger;
		}
	} 
}