// 
// TestClassID.cs
//  
// Copyright 2002-2004  Apache Software Foundation
//
// Jakarta Poi Authors:
//   Michael Zalewski (zalewski@optonline.net)
//
// Poi.Net Authors:
//   Johannes Roith(johannes at jroith dot de)
//  
// 
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

using System;

using NUnit.Framework;

namespace Poi.Net.HPSF.Basic
{
	
	/// <summary> Tests ClassID structure.
	/// 
	/// </summary>

	[TestFixture] 
	public class TestClassID
	{
		/// <summary> Constructor
		/// 
		/// </summary>
		/// <param name="name">the test case's name
		/// </param>

		public TestClassID()
		{
		}
		
		/// <summary> Various tests of overridden .equals() </summary>

		[Test]
		public virtual void Equals()
		{
			ClassID clsidTest1 = new ClassID(new byte[]{(byte) (0x01), (byte) (0x02), (byte) (0x03), (byte) (0x04), (byte) (0x05), (byte) (0x06), (byte) (0x07), (byte) (0x08), (byte) (0x09), (byte) (0x0a), (byte) (0x0b), (byte) (0x0c), (byte) (0x0d), (byte) (0x0e), (byte) (0x0f), (byte) (0x10)}, 0);
			ClassID clsidTest2 = new ClassID(new byte[]{(byte) (0x01), (byte) (0x02), (byte) (0x03), (byte) (0x04), (byte) (0x05), (byte) (0x06), (byte) (0x07), (byte) (0x08), (byte) (0x09), (byte) (0x0a), (byte) (0x0b), (byte) (0x0c), (byte) (0x0d), (byte) (0x0e), (byte) (0x0f), (byte) (0x10)}, 0);
			ClassID clsidTest3 = new ClassID(new byte[]{(byte) (0x01), (byte) (0x02), (byte) (0x03), (byte) (0x04), (byte) (0x05), (byte) (0x06), (byte) (0x07), (byte) (0x08), (byte) (0x09), (byte) (0x0a), (byte) (0x0b), (byte) (0x0c), (byte) (0x0d), (byte) (0x0e), (byte) (0x0f), (byte) (0x11)}, 0);
			Assert.AreEqual(clsidTest1, clsidTest1);
			Assert.AreEqual(clsidTest1, clsidTest2);
			Assert.IsFalse(clsidTest1.Equals(clsidTest3));
			Assert.IsFalse(clsidTest1.Equals(null));
		}
		/// <summary>
		/// Try to write to a buffer that is too small. This should
		/// throw an Exception
		/// </summary>

		[Test]
		public virtual void WriteArrayStoreException()
		{
			ClassID clsidTest = new ClassID(new byte[]{(byte) (0x01), (byte) (0x02), (byte) (0x03), (byte) (0x04), (byte) (0x05), (byte) (0x06), (byte) (0x07), (byte) (0x08), (byte) (0x09), (byte) (0x0a), (byte) (0x0b), (byte) (0x0c), (byte) (0x0d), (byte) (0x0e), (byte) (0x0f), (byte) (0x10)}, 0);
			bool bExceptionOccurred = false;
			try
			{
				clsidTest.Write(new byte[15], 0);
			}
			catch (Exception ignored)
			{
				bExceptionOccurred = true;
			}
			Assert.IsTrue(bExceptionOccurred);
			
			bExceptionOccurred = false;
			try
			{
				clsidTest.Write(new byte[16], 1);
			}
			catch (Exception ignored)
			{
				bExceptionOccurred = true;
			}
			Assert.IsTrue(bExceptionOccurred);
			
			// These should work without throwing an Exception
			bExceptionOccurred = false;
			try
			{
				clsidTest.Write(new byte[16], 0);
				clsidTest.Write(new byte[17], 1);
			}
			catch
			{
				bExceptionOccurred = true;
			}
			Assert.IsFalse(bExceptionOccurred);
		}

		/// <summary>
		/// Tests the  PropertySet} methods. The test file has two
		/// property set: the first one is a  SummaryInformation},
		/// the second one is a  DocumentSummaryInformation}.
		/// </summary>

		[Test]
		public virtual void ClassID()
		{
			ClassID clsidTest = new ClassID(new byte[]{(byte) (0x01), (byte) (0x02), (byte) (0x03), (byte) (0x04), (byte) (0x05), (byte) (0x06), (byte) (0x07), (byte) (0x08), (byte) (0x09), (byte) (0x0a), (byte) (0x0b), (byte) (0x0c), (byte) (0x0d), (byte) (0x0e), (byte) (0x0f), (byte) (0x10)}, 0);
			Assert.AreEqual(clsidTest.ToString().ToUpper(), "{04030201-0605-0807-090A-0B0C0D0E0F10}");
		}

	}
}