// 
// TestBasic.cs
//  
// Copyright 2002-2004  Apache Software Foundation
//
// Jakarta Poi Authors:
//   Rainer Klute (klute@rainer-klute.de)
//
// Poi.Net Authors:
//   Johannes Roith(johannes at jroith dot de)
//  
// 
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

using System;
using System.IO;

using NUnit.Framework;
using Poi.Net.HPSF;

namespace Poi.Net.HPSF.Basic
{

	/// <summary> Tests whether Unicode string can be read from a
	/// DocumentSummaryInformation.
	/// 
	/// </summary>

	[TestFixture]
	public class TestUnicode
	{
		
		internal const string POI_FS = "TestUnicode.xls";
		internal static readonly string[] POI_FILES = new string[]{"\x0005DocumentSummaryInformation"};
		internal FileInfo data;
		internal POIFile[] poiFiles = null;
		
		/// <summary> Read a the test file from the "data" directory.</summary>
		
		[SetUp]
		protected internal virtual void SetUp()
		{
			FileInfo dataDir = new FileInfo("Poi.Net\\Tests\\hpsf\\data");
			data = new FileInfo(dataDir.FullName + "\\" + POI_FS);
		}
		
		
		
		/// <summary> Tests the  PropertySet} methods. The test file has two
		/// property set: the first one is a  SummaryInformation},
		/// the second one is a  DocumentSummaryInformation}.
		/// </summary>

		[Test]
		public virtual void PropertySetMethods()
		{
			POIFile poiFile = Util.ReadPOIFiles(data, POI_FILES)[0];
			byte[] b = poiFile.Bytes;
			PropertySet ps = PropertySetFactory.Create(new MemoryStream(b));
			Assert.IsTrue(ps.DocumentSummaryInformation);
			Assert.AreEqual(ps.SectionCount, 2);
			Section s = (Section) ps.Sections[1];
			Assert.AreEqual(s.GetProperty(1), 1200);
			Assert.AreEqual(s.GetProperty(2), 4198897018L);
			Assert.AreEqual(s.GetProperty(3), "MCon_Info zu Office bei Schreiner");
			Assert.AreEqual(s.GetProperty(4), "petrovitsch@schreiner-online.de");
			Assert.AreEqual(s.GetProperty(5), "Petrovitsch, Wilhelm");
		}
		
	}
}